// #style-inject:#style-inject
function styleInject(css2, { insertAt } = {}) {
  if (!css2 || typeof document === "undefined") return;
  const head = document.head || document.getElementsByTagName("head")[0];
  const style = document.createElement("style");
  style.type = "text/css";
  if (insertAt === "top") {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }
  if (style.styleSheet) {
    style.styleSheet.cssText = css2;
  } else {
    style.appendChild(document.createTextNode(css2));
  }
}

// src/styles/fonts.css
styleInject('@import "https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,600;0,700;0,800;1,300;1,400;1,600;1,700;1,800&display=swap&family=Material+Symbols+Outlined:FILL@0..1";\n');

// src/accordion/Accordion.tsx
import { Children, useCallback, useContext as useContext2, useMemo as useMemo3, useState } from "react";
import styled5, { ThemeProvider as ThemeProvider2 } from "styled-components";

// src/common/coreTokens.ts
var CoreColorTokens = {
  // Color
  // Absolutes
  color_black: "#000000",
  color_white: "#ffffff",
  color_transparent: "transparent",
  // Greyscale
  // Solid variants
  color_grey_50: "#fafafa",
  color_grey_100: "#f2f2f2",
  color_grey_200: "#e6e6e6",
  color_grey_300: "#cccccc",
  color_grey_400: "#bfbfbf",
  color_grey_500: "#999999",
  color_grey_600: "#808080",
  color_grey_700: "#666666",
  color_grey_800: "#4d4d4d",
  color_grey_900: "#333333",
  // Transparent variants
  color_grey_50_a: "#00000005",
  color_grey_100_a: "#0000000d",
  color_grey_200_a: "#0000001a",
  color_grey_300_a: "#00000033",
  color_grey_400_a: "#0000004d",
  color_grey_500_a: "#00000066",
  color_grey_600_a: "#00000080",
  color_grey_700_a: "#00000099",
  color_grey_800_a: "#000000b3",
  color_grey_900_a: "#000000cc",
  // Purple
  color_purple_50: "#faf7fd",
  color_purple_100: "#f2eafa",
  color_purple_200: "#e5d5f6",
  color_purple_300: "#cbacec",
  color_purple_400: "#b182e3",
  color_purple_500: "#a46ede",
  color_purple_600: "#7d2fd0",
  color_purple_700: "#5f249f",
  color_purple_800: "#4b1c7d",
  color_purple_900: "#321353",
  // Blue
  color_blue_50: "#f5fbff",
  color_blue_100: "#e6f4ff",
  color_blue_200: "#cceaff",
  color_blue_300: "#99d5ff",
  color_blue_400: "#66bfff",
  color_blue_500: "#33aaff",
  color_blue_600: "#0095ff",
  color_blue_700: "#0086e6",
  color_blue_800: "#0067b3",
  color_blue_900: "#003c66",
  // Red
  color_red_50: "#fff5f6",
  color_red_100: "#ffe6e9",
  color_red_200: "#ffccd3",
  color_red_300: "#fe9aa7",
  color_red_400: "#fe677b",
  color_red_500: "#fe344f",
  color_red_600: "#fe0123",
  color_red_700: "#d0011b",
  color_red_800: "#980115",
  color_red_900: "#65010e",
  // Green
  color_green_50: "#f7fdf9",
  color_green_100: "#eafaef",
  color_green_200: "#d5f6df",
  color_green_300: "#acecbe",
  color_green_400: "#82e39e",
  color_green_500: "#59d97d",
  color_green_600: "#2fd05d",
  color_green_700: "#24a148",
  color_green_800: "#1c7d38",
  color_green_900: "#135325",
  // Yellow
  color_yellow_50: "#fffdf5",
  color_yellow_100: "#fef9e6",
  color_yellow_200: "#fdf4ce",
  color_yellow_300: "#fbe89d",
  color_yellow_400: "#fadd6b",
  color_yellow_500: "#f7cf2b",
  color_yellow_600: "#f6c709",
  color_yellow_700: "#c59f07",
  color_yellow_800: "#947705",
  color_yellow_900: "#624f04",
  // Orange
  color_orange_50: "#fefaf5",
  color_orange_100: "#fef3e7",
  color_orange_200: "#fce7cf",
  color_orange_300: "#facf9e",
  color_orange_400: "#f7b76e",
  color_orange_500: "#f59f3d",
  color_orange_600: "#f38f20",
  color_orange_700: "#c26c0a",
  color_orange_800: "#915108",
  color_orange_900: "#613605"
};
var getCoreColorToken = (key) => CoreColorTokens[key];
var CoreSpacingTokens = {
  spacing_0: "0rem",
  spacing_2: "0.125rem",
  spacing_4: "0.25rem",
  spacing_8: "0.5rem",
  spacing_12: "0.75rem",
  spacing_16: "1rem",
  spacing_24: "1.5rem",
  spacing_32: "2rem",
  spacing_40: "2.5rem",
  spacing_48: "3rem",
  spacing_56: "3.5rem",
  spacing_64: "4rem",
  spacing_80: "5rem",
  spacing_96: "6rem",
  spacing_112: "7rem"
};
var CoreTokens = {
  ...CoreColorTokens,
  ...CoreSpacingTokens,
  inherit: "inherit",
  // Typography
  type_sans: "Open Sans, sans-serif",
  type_scale_08: "3.75rem",
  type_scale_07: "2.5rem",
  type_scale_06: "2rem",
  type_scale_05: "1.5rem",
  type_scale_04: "1.25rem",
  type_scale_03: "1rem",
  type_scale_02: "0.875rem",
  type_scale_01: "0.75rem",
  type_light: "300",
  type_regular: "400",
  type_semibold: "600",
  type_bold: "bold",
  type_italic: "italic",
  type_normal: "normal",
  type_spacing_tight_02: "-0.05em",
  type_spacing_tight_01: "-0.025em",
  type_spacing_normal: "0em",
  type_spacing_wide_01: "0.025em",
  type_spacing_wide_02: "0.05em",
  type_spacing_wide_03: "0.1em",
  type_initial: "initial",
  type_uppercase: "uppercase",
  type_no_line: "none",
  type_underline: "underline",
  type_line_through: "line-through",
  type_leading_compact_03: "1em",
  type_leading_compact_02: "1.25em",
  type_leading_compact_01: "1.365em",
  type_leading_normal: "1.5em",
  type_leading_loose_01: "1.715em",
  type_leading_loose_02: "2em",
  // Border
  border_width_0: "0px",
  border_width_1: "1px",
  border_width_2: "2px",
  border_width_4: "4px",
  border_radius_none: "0rem",
  border_radius_small: "0.125rem",
  border_radius_medium: "0.25rem",
  border_radius_large: "0.375rem",
  border_solid: "solid",
  border_dashed: "dashed",
  border_none: "none"
};
var coreTokens_default = CoreTokens;

// src/common/variables.ts
var componentTokens = {
  accordion: {
    backgroundColor: coreTokens_default.color_white,
    hoverBackgroundColor: coreTokens_default.color_purple_100,
    focusBackgroundColor: coreTokens_default.color_transparent,
    activeBackgroundColor: coreTokens_default.color_purple_100,
    arrowColor: coreTokens_default.color_purple_700,
    disabledArrowColor: coreTokens_default.color_grey_500,
    subLabelFontFamily: coreTokens_default.type_sans,
    subLabelFontSize: coreTokens_default.type_scale_01,
    subLabelFontWeight: coreTokens_default.type_regular,
    subLabelFontStyle: coreTokens_default.type_normal,
    subLabelFontColor: coreTokens_default.color_grey_700,
    disabledSubLabelFontColor: coreTokens_default.color_grey_500,
    assistiveTextFontFamily: coreTokens_default.type_sans,
    assistiveTextFontSize: coreTokens_default.type_scale_01,
    assistiveTextFontWeight: coreTokens_default.type_regular,
    assistiveTextFontStyle: coreTokens_default.type_normal,
    assistiveTextFontColor: coreTokens_default.color_grey_700,
    disabledAssistiveTextFontColor: coreTokens_default.color_grey_500,
    titleLabelFontFamily: coreTokens_default.type_sans,
    titleLabelFontSize: coreTokens_default.type_scale_03,
    titleLabelFontWeight: coreTokens_default.type_regular,
    titleLabelFontStyle: coreTokens_default.type_normal,
    titleLabelFontColor: coreTokens_default.color_grey_900,
    disabledTitleLabelFontColor: coreTokens_default.color_grey_500,
    focusBorderColor: coreTokens_default.color_blue_600,
    focusBorderStyle: coreTokens_default.border_solid,
    focusBorderThickness: "2px",
    borderRadius: "4px",
    boxShadowOffsetX: "0px",
    boxShadowOffsetY: "12px",
    boxShadowBlur: "12px",
    boxShadowSpread: "0px",
    boxShadowColor: coreTokens_default.color_grey_200_a,
    iconColor: coreTokens_default.color_purple_700,
    disabledIconColor: coreTokens_default.color_grey_500,
    iconSize: "24px",
    accordionSeparatorBorderColor: coreTokens_default.color_grey_200,
    accordionSeparatorBorderThickness: "1px",
    accordionSeparatorBorderStyle: coreTokens_default.border_solid
  },
  alert: {
    errorBackgroundColor: coreTokens_default.color_red_100,
    errorIconColor: coreTokens_default.color_red_700,
    fontColor: coreTokens_default.color_grey_900,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_02,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    iconSize: "24px",
    infoBackgroundColor: coreTokens_default.color_blue_100,
    infoIconColor: coreTokens_default.color_blue_700,
    modalBackgroundColor: coreTokens_default.color_white,
    modalTitleFontSize: coreTokens_default.type_scale_05,
    modalTitleFontWeight: coreTokens_default.type_bold,
    overlayColor: coreTokens_default.color_grey_800_a,
    successBackgroundColor: coreTokens_default.color_green_100,
    successIconColor: coreTokens_default.color_green_700,
    warningBackgroundColor: coreTokens_default.color_yellow_100,
    warningIconColor: coreTokens_default.color_yellow_700
  },
  bulletedList: {
    fontColor: coreTokens_default.color_black,
    bulletIconHeight: "1.5rem",
    bulletIconWidth: "1.5rem",
    bulletHeight: "5px",
    bulletWidth: "5px",
    bulletMarginRight: coreTokens_default.spacing_8
  },
  button: {
    labelFontLineHeight: coreTokens_default.type_leading_normal,
    labelLetterSpacing: coreTokens_default.type_spacing_wide_01,
    paddingSmallTop: coreTokens_default.spacing_0,
    paddingSmallLeft: coreTokens_default.spacing_8,
    paddingSmallBottom: coreTokens_default.spacing_0,
    paddingSmallRight: coreTokens_default.spacing_8,
    paddingSmallOnlyIconTop: coreTokens_default.spacing_0,
    paddingSmallOnlyIconLeft: coreTokens_default.spacing_4,
    paddingSmallOnlyIconBottom: coreTokens_default.spacing_0,
    paddingSmallOnlyIconRight: coreTokens_default.spacing_4,
    paddingMediumTop: coreTokens_default.spacing_0,
    paddingMediumLeft: coreTokens_default.spacing_8,
    paddingMediumBottom: coreTokens_default.spacing_0,
    paddingMediumRight: coreTokens_default.spacing_8,
    paddingMediumOnlyIconTop: coreTokens_default.spacing_0,
    paddingMediumOnlyIconLeft: coreTokens_default.spacing_8,
    paddingMediumOnlyIconBottom: coreTokens_default.spacing_0,
    paddingMediumOnlyIconRight: coreTokens_default.spacing_8,
    paddingLargeTop: coreTokens_default.spacing_0,
    paddingLargeLeft: coreTokens_default.spacing_16,
    paddingLargeBottom: coreTokens_default.spacing_0,
    paddingLargeRight: coreTokens_default.spacing_16,
    paddingLargeOnlyIconTop: coreTokens_default.spacing_0,
    paddingLargeOnlyIconLeft: coreTokens_default.spacing_8,
    paddingLargeOnlyIconBottom: coreTokens_default.spacing_0,
    paddingLargeOnlyIconRight: coreTokens_default.spacing_8,
    focusBorderColor: coreTokens_default.color_blue_500,
    primaryDefaultBackgroundColor: coreTokens_default.color_purple_700,
    primaryErrorBackgroundColor: coreTokens_default.color_red_700,
    primaryWarningBackgroundColor: coreTokens_default.color_orange_700,
    primarySuccessBackgroundColor: coreTokens_default.color_green_700,
    primaryInfoBackgroundColor: coreTokens_default.color_blue_700,
    primaryDefaultFontColor: coreTokens_default.color_white,
    primaryErrorFontColor: coreTokens_default.color_white,
    primaryWarningFontColor: coreTokens_default.color_white,
    primarySuccessFontColor: coreTokens_default.color_white,
    primaryInfoFontColor: coreTokens_default.color_white,
    primaryHoverDefaultBackgroundColor: coreTokens_default.color_purple_800,
    primaryHoverErrorBackgroundColor: coreTokens_default.color_red_800,
    primaryHoverWarningBackgroundColor: coreTokens_default.color_orange_800,
    primaryHoverSuccessBackgroundColor: coreTokens_default.color_green_800,
    primaryHoverInfoBackgroundColor: coreTokens_default.color_blue_800,
    primaryActiveDefaultBackgroundColor: coreTokens_default.color_purple_900,
    primaryActiveErrorBackgroundColor: coreTokens_default.color_red_900,
    primaryActiveWarningBackgroundColor: coreTokens_default.color_orange_900,
    primaryActiveSuccessBackgroundColor: coreTokens_default.color_green_900,
    primaryActiveInfoBackgroundColor: coreTokens_default.color_blue_900,
    primaryDisabledDefaultBackgroundColor: coreTokens_default.color_purple_100,
    primaryDisabledErrorBackgroundColor: coreTokens_default.color_red_100,
    primaryDisabledWarningBackgroundColor: coreTokens_default.color_orange_100,
    primaryDisabledSuccessBackgroundColor: coreTokens_default.color_green_100,
    primaryDisabledInfoBackgroundColor: coreTokens_default.color_blue_100,
    primaryDisabledDefaultFontColor: coreTokens_default.color_purple_300,
    primaryDisabledErrorFontColor: coreTokens_default.color_red_300,
    primaryDisabledWarningFontColor: coreTokens_default.color_orange_300,
    primaryDisabledSuccessFontColor: coreTokens_default.color_green_300,
    primaryDisabledInfoFontColor: coreTokens_default.color_blue_300,
    primaryBorderThickness: coreTokens_default.border_width_0,
    primaryBorderStyle: coreTokens_default.border_none,
    primaryBorderRadius: coreTokens_default.border_radius_medium,
    primaryFontFamily: coreTokens_default.type_sans,
    primarySmallFontSize: coreTokens_default.type_scale_02,
    primaryMediumFontSize: coreTokens_default.type_scale_02,
    primaryLargeFontSize: coreTokens_default.type_scale_03,
    primaryFontWeight: coreTokens_default.type_semibold,
    secondaryDefaultBackgroundColor: coreTokens_default.color_transparent,
    secondaryErrorBackgroundColor: coreTokens_default.color_transparent,
    secondaryWarningBackgroundColor: coreTokens_default.color_transparent,
    secondarySuccessBackgroundColor: coreTokens_default.color_transparent,
    secondaryInfoBackgroundColor: coreTokens_default.color_transparent,
    secondaryDefaultFontColor: coreTokens_default.color_purple_700,
    secondaryErrorFontColor: coreTokens_default.color_red_700,
    secondaryWarningFontColor: coreTokens_default.color_orange_700,
    secondarySuccessFontColor: coreTokens_default.color_green_700,
    secondaryInfoFontColor: coreTokens_default.color_blue_700,
    secondaryDefaultBorderColor: coreTokens_default.color_purple_700,
    secondaryErrorBorderColor: coreTokens_default.color_red_700,
    secondaryWarningBorderColor: coreTokens_default.color_orange_700,
    secondarySuccessBorderColor: coreTokens_default.color_green_700,
    secondaryInfoBorderColor: coreTokens_default.color_blue_700,
    secondaryHoverDefaultBackgroundColor: coreTokens_default.color_purple_700,
    secondaryHoverErrorBackgroundColor: coreTokens_default.color_red_700,
    secondaryHoverWarningBackgroundColor: coreTokens_default.color_orange_700,
    secondaryHoverSuccessBackgroundColor: coreTokens_default.color_green_700,
    secondaryHoverInfoBackgroundColor: coreTokens_default.color_blue_700,
    secondaryHoverDefaultFontColor: coreTokens_default.color_white,
    secondaryHoverErrorFontColor: coreTokens_default.color_white,
    secondaryHoverWarningFontColor: coreTokens_default.color_white,
    secondaryHoverSuccessFontColor: coreTokens_default.color_white,
    secondaryHoverInfoFontColor: coreTokens_default.color_white,
    secondaryActiveDefaultBackgroundColor: coreTokens_default.color_purple_800,
    secondaryActiveErrorBackgroundColor: coreTokens_default.color_red_800,
    secondaryActiveWarningBackgroundColor: coreTokens_default.color_orange_800,
    secondaryActiveSuccessBackgroundColor: coreTokens_default.color_green_800,
    secondaryActiveInfoBackgroundColor: coreTokens_default.color_blue_800,
    secondaryDisabledDefaultBackgroundColor: coreTokens_default.color_transparent,
    secondaryDisabledErrorBackgroundColor: coreTokens_default.color_transparent,
    secondaryDisabledWarningBackgroundColor: coreTokens_default.color_transparent,
    secondaryDisabledSuccessBackgroundColor: coreTokens_default.color_transparent,
    secondaryDisabledInfoBackgroundColor: coreTokens_default.color_transparent,
    secondaryDisabledDefaultFontColor: coreTokens_default.color_purple_300,
    secondaryDisabledErrorFontColor: coreTokens_default.color_red_300,
    secondaryDisabledWarningFontColor: coreTokens_default.color_orange_300,
    secondaryDisabledSuccessFontColor: coreTokens_default.color_green_300,
    secondaryDisabledInfoFontColor: coreTokens_default.color_blue_300,
    secondaryDisabledDefaultBorderColor: coreTokens_default.color_purple_300,
    secondaryDisabledErrorBorderColor: coreTokens_default.color_red_300,
    secondaryDisabledWarningBorderColor: coreTokens_default.color_orange_300,
    secondaryDisabledSuccessBorderColor: coreTokens_default.color_green_300,
    secondaryDisabledInfoBorderColor: coreTokens_default.color_blue_300,
    secondaryBorderThickness: coreTokens_default.border_width_1,
    secondaryBorderStyle: coreTokens_default.border_solid,
    secondaryBorderRadius: coreTokens_default.border_radius_medium,
    secondaryFontFamily: coreTokens_default.type_sans,
    secondarySmallFontSize: coreTokens_default.type_scale_02,
    secondaryMediumFontSize: coreTokens_default.type_scale_02,
    secondaryLargeFontSize: coreTokens_default.type_scale_03,
    secondaryFontWeight: coreTokens_default.type_semibold,
    tertiaryDefaultBackgroundColor: coreTokens_default.color_transparent,
    tertiaryErrorBackgroundColor: coreTokens_default.color_transparent,
    tertiaryWarningBackgroundColor: coreTokens_default.color_transparent,
    tertiarySuccessBackgroundColor: coreTokens_default.color_transparent,
    tertiaryInfoBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDefaultFontColor: coreTokens_default.color_purple_700,
    tertiaryErrorFontColor: coreTokens_default.color_red_700,
    tertiaryWarningFontColor: coreTokens_default.color_orange_700,
    tertiarySuccessFontColor: coreTokens_default.color_green_700,
    tertiaryInfoFontColor: coreTokens_default.color_blue_700,
    tertiaryHoverDefaultBackgroundColor: coreTokens_default.color_purple_100,
    tertiaryHoverErrorBackgroundColor: coreTokens_default.color_red_100,
    tertiaryHoverWarningBackgroundColor: coreTokens_default.color_orange_100,
    tertiaryHoverSuccessBackgroundColor: coreTokens_default.color_green_100,
    tertiaryHoverInfoBackgroundColor: coreTokens_default.color_blue_100,
    tertiaryActiveDefaultBackgroundColor: coreTokens_default.color_purple_200,
    tertiaryActiveErrorBackgroundColor: coreTokens_default.color_red_200,
    tertiaryActiveWarningBackgroundColor: coreTokens_default.color_orange_200,
    tertiaryActiveSuccessBackgroundColor: coreTokens_default.color_green_200,
    tertiaryActiveInfoBackgroundColor: coreTokens_default.color_blue_200,
    tertiaryDisabledDefaultBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDisabledErrorBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDisabledWarningBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDisabledSuccessBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDisabledInfoBackgroundColor: coreTokens_default.color_transparent,
    tertiaryDisabledDefaultFontColor: coreTokens_default.color_purple_300,
    tertiaryDisabledErrorFontColor: coreTokens_default.color_red_300,
    tertiaryDisabledWarningFontColor: coreTokens_default.color_orange_300,
    tertiaryDisabledSuccessFontColor: coreTokens_default.color_green_300,
    tertiaryDisabledInfoFontColor: coreTokens_default.color_blue_300,
    tertiaryBorderThickness: coreTokens_default.border_width_0,
    tertiaryBorderStyle: coreTokens_default.border_none,
    tertiaryBorderRadius: coreTokens_default.border_radius_medium,
    tertiaryFontFamily: coreTokens_default.type_sans,
    tertiarySmallFontSize: coreTokens_default.type_scale_02,
    tertiaryMediumFontSize: coreTokens_default.type_scale_02,
    tertiaryLargeFontSize: coreTokens_default.type_scale_03,
    tertiaryFontWeight: coreTokens_default.type_semibold
  },
  card: {
    height: "220px",
    width: "400px"
  },
  checkbox: {
    backgroundColorChecked: coreTokens_default.color_blue_800,
    hoverBackgroundColorChecked: coreTokens_default.color_blue_900,
    disabledBackgroundColorChecked: coreTokens_default.color_grey_500,
    readOnlyBackgroundColorChecked: coreTokens_default.color_grey_500,
    hoverReadOnlyBackgroundColorChecked: coreTokens_default.color_grey_600,
    borderColor: coreTokens_default.color_blue_800,
    hoverBorderColor: coreTokens_default.color_blue_900,
    disabledBorderColor: coreTokens_default.color_grey_500,
    readOnlyBorderColor: coreTokens_default.color_grey_500,
    hoverReadOnlyBorderColor: coreTokens_default.color_grey_600,
    checkColor: coreTokens_default.color_white,
    disabledCheckColor: coreTokens_default.color_white,
    readOnlyCheckColor: coreTokens_default.color_white,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_02,
    fontWeight: coreTokens_default.type_regular,
    fontColor: coreTokens_default.color_black,
    disabledFontColor: coreTokens_default.color_grey_500,
    focusColor: coreTokens_default.color_blue_600,
    checkLabelSpacing: coreTokens_default.spacing_8
  },
  chip: {
    backgroundColor: coreTokens_default.color_grey_200,
    disabledBackgroundColor: coreTokens_default.color_grey_100,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_03,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    fontColor: coreTokens_default.color_black,
    disabledFontColor: coreTokens_default.color_grey_500,
    borderColor: coreTokens_default.color_transparent,
    borderRadius: "80px",
    borderThickness: coreTokens_default.border_width_0,
    borderStyle: coreTokens_default.border_solid,
    contentPaddingLeft: coreTokens_default.spacing_16,
    contentPaddingRight: coreTokens_default.spacing_16,
    contentPaddingTop: coreTokens_default.spacing_0,
    contentPaddingBottom: coreTokens_default.spacing_0,
    iconSize: "24px",
    iconSpacing: coreTokens_default.spacing_8,
    iconColor: coreTokens_default.color_grey_800,
    hoverIconColor: coreTokens_default.color_grey_900,
    activeIconColor: coreTokens_default.color_black,
    disabledIconColor: coreTokens_default.color_grey_500,
    focusColor: coreTokens_default.color_blue_600,
    focusBorderStyle: coreTokens_default.border_solid,
    focusBorderThickness: coreTokens_default.border_width_2,
    focusBorderRadius: coreTokens_default.border_radius_medium
  },
  contextualMenu: {
    fontFamily: coreTokens_default.type_sans,
    backgroundColor: coreTokens_default.color_white,
    borderColor: coreTokens_default.color_grey_200,
    menuItemFontColor: coreTokens_default.color_grey_900,
    menuItemFontSize: coreTokens_default.type_scale_02,
    menuItemFontStyle: coreTokens_default.type_normal,
    menuItemFontWeight: coreTokens_default.type_regular,
    menuItemLineHeight: "24px",
    hoverMenuItemBackgroundColor: coreTokens_default.color_grey_100,
    activeMenuItemBackgroundColor: coreTokens_default.color_grey_100,
    selectedMenuItemBackgroundColor: coreTokens_default.color_purple_100,
    hoverSelectedMenuItemBackgroundColor: coreTokens_default.color_purple_200,
    activeSelectedMenuItemBackgroundColor: coreTokens_default.color_purple_200,
    selectedMenuItemFontWeight: coreTokens_default.type_semibold,
    sectionTitleFontColor: coreTokens_default.color_grey_900,
    sectionTitleFontSize: coreTokens_default.type_scale_03,
    sectionTitleFontStyle: coreTokens_default.type_normal,
    sectionTitleFontWeight: coreTokens_default.type_semibold,
    sectionTitleLineHeight: "24px",
    iconColor: coreTokens_default.color_grey_900,
    iconSize: "16px"
  },
  dataGrid: {
    rowSeparatorThickness: "1px",
    rowSeparatorStyle: coreTokens_default.border_solid,
    rowSeparatorColor: coreTokens_default.color_grey_300,
    dataBackgroundColor: coreTokens_default.color_white,
    dataFontFamily: coreTokens_default.type_sans,
    dataFontSize: coreTokens_default.type_scale_02,
    dataFontStyle: coreTokens_default.type_normal,
    dataFontWeight: coreTokens_default.type_regular,
    dataFontColor: coreTokens_default.color_black,
    dataFontTextTransform: "none",
    dataPaddingRight: coreTokens_default.spacing_8,
    dataPaddingLeft: coreTokens_default.spacing_8,
    dataRowHeight: 36,
    dataTextLineHeight: "normal",
    headerBackgroundColor: coreTokens_default.color_purple_700,
    headerBorderRadius: "4px",
    headerFontFamily: coreTokens_default.type_sans,
    headerFontSize: coreTokens_default.type_scale_02,
    headerFontStyle: coreTokens_default.type_normal,
    headerFontWeight: coreTokens_default.type_bold,
    headerFontColor: coreTokens_default.color_white,
    headerFontTextTransform: "none",
    headerPaddingRight: coreTokens_default.spacing_8,
    headerPaddingLeft: coreTokens_default.spacing_8,
    headerRowHeight: 36,
    headerTextLineHeight: "normal",
    headerCheckboxBackgroundColorChecked: coreTokens_default.color_white,
    headerCheckboxHoverBackgroundColorChecked: coreTokens_default.color_grey_200,
    headerCheckboxBorderColor: coreTokens_default.color_white,
    headerCheckboxHoverBorderColor: coreTokens_default.color_white,
    headerCheckboxCheckColor: coreTokens_default.color_purple_700,
    summaryRowHeight: 36,
    focusColor: coreTokens_default.color_blue_600,
    scrollBarThumbColor: coreTokens_default.color_grey_700,
    scrollBarTrackColor: coreTokens_default.color_grey_300,
    actionIconColor: coreTokens_default.color_purple_700,
    disabledActionIconColor: coreTokens_default.color_grey_500,
    hoverActionIconColor: coreTokens_default.color_purple_700,
    focusActionIconColor: coreTokens_default.color_purple_700,
    activeActionIconColor: coreTokens_default.color_purple_700,
    actionBackgroundColor: coreTokens_default.color_transparent,
    disabledActionBackgroundColor: coreTokens_default.color_transparent,
    hoverActionBackgroundColor: coreTokens_default.color_grey_100,
    focusActionBorderColor: coreTokens_default.color_blue_600,
    activeActionBackgroundColor: coreTokens_default.color_grey_300
  },
  dateInput: {
    pickerBackgroundColor: coreTokens_default.color_white,
    pickerFontColor: coreTokens_default.color_black,
    pickerBorderColor: coreTokens_default.color_grey_400,
    pickerSelectedBackgroundColor: coreTokens_default.color_purple_700,
    pickerSelectedFontColor: coreTokens_default.color_white,
    pickerHoverBackgroundColor: coreTokens_default.color_purple_200,
    pickerHoverFontColor: coreTokens_default.color_black,
    pickerActiveBackgroundColor: coreTokens_default.color_purple_800,
    pickerActiveFontColor: coreTokens_default.color_white,
    pickerNonCurrentMonthFontColor: coreTokens_default.color_grey_500,
    pickerCurrentDateBorderColor: coreTokens_default.color_purple_300,
    pickerCurrentDateFontColor: coreTokens_default.color_black,
    pickerCurrentYearFontColor: coreTokens_default.color_purple_700,
    pickerHeaderBackgroundColor: coreTokens_default.color_transparent,
    pickerHeaderFontColor: coreTokens_default.color_black,
    pickerHeaderHoverBackgroundColor: coreTokens_default.color_purple_200,
    pickerHeaderHoverFontColor: coreTokens_default.color_black,
    pickerHeaderActiveBackgroundColor: coreTokens_default.color_purple_800,
    pickerHeaderActiveFontColor: coreTokens_default.color_white,
    pickerFocusColor: coreTokens_default.color_blue_600,
    pickerBorderWidth: coreTokens_default.border_width_1,
    pickerBorderStyle: coreTokens_default.border_solid,
    pickerFocusWidth: coreTokens_default.border_width_2,
    pickerCurrentDateBorderWidth: coreTokens_default.border_width_1,
    pickerFontFamily: coreTokens_default.type_sans,
    pickerFontSize: coreTokens_default.type_scale_02,
    pickerFontWeight: coreTokens_default.type_regular,
    pickerInteractedYearFontSize: coreTokens_default.type_scale_05,
    pickerHeaderFontSize: coreTokens_default.type_scale_02
  },
  dialog: {
    overlayColor: coreTokens_default.color_grey_800_a,
    backgroundColor: coreTokens_default.color_white,
    closeIconBackgroundColor: coreTokens_default.color_transparent,
    closeIconColor: coreTokens_default.color_black,
    boxShadowOffsetX: "0px",
    boxShadowOffsetY: "1px",
    boxShadowBlur: "3px",
    boxShadowColor: coreTokens_default.color_grey_300_a
  },
  dropdown: {
    buttonBackgroundColor: coreTokens_default.color_white,
    hoverButtonBackgroundColor: coreTokens_default.color_grey_100,
    activeButtonBackgroundColor: coreTokens_default.color_grey_300,
    buttonFontFamily: coreTokens_default.type_sans,
    buttonFontSize: coreTokens_default.type_scale_03,
    buttonFontStyle: coreTokens_default.type_normal,
    buttonFontWeight: coreTokens_default.type_regular,
    buttonFontColor: coreTokens_default.color_black,
    buttonIconSize: "20px",
    buttonIconSpacing: "10px",
    buttonIconColor: coreTokens_default.color_black,
    buttonPaddingTop: coreTokens_default.spacing_0,
    buttonPaddingBottom: coreTokens_default.spacing_0,
    buttonPaddingLeft: coreTokens_default.spacing_16,
    buttonPaddingRight: coreTokens_default.spacing_16,
    buttonHeight: "40px",
    buttonBorderRadius: "4px",
    buttonBorderStyle: coreTokens_default.border_none,
    buttonBorderThickness: coreTokens_default.border_width_0,
    buttonBorderColor: coreTokens_default.color_transparent,
    disabledColor: coreTokens_default.color_grey_500,
    disabledButtonBackgroundColor: coreTokens_default.color_transparent,
    disabledButtonBorderColor: coreTokens_default.color_transparent,
    optionBackgroundColor: coreTokens_default.color_white,
    hoverOptionBackgroundColor: coreTokens_default.color_grey_100,
    activeOptionBackgroundColor: coreTokens_default.color_grey_300,
    optionFontFamily: coreTokens_default.type_sans,
    optionFontSize: coreTokens_default.type_scale_03,
    optionFontStyle: coreTokens_default.type_normal,
    optionFontWeight: coreTokens_default.type_regular,
    optionFontColor: coreTokens_default.color_black,
    optionIconSize: "20px",
    optionIconSpacing: "10px",
    optionIconColor: coreTokens_default.color_black,
    optionPaddingTop: "6px",
    optionPaddingBottom: "6px",
    optionPaddingLeft: coreTokens_default.spacing_16,
    optionPaddingRight: coreTokens_default.spacing_16,
    caretIconSize: "24px",
    caretIconColor: coreTokens_default.color_black,
    caretIconSpacing: coreTokens_default.spacing_12,
    borderRadius: "4px",
    borderStyle: coreTokens_default.border_none,
    borderThickness: coreTokens_default.border_width_0,
    borderColor: coreTokens_default.color_transparent,
    scrollBarThumbColor: coreTokens_default.color_grey_700,
    scrollBarTrackColor: coreTokens_default.color_grey_300,
    focusColor: coreTokens_default.color_blue_600
  },
  fileInput: {
    dropBorderColor: coreTokens_default.color_black,
    fileItemBorderColor: coreTokens_default.color_grey_300,
    fileNameFontColor: coreTokens_default.color_black,
    labelFontColor: coreTokens_default.color_black,
    helperTextFontColor: coreTokens_default.color_black,
    dropLabelFontColor: coreTokens_default.color_black,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    disabledDropLabelFontColor: coreTokens_default.color_grey_500,
    focusDropBorderColor: coreTokens_default.color_blue_600,
    disabledDropBorderColor: coreTokens_default.color_grey_500,
    dragoverDropBackgroundColor: coreTokens_default.color_blue_50,
    errorFileItemBorderColor: coreTokens_default.color_red_700,
    errorFileItemBackgroundColor: coreTokens_default.color_red_50,
    errorFilePreviewBackgroundColor: coreTokens_default.color_red_200,
    errorFileItemIconColor: coreTokens_default.color_red_700,
    fileItemIconBackgroundColor: coreTokens_default.color_grey_100,
    deleteFileItemColor: coreTokens_default.color_black,
    errorMessageFontColor: coreTokens_default.color_red_700,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    fileItemFontFamily: coreTokens_default.type_sans,
    fileItemFontSize: coreTokens_default.type_scale_02,
    fileItemFontWeight: coreTokens_default.type_regular,
    fileItemLineHeight: coreTokens_default.type_leading_normal,
    helperTextFontFamily: coreTokens_default.type_sans,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    dropLabelFontFamily: coreTokens_default.type_sans,
    dropLabelFontSize: coreTokens_default.type_scale_03,
    dropLabelFontWeight: coreTokens_default.type_regular,
    errorMessageFontFamily: coreTokens_default.type_sans,
    errorMessageFontSize: coreTokens_default.type_scale_01,
    errorMessageFontWeight: coreTokens_default.type_regular,
    errorMessageLineHeight: coreTokens_default.type_leading_normal,
    dropBorderThickness: coreTokens_default.border_width_1,
    dropBorderStyle: coreTokens_default.border_dashed,
    dropBorderRadius: coreTokens_default.border_radius_large,
    fileItemBorderThickness: coreTokens_default.border_width_1,
    fileItemBorderStyle: coreTokens_default.border_solid,
    fileItemBorderRadius: coreTokens_default.border_radius_medium,
    hoverDeleteFileItemBackgroundColor: coreTokens_default.color_grey_100_a,
    activeDeleteFileItemBackgroundColor: coreTokens_default.color_grey_300_a,
    focusDeleteFileItemBorderColor: coreTokens_default.color_blue_600,
    filePreviewBackgroundColor: coreTokens_default.color_grey_100,
    filePreviewIconColor: coreTokens_default.color_grey_600,
    errorFilePreviewIconColor: coreTokens_default.color_red_700
  },
  footer: {
    height: "124px",
    backgroundColor: coreTokens_default.color_black,
    bottomLinksDividerColor: coreTokens_default.color_blue_600,
    bottomLinksDividerThickness: "1px",
    bottomLinksDividerStyle: coreTokens_default.border_solid,
    bottomLinksDividerSpacing: coreTokens_default.spacing_8,
    bottomLinksFontFamily: coreTokens_default.type_sans,
    bottomLinksFontSize: coreTokens_default.type_scale_01,
    bottomLinksFontStyle: coreTokens_default.type_normal,
    bottomLinksFontWeight: coreTokens_default.type_regular,
    bottomLinksFontColor: coreTokens_default.color_white,
    bottomLinksTextDecoration: coreTokens_default.type_no_line,
    copyrightFontFamily: coreTokens_default.type_sans,
    copyrightFontSize: coreTokens_default.type_scale_01,
    copyrightFontStyle: coreTokens_default.type_normal,
    copyrightFontWeight: coreTokens_default.type_regular,
    copyrightFontColor: coreTokens_default.color_white,
    logo: "",
    logoHeight: "32px",
    logoWidth: "auto",
    socialLinksSize: "24px",
    socialLinksGutter: coreTokens_default.spacing_16,
    socialLinksColor: coreTokens_default.color_white
  },
  header: {
    backgroundColor: coreTokens_default.color_white,
    hamburgerFocusColor: coreTokens_default.color_blue_600,
    hamburgerFontFamily: coreTokens_default.type_sans,
    hamburgerFontStyle: coreTokens_default.type_normal,
    hamburgerFontColor: coreTokens_default.color_black,
    hamburgerFontSize: "10px",
    hamburgerFontWeight: coreTokens_default.type_semibold,
    hamburgerTextTransform: coreTokens_default.type_uppercase,
    hamburgerIconColor: coreTokens_default.color_black,
    hamburgerHoverColor: coreTokens_default.color_grey_200,
    logo: "",
    logoResponsive: "",
    logoHeight: "40px",
    logoWidth: "auto",
    menuBackgroundColor: coreTokens_default.color_white,
    menuZindex: "2000",
    menuTabletWidth: "60vw",
    menuMobileWidth: "100vw",
    minHeight: "64px",
    overlayColor: coreTokens_default.color_grey_800_a,
    overlayOpacity: "0.7",
    overlayZindex: "1600",
    paddingTop: coreTokens_default.spacing_0,
    paddingBottom: coreTokens_default.spacing_0,
    paddingRight: coreTokens_default.spacing_24,
    paddingLeft: coreTokens_default.spacing_24,
    underlinedColor: coreTokens_default.color_black,
    underlinedThickness: "2px",
    underlinedStyle: coreTokens_default.border_solid,
    contentColor: coreTokens_default.color_black
  },
  heading: {
    level1FontColor: coreTokens_default.inherit,
    level1FontFamily: coreTokens_default.type_sans,
    level1FontSize: coreTokens_default.type_scale_07,
    level1FontStyle: coreTokens_default.type_normal,
    level1FontWeight: coreTokens_default.type_semibold,
    level1LineHeight: coreTokens_default.type_leading_compact_01,
    level1LetterSpacing: coreTokens_default.type_spacing_tight_01,
    level2FontColor: coreTokens_default.inherit,
    level2FontFamily: coreTokens_default.type_sans,
    level2FontSize: coreTokens_default.type_scale_05,
    level2FontStyle: coreTokens_default.type_normal,
    level2FontWeight: coreTokens_default.type_semibold,
    level2LineHeight: coreTokens_default.type_leading_normal,
    level2LetterSpacing: coreTokens_default.type_spacing_normal,
    level3FontColor: coreTokens_default.inherit,
    level3FontFamily: coreTokens_default.type_sans,
    level3FontSize: coreTokens_default.type_scale_04,
    level3FontStyle: coreTokens_default.type_normal,
    level3FontWeight: coreTokens_default.type_semibold,
    level3LineHeight: coreTokens_default.type_leading_compact_01,
    level3LetterSpacing: coreTokens_default.type_spacing_wide_01,
    level4FontColor: coreTokens_default.inherit,
    level4FontFamily: coreTokens_default.type_sans,
    level4FontSize: coreTokens_default.type_scale_03,
    level4FontStyle: coreTokens_default.type_normal,
    level4FontWeight: coreTokens_default.type_semibold,
    level4LineHeight: coreTokens_default.type_leading_normal,
    level4LetterSpacing: coreTokens_default.type_spacing_normal,
    level5FontColor: coreTokens_default.inherit,
    level5FontFamily: coreTokens_default.type_sans,
    level5FontSize: coreTokens_default.type_scale_02,
    level5FontStyle: coreTokens_default.type_normal,
    level5FontWeight: coreTokens_default.type_semibold,
    level5LineHeight: coreTokens_default.type_leading_normal,
    level5LetterSpacing: coreTokens_default.type_spacing_wide_01
  },
  image: {
    captionFontColor: coreTokens_default.color_grey_900,
    captionFontFamily: coreTokens_default.type_sans,
    captionFontSize: coreTokens_default.type_scale_02,
    captionFontStyle: coreTokens_default.type_normal,
    captionFontWeight: coreTokens_default.type_regular,
    captionLineHeight: coreTokens_default.type_leading_normal
  },
  link: {
    fontColor: coreTokens_default.color_blue_800,
    fontFamily: coreTokens_default.inherit,
    fontSize: coreTokens_default.inherit,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    iconSize: "16px",
    iconSpacing: coreTokens_default.spacing_4,
    underlineSpacing: coreTokens_default.spacing_0,
    underlineStyle: coreTokens_default.border_solid,
    underlineThickness: "1px",
    disabledFontColor: coreTokens_default.color_grey_500,
    hoverFontColor: coreTokens_default.color_blue_800,
    hoverUnderlineColor: coreTokens_default.color_blue_800,
    visitedFontColor: coreTokens_default.color_purple_700,
    visitedUnderlineColor: coreTokens_default.color_purple_700,
    activeFontColor: coreTokens_default.color_black,
    activeUnderlineColor: coreTokens_default.color_black,
    focusColor: coreTokens_default.color_blue_600
  },
  navTabs: {
    selectedBackgroundColor: coreTokens_default.color_white,
    unselectedBackgroundColor: coreTokens_default.color_white,
    hoverBackgroundColor: coreTokens_default.color_grey_100,
    pressedBackgroundColor: coreTokens_default.color_grey_200,
    selectedFontColor: coreTokens_default.color_grey_700,
    unselectedFontColor: coreTokens_default.color_grey_700,
    disabledFontColor: coreTokens_default.color_grey_500,
    focusOutline: coreTokens_default.color_blue_600,
    selectedUnderlineColor: coreTokens_default.color_purple_700,
    dividerColor: coreTokens_default.color_grey_400,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_03,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    selectedIconColor: coreTokens_default.color_grey_700,
    unselectedIconColor: coreTokens_default.color_grey_700,
    disabledIconColor: coreTokens_default.color_grey_500
  },
  paginator: {
    backgroundColor: coreTokens_default.color_grey_100,
    fontColor: coreTokens_default.color_black,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_02,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    fontTextTransform: "none",
    verticalPadding: coreTokens_default.spacing_12,
    horizontalPadding: coreTokens_default.spacing_32,
    marginRight: coreTokens_default.spacing_40,
    marginLeft: "20px",
    itemsPerPageSelectorMarginLeft: coreTokens_default.spacing_0,
    itemsPerPageSelectorMarginRight: coreTokens_default.spacing_8,
    pageSelectorMarginRight: "30px",
    pageSelectorMarginLeft: coreTokens_default.spacing_0,
    totalItemsContainerMarginRight: coreTokens_default.spacing_40,
    totalItemsContainerMarginLeft: coreTokens_default.spacing_0
  },
  paragraph: {
    display: "block",
    fontColor: coreTokens_default.color_black,
    fontSize: coreTokens_default.type_scale_03,
    fontWeight: coreTokens_default.type_regular
  },
  progressBar: {
    trackLineColor: coreTokens_default.color_purple_700,
    totalLineColor: coreTokens_default.color_grey_200,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_01,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_regular,
    labelFontColor: coreTokens_default.color_black,
    labelFontTextTransform: coreTokens_default.type_uppercase,
    valueFontFamily: coreTokens_default.type_sans,
    valueFontSize: coreTokens_default.type_scale_01,
    valueFontStyle: coreTokens_default.type_normal,
    valueFontWeight: coreTokens_default.type_regular,
    valueFontColor: coreTokens_default.color_black,
    valueFontTextTransform: coreTokens_default.type_uppercase,
    helperTextFontColor: coreTokens_default.color_black,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextFontFamily: coreTokens_default.type_sans,
    thickness: "9px",
    borderRadius: "5px",
    overlayColor: coreTokens_default.color_grey_800_a,
    overlayFontColor: coreTokens_default.color_white
  },
  quickNav: {
    fontColor: coreTokens_default.color_grey_700,
    hoverFontColor: coreTokens_default.color_purple_600,
    dividerBorderColor: coreTokens_default.color_grey_400,
    focusBorderColor: coreTokens_default.color_blue_600,
    focusBorderStyle: coreTokens_default.border_solid,
    focusBorderThickness: coreTokens_default.border_width_2,
    focusBorderRadius: coreTokens_default.border_width_2,
    paddingTop: coreTokens_default.spacing_8,
    paddingBottom: coreTokens_default.spacing_8,
    paddingLeft: coreTokens_default.spacing_16,
    paddingRight: coreTokens_default.spacing_16,
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_02,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular
  },
  radioGroup: {
    fontFamily: coreTokens_default.type_sans,
    radioInputColor: coreTokens_default.color_blue_700,
    hoverRadioInputColor: coreTokens_default.color_blue_800,
    focusBorderColor: coreTokens_default.color_blue_600,
    activeRadioInputColor: coreTokens_default.color_blue_900,
    errorRadioInputColor: coreTokens_default.color_red_700,
    hoverErrorRadioInputColor: coreTokens_default.color_red_800,
    activeErrorRadioInputColor: coreTokens_default.color_red_900,
    readOnlyRadioInputColor: coreTokens_default.color_grey_500,
    hoverReadOnlyRadioInputColor: coreTokens_default.color_grey_600,
    activeReadOnlyRadioInputColor: coreTokens_default.color_grey_700,
    disabledRadioInputColor: coreTokens_default.color_grey_500,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    disabledRadioInputLabelFontColor: coreTokens_default.color_grey_500,
    errorMessageColor: coreTokens_default.color_red_700,
    labelFontColor: coreTokens_default.color_black,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    optionalLabelFontWeight: coreTokens_default.type_regular,
    helperTextFontColor: coreTokens_default.color_black,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    radioInputLabelFontColor: coreTokens_default.color_black,
    radioInputLabelFontSize: coreTokens_default.type_scale_02,
    radioInputLabelFontStyle: coreTokens_default.type_normal,
    radioInputLabelFontWeight: coreTokens_default.type_regular,
    radioInputLabelLineHeight: coreTokens_default.type_leading_loose_01,
    groupLabelMargin: coreTokens_default.spacing_8,
    radioInputLabelMargin: coreTokens_default.spacing_8,
    groupVerticalGutter: coreTokens_default.spacing_4,
    groupHorizontalGutter: coreTokens_default.spacing_32
  },
  select: {
    fontFamily: coreTokens_default.type_sans,
    disabledColor: coreTokens_default.color_grey_500,
    enabledInputBorderColor: coreTokens_default.color_black,
    hoverInputBorderColor: coreTokens_default.color_purple_500,
    focusInputBorderColor: coreTokens_default.color_blue_600,
    errorInputBorderColor: coreTokens_default.color_red_700,
    hoverInputErrorBorderColor: coreTokens_default.color_red_600,
    disabledInputBorderColor: coreTokens_default.color_grey_500,
    disabledInputBackgroundColor: coreTokens_default.color_grey_100,
    inputMarginTop: coreTokens_default.spacing_4,
    inputMarginBottom: coreTokens_default.spacing_4,
    errorMessageColor: coreTokens_default.color_red_700,
    errorIconColor: coreTokens_default.color_red_700,
    labelFontColor: coreTokens_default.color_black,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    optionalLabelFontWeight: coreTokens_default.type_regular,
    helperTextFontColor: coreTokens_default.color_black,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    placeholderFontColor: coreTokens_default.color_grey_800_a,
    valueFontColor: coreTokens_default.color_black,
    valueFontSize: coreTokens_default.type_scale_03,
    valueFontStyle: coreTokens_default.type_normal,
    valueFontWeight: coreTokens_default.type_regular,
    actionIconColor: coreTokens_default.color_black,
    hoverActionIconColor: coreTokens_default.color_black,
    activeActionIconColor: coreTokens_default.color_black,
    actionBackgroundColor: coreTokens_default.color_transparent,
    hoverActionBackgroundColor: coreTokens_default.color_grey_100,
    activeActionBackgroundColor: coreTokens_default.color_grey_300,
    listOptionFontColor: coreTokens_default.color_black,
    listOptionFontSize: coreTokens_default.type_scale_02,
    listOptionFontStyle: coreTokens_default.type_normal,
    listOptionFontWeight: coreTokens_default.type_regular,
    listOptionIconColor: coreTokens_default.color_black,
    listOptionDividerColor: coreTokens_default.color_grey_200,
    listGroupLabelFontWeight: coreTokens_default.type_semibold,
    focusListOptionBorderColor: coreTokens_default.color_blue_600,
    systemMessageFontColor: coreTokens_default.color_grey_700,
    collapseIndicatorColor: coreTokens_default.color_black,
    listDialogBackgroundColor: coreTokens_default.color_white,
    listDialogBorderColor: coreTokens_default.color_grey_400,
    selectedListOptionBackgroundColor: coreTokens_default.color_blue_100,
    selectedHoverListOptionBackgroundColor: coreTokens_default.color_blue_200,
    selectedActiveListOptionBackgroundColor: coreTokens_default.color_blue_300,
    selectedListOptionIconColor: coreTokens_default.color_blue_900,
    unselectedHoverListOptionBackgroundColor: coreTokens_default.color_grey_100,
    unselectedActiveListOptionBackgroundColor: coreTokens_default.color_grey_200,
    selectionIndicatorFontColor: coreTokens_default.color_black,
    selectionIndicatorFontSize: coreTokens_default.type_scale_01,
    selectionIndicatorFontStyle: coreTokens_default.type_regular,
    selectionIndicatorFontWeight: coreTokens_default.type_normal,
    selectionIndicatorBorderColor: coreTokens_default.color_grey_400,
    selectionIndicatorBackgroundColor: coreTokens_default.color_grey_50,
    enabledSelectionIndicatorActionBackgroundColor: coreTokens_default.color_transparent,
    enabledSelectionIndicatorActionIconColor: coreTokens_default.color_black,
    hoverSelectionIndicatorActionBackgroundColor: coreTokens_default.color_grey_100,
    hoverSelectionIndicatorActionIconColor: coreTokens_default.color_black,
    activeSelectionIndicatorActionBackgroundColor: coreTokens_default.color_grey_300,
    activeSelectionIndicatorActionIconColor: coreTokens_default.color_black
  },
  sidenav: {
    backgroundColor: coreTokens_default.color_grey_100,
    titleFontFamily: coreTokens_default.type_sans,
    titleFontSize: coreTokens_default.type_scale_04,
    titleFontStyle: coreTokens_default.type_normal,
    titleFontWeight: coreTokens_default.type_semibold,
    titleFontColor: coreTokens_default.color_grey_800,
    titleFontTextTransform: "none",
    titleFontLetterSpacing: coreTokens_default.type_spacing_normal,
    groupTitleFontFamily: coreTokens_default.type_sans,
    groupTitleFontSize: coreTokens_default.type_scale_02,
    groupTitleFontStyle: coreTokens_default.type_normal,
    groupTitleFontWeight: coreTokens_default.type_semibold,
    groupTitleFontColor: coreTokens_default.color_black,
    groupTitleHoverBackgroundColor: coreTokens_default.color_grey_200,
    groupTitleActiveBackgroundColor: coreTokens_default.color_grey_800,
    groupTitleSelectedFontColor: coreTokens_default.color_white,
    groupTitleSelectedBackgroundColor: coreTokens_default.color_grey_800,
    groupTitleSelectedHoverFontColor: coreTokens_default.color_white,
    groupTitleSelectedHoverBackgroundColor: coreTokens_default.color_grey_900,
    groupTitleFontTextTransform: coreTokens_default.type_uppercase,
    groupTitleFontLetterSpacing: coreTokens_default.type_spacing_wide_02,
    linkFontFamily: coreTokens_default.type_sans,
    linkFontSize: coreTokens_default.type_scale_02,
    linkFontStyle: coreTokens_default.type_normal,
    linkFontWeight: coreTokens_default.type_regular,
    linkFontColor: coreTokens_default.color_grey_800,
    linkHoverBackgroundColor: coreTokens_default.color_grey_200,
    linkSelectedFontColor: coreTokens_default.color_white,
    linkSelectedBackgroundColor: coreTokens_default.color_grey_800,
    linkSelectedHoverFontColor: coreTokens_default.color_white,
    linkSelectedHoverBackgroundColor: coreTokens_default.color_grey_900,
    linkFontTextTransform: "none",
    linkFontLetterSpacing: coreTokens_default.type_spacing_wide_01,
    linkTextDecoration: coreTokens_default.type_no_line,
    linkMarginTop: coreTokens_default.spacing_4,
    linkMarginBottom: coreTokens_default.spacing_4,
    linkMarginRight: coreTokens_default.spacing_16,
    linkMarginLeft: coreTokens_default.spacing_16,
    linkFocusColor: coreTokens_default.color_blue_600,
    scrollBarThumbColor: coreTokens_default.color_grey_200_a,
    scrollBarTrackColor: coreTokens_default.color_transparent
  },
  slider: {
    fontFamily: coreTokens_default.type_sans,
    limitValuesFontColor: coreTokens_default.color_black,
    limitValuesFontSize: coreTokens_default.type_scale_03,
    limitValuesFontStyle: coreTokens_default.type_normal,
    limitValuesFontWeight: coreTokens_default.type_regular,
    limitValuesFontLetterSpacing: coreTokens_default.type_spacing_normal,
    disabledLimitValuesFontColor: coreTokens_default.color_grey_500,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    helperTextFontFamily: coreTokens_default.type_sans,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    fontColor: coreTokens_default.color_black,
    labelFontColor: coreTokens_default.color_black,
    helperTextFontColor: coreTokens_default.color_black,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    thumbHeight: "12px",
    thumbWidth: "12px",
    hoverThumbHeight: "14px",
    hoverThumbWidth: "14px",
    thumbVerticalPosition: "12px",
    hoverThumbVerticalPosition: "11px",
    thumbBackgroundColor: coreTokens_default.color_blue_800,
    hoverThumbScale: "1.166666",
    hoverThumbBackgroundColor: coreTokens_default.color_blue_900,
    activeThumbScale: "1.166666",
    activeThumbBackgroundColor: coreTokens_default.color_blue_900,
    focusThumbBackgroundColor: coreTokens_default.color_blue_800,
    tickHeight: "4px",
    tickWidth: "4px",
    tickVerticalPosition: "11px",
    tickBackgroundColor: coreTokens_default.color_blue_800,
    trackLineThickness: "2px",
    trackLineVerticalPosition: "50%",
    trackLineColor: coreTokens_default.color_blue_800,
    totalLineThickness: "2px",
    totalLineVerticalPosition: "50%",
    totalLineColor: coreTokens_default.color_grey_200_a,
    disabledThumbVerticalPosition: "10px",
    disabledThumbBackgroundColor: coreTokens_default.color_grey_500,
    disabledTickVerticalPosition: "11px",
    disabledTickBackgroundColor: coreTokens_default.color_grey_500,
    disabledTrackLineColor: coreTokens_default.color_grey_500,
    disabledTotalLineColor: coreTokens_default.color_grey_100,
    focusColor: coreTokens_default.color_blue_600,
    floorLabelMarginRight: coreTokens_default.type_scale_03,
    ceilLabelMarginLeft: coreTokens_default.type_scale_03,
    inputMarginLeft: coreTokens_default.type_scale_06
  },
  spinner: {
    trackCircleColor: coreTokens_default.color_purple_700,
    trackCircleColorOverlay: coreTokens_default.color_purple_500,
    totalCircleColor: coreTokens_default.color_white,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_regular,
    labelFontColor: coreTokens_default.color_black,
    labelTextAlign: "center",
    progressValueFontFamily: coreTokens_default.type_sans,
    progressValueFontSize: coreTokens_default.type_scale_02,
    progressValueFontStyle: coreTokens_default.type_normal,
    progressValueFontWeight: coreTokens_default.type_bold,
    progressValueFontColor: coreTokens_default.inherit,
    progressValueTextAlign: "center",
    overlayBackgroundColor: coreTokens_default.color_black,
    overlayOpacity: "0.8",
    overlayLabelFontFamily: coreTokens_default.type_sans,
    overlayLabelFontSize: coreTokens_default.type_scale_02,
    overlayLabelFontStyle: coreTokens_default.type_normal,
    overlayLabelFontWeight: coreTokens_default.type_regular,
    overlayLabelFontColor: coreTokens_default.color_white,
    overlayLabelTextAlign: "center",
    overlayProgressValueFontFamily: coreTokens_default.type_sans,
    overlayProgressValueFontSize: coreTokens_default.type_scale_02,
    overlayProgressValueFontStyle: coreTokens_default.type_normal,
    overlayProgressValueFontWeight: coreTokens_default.type_bold,
    overlayProgressValueFontColor: coreTokens_default.color_white,
    overlayProgressValueTextAlign: "center"
  },
  switch: {
    checkedTrackBackgroundColor: coreTokens_default.color_purple_700,
    checkedThumbBackgroundColor: coreTokens_default.color_white,
    uncheckedTrackBackgroundColor: coreTokens_default.color_grey_400,
    uncheckedThumbBackgroundColor: coreTokens_default.color_white,
    disabledCheckedTrackBackgroundColor: coreTokens_default.color_purple_100,
    disabledCheckedThumbBackgroundColor: coreTokens_default.color_white,
    disabledUncheckedTrackBackgroundColor: coreTokens_default.color_grey_100,
    disabledUncheckedThumbBackgroundColor: coreTokens_default.color_white,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    disabledLabelFontStyle: coreTokens_default.type_normal,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_03,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_regular,
    labelFontColor: coreTokens_default.color_black,
    thumbFocusColor: coreTokens_default.color_blue_600,
    thumbHeight: "24px",
    thumbWidth: "24px",
    thumbShift: "1.25rem",
    trackHeight: "12px",
    trackWidth: "36px",
    spaceBetweenLabelSwitch: coreTokens_default.spacing_8
  },
  table: {
    rowSeparatorThickness: "1px",
    rowSeparatorStyle: coreTokens_default.border_solid,
    rowSeparatorColor: coreTokens_default.color_grey_300,
    dataBackgroundColor: coreTokens_default.color_white,
    dataFontFamily: coreTokens_default.type_sans,
    dataFontSize: coreTokens_default.type_scale_02,
    dataFontStyle: coreTokens_default.type_normal,
    dataFontWeight: coreTokens_default.type_regular,
    dataFontColor: coreTokens_default.color_black,
    dataFontTextTransform: "none",
    dataPaddingTop: coreTokens_default.spacing_16,
    dataPaddingBottom: coreTokens_default.spacing_16,
    dataPaddingRight: "20px",
    dataPaddingLeft: "20px",
    dataPaddingTopReduced: coreTokens_default.spacing_8,
    dataPaddingBottomReduced: coreTokens_default.spacing_8,
    dataPaddingRightReduced: coreTokens_default.spacing_16,
    dataPaddingLeftReduced: coreTokens_default.spacing_16,
    dataTextAlign: "left",
    dataTextLineHeight: "normal",
    firstChildPaddingLeft: coreTokens_default.spacing_24,
    lastChildPaddingRight: coreTokens_default.spacing_24,
    firstChildPaddingLeftReduced: "20px",
    lastChildPaddingRightReduced: "20px",
    headerBackgroundColor: coreTokens_default.color_purple_700,
    headerBorderRadius: "4px",
    headerFontFamily: coreTokens_default.type_sans,
    headerFontSize: coreTokens_default.type_scale_02,
    headerFontStyle: coreTokens_default.type_normal,
    headerFontWeight: coreTokens_default.type_regular,
    headerFontColor: coreTokens_default.color_white,
    headerFontTextTransform: "none",
    headerPaddingTop: coreTokens_default.spacing_16,
    headerPaddingBottom: coreTokens_default.spacing_16,
    headerPaddingRight: "20px",
    headerPaddingLeft: "20px",
    headerPaddingTopReduced: coreTokens_default.spacing_8,
    headerPaddingBottomReduced: coreTokens_default.spacing_8,
    headerPaddingRightReduced: coreTokens_default.spacing_16,
    headerPaddingLeftReduced: coreTokens_default.spacing_16,
    headerTextAlign: "left",
    headerTextLineHeight: "normal",
    scrollBarThumbColor: coreTokens_default.color_grey_700,
    scrollBarTrackColor: coreTokens_default.color_grey_300,
    sortIconColor: coreTokens_default.color_white,
    actionIconColor: coreTokens_default.color_purple_700,
    disabledActionIconColor: coreTokens_default.color_grey_500,
    hoverActionIconColor: coreTokens_default.color_purple_700,
    focusActionIconColor: coreTokens_default.color_purple_700,
    activeActionIconColor: coreTokens_default.color_purple_700,
    actionBackgroundColor: coreTokens_default.color_transparent,
    disabledActionBackgroundColor: coreTokens_default.color_transparent,
    hoverActionBackgroundColor: coreTokens_default.color_grey_100,
    focusActionBorderColor: coreTokens_default.color_blue_600,
    activeActionBackgroundColor: coreTokens_default.color_grey_300
  },
  tabs: {
    fontFamily: coreTokens_default.type_sans,
    fontSize: coreTokens_default.type_scale_03,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_semibold,
    fontTextTransform: "none",
    selectedBackgroundColor: coreTokens_default.color_white,
    selectedFontColor: coreTokens_default.color_purple_700,
    selectedIconColor: coreTokens_default.color_purple_700,
    selectedUnderlineColor: coreTokens_default.color_purple_700,
    selectedUnderlineThickness: "2px",
    unselectedBackgroundColor: coreTokens_default.color_white,
    unselectedFontColor: coreTokens_default.color_grey_700,
    unselectedIconColor: coreTokens_default.color_grey_700,
    disabledFontColor: coreTokens_default.color_grey_500,
    disabledIconColor: coreTokens_default.color_grey_500,
    disabledFontStyle: coreTokens_default.type_normal,
    hoverBackgroundColor: coreTokens_default.color_purple_100,
    pressedBackgroundColor: coreTokens_default.color_purple_200,
    pressedFontWeight: coreTokens_default.type_semibold,
    dividerColor: coreTokens_default.color_grey_400,
    dividerThickness: "1px",
    focusOutline: coreTokens_default.color_purple_700,
    scrollButtonsWidth: "48px"
  },
  tag: {
    fontFamily: coreTokens_default.type_sans,
    fontColor: coreTokens_default.color_black,
    fontSize: coreTokens_default.type_scale_02,
    fontStyle: coreTokens_default.type_normal,
    fontWeight: coreTokens_default.type_regular,
    labelPaddingTop: coreTokens_default.spacing_0,
    labelPaddingBottom: coreTokens_default.spacing_0,
    labelPaddingLeft: coreTokens_default.spacing_16,
    labelPaddingRight: coreTokens_default.spacing_16,
    height: "40px",
    iconColor: coreTokens_default.color_white,
    iconSectionWidth: "40px",
    iconHeight: "24px",
    iconWidth: "auto",
    focusColor: coreTokens_default.color_blue_600
  },
  textarea: {
    fontFamily: coreTokens_default.type_sans,
    enabledBorderColor: coreTokens_default.color_black,
    hoverBorderColor: coreTokens_default.color_purple_500,
    focusBorderColor: coreTokens_default.color_blue_600,
    disabledBorderColor: coreTokens_default.color_grey_500,
    disabledContainerFillColor: coreTokens_default.color_grey_100,
    readOnlyBorderColor: coreTokens_default.color_grey_500,
    hoverReadOnlyBorderColor: coreTokens_default.color_grey_600,
    errorBorderColor: coreTokens_default.color_red_700,
    hoverErrorBorderColor: coreTokens_default.color_red_600,
    inputMarginTop: coreTokens_default.spacing_4,
    inputMarginBottom: coreTokens_default.spacing_4,
    errorMessageColor: coreTokens_default.color_red_700,
    labelFontColor: coreTokens_default.color_black,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    optionalLabelFontWeight: coreTokens_default.type_regular,
    helperTextFontColor: coreTokens_default.color_black,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    placeholderFontColor: coreTokens_default.color_grey_800_a,
    disabledPlaceholderFontColor: coreTokens_default.color_grey_500,
    valueFontColor: coreTokens_default.color_black,
    valueFontSize: coreTokens_default.type_scale_03,
    valueFontStyle: coreTokens_default.type_normal,
    valueFontWeight: coreTokens_default.type_regular,
    disabledValueFontColor: coreTokens_default.color_grey_500
  },
  textInput: {
    fontFamily: coreTokens_default.type_sans,
    enabledBorderColor: coreTokens_default.color_black,
    hoverBorderColor: coreTokens_default.color_purple_500,
    focusBorderColor: coreTokens_default.color_blue_600,
    disabledBorderColor: coreTokens_default.color_grey_500,
    disabledContainerFillColor: coreTokens_default.color_grey_100,
    readOnlyBorderColor: coreTokens_default.color_grey_500,
    hoverReadOnlyBorderColor: coreTokens_default.color_grey_600,
    errorBorderColor: coreTokens_default.color_red_700,
    hoverErrorBorderColor: coreTokens_default.color_red_600,
    inputMarginTop: coreTokens_default.spacing_4,
    inputMarginBottom: coreTokens_default.spacing_4,
    errorMessageColor: coreTokens_default.color_red_700,
    errorIconColor: coreTokens_default.color_red_700,
    labelFontColor: coreTokens_default.color_black,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    optionalLabelFontWeight: coreTokens_default.type_regular,
    helperTextFontColor: coreTokens_default.color_black,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    prefixColor: coreTokens_default.color_grey_700,
    prefixDividerBorderWidth: "1px",
    prefixDividerBorderStyle: coreTokens_default.border_solid,
    prefixDividerPaddingRight: coreTokens_default.spacing_8,
    suffixColor: coreTokens_default.color_grey_700,
    suffixDividerBorderStyle: coreTokens_default.border_solid,
    suffixDividerBorderWidth: "1px",
    suffixDividerPaddingLeft: coreTokens_default.spacing_8,
    disabledPrefixColor: coreTokens_default.color_grey_400,
    disabledSuffixColor: coreTokens_default.color_grey_400,
    placeholderFontColor: coreTokens_default.color_grey_800_a,
    disabledPlaceholderFontColor: coreTokens_default.color_grey_500,
    valueFontColor: coreTokens_default.color_black,
    valueFontSize: coreTokens_default.type_scale_03,
    valueFontStyle: coreTokens_default.type_normal,
    valueFontWeight: coreTokens_default.type_regular,
    disabledValueFontColor: coreTokens_default.color_grey_500,
    actionIconColor: coreTokens_default.color_black,
    disabledActionIconColor: coreTokens_default.color_grey_500,
    hoverActionIconColor: coreTokens_default.color_black,
    focusActionIconColor: coreTokens_default.color_black,
    activeActionIconColor: coreTokens_default.color_black,
    actionBackgroundColor: coreTokens_default.color_transparent,
    disabledActionBackgroundColor: coreTokens_default.color_transparent,
    hoverActionBackgroundColor: coreTokens_default.color_grey_100,
    focusActionBorderColor: coreTokens_default.color_blue_600,
    activeActionBackgroundColor: coreTokens_default.color_grey_300,
    listDialogBackgroundColor: coreTokens_default.color_white,
    listDialogBorderColor: coreTokens_default.color_grey_400,
    listOptionDividerColor: coreTokens_default.color_grey_200,
    listOptionFontColor: coreTokens_default.color_black,
    listOptionFontSize: coreTokens_default.type_scale_02,
    listOptionFontStyle: coreTokens_default.type_normal,
    listOptionFontWeight: coreTokens_default.type_regular,
    systemMessageFontColor: coreTokens_default.color_grey_700,
    errorListDialogFontColor: coreTokens_default.color_black,
    errorListDialogBackgroundColor: coreTokens_default.color_red_50,
    errorListDialogBorderColor: coreTokens_default.color_red_700,
    hoverListOptionBackgroundColor: coreTokens_default.color_grey_100,
    activeListOptionBackgroundColor: coreTokens_default.color_grey_200,
    focusListOptionBorderColor: coreTokens_default.color_blue_600
  },
  toggleGroup: {
    containerBackgroundColor: coreTokens_default.color_grey_50,
    containerBorderColor: coreTokens_default.color_grey_500,
    labelFontColor: coreTokens_default.color_black,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    helperTextFontColor: coreTokens_default.color_black,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    unselectedBackgroundColor: coreTokens_default.color_grey_200,
    unselectedHoverBackgroundColor: coreTokens_default.color_grey_300,
    unselectedActiveBackgroundColor: coreTokens_default.color_purple_700,
    unselectedDisabledBackgroundColor: coreTokens_default.color_grey_100,
    unselectedFontColor: coreTokens_default.color_black,
    unselectedDisabledFontColor: coreTokens_default.color_grey_500,
    selectedBackgroundColor: coreTokens_default.color_purple_700,
    selectedHoverBackgroundColor: coreTokens_default.color_purple_800,
    selectedActiveBackgroundColor: coreTokens_default.color_purple_900,
    selectedDisabledBackgroundColor: coreTokens_default.color_purple_100,
    selectedFontColor: coreTokens_default.color_white,
    selectedDisabledFontColor: coreTokens_default.color_purple_300,
    focusColor: coreTokens_default.color_blue_600,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontSize: coreTokens_default.type_scale_02,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_semibold,
    labelLineHeight: coreTokens_default.type_leading_loose_01,
    helperTextFontFamily: coreTokens_default.type_sans,
    helperTextFontSize: coreTokens_default.type_scale_01,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextLineHeight: coreTokens_default.type_leading_normal,
    optionLabelFontFamily: coreTokens_default.type_sans,
    optionLabelFontSize: coreTokens_default.type_scale_03,
    optionLabelFontStyle: coreTokens_default.type_normal,
    optionLabelFontWeight: coreTokens_default.type_regular,
    iconPaddingRight: coreTokens_default.spacing_8,
    iconPaddingLeft: coreTokens_default.spacing_8,
    labelPaddingLeft: coreTokens_default.spacing_24,
    labelPaddingRight: coreTokens_default.spacing_24,
    iconMarginRight: coreTokens_default.spacing_8,
    containerMarginTop: coreTokens_default.spacing_4,
    optionBorderThickness: coreTokens_default.border_width_0,
    optionBorderStyle: coreTokens_default.border_none,
    optionBorderRadius: coreTokens_default.border_radius_medium,
    containerBorderThickness: coreTokens_default.border_width_1,
    containerBorderStyle: coreTokens_default.border_solid,
    containerBorderRadius: coreTokens_default.border_radius_large,
    optionFocusBorderThickness: coreTokens_default.border_width_2
  },
  wizard: {
    visitedStepFontColor: coreTokens_default.color_black,
    visitedStepBackgroundColor: coreTokens_default.color_white,
    visitedStepBorderColor: coreTokens_default.color_black,
    unvisitedStepFontColor: coreTokens_default.color_grey_700,
    unvisitedLabelFontColor: coreTokens_default.color_grey_700,
    unvisitedHelperTextFontColor: coreTokens_default.color_grey_700,
    unvisitedStepBackgroundColor: coreTokens_default.color_transparent,
    unvisitedStepBorderColor: coreTokens_default.color_grey_700,
    selectedStepFontColor: coreTokens_default.color_white,
    selectedStepBackgroundColor: coreTokens_default.color_purple_700,
    selectedStepBorderColor: coreTokens_default.color_purple_700,
    selectedLabelFontColor: coreTokens_default.color_black,
    selectedHelperTextFontColor: coreTokens_default.color_black,
    selectedStepWidth: "32px",
    selectedStepHeight: "32px",
    selectedStepBorderThickness: "2px",
    selectedStepBorderStyle: coreTokens_default.border_solid,
    selectedStepBorderRadius: "45px",
    stepFontSize: coreTokens_default.type_scale_03,
    stepFontFamily: coreTokens_default.type_sans,
    stepFontStyle: coreTokens_default.type_normal,
    stepFontWeight: coreTokens_default.type_regular,
    stepFontTracking: coreTokens_default.type_spacing_wide_02,
    stepIconSize: "20px",
    stepWidth: "32px",
    stepHeight: "32px",
    stepBorderThickness: "2px",
    stepBorderStyle: coreTokens_default.border_solid,
    stepBorderRadius: "45px",
    visitedLabelFontColor: coreTokens_default.color_black,
    labelFontSize: coreTokens_default.type_scale_03,
    labelFontFamily: coreTokens_default.type_sans,
    labelFontStyle: coreTokens_default.type_normal,
    labelFontWeight: coreTokens_default.type_regular,
    labelFontTracking: coreTokens_default.type_spacing_normal,
    labelFontTextTransform: "none",
    labelTextAlign: "left",
    helperTextFontSize: coreTokens_default.type_scale_02,
    helperTextFontFamily: coreTokens_default.type_sans,
    helperTextFontStyle: coreTokens_default.type_normal,
    helperTextFontWeight: coreTokens_default.type_regular,
    helperTextFontTracking: coreTokens_default.type_spacing_normal,
    helperTextFontTextTransform: "none",
    visitedHelperTextFontColor: coreTokens_default.color_black,
    helperTextTextAlign: "left",
    disabledStepBackgroundColor: coreTokens_default.color_grey_100,
    disabledStepFontColor: coreTokens_default.color_grey_500,
    disabledLabelFontColor: coreTokens_default.color_grey_500,
    disabledHelperTextFontColor: coreTokens_default.color_grey_500,
    disabledStepBorderColor: coreTokens_default.color_grey_100,
    disabledStepWidth: "32px",
    disabledStepHeight: "32px",
    disabledStepBorderThickness: "2px",
    disabledStepBorderStyle: coreTokens_default.border_solid,
    disabledStepBorderRadius: "45px",
    separatorBorderThickness: "1px",
    separatorBorderStyle: coreTokens_default.border_solid,
    separatorColor: coreTokens_default.color_grey_700,
    focusColor: coreTokens_default.color_blue_600
  }
};
var spaces = {
  xxsmall: coreTokens_default.spacing_4,
  xsmall: coreTokens_default.spacing_8,
  small: coreTokens_default.spacing_12,
  medium: coreTokens_default.spacing_16,
  large: coreTokens_default.spacing_24,
  xlarge: coreTokens_default.spacing_32,
  xxlarge: coreTokens_default.spacing_48
};
var responsiveSizes = {
  xsmall: "20",
  small: "30",
  medium: "45",
  large: "66",
  xlarge: "90"
};
var defaultTranslatedComponentLabels = {
  applicationLayout: {
    visibilityToggleTitle: "Toggle sidenav visibility"
  },
  alert: {
    previousMessageActionTitle: "Previous message",
    nextMessageActionTitle: "Next message",
    closeAlertActionTitle: "Close alert",
    closeMessageActionTitle: "Close message"
  },
  calendar: {
    daysShort: ["Mo", "Tu", "We", "Th", "Fr", "Sa", "Su"],
    months: [
      "January",
      "February",
      "March",
      "April",
      "May",
      "June",
      "July",
      "August",
      "September",
      "October",
      "November",
      "December"
    ],
    previousMonthTitle: "Previous month",
    nextMonthTitle: "Next month"
  },
  dateInput: {
    invalidDateErrorMessage: "Invalid date."
  },
  dialog: {
    closeIconAriaLabel: "Close dialog"
  },
  fileInput: {
    fileSizeGreaterThanErrorMessage: "File size must be greater than min size.",
    fileSizeLessThanErrorMessage: "File size must be less than max size.",
    multipleButtonLabelDefault: "Select files",
    singleButtonLabelDefault: "Select file",
    dropAreaButtonLabelDefault: "Select",
    multipleDropAreaLabelDefault: "or drop files",
    singleDropAreaLabelDefault: "or drop a file",
    deleteFileActionTitle: "Remove file"
  },
  footer: {
    copyrightText: (year2) => `\xA9 DXC Technology ${year2}. All rights reserved.`
  },
  formFields: {
    optionalLabel: "(Optional)",
    requiredSelectionErrorMessage: "This field is required. Please, choose an option.",
    requiredValueErrorMessage: "This field is required. Please, enter a value.",
    formatRequestedErrorMessage: "Please match the format requested.",
    lengthErrorMessage: (minLength, maxLength) => `Min length ${minLength}, max length ${maxLength}.`,
    logoAlternativeText: "Logo"
  },
  header: {
    closeIcon: "Close menu",
    hamburgerTitle: "Menu"
  },
  numberInput: {
    valueGreaterThanOrEqualToErrorMessage: (value) => `Value must be greater than or equal to ${value}.`,
    valueLessThanOrEqualToErrorMessage: (value) => `Value must be less than or equal to ${value}.`,
    decrementValueTitle: "Decrement value",
    incrementValueTitle: "Increment value"
  },
  paginator: {
    itemsPerPageText: "Items per page: ",
    minToMaxOfText: (minNumberOfItems, maxNumberOfItems, totalItems) => `${minNumberOfItems} to ${maxNumberOfItems} of ${totalItems}`,
    goToPageText: "Go to page:",
    pageOfText: (pageNumber, totalPagesNumber) => `Page: ${pageNumber} of ${totalPagesNumber}`
  },
  passwordInput: {
    inputShowPasswordTitle: "Show password",
    inputHidePasswordTitle: "Hide password"
  },
  quickNav: {
    contentTitle: "Contents"
  },
  radioGroup: {
    optionalItemLabelDefault: "N/A"
  },
  select: {
    noMatchesErrorMessage: "No matches found",
    actionClearSelectionTitle: "Clear selection",
    actionClearSearchTitle: "Clear search"
  },
  tabs: {
    scrollLeft: "Scroll left",
    scrollRight: "Scroll right"
  },
  textInput: {
    clearFieldActionTitle: "Clear field",
    searchingMessage: "Searching...",
    fetchingDataErrorMessage: "Error fetching data"
  },
  toast: {
    clearToastActionTitle: "Clear toast"
  }
};

// src/common/utils.ts
var getMargin = (marginProp, side) => marginProp && typeof marginProp === "object" ? marginProp[side] && spaces[marginProp[side]] || "0px" : marginProp && typeof marginProp === "string" ? spaces[marginProp] : "0px";

// src/accordion/AccordionContext.tsx
import { createContext } from "react";
var AccordionContext_default = createContext(null);

// src/HalstackContext.tsx
import { createContext as createContext2, useMemo } from "react";
import Color from "color";
import { Fragment, jsx } from "react/jsx-runtime";
var HalstackContext = createContext2(componentTokens);
var HalstackLanguageContext = createContext2(defaultTranslatedComponentLabels);
var addLightness = (newLightness, hexColor) => {
  try {
    if (hexColor) {
      const color = Color(hexColor);
      const hslColor = color.hsl();
      const lightnessColor = hslColor.lightness();
      return hslColor.lightness(lightnessColor + newLightness).hex();
    }
    return null;
  } catch (e) {
    return null;
  }
};
var subLightness = (newLightness, hexColor) => {
  try {
    if (hexColor) {
      const color = Color(hexColor);
      const hslColor = color.hsl();
      const lightnessColor = hslColor.lightness();
      return hslColor.lightness(lightnessColor - newLightness).hex();
    }
    return null;
  } catch (e) {
    return null;
  }
};
var parseTheme = (theme) => {
  const componentTokensCopy = JSON.parse(JSON.stringify(componentTokens));
  const accordionTokens = componentTokensCopy.accordion;
  accordionTokens.assistiveTextFontColor = theme.accordion?.assistiveTextFontColor ?? accordionTokens.assistiveTextFontColor;
  accordionTokens.subLabelFontColor = theme.accordion?.subLabelFontColor ?? accordionTokens.subLabelFontColor;
  accordionTokens.titleLabelFontColor = theme.accordion?.titleFontColor ?? accordionTokens.titleLabelFontColor;
  accordionTokens.arrowColor = theme.accordion?.accentColor ?? accordionTokens.arrowColor;
  accordionTokens.iconColor = theme.accordion?.accentColor ?? accordionTokens.iconColor;
  accordionTokens.hoverBackgroundColor = addLightness(57, theme.accordion?.accentColor) ?? accordionTokens.hoverBackgroundColor;
  const buttonTokens = componentTokensCopy.button;
  buttonTokens.primaryDefaultFontColor = theme.button?.primaryFontColor ?? buttonTokens.primaryDefaultFontColor;
  buttonTokens.primaryDefaultBackgroundColor = theme.button?.baseColor ?? buttonTokens.primaryDefaultBackgroundColor;
  buttonTokens.secondaryDefaultFontColor = theme.button?.baseColor ?? buttonTokens.secondaryDefaultFontColor;
  buttonTokens.secondaryHoverDefaultFontColor = theme.button?.secondaryHoverFontColor ?? buttonTokens.secondaryHoverDefaultFontColor;
  buttonTokens.secondaryDefaultBorderColor = theme.button?.baseColor ?? buttonTokens.secondaryDefaultBorderColor;
  buttonTokens.secondaryHoverDefaultBackgroundColor = theme.button?.baseColor ?? buttonTokens.secondaryHoverDefaultBackgroundColor;
  buttonTokens.tertiaryDefaultFontColor = theme.button?.baseColor ?? buttonTokens.tertiaryDefaultFontColor;
  buttonTokens.primaryHoverDefaultBackgroundColor = subLightness(8, theme.button?.baseColor) ?? buttonTokens.primaryHoverDefaultBackgroundColor;
  buttonTokens.primaryActiveDefaultBackgroundColor = subLightness(18, theme.button?.baseColor) ?? buttonTokens.primaryActiveDefaultBackgroundColor;
  buttonTokens.secondaryActiveDefaultBackgroundColor = subLightness(18, theme.button?.baseColor) ?? buttonTokens.secondaryActiveDefaultBackgroundColor;
  buttonTokens.tertiaryHoverDefaultBackgroundColor = addLightness(57, theme.button?.baseColor) ?? buttonTokens.tertiaryHoverDefaultBackgroundColor;
  buttonTokens.tertiaryActiveDefaultBackgroundColor = addLightness(52, theme.button?.baseColor) ?? buttonTokens.tertiaryActiveDefaultBackgroundColor;
  buttonTokens.primaryDisabledDefaultBackgroundColor = addLightness(42, theme.button?.baseColor) ?? buttonTokens.primaryDisabledDefaultBackgroundColor;
  buttonTokens.primaryDisabledDefaultFontColor = addLightness(42, theme.button?.primaryFontColor) ?? buttonTokens.primaryDisabledDefaultFontColor;
  buttonTokens.secondaryDisabledDefaultBorderColor = addLightness(42, theme.button?.baseColor) ?? buttonTokens.secondaryDisabledDefaultBorderColor;
  buttonTokens.secondaryDisabledDefaultFontColor = addLightness(42, theme.button?.baseColor) ?? buttonTokens.secondaryDisabledDefaultFontColor;
  buttonTokens.tertiaryDisabledDefaultFontColor = addLightness(42, theme.button?.baseColor) ?? buttonTokens.tertiaryDisabledDefaultFontColor;
  const checkboxTokens = componentTokensCopy.checkbox;
  checkboxTokens.backgroundColorChecked = theme.checkbox?.baseColor ?? checkboxTokens.backgroundColorChecked;
  checkboxTokens.borderColor = theme.checkbox?.baseColor ?? checkboxTokens.borderColor;
  checkboxTokens.checkColor = theme.checkbox?.checkColor ?? checkboxTokens.checkColor;
  checkboxTokens.fontColor = theme.checkbox?.fontColor ?? checkboxTokens.fontColor;
  checkboxTokens.hoverBackgroundColorChecked = subLightness(15, theme.checkbox?.baseColor) ?? checkboxTokens.hoverBackgroundColorChecked;
  checkboxTokens.hoverBorderColor = subLightness(15, theme.checkbox?.baseColor) ?? checkboxTokens.hoverBorderColor;
  const chipTokens = componentTokensCopy.chip;
  chipTokens.backgroundColor = theme.chip?.baseColor ?? chipTokens.backgroundColor;
  chipTokens.fontColor = theme.chip?.fontColor ?? chipTokens.fontColor;
  chipTokens.iconColor = theme.chip?.iconColor ?? chipTokens.iconColor;
  chipTokens.hoverIconColor = subLightness(10, theme.chip?.iconColor) ?? chipTokens.hoverIconColor;
  chipTokens.activeIconColor = subLightness(30, theme.chip?.iconColor) ?? chipTokens.activeIconColor;
  const contextualMenuTokens = componentTokensCopy.contextualMenu;
  contextualMenuTokens.selectedMenuItemBackgroundColor = theme.contextualMenu?.accentColor ?? contextualMenuTokens.selectedMenuItemBackgroundColor;
  contextualMenuTokens.hoverSelectedMenuItemBackgroundColor = subLightness(5, theme.contextualMenu?.accentColor) ?? contextualMenuTokens.hoverSelectedMenuItemBackgroundColor;
  contextualMenuTokens.activeSelectedMenuItemBackgroundColor = subLightness(5, theme.contextualMenu?.accentColor) ?? contextualMenuTokens.activeSelectedMenuItemBackgroundColor;
  contextualMenuTokens.backgroundColor = theme.contextualMenu?.baseColor ?? contextualMenuTokens.backgroundColor;
  contextualMenuTokens.hoverMenuItemBackgroundColor = subLightness(5, theme.contextualMenu?.baseColor) ?? contextualMenuTokens.hoverMenuItemBackgroundColor;
  contextualMenuTokens.activeMenuItemBackgroundColor = subLightness(5, theme.contextualMenu?.baseColor) ?? contextualMenuTokens.activeMenuItemBackgroundColor;
  contextualMenuTokens.menuItemFontColor = theme.contextualMenu?.fontColor ?? contextualMenuTokens.menuItemFontColor;
  contextualMenuTokens.sectionTitleFontColor = theme.contextualMenu?.fontColor ?? contextualMenuTokens.sectionTitleFontColor;
  contextualMenuTokens.iconColor = theme.contextualMenu?.iconColor ?? contextualMenuTokens.iconColor;
  const dataGridTokens = componentTokensCopy.dataGrid;
  dataGridTokens.headerBackgroundColor = theme.dataGrid?.baseColor ?? dataGridTokens.headerBackgroundColor;
  dataGridTokens.headerFontColor = theme.dataGrid?.headerFontColor ?? dataGridTokens.headerFontColor;
  dataGridTokens.dataFontColor = theme.dataGrid?.cellFontColor ?? dataGridTokens.dataFontColor;
  dataGridTokens.headerCheckboxCheckColor = theme.dataGrid?.baseColor ?? dataGridTokens.headerCheckboxCheckColor;
  dataGridTokens.actionIconColor = theme.dataGrid?.baseColor ?? dataGridTokens.actionIconColor;
  dataGridTokens.hoverActionIconColor = theme.dataGrid?.baseColor ?? dataGridTokens.hoverActionIconColor;
  dataGridTokens.focusActionIconColor = theme.dataGrid?.baseColor ?? dataGridTokens.focusActionIconColor;
  dataGridTokens.activeActionIconColor = theme.dataGrid?.baseColor ?? dataGridTokens.activeActionIconColor;
  const dateTokens = componentTokensCopy.dateInput;
  dateTokens.pickerSelectedBackgroundColor = theme.dateInput?.baseColor ?? dateTokens.pickerSelectedBackgroundColor;
  dateTokens.pickerSelectedFontColor = theme.dateInput?.selectedFontColor ?? dateTokens.pickerSelectedFontColor;
  dateTokens.pickerActiveBackgroundColor = subLightness(8, theme.dateInput?.baseColor) ?? dateTokens.pickerActiveBackgroundColor;
  dateTokens.pickerActiveFontColor = theme.dateInput?.selectedFontColor ?? dateTokens.pickerActiveFontColor;
  dateTokens.pickerCurrentYearFontColor = theme.dateInput?.baseColor ?? dateTokens.pickerCurrentYearFontColor;
  dateTokens.pickerHeaderActiveBackgroundColor = subLightness(8, theme.dateInput?.baseColor) ?? dateTokens.pickerHeaderActiveBackgroundColor;
  dateTokens.pickerHeaderActiveFontColor = theme.dateInput?.selectedFontColor ?? dateTokens.pickerHeaderActiveFontColor;
  dateTokens.pickerHoverBackgroundColor = addLightness(52, theme.dateInput?.baseColor) ?? dateTokens.pickerHoverBackgroundColor;
  dateTokens.pickerCurrentDateBorderColor = addLightness(42, theme.dateInput?.baseColor) ?? dateTokens.pickerCurrentDateBorderColor;
  dateTokens.pickerHeaderHoverBackgroundColor = addLightness(52, theme.dateInput?.baseColor) ?? dateTokens.pickerHeaderHoverBackgroundColor;
  const dialogTokens = componentTokensCopy.dialog;
  dialogTokens.backgroundColor = theme.dialog?.baseColor ?? dialogTokens.backgroundColor;
  dialogTokens.closeIconColor = theme.dialog?.closeIconColor ?? dialogTokens.closeIconColor;
  dialogTokens.overlayColor = theme.dialog?.overlayColor ?? dialogTokens.overlayColor;
  const dropdownTokens = componentTokensCopy.dropdown;
  dropdownTokens.buttonBackgroundColor = theme.dropdown?.baseColor ?? dropdownTokens.buttonBackgroundColor;
  dropdownTokens.buttonFontColor = theme.dropdown?.fontColor ?? dropdownTokens.buttonFontColor;
  dropdownTokens.buttonIconColor = theme.dropdown?.fontColor ?? dropdownTokens.caretIconColor;
  dropdownTokens.caretIconColor = theme.dropdown?.fontColor ?? dropdownTokens.caretIconColor;
  dropdownTokens.optionFontColor = theme.dropdown?.optionFontColor ?? dropdownTokens.optionFontColor;
  dropdownTokens.optionIconColor = theme.dropdown?.optionFontColor ?? dropdownTokens.optionIconColor;
  dropdownTokens.hoverButtonBackgroundColor = subLightness(5, theme.dropdown?.baseColor) ?? dropdownTokens.hoverButtonBackgroundColor;
  dropdownTokens.activeButtonBackgroundColor = subLightness(12, theme.dropdown?.baseColor) ?? dropdownTokens.activeButtonBackgroundColor;
  dropdownTokens.hoverOptionBackgroundColor = subLightness(5, theme.dropdown?.baseColor) ?? dropdownTokens.hoverOptionBackgroundColor;
  dropdownTokens.activeOptionBackgroundColor = subLightness(20, theme.dropdown?.baseColor) ?? dropdownTokens.activeOptionBackgroundColor;
  const fileInputTokens = componentTokensCopy.fileInput;
  fileInputTokens.labelFontColor = theme.fileInput?.fontColor ?? fileInputTokens.labelFontColor;
  fileInputTokens.helperTextFontColor = theme.fileInput?.fontColor ?? fileInputTokens.helperTextFontColor;
  fileInputTokens.dropLabelFontColor = theme.fileInput?.fontColor ?? fileInputTokens.dropLabelFontColor;
  fileInputTokens.fileNameFontColor = theme.fileInput?.fontColor ?? fileInputTokens.fileNameFontColor;
  const footerTokens = componentTokensCopy.footer;
  footerTokens.backgroundColor = theme.footer?.baseColor ?? footerTokens.backgroundColor;
  footerTokens.bottomLinksFontColor = theme.footer?.fontColor ?? footerTokens.bottomLinksFontColor;
  footerTokens.copyrightFontColor = theme.footer?.fontColor ?? footerTokens.copyrightFontColor;
  footerTokens.socialLinksColor = theme.footer?.fontColor ?? footerTokens.socialLinksColor;
  footerTokens.bottomLinksDividerColor = theme.footer?.accentColor ?? footerTokens.bottomLinksDividerColor;
  footerTokens.logo = theme.footer?.logo ?? footerTokens.logo;
  const headerTokens = componentTokensCopy.header;
  headerTokens.backgroundColor = theme.header?.baseColor ?? headerTokens.backgroundColor;
  headerTokens.underlinedColor = theme.header?.accentColor ?? headerTokens.underlinedColor;
  headerTokens.menuBackgroundColor = theme.header?.menuBaseColor ?? headerTokens.menuBackgroundColor;
  headerTokens.hamburgerFontColor = theme.header?.fontColor ?? headerTokens.hamburgerFontColor;
  headerTokens.hamburgerIconColor = theme.header?.hamburgerColor ?? headerTokens.hamburgerIconColor;
  headerTokens.hamburgerHoverColor = addLightness(90, theme.header?.hamburgerColor) ?? headerTokens.hamburgerHoverColor;
  headerTokens.logo = theme.header?.logo ?? headerTokens.logo;
  headerTokens.logoResponsive = theme.header?.logoResponsive ?? headerTokens.logoResponsive;
  headerTokens.contentColor = theme.header?.contentColor ?? headerTokens.contentColor;
  headerTokens.overlayColor = theme.header?.overlayColor ?? headerTokens.overlayColor;
  const linkTokens = componentTokensCopy.link;
  linkTokens.visitedFontColor = theme.link?.baseColor ?? linkTokens.visitedFontColor;
  linkTokens.visitedUnderlineColor = theme.link?.baseColor ?? linkTokens.visitedUnderlineColor;
  const navTabsTokens = componentTokensCopy.navTabs;
  navTabsTokens.selectedFontColor = theme.navTabs?.baseColor ?? navTabsTokens.selectedFontColor;
  navTabsTokens.unselectedFontColor = theme.navTabs?.baseColor ?? navTabsTokens.selectedFontColor;
  navTabsTokens.selectedIconColor = theme.navTabs?.baseColor ?? navTabsTokens.selectedIconColor;
  navTabsTokens.unselectedIconColor = theme.navTabs?.baseColor ?? navTabsTokens.selectedIconColor;
  navTabsTokens.selectedUnderlineColor = theme.navTabs?.accentColor ?? navTabsTokens.selectedUnderlineColor;
  navTabsTokens.hoverBackgroundColor = addLightness(55, theme.navTabs?.baseColor) ?? navTabsTokens.hoverBackgroundColor;
  navTabsTokens.pressedBackgroundColor = addLightness(50, theme.navTabs?.baseColor) ?? navTabsTokens.pressedBackgroundColor;
  const paginatorTokens = componentTokensCopy.paginator;
  paginatorTokens.backgroundColor = theme.paginator?.baseColor ?? paginatorTokens.backgroundColor;
  paginatorTokens.fontColor = theme.paginator?.fontColor ?? paginatorTokens.fontColor;
  const progressBarTokens = componentTokensCopy.progressBar;
  progressBarTokens.trackLineColor = theme.progressBar?.accentColor ?? progressBarTokens.trackLineColor;
  progressBarTokens.totalLineColor = theme.progressBar?.baseColor ?? progressBarTokens.totalLineColor;
  progressBarTokens.labelFontColor = theme.progressBar?.fontColor ?? progressBarTokens.labelFontColor;
  progressBarTokens.valueFontColor = theme.progressBar?.fontColor ?? progressBarTokens.valueFontColor;
  progressBarTokens.helperTextFontColor = theme.progressBar?.fontColor ?? progressBarTokens.helperTextFontColor;
  progressBarTokens.overlayColor = theme.progressBar?.overlayColor ?? progressBarTokens.overlayColor;
  progressBarTokens.overlayFontColor = theme.progressBar?.overlayFontColor ?? progressBarTokens.overlayFontColor;
  const quickNavTokens = componentTokensCopy.quickNav;
  quickNavTokens.fontColor = theme.quickNav?.fontColor ?? quickNavTokens.fontColor;
  quickNavTokens.hoverFontColor = theme.quickNav?.accentColor ?? quickNavTokens.hoverFontColor;
  const radioGroupTokens = componentTokensCopy.radioGroup;
  radioGroupTokens.radioInputColor = theme.radioGroup?.baseColor ?? radioGroupTokens.radioInputColor;
  radioGroupTokens.labelFontColor = theme.radioGroup?.fontColor ?? radioGroupTokens.labelFontColor;
  radioGroupTokens.helperTextFontColor = theme.radioGroup?.fontColor ?? radioGroupTokens.helperTextFontColor;
  radioGroupTokens.radioInputLabelFontColor = theme.radioGroup?.fontColor ?? radioGroupTokens.radioInputLabelFontColor;
  radioGroupTokens.hoverRadioInputColor = subLightness(10, theme.radioGroup?.baseColor) ?? radioGroupTokens.radioInputColor;
  radioGroupTokens.activeRadioInputColor = subLightness(25, theme.radioGroup?.baseColor) ?? radioGroupTokens.radioInputColor;
  const selectTokens = componentTokensCopy.select;
  selectTokens.selectedListOptionBackgroundColor = theme.select?.selectedOptionBackgroundColor ?? selectTokens.selectedListOptionBackgroundColor;
  selectTokens.valueFontColor = theme.select?.fontColor ?? selectTokens.valueFontColor;
  selectTokens.labelFontColor = theme.select?.fontColor ?? selectTokens.labelFontColor;
  selectTokens.helperTextFontColor = theme.select?.fontColor ?? selectTokens.helperTextFontColor;
  selectTokens.listOptionFontColor = theme.select?.optionFontColor ?? selectTokens.listOptionFontColor;
  selectTokens.listOptionIconColor = theme.select?.optionFontColor ?? selectTokens.listOptionIconColor;
  selectTokens.placeholderFontColor = addLightness(30, theme.select?.fontColor) ?? selectTokens.placeholderFontColor;
  selectTokens.collapseIndicatorColor = theme.select?.fontColor ?? selectTokens.collapseIndicatorColor;
  selectTokens.hoverInputBorderColor = theme.select?.hoverBorderColor ?? selectTokens.hoverInputBorderColor;
  selectTokens.selectedHoverListOptionBackgroundColor = subLightness(5, theme.select?.selectedOptionBackgroundColor) ?? selectTokens.selectedHoverListOptionBackgroundColor;
  selectTokens.selectedActiveListOptionBackgroundColor = subLightness(15, theme.select?.selectedOptionBackgroundColor) ?? selectTokens.selectedActiveListOptionBackgroundColor;
  const sideNavTokens = componentTokensCopy.sidenav;
  sideNavTokens.backgroundColor = theme.sidenav?.baseColor ?? sideNavTokens.backgroundColor;
  const sliderTokens = componentTokensCopy.slider;
  sliderTokens.labelFontColor = theme.slider?.fontColor ?? sliderTokens.labelFontColor;
  sliderTokens.helperTextFontColor = theme.slider?.fontColor ?? sliderTokens.helperTextFontColor;
  sliderTokens.limitValuesFontColor = theme.slider?.fontColor ?? sliderTokens.limitValuesFontColor;
  sliderTokens.thumbBackgroundColor = theme.slider?.baseColor ?? sliderTokens.thumbBackgroundColor;
  sliderTokens.focusThumbBackgroundColor = theme.slider?.baseColor ?? sliderTokens.focusThumbBackgroundColor;
  sliderTokens.tickBackgroundColor = theme.slider?.baseColor ?? sliderTokens.tickBackgroundColor;
  sliderTokens.trackLineColor = theme.slider?.baseColor ?? sliderTokens.trackLineColor;
  sliderTokens.totalLineColor = theme.slider?.totalLineColor ?? sliderTokens.totalLineColor;
  sliderTokens.hoverThumbBackgroundColor = subLightness(15, theme.slider?.baseColor) ?? sliderTokens.thumbBackgroundColor;
  sliderTokens.activeThumbBackgroundColor = subLightness(15, theme.slider?.baseColor) ?? sliderTokens.thumbBackgroundColor;
  const spinnerTokens = componentTokensCopy.spinner;
  spinnerTokens.trackCircleColor = theme.spinner?.accentColor ?? spinnerTokens.trackCircleColor;
  spinnerTokens.totalCircleColor = theme.spinner?.baseColor ?? spinnerTokens.totalCircleColor;
  spinnerTokens.trackCircleColorOverlay = theme.spinner?.overlayColor ?? spinnerTokens.trackCircleColorOverlay;
  spinnerTokens.labelFontColor = theme.spinner?.fontColor ?? spinnerTokens.labelFontColor;
  spinnerTokens.progressValueFontColor = theme.spinner?.fontColor ?? spinnerTokens.progressValueFontColor;
  spinnerTokens.overlayLabelFontColor = theme.spinner?.overlayFontColor ?? spinnerTokens.overlayLabelFontColor;
  spinnerTokens.overlayProgressValueFontColor = theme.spinner?.overlayFontColor ?? spinnerTokens.overlayProgressValueFontColor;
  const switchTokens = componentTokensCopy.switch;
  switchTokens.checkedTrackBackgroundColor = theme.switch?.checkedBaseColor ?? switchTokens.checkedTrackBackgroundColor;
  switchTokens.labelFontColor = theme.switch?.fontColor ?? switchTokens.labelFontColor;
  switchTokens.disabledCheckedTrackBackgroundColor = addLightness(57, theme.switch?.checkedBaseColor) ?? switchTokens.disabledCheckedTrackBackgroundColor;
  const tableTokens = componentTokensCopy.table;
  tableTokens.headerBackgroundColor = theme.table?.baseColor ?? tableTokens.headerBackgroundColor;
  tableTokens.headerFontColor = theme.table?.headerFontColor ?? tableTokens.headerFontColor;
  tableTokens.dataFontColor = theme.table?.cellFontColor ?? tableTokens.dataFontColor;
  tableTokens.sortIconColor = theme.table?.headerFontColor ?? tableTokens.sortIconColor;
  tableTokens.actionIconColor = theme.table?.baseColor ?? tableTokens.actionIconColor;
  tableTokens.hoverActionIconColor = theme.table?.baseColor ?? tableTokens.hoverActionIconColor;
  tableTokens.focusActionIconColor = theme.table?.baseColor ?? tableTokens.focusActionIconColor;
  tableTokens.activeActionIconColor = theme.table?.baseColor ?? tableTokens.activeActionIconColor;
  const tabsTokens = componentTokensCopy.tabs;
  tabsTokens.selectedFontColor = theme.tabs?.baseColor ?? tabsTokens.selectedFontColor;
  tabsTokens.selectedIconColor = theme.tabs?.baseColor ?? tabsTokens.selectedIconColor;
  tabsTokens.selectedUnderlineColor = theme.tabs?.baseColor ?? tabsTokens.selectedUnderlineColor;
  tabsTokens.focusOutline = theme.tabs?.baseColor ?? tabsTokens.focusOutline;
  tabsTokens.hoverBackgroundColor = addLightness(57, theme.tabs?.baseColor) ?? tabsTokens.hoverBackgroundColor;
  tabsTokens.pressedBackgroundColor = addLightness(52, theme.tabs?.baseColor) ?? tabsTokens.pressedBackgroundColor;
  const tagTokens = componentTokensCopy.tag;
  tagTokens.fontColor = theme.tag?.fontColor ?? tagTokens.fontColor;
  tagTokens.iconColor = theme.tag?.iconColor ?? tagTokens.iconColor;
  const textInputTokens = componentTokensCopy.textInput;
  textInputTokens.labelFontColor = theme.textInput?.fontColor ?? textInputTokens.labelFontColor;
  textInputTokens.helperTextFontColor = theme.textInput?.fontColor ?? textInputTokens.helperTextFontColor;
  textInputTokens.valueFontColor = theme.textInput?.fontColor ?? textInputTokens.valueFontColor;
  textInputTokens.actionIconColor = theme.textInput?.fontColor ?? textInputTokens.actionIconColor;
  textInputTokens.hoverActionIconColor = theme.textInput?.fontColor ?? textInputTokens.hoverActionIconColor;
  textInputTokens.focusActionIconColor = theme.textInput?.fontColor ?? textInputTokens.focusActionIconColor;
  textInputTokens.activeActionIconColor = theme.textInput?.fontColor ?? textInputTokens.activeActionIconColor;
  textInputTokens.hoverBorderColor = theme.textInput?.hoverBorderColor ?? textInputTokens.hoverBorderColor;
  textInputTokens.suffixColor = addLightness(40, theme.textInput?.fontColor) ?? textInputTokens.suffixColor;
  textInputTokens.prefixColor = addLightness(40, theme.textInput?.fontColor) ?? textInputTokens.prefixColor;
  textInputTokens.placeholderFontColor = addLightness(30, theme.textInput?.fontColor) ?? textInputTokens.placeholderFontColor;
  const textareaTokens = componentTokensCopy.textarea;
  textareaTokens.labelFontColor = theme.textarea?.fontColor ?? textareaTokens.labelFontColor;
  textareaTokens.helperTextFontColor = theme.textarea?.fontColor ?? textareaTokens.helperTextFontColor;
  textareaTokens.valueFontColor = theme.textarea?.fontColor ?? textareaTokens.valueFontColor;
  textareaTokens.hoverBorderColor = theme.textarea?.hoverBorderColor ?? textareaTokens.hoverBorderColor;
  textareaTokens.placeholderFontColor = addLightness(30, theme.textarea?.fontColor) ?? textareaTokens.placeholderFontColor;
  const toggleGroupTokens = componentTokensCopy.toggleGroup;
  toggleGroupTokens.selectedBackgroundColor = theme.toggleGroup?.selectedBaseColor ?? toggleGroupTokens.selectedBackgroundColor;
  toggleGroupTokens.selectedFontColor = theme.toggleGroup?.selectedFontColor ?? toggleGroupTokens.selectedFontColor;
  toggleGroupTokens.unselectedBackgroundColor = theme.toggleGroup?.unselectedBaseColor ?? toggleGroupTokens.unselectedBackgroundColor;
  toggleGroupTokens.unselectedActiveBackgroundColor = theme.toggleGroup?.selectedBaseColor ?? toggleGroupTokens.unselectedActiveBackgroundColor;
  toggleGroupTokens.unselectedFontColor = theme.toggleGroup?.unselectedFontColor ?? toggleGroupTokens.unselectedFontColor;
  toggleGroupTokens.selectedHoverBackgroundColor = subLightness(8, theme.toggleGroup?.selectedBaseColor) ?? toggleGroupTokens.selectedHoverBackgroundColor;
  toggleGroupTokens.selectedActiveBackgroundColor = subLightness(18, theme.toggleGroup?.selectedBaseColor) ?? toggleGroupTokens.selectedActiveBackgroundColor;
  toggleGroupTokens.selectedDisabledBackgroundColor = addLightness(57, theme.toggleGroup?.selectedBaseColor) ?? toggleGroupTokens.selectedDisabledBackgroundColor;
  toggleGroupTokens.selectedDisabledFontColor = addLightness(42, theme.toggleGroup?.selectedBaseColor) ?? toggleGroupTokens.selectedDisabledFontColor;
  toggleGroupTokens.unselectedHoverBackgroundColor = subLightness(10, theme.toggleGroup?.unselectedBaseColor) ?? toggleGroupTokens.unselectedHoverBackgroundColor;
  const wizardTokens = componentTokensCopy.wizard;
  wizardTokens.selectedStepBackgroundColor = theme.wizard?.baseColor ?? wizardTokens.selectedStepBackgroundColor;
  wizardTokens.selectedStepFontColor = theme.wizard?.selectedStepFontColor ?? wizardTokens.selectedStepFontColor;
  wizardTokens.selectedStepBorderColor = theme.wizard?.baseColor ?? wizardTokens.selectedStepBorderColor;
  wizardTokens.visitedLabelFontColor = theme.wizard?.fontColor ?? wizardTokens.visitedLabelFontColor;
  wizardTokens.selectedLabelFontColor = theme.wizard?.fontColor ?? wizardTokens.selectedLabelFontColor;
  wizardTokens.visitedHelperTextFontColor = theme.wizard?.fontColor ?? wizardTokens.visitedHelperTextFontColor;
  wizardTokens.selectedHelperTextFontColor = theme.wizard?.fontColor ?? wizardTokens.selectedHelperTextFontColor;
  wizardTokens.unvisitedStepBorderColor = addLightness(40, theme.wizard?.fontColor) ?? wizardTokens.unvisitedStepBorderColor;
  wizardTokens.unvisitedStepFontColor = addLightness(40, theme.wizard?.fontColor) ?? wizardTokens.unvisitedStepFontColor;
  wizardTokens.unvisitedLabelFontColor = addLightness(40, theme.wizard?.fontColor) ?? wizardTokens.unvisitedLabelFontColor;
  wizardTokens.unvisitedHelperTextFontColor = addLightness(40, theme.wizard?.fontColor) ?? wizardTokens.unvisitedHelperTextFontColor;
  return componentTokensCopy;
};
var parseAdvancedTheme = (advancedTheme) => {
  const allTokensCopy = JSON.parse(JSON.stringify(componentTokens));
  Object.keys(allTokensCopy).forEach((component) => {
    const componentTheme = advancedTheme[component];
    if (componentTheme != null) {
      Object.keys(componentTheme).forEach((objectKey) => {
        if (componentTheme[objectKey]) {
          allTokensCopy[component][objectKey] = componentTheme[objectKey];
        }
      });
    }
  });
  return allTokensCopy;
};
var parseLabels = (labels) => {
  const parsedLabels = defaultTranslatedComponentLabels;
  Object.keys(labels).forEach((component) => {
    if (parsedLabels[component]) {
      const componentLabels = labels[component];
      if (componentLabels != null) {
        Object.keys(parsedLabels[component]).forEach((label) => {
          if (componentLabels[label]) {
            parsedLabels[component][label] = componentLabels[label];
          }
        });
      }
    }
  });
  return parsedLabels;
};
var HalstackProvider = ({ theme, advancedTheme, labels, children }) => {
  const parsedTheme = useMemo(
    () => theme ? parseTheme(theme) : advancedTheme ? parseAdvancedTheme(advancedTheme) : null,
    [theme, advancedTheme]
  );
  const parsedLabels = useMemo(() => labels ? parseLabels(labels) : null, [labels]);
  return /* @__PURE__ */ jsx(Fragment, { children: parsedTheme ? /* @__PURE__ */ jsx(HalstackContext.Provider, { value: parsedTheme, children: parsedLabels ? /* @__PURE__ */ jsx(HalstackLanguageContext.Provider, { value: parsedLabels, children }) : children }) : parsedLabels ? /* @__PURE__ */ jsx(HalstackLanguageContext.Provider, { value: parsedLabels, children }) : children });
};

// src/accordion/AccordionItem.tsx
import { useContext, useId, cloneElement, useMemo as useMemo2 } from "react";
import styled4, { ThemeProvider } from "styled-components";

// src/icon/Icon.tsx
import styled from "styled-components";
import { jsx as jsx2 } from "react/jsx-runtime";
var DxcIcon = ({ icon }) => /* @__PURE__ */ jsx2(
  IconContainer,
  {
    role: "img",
    filled: icon.startsWith("filled_"),
    icon: icon.startsWith("filled_") ? icon.replace(/filled_/g, "") : icon,
    "aria-hidden": "true"
  }
);
var IconContainer = styled.span`
  @import url("https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:FILL@0..1");
  font-family: "Material Symbols Outlined";
  font-weight: normal;
  font-style: normal;
  line-height: 1;
  letter-spacing: normal;
  text-transform: none;
  display: inline-block;
  white-space: nowrap;
  word-wrap: normal;
  direction: ltr;
  -webkit-font-feature-settings: "liga";
  -webkit-font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  -moz-osx-font-smoothing: grayscale;
  font-variation-settings: ${(props) => props.filled ? "'FILL' 1" : "'FILL' 0"};
  ::before {
    content: "${(props) => props.icon}";
  }
`;
var Icon_default = DxcIcon;

// src/flex/Flex.tsx
import styled2 from "styled-components";
import { jsx as jsx3 } from "react/jsx-runtime";
var Flex = styled2.div`
  display: flex;
  ${(props) => `
    ${typeof props.alignContent === "string" ? `align-content: ${props.alignContent};` : ""}
    ${typeof props.alignItems === "string" ? `align-items: ${props.alignItems};` : ""}
    ${typeof props.alignSelf === "string" ? `align-self: ${props.alignSelf};` : ""}
    ${typeof props.$basis === "string" ? `flex-basis: ${props.$basis};` : ""}
    ${typeof props.$direction === "string" ? `flex-direction: ${props.$direction};` : ""}
    ${typeof props.$gap === "string" ? `gap: ${props.$gap};` : ""}
    ${typeof props.$gap === "object" ? `column-gap: ${props.$gap.columnGap}; row-gap: ${props.$gap.rowGap};` : ""}
    ${typeof props.$grow === "number" ? `flex-grow: ${props.$grow};` : ""}
    ${typeof props.justifyContent === "string" ? `justify-content: ${props.justifyContent};` : ""}
    ${typeof props.$order === "number" ? `order: ${props.$order};` : ""}
    ${typeof props.$shrink === "number" ? `flex-shrink: ${props.$shrink};` : ""}
    ${typeof props.$wrap === "string" ? `flex-wrap: ${props.$wrap};` : ""}
  `}
`;
var DxcFlex = ({
  basis,
  direction,
  gap,
  grow,
  order,
  shrink,
  wrap,
  ...props
}) => /* @__PURE__ */ jsx3(
  Flex,
  {
    $basis: basis,
    $direction: direction,
    $gap: gap,
    $grow: grow,
    $order: order,
    $shrink: shrink,
    $wrap: wrap,
    ...props
  }
);
var Flex_default = DxcFlex;

// src/container/Container.tsx
import styled3 from "styled-components";
import { jsx as jsx4 } from "react/jsx-runtime";
var getBorderStyles = (direction, borderProperties) => `border-${direction}: ${borderProperties.width ?? ""} ${borderProperties.style ?? ""} ${borderProperties.color ? getCoreColorToken(borderProperties.color) : ""};`;
var Container = styled3.div`
  box-sizing: ${({ boxSizing }) => boxSizing};
  display: ${({ $display }) => $display};
  width: ${({ $width }) => $width};
  height: ${({ $height }) => $height};
  max-width: ${({ maxWidth }) => maxWidth};
  max-height: ${({ maxHeight }) => maxHeight};
  min-width: ${({ minWidth }) => minWidth};
  min-height: ${({ minHeight }) => minHeight};
  position: ${({ position }) => position};
  top: ${({ inset }) => inset?.top};
  right: ${({ inset }) => inset?.right};
  bottom: ${({ inset }) => inset?.bottom};
  left: ${({ inset }) => inset?.left};
  float: ${({ float }) => float};
  z-index: ${({ zIndex }) => zIndex};
  box-shadow: ${({ boxShadow }) => boxShadow};
  background-attachment: ${({ background }) => background?.attachment};
  background-clip: ${({ background }) => background?.clip};
  background-color: ${({ background }) => background?.color ? getCoreColorToken(background?.color) : ""};
  background-image: ${({ background }) => background?.image};
  background-origin: ${({ background }) => background?.origin};
  background-position: ${({ background }) => background?.position};
  background-repeat: ${({ background }) => background?.repeat};
  background-size: ${({ background }) => background?.size};
  border-radius: ${({ borderRadius }) => borderRadius};
  border-width: ${({ border }) => border && "width" in border ? `${border?.width}` : ""};
  border-style: ${({ border }) => border && "style" in border ? `${border?.style}` : ""};
  border-color: ${({ border }) => border && "color" in border && border?.color ? `${getCoreColorToken(border?.color)}` : ""};
  ${({ border }) => {
  let styles = "";
  if (border != null) {
    switch (true) {
      case "top" in border:
        styles += border.top ? getBorderStyles("top", border.top) : "";
      case "right" in border:
        styles += border.right ? getBorderStyles("right", border.right) : "";
      case "left" in border:
        styles += border.left ? getBorderStyles("left", border.left) : "";
      case "bottom" in border:
        styles += border.bottom ? getBorderStyles("bottom", border.bottom) : "";
    }
  }
  return styles;
}};
  margin: ${({ margin }) => typeof margin === "string" ? spaces[margin] : ""};
  margin-top: ${({ margin }) => typeof margin === "object" && margin.top ? spaces[margin.top] : ""};
  margin-right: ${({ margin }) => typeof margin === "object" && margin.right ? spaces[margin.right] : ""};
  margin-bottom: ${({ margin }) => typeof margin === "object" && margin.bottom ? spaces[margin.bottom] : ""};
  margin-left: ${({ margin }) => typeof margin === "object" && margin.left ? spaces[margin.left] : ""};
  outline: ${({ outline }) => `${outline?.width ?? ""} ${outline?.style ?? ""} ${outline?.color ? getCoreColorToken(outline?.color) : ""}`};
  outline-offset: ${({ outline }) => outline?.offset};
  overflow: ${({ $overflow }) => typeof $overflow === "string" ? $overflow : ""};
  overflow-x: ${({ $overflow }) => typeof $overflow === "object" ? `${$overflow?.x}` : ""};
  overflow-y: ${({ $overflow }) => typeof $overflow === "object" ? `${$overflow?.y}` : ""};
  padding: ${({ padding }) => typeof padding === "string" ? spaces[padding] : ""};
  padding-top: ${({ padding }) => typeof padding === "object" && padding.top ? spaces[padding.top] : ""};
  padding-right: ${({ padding }) => typeof padding === "object" && padding.right ? spaces[padding.right] : ""};
  padding-bottom: ${({ padding }) => typeof padding === "object" && padding.bottom ? spaces[padding.bottom] : ""};
  padding-left: ${({ padding }) => typeof padding === "object" && padding.left ? spaces[padding.left] : ""};
`;
function DxcContainer({ display, width, height, overflow, ...props }) {
  return /* @__PURE__ */ jsx4(Container, { $display: display, $width: width, $height: height, $overflow: overflow, ...props });
}

// src/accordion/AccordionItem.tsx
import React from "react";
import { jsx as jsx5, jsxs } from "react/jsx-runtime";
var AccordionItem = ({
  label = "",
  subLabel = "",
  badge,
  statusLight,
  icon,
  assistiveText = "",
  disabled = false,
  children,
  tabIndex = 0
}) => {
  const id = useId();
  const colorsTheme = useContext(HalstackContext);
  const { activeIndex, handlerActiveChange, index, independent } = useContext(AccordionContext_default) ?? {};
  const isItemExpanded = useMemo2(() => {
    return independent ? activeIndex === index : Array.isArray(activeIndex) && index !== void 0 && activeIndex.includes(index);
  }, [independent, activeIndex, index]);
  const handleAccordionState = () => {
    if (index !== void 0) handlerActiveChange?.(index);
  };
  return /* @__PURE__ */ jsx5(ThemeProvider, { theme: colorsTheme.accordion, children: /* @__PURE__ */ jsxs(AccordionContainer, { children: [
    /* @__PURE__ */ jsx5(
      AccordionTrigger,
      {
        id: `accordion-${id}`,
        onClick: disabled ? void 0 : handleAccordionState,
        disabled,
        tabIndex: disabled ? -1 : tabIndex,
        "aria-expanded": isItemExpanded,
        "aria-controls": `accordion-panel-${id}`,
        children: /* @__PURE__ */ jsx5(DxcContainer, { width: "100%", height: "100%", children: /* @__PURE__ */ jsxs(Flex_default, { gap: "1.5rem", children: [
          /* @__PURE__ */ jsx5(LeftSideContainer, { children: /* @__PURE__ */ jsxs(Flex_default, { gap: "0.75rem", children: [
            (icon || badge?.position === "before") && /* @__PURE__ */ jsx5(OptionalElement, { children: icon ? /* @__PURE__ */ jsx5(IconContainer2, { disabled, children: typeof icon === "string" ? /* @__PURE__ */ jsx5(Icon_default, { icon }) : icon }) : /* @__PURE__ */ jsx5(StatusContainer, { subLabel, children: disabled ? cloneElement(badge?.element, { color: "grey" }) : badge?.element }) }),
            /* @__PURE__ */ jsxs(LabelsContainer, { children: [
              /* @__PURE__ */ jsx5(AccordionLabel, { disabled, children: label }),
              subLabel && /* @__PURE__ */ jsx5(SubLabel, { disabled, children: subLabel })
            ] })
          ] }) }),
          /* @__PURE__ */ jsxs(RightSideContainer, { children: [
            assistiveText && /* @__PURE__ */ jsx5(AssistiveText, { disabled, subLabel, children: assistiveText }),
            badge && badge?.position === "after" && !assistiveText && /* @__PURE__ */ jsx5(StatusContainer, { subLabel, children: disabled ? React.cloneElement(badge.element, { color: "grey" }) : badge.element }),
            badge?.position !== "after" && statusLight && !assistiveText && /* @__PURE__ */ jsx5(StatusContainer, { subLabel, children: disabled ? React.cloneElement(statusLight, { mode: "default" }) : statusLight }),
            /* @__PURE__ */ jsx5(CollapseIndicator, { disabled, children: /* @__PURE__ */ jsx5(Icon_default, { icon: isItemExpanded ? "expand_less" : "expand_more" }) })
          ] })
        ] }) })
      }
    ),
    isItemExpanded && /* @__PURE__ */ jsx5(AccordionPanel, { id: `accordion-panel-${id}`, role: "region", "aria-labelledby": `accordion-${id}`, children })
  ] }) });
};
var AccordionContainer = styled4.div`
  display: flex;
  flex-direction: column;
  background-color: ${(props) => props.theme.backgroundColor};
  border-radius: ${(props) => props.theme.borderRadius};
  box-shadow: ${(props) => `${props.theme.boxShadowOffsetX} ${props.theme.boxShadowOffsetY} ${props.theme.boxShadowBlur} ${props.theme.boxShadowSpread} ${props.theme.boxShadowColor}`};
  min-width: 280px;
  width: 100%;
`;
var AccordionTrigger = styled4.button`
  display: flex;
  justify-content: space-between;
  gap: 1.5rem;
  width: 100%;
  background-color: transparent;
  border: none;
  border-radius: ${(props) => props.theme.borderRadius};
  padding: 8px 16px;
  cursor: ${(props) => props.disabled ? "not-allowed" : "pointer"};
  :focus {
    background-color: ${(props) => `${props.theme.focusBackgroundColor}`};
    box-shadow: inset 0 0 0 ${(props) => props.theme.focusBorderThickness} ${(props) => props.theme.focusBorderColor};
  }
  :focus-visible {
    background-color: ${(props) => `${props.theme.focusBackgroundColor}`};
    box-shadow: inset 0 0 0 ${(props) => props.theme.focusBorderThickness} ${(props) => props.theme.focusBorderColor};
    outline: none;
  }
  :active:enabled {
    background-color: ${(props) => `${props.theme.activeBackgroundColor}`};
    box-shadow: inset 0 0 0 ${(props) => props.theme.focusBorderThickness} ${(props) => props.theme.focusBorderColor};
  }
  :hover:enabled {
    background-color: ${(props) => `${props.theme.hoverBackgroundColor}`};
  }
`;
var LeftSideContainer = styled4.div`
  flex: 1;
  overflow: hidden;
`;
var RightSideContainer = styled4.div`
  display: flex;
  overflow: hidden;
  justify-content: flex-end;
  gap: 0.5rem;
  max-width: 30%;
  flex-shrink: 0;
`;
var OptionalElement = styled4.div`
  max-width: 30%;
  overflow: hidden;
`;
var LabelsContainer = styled4.div`
  display: flex;
  flex-direction: column;
  overflow: hidden;
`;
var StatusContainer = styled4.div`
  display: flex;
  align-items: ${(props) => props.subLabel ? "flex-start" : "center"};
  margin-top: ${(props) => props.subLabel && "4px"};
`;
var IconContainer2 = styled4.span`
  display: flex;
  color: ${(props) => props.disabled ? props.theme.disabledIconColor : props.theme.iconColor};
  font-size: ${(props) => props.theme.iconSize};
  svg {
    height: ${(props) => props.theme.iconSize};
    width: ${(props) => props.theme.iconSize};
  }
`;
var AccordionLabel = styled4.span`
  color: ${(props) => props.disabled ? props.theme.disabledTitleLabelFontColor : props.theme.titleLabelFontColor};
  font-family: ${(props) => props.theme.titleLabelFontFamily};
  font-size: ${(props) => props.theme.titleLabelFontSize};
  font-style: ${(props) => props.theme.titleLabelFontStyle};
  font-weight: ${(props) => props.theme.titleLabelFontWeight};
  line-height: 1.5em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  text-align: left;
`;
var SubLabel = styled4.span`
  height: 20px;
  color: ${(props) => props.disabled ? props.theme.disabledSubLabelFontColor : props.theme.subLabelFontColor};
  font-family: ${(props) => props.theme.subLabelFontFamily};
  font-size: ${(props) => props.theme.subLabelFontSize};
  font-style: ${(props) => props.theme.subLabelFontStyle};
  font-weight: ${(props) => props.theme.subLabelFontWeight};
  line-height: 1.5em;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  text-align: left;
`;
var AssistiveText = styled4.span`
  color: ${(props) => props.disabled ? props.theme.disabledAssistiveTextFontColor : props.theme.assistiveTextFontColor};
  font-family: ${(props) => props.theme.assistiveTextFontFamily};
  font-size: ${(props) => props.theme.assistiveTextFontSize};
  font-style: ${(props) => props.theme.assistiveTextFontStyle};
  font-weight: ${(props) => props.theme.assistiveTextFontWeight};
  line-height: 1.5em;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  align-content: ${(props) => !props.subLabel && "center"};
  margin-top: ${(props) => props.subLabel && "4px"};
`;
var CollapseIndicator = styled4.span`
  display: flex;
  flex-wrap: wrap;
  font-size: 24px;
  color: ${(props) => props.disabled ? props.theme.disabledArrowColor : props.theme.arrowColor};
  svg {
    height: ${(props) => props.theme.iconSize};
    width: ${(props) => props.theme.iconSize};
  }
`;
var AccordionPanel = styled4.div`
  border-bottom-left-radius: ${(props) => props.theme.borderRadius};
  border-bottom-right-radius: ${(props) => props.theme.borderRadius};
`;
var AccordionItem_default = AccordionItem;

// src/accordion/Accordion.tsx
import { jsx as jsx6 } from "react/jsx-runtime";
var DxcAccordion = (props) => {
  const { children, margin, onActiveChange } = props;
  const colorsTheme = useContext2(HalstackContext);
  const [innerIndexActive, setInnerIndexActive] = useState(
    props.independent ? props.defaultIndexActive ?? -1 : Array.isArray(props.defaultIndexActive) ? props.defaultIndexActive.filter((i) => i !== void 0) : []
  );
  const handlerActiveChange = useCallback(
    (index) => {
      if (props.indexActive == null) {
        setInnerIndexActive((prev) => {
          if (props.independent) return typeof index === "number" ? index === prev ? -1 : index : prev;
          else {
            const prevArray = Array.isArray(prev) ? prev : [];
            return Array.isArray(index) ? index : prevArray.includes(index) ? prevArray.filter((i) => i !== index) : [...prevArray, index];
          }
        });
      }
      onActiveChange?.(index);
    },
    [props.indexActive, props.independent, onActiveChange, innerIndexActive]
  );
  const contextValue = useMemo3(
    () => ({
      activeIndex: props.indexActive ?? innerIndexActive,
      handlerActiveChange,
      independent: props.independent
    }),
    [props.indexActive, innerIndexActive, handlerActiveChange, props.independent]
  );
  return /* @__PURE__ */ jsx6(ThemeProvider2, { theme: colorsTheme.accordion, children: /* @__PURE__ */ jsx6(AccordionContainer2, { margin, children: Children.map(children, (accordion, index) => /* @__PURE__ */ jsx6(AccordionContext_default.Provider, { value: { index, ...contextValue }, children: accordion }, `accordion-${index}`)) }) });
};
DxcAccordion.AccordionItem = AccordionItem_default;
var calculateWidth = (margin) => `calc(100% - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})`;
var AccordionContainer2 = styled5.div`
  width: ${(props) => calculateWidth(props.margin)};
  margin: ${({ margin }) => margin && typeof margin !== "object" ? spaces[margin] : "0px"};
  margin-top: ${({ margin }) => margin && typeof margin === "object" && margin.top ? spaces[margin.top] : ""};
  margin-right: ${({ margin }) => margin && typeof margin === "object" && margin.right ? spaces[margin.right] : ""};
  margin-bottom: ${({ margin }) => margin && typeof margin === "object" && margin.bottom ? spaces[margin.bottom] : ""};
  margin-left: ${({ margin }) => margin && typeof margin === "object" && margin.left ? spaces[margin.left] : ""};
  cursor: "pointer";

  // first and middle accordions (separator)
  > div:not(:last-of-type):not(:only-of-type) {
    border-bottom: ${(props) => `${props.theme.accordionSeparatorBorderThickness} ${props.theme.accordionSeparatorBorderStyle}`};
    border-color: ${(props) => props.theme.accordionSeparatorBorderColor};
  }

  // first accordion
  > div:first-of-type:not(:only-of-type) {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    border-top-left-radius: ${(props) => props.theme.borderRadius};
    border-top-right-radius: ${(props) => props.theme.borderRadius};
  }

  // first accordion: hover, focus and active
  > div:first-of-type:not(:only-of-type) button:hover,
  div:first-of-type:not(:only-of-type) button:focus,
  div:first-of-type:not(:only-of-type) button:active {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
  }

  // middle accordions
  > div:not(:first-of-type):not(:last-of-type):not(:only-of-type) {
    border-radius: 0;
  }

  // middle accordions: hover, focus and active
  > div:not(:first-of-type):not(:last-of-type):not(:only-of-type) button:hover,
  div:not(:first-of-type):not(:last-of-type):not(:only-of-type) button:focus,
  div:not(:first-of-type):not(:last-of-type):not(:only-of-type) button:active {
    border-radius: 0;
  }

  // last accordion
  > div:last-of-type:not(:only-of-type) {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    border-bottom-left-radius: ${(props) => props.theme.borderRadius};
    border-bottom-right-radius: ${(props) => props.theme.borderRadius};
  }

  // last accordion: hover, focus and active
  > div:last-of-type:not(:only-of-type) button:hover,
  div:last-of-type:not(:only-of-type) button:focus,
  div:last-of-type:not(:only-of-type) button:active {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    border-bottom-left-radius: ${(props) => props.theme.borderRadius};
    border-bottom-right-radius: ${(props) => props.theme.borderRadius};
  }

  // last expanded accordion
  > div:last-of-type:not(:only-of-type) > button[aria-expanded="true"] {
    border-radius: 0;
  }
  // last expanded accordion: hover, focus and active
  > div:last-of-type:not(:only-of-type) > button[aria-expanded="true"]:hover,
  div:last-of-type:not(:only-of-type) > button[aria-expanded="true"]:focus,
  div:last-of-type:not(:only-of-type) > button[aria-expanded="true"]:active {
    border-radius: 0;
  }
`;
var Accordion_default = DxcAccordion;

// src/alert/Alert.tsx
import styled11, { css, ThemeProvider as ThemeProvider4 } from "styled-components";
import { useState as useState3, memo, useId as useId2, useEffect as useEffect2, useCallback as useCallback3, useContext as useContext5 } from "react";

// src/button/Button.tsx
import { useContext as useContext4 } from "react";
import styled7, { ThemeProvider as ThemeProvider3 } from "styled-components";

// src/tooltip/Tooltip.tsx
import styled6 from "styled-components";
import { useContext as useContext3 } from "react";
import { Root, Trigger, Portal, Arrow, Content } from "@radix-ui/react-tooltip";
import { Provider } from "@radix-ui/react-tooltip";

// src/tooltip/TooltipContext.tsx
import { createContext as createContext3 } from "react";
var TooltipContext = createContext3(false);

// src/tooltip/Tooltip.tsx
import { Fragment as Fragment2, jsx as jsx7, jsxs as jsxs2 } from "react/jsx-runtime";
var TooltipTriggerContainer = styled6.div`
  position: relative;
  display: inline-flex;
`;
var StyledTooltipContent = styled6(Content)`
  z-index: 2147483647;

  animation-duration: 0.2s;
  animation-timing-function: ease-out;

  /* Additional optimization to prevent blurry text in certain browsers */
  -webkit-font-smoothing: antialiased;
  transform: translateZ(0) scale(1, 1);

  &[data-side="top"] {
    animation-name: slideUp;
  }
  &[data-side="bottom"] {
    animation-name: slideDown;
  }
  &[data-side="left"] {
    animation-name: slideLeft;
  }
  &[data-side="right"] {
    animation-name: slideRight;
  }
  @keyframes slideDown {
    from {
      opacity: 0;
      transform: translateY(-10px);
    }
    to {
      opacity: 1;
      transform: translateY(0);
    }
  }
  @keyframes slideUp {
    from {
      opacity: 0;
      transform: translateY(10px);
    }
    to {
      opacity: 1;
      transform: translateY(0);
    }
  }
  @keyframes slideLeft {
    from {
      opacity: 0;
      transform: translateX(10px);
    }
    to {
      opacity: 1;
      transform: translateX(0);
    }
  }
  @keyframes slideRight {
    from {
      opacity: 0;
      transform: translateX(-10px);
    }
    to {
      opacity: 1;
      transform: translateX(0);
    }
  }
`;
var TooltipContainer = styled6.div`
  box-sizing: border-box;
  max-width: 242px;
  border-radius: 4px;
  border-color: ${coreTokens_default.color_grey_800};
  padding: 8px 12px;
  font-size: ${coreTokens_default.type_scale_01};
  font-family: ${coreTokens_default.type_sans};
  color: ${coreTokens_default.color_white};
  background-color: ${coreTokens_default.color_grey_800};
  overflow-wrap: break-word;
`;
var triangleIcon = /* @__PURE__ */ jsx7(
  "svg",
  {
    width: "12",
    height: "6",
    viewBox: "0 0 12 6",
    xmlns: "http://www.w3.org/2000/svg",
    preserveAspectRatio: "none",
    display: "block",
    children: /* @__PURE__ */ jsx7(
      "path",
      {
        d: "M0.351562 0L5.30131 4.94975C5.69184 5.34027 6.325 5.34027 6.71552 4.94975L11.6653 0H6.00842H0.351562Z",
        fill: coreTokens_default.color_grey_800
      }
    )
  }
);
var Tooltip = ({
  label,
  hasAdditionalContainer = false,
  position = "bottom",
  children
}) => {
  const hasTooltip = useContext3(TooltipContext);
  return /* @__PURE__ */ jsx7(TooltipContext.Provider, { value: true, children: label && !hasTooltip ? /* @__PURE__ */ jsx7(Provider, { delayDuration: 300, children: /* @__PURE__ */ jsxs2(Root, { children: [
    /* @__PURE__ */ jsx7(Trigger, { asChild: true, children: hasAdditionalContainer ? /* @__PURE__ */ jsx7(TooltipTriggerContainer, { children }) : children }),
    /* @__PURE__ */ jsx7(Portal, { children: /* @__PURE__ */ jsxs2(StyledTooltipContent, { side: position, sideOffset: 8, children: [
      /* @__PURE__ */ jsx7(TooltipContainer, { children: label }),
      /* @__PURE__ */ jsx7(Arrow, { asChild: true, "aria-hidden": true, children: triangleIcon })
    ] }) })
  ] }) }) : children });
};
var TooltipWrapper = ({ condition, children, label }) => condition ? /* @__PURE__ */ jsx7(Tooltip, { label, children }) : /* @__PURE__ */ jsx7(Fragment2, { children });
function DxcTooltip(props) {
  return /* @__PURE__ */ jsx7(Tooltip, { ...props, hasAdditionalContainer: true });
}

// src/button/Button.tsx
import { jsx as jsx8, jsxs as jsxs3 } from "react/jsx-runtime";
var DxcButton = ({
  label = "",
  mode = "primary",
  semantic = "default",
  disabled = false,
  iconPosition = "before",
  title,
  type = "button",
  icon,
  onClick = () => {
  },
  margin,
  size = { height: "large", width: "fitContent" },
  tabIndex = 0
}) => {
  const colorsTheme = useContext4(HalstackContext);
  return /* @__PURE__ */ jsx8(ThemeProvider3, { theme: colorsTheme.button, children: /* @__PURE__ */ jsx8(Tooltip, { label: title, children: /* @__PURE__ */ jsxs3(
    Button,
    {
      "aria-label": title,
      disabled,
      onClick: () => {
        onClick();
      },
      tabIndex: disabled ? -1 : tabIndex,
      type,
      $mode: mode,
      hasLabel: !!label,
      hasIcon: !!icon,
      iconPosition,
      size,
      margin,
      semantic,
      children: [
        label && /* @__PURE__ */ jsx8(LabelContainer, { children: label }),
        icon && /* @__PURE__ */ jsx8(IconContainer3, { size, children: typeof icon === "string" ? /* @__PURE__ */ jsx8(Icon_default, { icon }) : icon })
      ]
    }
  ) }) });
};
var widths = {
  small: "42px",
  medium: "120px",
  large: "240px",
  fillParent: "100%",
  fitContent: "fit-content"
};
var calculateWidth2 = (margin, size) => size?.width === "fillParent" ? `calc(${widths[size?.width]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size?.width && widths[size?.width];
var getHeight = (height) => {
  switch (height) {
    case "small":
      return 1.5;
    case "medium":
      return 2;
    case "large":
      return 2.5;
    default:
      return 2.5;
  }
};
var getButtonStyles = ($mode, semantic, theme, size) => {
  let enabled = "";
  let hover = "";
  let active = "";
  let focus = "";
  let disabled = "";
  const commonPrimaryStyles = `
    font-weight: ${theme.primaryFontWeight};
    font-size: ${size?.height === "small" ? theme.primarySmallFontSize : size?.height === "medium" ? theme.primaryMediumFontSize : theme.primaryLargeFontSize};
    font-family: ${theme.primaryFontFamily};
    border-radius: ${theme.primaryBorderRadius};
    border-width ${theme.primaryBorderThickness};
    border-style: ${theme.primaryBorderStyle};`;
  const commonSecondaryStyles = `
    font-weight: ${theme.secondaryFontWeight};
    font-size: ${size?.height === "small" ? theme.secondarySmallFontSize : size?.height === "medium" ? theme.secondaryMediumFontSize : theme.secondaryLargeFontSize};
    font-family: ${theme.secondaryFontFamily};
    border-radius: ${theme.secondaryBorderRadius};
    border-width ${theme.secondaryBorderThickness};
    border-style: ${theme.secondaryBorderStyle};`;
  const commonTertiaryStyles = `
    font-weight: ${theme.tertiaryFontWeight};
    font-size: ${size?.height === "small" ? theme.tertiarySmallFontSize : size?.height === "medium" ? theme.tertiaryMediumFontSize : theme.tertiaryLargeFontSize};
    font-family: ${theme.tertiaryFontFamily};
    border-radius: ${theme.tertiaryBorderRadius};
    border-width ${theme.tertiaryBorderThickness};
    border-style: ${theme.tertiaryBorderStyle};`;
  switch ($mode) {
    case "primary":
      switch (semantic) {
        case "default":
          enabled = `background-color: ${theme.primaryDefaultBackgroundColor};
          color: ${theme.primaryDefaultFontColor};`;
          hover = `background-color: ${theme.primaryHoverDefaultBackgroundColor};`;
          active = `background-color: ${theme.primaryActiveDefaultBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.primaryDisabledDefaultBackgroundColor};
          color: ${theme.primaryDisabledDefaultFontColor};`;
          break;
        case "error":
          enabled = `background-color: ${theme.primaryErrorBackgroundColor};
          color: ${theme.primaryErrorFontColor};`;
          hover = `background-color: ${theme.primaryHoverErrorBackgroundColor};`;
          active = `background-color: ${theme.primaryActiveErrorBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.primaryDisabledErrorBackgroundColor};
          color: ${theme.primaryDisabledErrorFontColor};`;
          break;
        case "warning":
          enabled = `background-color: ${theme.primaryWarningBackgroundColor};
          color: ${theme.primaryWarningFontColor};`;
          hover = `background-color: ${theme.primaryHoverWarningBackgroundColor};`;
          active = `background-color: ${theme.primaryActiveWarningBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.primaryDisabledWarningBackgroundColor};
          color: ${theme.primaryDisabledWarningFontColor};`;
          break;
        case "success":
          enabled = `background-color: ${theme.primarySuccessBackgroundColor};
          color: ${theme.primarySuccessFontColor};`;
          hover = `background-color: ${theme.primaryHoverSuccessBackgroundColor};`;
          active = `background-color: ${theme.primaryActiveSuccessBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.primaryDisabledSuccessBackgroundColor};
          color: ${theme.primaryDisabledSuccessFontColor};`;
          break;
        case "info":
          enabled = `background-color: ${theme.primaryInfoBackgroundColor};
          color: ${theme.primaryInfoFontColor};`;
          hover = `background-color: ${theme.primaryHoverInfoBackgroundColor};`;
          active = `background-color: ${theme.primaryActiveInfoBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.primaryDisabledInfoBackgroundColor};
          color: ${theme.primaryDisabledInfoFontColor};`;
          break;
        default:
          enabled = `background-color: ${theme.primaryDefaultBackgroundColor};
          color: ${theme.primaryDefaultFontColor};`;
          break;
      }
      return `${commonPrimaryStyles}
        ${enabled}
        &:hover {
          ${hover}
        }
        &:active {
          ${active}
        }
        &:focus {
          ${focus}
        }
        &:disabled {
          ${disabled}
        }`;
    case "secondary":
      switch (semantic) {
        case "default":
          enabled = `background-color: ${theme.secondaryDefaultBackgroundColor};
          color: ${theme.secondaryDefaultFontColor};
          border-color ${theme.secondaryDefaultBorderColor};`;
          hover = `background-color: ${theme.secondaryHoverDefaultBackgroundColor};
          color: ${theme.secondaryHoverDefaultFontColor};`;
          active = `background-color: ${theme.secondaryActiveDefaultBackgroundColor};
          color: ${theme.secondaryHoverDefaultFontColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          focus = `border-color: transparent;`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.secondaryDisabledDefaultBackgroundColor};
          color: ${theme.secondaryDisabledDefaultFontColor};
          border-color: ${theme.secondaryDisabledDefaultBorderColor};`;
          break;
        case "error":
          enabled = `background-color: ${theme.secondaryErrorBackgroundColor};
          color: ${theme.secondaryErrorFontColor};
          border-color ${theme.secondaryErrorBorderColor};`;
          hover = `background-color: ${theme.secondaryHoverErrorBackgroundColor};
          color: ${theme.secondaryHoverErrorFontColor};`;
          active = `background-color: ${theme.secondaryActiveErrorBackgroundColor};
          color: ${theme.secondaryHoverErrorFontColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          focus = `border-color: transparent;`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.secondaryDisabledErrorBackgroundColor};
          color: ${theme.secondaryDisabledErrorFontColor};
          border-color: ${theme.secondaryDisabledErrorBorderColor};`;
          break;
        case "warning":
          enabled = `background-color: ${theme.secondaryWarningBackgroundColor};
          color: ${theme.secondaryWarningFontColor};
          border-color ${theme.secondaryWarningBorderColor};`;
          hover = `background-color: ${theme.secondaryHoverWarningBackgroundColor};
          color: ${theme.secondaryHoverWarningFontColor};`;
          active = `background-color: ${theme.secondaryActiveWarningBackgroundColor};
          color: ${theme.secondaryHoverWarningFontColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          focus = `border-color: transparent;`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.secondaryDisabledWarningBackgroundColor};
          color: ${theme.secondaryDisabledWarningFontColor};
          border-color: ${theme.secondaryDisabledWarningBorderColor};`;
          break;
        case "success":
          enabled = `background-color: ${theme.secondarySuccessBackgroundColor};
          color: ${theme.secondarySuccessFontColor};
          border-color ${theme.secondarySuccessBorderColor};`;
          hover = `background-color: ${theme.secondaryHoverSuccessBackgroundColor};
          color: ${theme.secondaryHoverSuccessFontColor};`;
          active = `background-color: ${theme.secondaryActiveSuccessBackgroundColor};
          color: ${theme.secondaryHoverSuccessFontColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          focus = `border-color: transparent;`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.secondaryDisabledSuccessBackgroundColor};
          color: ${theme.secondaryDisabledSuccessFontColor};
          border-color: ${theme.secondaryDisabledSuccessBorderColor};`;
          break;
        case "info":
          enabled = `background-color: ${theme.secondaryInfoBackgroundColor};
          color: ${theme.secondaryInfoFontColor};
          border-color ${theme.secondaryInfoBorderColor};`;
          hover = `background-color: ${theme.secondaryHoverInfoBackgroundColor};
          color: ${theme.secondaryHoverInfoFontColor};`;
          active = `background-color: ${theme.secondaryActiveInfoBackgroundColor};
          color: ${theme.secondaryHoverInfoFontColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          focus = `border-color: transparent;`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.secondaryDisabledInfoBackgroundColor};
          color: ${theme.secondaryDisabledInfoFontColor};
          border-color: ${theme.secondaryDisabledInfoBorderColor};`;
          break;
        default:
          enabled = `background-color: ${theme.secondaryDefaultBackgroundColor};
          color: ${theme.secondaryDefaultFontColor};
          border-color ${theme.secondaryDefaultBorderColor};`;
          break;
      }
      return `${commonSecondaryStyles}
        ${enabled}
        &:hover {
          ${hover}
        }
        &:active {
          ${active}
        }
        &:focus {
          ${focus}
        }
        &:disabled {
          ${disabled}
        }`;
    case "tertiary":
      switch (semantic) {
        case "default":
          enabled = `background-color: ${theme.tertiaryDefaultBackgroundColor};
            color: ${theme.tertiaryDefaultFontColor};`;
          hover = `background-color: ${theme.tertiaryHoverDefaultBackgroundColor};`;
          active = `background-color: ${theme.tertiaryActiveDefaultBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.tertiaryDisabledDefaultBackgroundColor};
          color: ${theme.tertiaryDisabledDefaultFontColor};`;
          break;
        case "error":
          enabled = `background-color: ${theme.tertiaryErrorBackgroundColor};
            color: ${theme.tertiaryErrorFontColor};`;
          hover = `background-color: ${theme.tertiaryHoverErrorBackgroundColor};`;
          active = `background-color: ${theme.tertiaryActiveErrorBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.tertiaryDisabledErrorBackgroundColor};
          color: ${theme.tertiaryDisabledErrorFontColor};`;
          break;
        case "warning":
          enabled = `background-color: ${theme.tertiaryWarningBackgroundColor};
            color: ${theme.tertiaryWarningFontColor};`;
          hover = `background-color: ${theme.tertiaryHoverWarningBackgroundColor};`;
          active = `background-color: ${theme.tertiaryActiveWarningBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.tertiaryDisabledWarningBackgroundColor};
          color: ${theme.tertiaryDisabledWarningFontColor};`;
          break;
        case "success":
          enabled = `background-color: ${theme.tertiarySuccessBackgroundColor};
            color: ${theme.tertiarySuccessFontColor};`;
          hover = `background-color: ${theme.tertiaryHoverSuccessBackgroundColor};`;
          active = `background-color: ${theme.tertiaryActiveSuccessBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.tertiaryDisabledSuccessBackgroundColor};
          color: ${theme.tertiaryDisabledSuccessFontColor};`;
          break;
        case "info":
          enabled = `background-color: ${theme.tertiaryInfoBackgroundColor};
            color: ${theme.tertiaryInfoFontColor};`;
          hover = `background-color: ${theme.tertiaryHoverInfoBackgroundColor};`;
          active = `background-color: ${theme.tertiaryActiveInfoBackgroundColor};
          border-color: transparent;
          outline: none;
          box-shadow: 0 0 0 2px ${theme.focusBorderColor};`;
          disabled = `cursor: not-allowed;
          background-color: ${theme.tertiaryDisabledInfoBackgroundColor};
          color: ${theme.tertiaryDisabledInfoFontColor};`;
          break;
        default:
          enabled = `background-color: ${theme.tertiaryDefaultBackgroundColor};
            color: ${theme.tertiaryDefaultFontColor};`;
          break;
      }
      return `${commonTertiaryStyles}
        ${enabled}
        &:hover {
          ${hover}
        }
        &:active {
          ${active}
        }
        &:focus {
          ${focus}
        }
        &:disabled {
          ${disabled}
        }`;
    default:
      return void 0;
  }
};
var Button = styled7.button`
  display: inline-flex;
  flex-direction: ${(props) => props.iconPosition === "after" ? "row" : "row-reverse"};
  gap: 0.5rem;
  align-items: center;
  justify-content: center;
  height: ${(props) => `${getHeight(props.size?.height && props.size?.height)}rem`};
  width: ${(props) => calculateWidth2(props.margin, props.size)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  padding-top: ${(props) => props.hasIcon && !props.hasLabel ? props.size?.height === "small" ? props.theme.paddingSmallOnlyIconTop : props.size?.height === "medium" ? props.theme.paddingMediumOnlyIconTop : props.theme.paddingLargeOnlyIconTop : props.size?.height === "small" ? props.theme.paddingSmallTop : props.size?.height === "medium" ? props.theme.paddingMediumTop : props.theme.paddingLargeTop};
  padding-bottom: ${(props) => props.hasIcon && !props.hasLabel ? props.size?.height === "small" ? props.theme.paddingSmallOnlyIconBottom : props.size?.height === "medium" ? props.theme.paddingMediumOnlyIconBottom : props.theme.paddingLargeOnlyIconBottom : props.size?.height === "small" ? props.theme.paddingSmallBottom : props.size?.height === "medium" ? props.theme.paddingMediumBottom : props.theme.paddingLargeBottom};
  padding-left: ${(props) => props.hasIcon && !props.hasLabel ? props.size?.height === "small" ? props.theme.paddingSmallOnlyIconLeft : props.size?.height === "medium" ? props.theme.paddingMediumOnlyIconLeft : props.theme.paddingLargeOnlyIconLeft : props.size?.height === "small" ? props.theme.paddingSmallLeft : props.size?.height === "medium" ? props.theme.paddingMediumLeft : props.theme.paddingLargeLeft};
  padding-right: ${(props) => props.hasIcon && !props.hasLabel ? props.size?.height === "small" ? props.theme.paddingSmallOnlyIconRight : props.size?.height === "medium" ? props.theme.paddingMediumOnlyIconRight : props.theme.paddingLargeOnlyIconRight : props.size?.height === "small" ? props.theme.paddingSmallRight : props.size?.height === "medium" ? props.theme.paddingMediumRight : props.theme.paddingLargeRight};

  box-shadow: 0 0 0 2px transparent;
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-weight: ${(props) => props.theme.fontWeight};
  letter-spacing: ${(props) => props.theme.labelLetterSpacing};
  cursor: pointer;

  &:focus {
    outline: none;
    box-shadow: 0 0 0 2px ${(props) => props.theme.focusBorderColor};
  }

  ${(props) => getButtonStyles(props.$mode, props.semantic, props.theme, props.size)};
`;
var LabelContainer = styled7.span`
  line-height: ${(props) => props.theme.labelFontLineHeight};
  font-size: ${(props) => props.theme.fontSize};
  text-overflow: ellipsis;
  overflow: hidden;
  text-transform: none;
  white-space: nowrap;
`;
var IconContainer3 = styled7.div`
  display: flex;
  font-size: ${(props) => props.size?.height === "small" ? "16" : props.size?.height === "medium" ? "16" : "24"}px;
  svg {
    height: ${(props) => props.size?.height === "small" ? "16" : props.size?.height === "medium" ? "16" : "24"}px;
    width: ${(props) => props.size?.height === "small" ? "16" : props.size?.height === "medium" ? "16" : "24"}px;
  }
`;
var Button_default = DxcButton;

// src/divider/Divider.tsx
import styled8 from "styled-components";
import { jsx as jsx9 } from "react/jsx-runtime";
var DxcDivider = ({
  orientation = "horizontal",
  weight = "regular",
  color = "mediumGrey",
  decorative = true
}) => /* @__PURE__ */ jsx9(
  StyledDivider,
  {
    orientation,
    weight,
    color,
    "aria-orientation": orientation,
    "aria-hidden": decorative
  }
);
var StyledDivider = styled8.hr`
  ${({ orientation, weight, color }) => `
    border-color: ${color === "lightGrey" ? coreTokens_default.color_grey_200 : color === "mediumGrey" ? coreTokens_default.color_grey_400 : coreTokens_default.color_grey_700};
    ${orientation === "horizontal" ? "width" : "min-height"}: 100%;
    ${orientation === "horizontal" ? "height" : "width"}: 0px;
    ${orientation === "horizontal" ? "border-width: " + (weight === "regular" ? "1px 0 0 0" : "2px 0 0 0") : "border-width: " + (weight === "regular" ? "0 0 0 1px" : "0 0 0 2px")};
    margin: 0px;
  `}
`;
var Divider_default = DxcDivider;

// src/action-icon/ActionIcon.tsx
import { forwardRef } from "react";
import styled9 from "styled-components";
import { jsx as jsx10 } from "react/jsx-runtime";
var ActionIcon = styled9.button`
  all: unset;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  border-radius: 2px;
  width: 24px;
  height: 24px;
  ${(props) => props.disabled ? `cursor: not-allowed;` : `cursor: pointer;`}
  box-shadow: 0 0 0 2px transparent;
  background-color: ${(props) => props.disabled ? props.theme.disabledActionBackgroundColor ?? coreTokens_default.color_transparent : props.theme.actionBackgroundColor ?? coreTokens_default.color_transparent};
  color: ${(props) => props.disabled ? props.theme.disabledActionIconColor ?? coreTokens_default.color_grey_500 : props.theme.actionIconColor ?? coreTokens_default.color_grey_900};

  ${(props) => !props.disabled && `
      &:focus,
      &:focus-visible {
        outline: none;
        box-shadow: 0 0 0 2px ${props.theme.focusActionBorderColor ?? coreTokens_default.color_blue_600};
        color: ${props.theme.focusActionIconColor ?? coreTokens_default.color_grey_900};
      }
      &:hover {
        background-color: ${props.theme.hoverActionBackgroundColor ?? coreTokens_default.color_grey_100};
        color: ${props.theme.hoverActionIconColor ?? coreTokens_default.color_grey_900};
      }
      &:active {
        background-color: ${props.theme.activeActionBackgroundColor ?? coreTokens_default.color_grey_300};
        color: ${props.theme.activeActionIconColor ?? coreTokens_default.color_grey_900};
      }
    `}

  font-size: 16px;  
  > svg {
    width: 16px;
    height: 16px;
  }
`;
var ActionIcon_default = forwardRef(
  ({ disabled = false, title, icon, onClick, tabIndex }, ref) => /* @__PURE__ */ jsx10(Tooltip, { label: title, children: /* @__PURE__ */ jsx10(
    ActionIcon,
    {
      "aria-label": title,
      disabled,
      onClick,
      onMouseDown: (event) => {
        event.stopPropagation();
      },
      tabIndex,
      type: "button",
      ref,
      children: typeof icon === "string" ? /* @__PURE__ */ jsx10(Icon_default, { icon }) : icon
    }
  ) })
);

// src/alert/ModalAlertWrapper.tsx
import { createPortal } from "react-dom";
import styled10, { createGlobalStyle } from "styled-components";

// src/utils/FocusLock.tsx
import { useCallback as useCallback2, useEffect, useRef, useState as useState2 } from "react";
import { Fragment as Fragment3, jsx as jsx11, jsxs as jsxs4 } from "react/jsx-runtime";
var not = {
  negTabIndex: ':not([tabindex^="-"])',
  disabled: ":not(:disabled)"
};
var focusableQuery = [
  `a[href]${not.negTabIndex}`,
  `area[href]${not.negTabIndex}`,
  `input:not([type="hidden"])${not.negTabIndex}${not.disabled}`,
  `select${not.negTabIndex}${not.disabled}`,
  `textarea${not.negTabIndex}${not.disabled}`,
  `button${not.negTabIndex}${not.disabled}`,
  `details > summary:first-of-type${not.negTabIndex}`,
  `iframe${not.negTabIndex}`,
  `audio[controls]${not.negTabIndex}`,
  `video[controls]${not.negTabIndex}`,
  `[contenteditable]${not.negTabIndex}`,
  `[tabindex]${not.negTabIndex}${not.disabled}`
].join(",");
var getFocusableElements = (container) => Array.prototype.slice.call(container.querySelectorAll(focusableQuery)).filter(
  (element) => element.getAttribute("aria-hidden") !== "true" && window.getComputedStyle(element).display !== "none" && window.getComputedStyle(element).visibility !== "hidden"
);
var attemptFocus = (element) => {
  element.focus();
  return document.activeElement === element;
};
var radixPortalContains = (activeElement) => {
  const radixPortals = document.querySelectorAll("[data-radix-portal]");
  const radixPoppers = document.querySelectorAll("[data-radix-popper-content-wrapper]");
  return Array.prototype.slice.call(radixPortals).some((portal) => portal.contains(activeElement)) || Array.prototype.slice.call(radixPoppers).some((popper) => popper.contains(activeElement));
};
var useFocusableElements = (ref) => {
  const [focusableElements, setFocusableElements] = useState2(null);
  useEffect(() => {
    if (ref.current != null) {
      setFocusableElements(getFocusableElements(ref.current));
      const observer = new MutationObserver(() => {
        if (ref.current != null) setFocusableElements(getFocusableElements(ref.current));
      });
      observer.observe(ref.current, { childList: true, subtree: true });
      return () => {
        observer.disconnect();
      };
    }
  }, []);
  return focusableElements;
};
var FocusLock = ({ children }) => {
  const childrenContainerRef = useRef(null);
  const focusableElements = useFocusableElements(childrenContainerRef);
  const initialFocus = useRef(false);
  const focusFirst = useCallback2(() => {
    if (focusableElements != null) {
      if (focusableElements.length === 0) childrenContainerRef.current?.focus();
      else if (focusableElements.length > 0) focusableElements.some((element) => attemptFocus(element));
    }
  }, [focusableElements]);
  const focusLast = () => {
    focusableElements?.slice().reverse().some((element) => attemptFocus(element));
  };
  const focusLock = (event) => {
    if (event.key === "Tab" && focusableElements?.length === 0) event.preventDefault();
  };
  useEffect(() => {
    if (focusableElements != null && !initialFocus.current) {
      initialFocus.current = true;
      focusFirst();
    }
  }, [focusableElements, focusFirst]);
  useEffect(() => {
    const focusGuardHandler = (event) => {
      const target = event.relatedTarget;
      const container = childrenContainerRef.current;
      if (target != null && !(container?.contains(target) || container?.nextElementSibling?.contains(target) || container?.previousElementSibling?.contains(target) || radixPortalContains(target)))
        focusFirst();
    };
    document.addEventListener("focusout", focusGuardHandler);
    return () => {
      document.removeEventListener("focusout", focusGuardHandler);
    };
  }, [focusFirst]);
  return /* @__PURE__ */ jsxs4(Fragment3, { children: [
    /* @__PURE__ */ jsx11("div", { onFocus: focusLast, tabIndex: 0 }),
    /* @__PURE__ */ jsx11(
      "div",
      {
        onKeyDown: focusLock,
        ref: childrenContainerRef,
        tabIndex: focusableElements?.length === 0 ? 0 : -1,
        style: { outline: "none" },
        children
      }
    ),
    /* @__PURE__ */ jsx11("div", { onFocus: focusFirst, tabIndex: 0 })
  ] });
};
var FocusLock_default = FocusLock;

// src/alert/ModalAlertWrapper.tsx
import { Fragment as Fragment4, jsx as jsx12, jsxs as jsxs5 } from "react/jsx-runtime";
var BodyStyle = createGlobalStyle`
  body {
    overflow: hidden;
  }
`;
var Modal = styled10.div`
  position: fixed;
  inset: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  z-index: 2147483647;
`;
var Overlay = styled10.div`
  position: fixed;
  inset: 0;
  height: 100%;
  background-color: ${(props) => props.theme.overlayColor};
`;
var ModalAlertContainer = styled10.div`
  position: relative;
  box-sizing: border-box;
  max-width: 80%;
  min-width: 696px;
  z-index: 2147483647;

  @media (max-width: ${responsiveSizes.medium}rem) {
    max-width: 92%;
    min-width: 92%;
  }
`;
var ModalAlertWrapper = ({ condition, onClose, children }) => condition ? /* @__PURE__ */ jsxs5(Fragment4, { children: [
  /* @__PURE__ */ jsx12(BodyStyle, {}),
  createPortal(
    /* @__PURE__ */ jsxs5(Modal, { children: [
      /* @__PURE__ */ jsx12(Overlay, { onClick: onClose }),
      /* @__PURE__ */ jsx12(ModalAlertContainer, { children: /* @__PURE__ */ jsx12(FocusLock_default, { children }) })
    ] }),
    document.body
  )
] }) : children;
var ModalAlertWrapper_default = ModalAlertWrapper;

// src/alert/Alert.tsx
import { Fragment as Fragment5, jsx as jsx13, jsxs as jsxs6 } from "react/jsx-runtime";
var AlertContainer = styled11.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  gap: ${coreTokens_default.spacing_8};
  ${(props) => (props.mode === "modal" || props.mode === "inline") && `border-radius: ${coreTokens_default.border_radius_medium};`};
  padding: ${(props) => props.mode === "modal" ? coreTokens_default.spacing_24 : props.mode === "inline" ? coreTokens_default.spacing_12 : `${coreTokens_default.spacing_8} ${coreTokens_default.spacing_12}`};
  background-color: ${(props) => props.mode === "modal" && props.theme.modalBackgroundColor || props.semantic === "info" && props.theme.infoBackgroundColor || props.semantic === "success" && props.theme.successBackgroundColor || props.semantic === "warning" && props.theme.warningBackgroundColor || props.semantic === "error" && props.theme.errorBackgroundColor};
  overflow: hidden;
`;
var TitleContainer = styled11.div`
  flex-grow: 1;
  display: flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_8};
  color: ${(props) => props.semantic === "info" && props.theme.infoIconColor || props.semantic === "success" && props.theme.successIconColor || props.semantic === "warning" && props.theme.warningIconColor || props.semantic === "error" && props.theme.errorIconColor};
  font-size: ${(props) => props.theme.iconSize};
  overflow: hidden;
`;
var typographyStyles = css`
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  color: ${(props) => props.theme.fontColor};
`;
var Title = styled11.span`
  ${typographyStyles}
  ${(props) => props.mode === "modal" && `font-size: ${props.theme.modalTitleFontSize}`};
  font-weight: ${(props) => props.theme.modalTitleFontWeight};
`;
var Message = styled11.div`
  ${typographyStyles}
  white-space: ${(props) => props.mode === "banner" && "nowrap"};
  text-overflow: ${(props) => props.mode === "banner" && "ellipsis"};
  overflow: ${(props) => props.mode === "banner" && "hidden"};

  > strong {
    font-weight: ${(props) => props.theme.modalTitleFontWeight};
  }
`;
var NavigationText = styled11.span`
  ${typographyStyles}
  white-space: nowrap;
`;
var Actions = memo(
  ({
    mode,
    primaryAction,
    secondaryAction,
    semantic
  }) => (primaryAction != null || secondaryAction != null) && /* @__PURE__ */ jsxs6(Flex_default, { gap: "0.5rem", alignSelf: mode === "inline" || mode === "modal" ? "flex-end" : void 0, children: [
    secondaryAction?.onClick && /* @__PURE__ */ jsx13(
      Button_default,
      {
        icon: secondaryAction.icon,
        label: secondaryAction.label,
        mode: "secondary",
        semantic,
        size: { height: mode === "modal" ? "medium" : "small" },
        onClick: secondaryAction.onClick
      }
    ),
    primaryAction?.onClick && /* @__PURE__ */ jsx13(
      Button_default,
      {
        icon: primaryAction.icon,
        label: primaryAction.label,
        semantic,
        size: { height: mode === "modal" ? "medium" : "small" },
        onClick: primaryAction.onClick
      }
    )
  ] })
);
var getIcon = (semantic) => {
  switch (semantic) {
    case "info":
      return /* @__PURE__ */ jsx13(Icon_default, { icon: "filled_info" });
    case "success":
      return /* @__PURE__ */ jsx13(Icon_default, { icon: "filled_check_circle" });
    case "warning":
      return /* @__PURE__ */ jsx13(Icon_default, { icon: "filled_warning" });
    case "error":
      return /* @__PURE__ */ jsx13(Icon_default, { icon: "filled_cancel" });
  }
};
function DxcAlert({
  closable = true,
  message = [],
  mode = "inline",
  primaryAction,
  secondaryAction,
  semantic = "info",
  title = ""
}) {
  const [messages, setMessages] = useState3(Array.isArray(message) ? message : [message]);
  const [currentIndex, setCurrentIndex] = useState3(0);
  const id = useId2();
  const colorsTheme = useContext5(HalstackContext);
  const translatedLabels = useContext5(HalstackLanguageContext);
  const handleNextOnClick = () => {
    setCurrentIndex((prevIndex) => prevIndex < messages.length ? prevIndex + 1 : prevIndex);
  };
  const handlePrevOnClick = useCallback3(() => {
    setCurrentIndex((prevIndex) => prevIndex > 0 ? prevIndex - 1 : prevIndex);
  }, []);
  const handleOnClose = () => {
    messages[currentIndex]?.onClose?.();
    if (mode !== "modal") {
      setMessages((prevMessages) => prevMessages.filter((_, index) => index !== currentIndex));
    }
  };
  useEffect2(() => {
    if (currentIndex === messages.length) handlePrevOnClick();
  }, [currentIndex, messages, handlePrevOnClick]);
  return /* @__PURE__ */ jsx13(ThemeProvider4, { theme: colorsTheme.alert, children: /* @__PURE__ */ jsx13(ModalAlertWrapper_default, { condition: mode === "modal", onClose: handleOnClose, children: /* @__PURE__ */ jsxs6(
    AlertContainer,
    {
      role: mode === "modal" ? "alertdialog" : "alert",
      "aria-modal": mode === "modal" ? true : void 0,
      "aria-labelledby": mode === "modal" ? `${id}-title` : void 0,
      "aria-describedby": mode === "modal" ? `${id}-message` : void 0,
      semantic,
      mode,
      children: [
        /* @__PURE__ */ jsxs6(Flex_default, { gap: "0.75rem", alignItems: "center", children: [
          /* @__PURE__ */ jsxs6(TitleContainer, { mode, semantic, children: [
            getIcon(semantic),
            mode === "banner" ? /* @__PURE__ */ jsxs6(Message, { mode, children: [
              /* @__PURE__ */ jsx13("strong", { children: title }),
              messages.length > 0 && /* @__PURE__ */ jsxs6(Fragment5, { children: [
                " - ",
                messages[currentIndex]?.text
              ] })
            ] }) : /* @__PURE__ */ jsx13(Title, { id: `${id}-title`, mode, children: title })
          ] }),
          mode === "banner" && /* @__PURE__ */ jsx13(
            Actions,
            {
              semantic,
              mode,
              primaryAction,
              secondaryAction
            }
          ),
          messages.length > 1 && /* @__PURE__ */ jsxs6(Flex_default, { alignItems: "center", gap: "0.25rem", children: [
            /* @__PURE__ */ jsx13(
              ActionIcon_default,
              {
                icon: "chevron_left",
                title: translatedLabels.alert.previousMessageActionTitle,
                onClick: handlePrevOnClick,
                disabled: currentIndex === 0
              }
            ),
            /* @__PURE__ */ jsxs6(NavigationText, { children: [
              currentIndex + 1,
              " of ",
              messages.length
            ] }),
            /* @__PURE__ */ jsx13(
              ActionIcon_default,
              {
                icon: "chevron_right",
                title: translatedLabels.alert.nextMessageActionTitle,
                onClick: handleNextOnClick,
                disabled: currentIndex === messages.length - 1
              }
            )
          ] }),
          closable && /* @__PURE__ */ jsxs6(Flex_default, { gap: "0.25rem", children: [
            mode !== "modal" && /* @__PURE__ */ jsx13(Divider_default, { orientation: "vertical" }),
            /* @__PURE__ */ jsx13(
              ActionIcon_default,
              {
                icon: "close",
                title: messages.length > 1 ? translatedLabels.alert.closeMessageActionTitle : translatedLabels.alert.closeAlertActionTitle,
                onClick: handleOnClose
              }
            )
          ] })
        ] }),
        mode === "modal" && /* @__PURE__ */ jsx13(Divider_default, {}),
        mode !== "banner" && /* @__PURE__ */ jsxs6(Fragment5, { children: [
          messages.length > 0 && /* @__PURE__ */ jsx13(Message, { id: `${id}-message`, mode, children: messages[currentIndex]?.text }),
          /* @__PURE__ */ jsx13(
            Actions,
            {
              semantic,
              mode,
              primaryAction,
              secondaryAction
            }
          )
        ] })
      ]
    }
  ) }) });
}

// src/layout/ApplicationLayout.tsx
import { useContext as useContext11, useEffect as useEffect6, useRef as useRef4, useState as useState9 } from "react";
import styled19 from "styled-components";

// src/footer/Footer.tsx
import { useMemo as useMemo4, useContext as useContext6 } from "react";
import styled12, { ThemeProvider as ThemeProvider5 } from "styled-components";

// src/footer/Icons.tsx
import { jsx as jsx14, jsxs as jsxs7 } from "react/jsx-runtime";
var dxcLogo = /* @__PURE__ */ jsxs7("svg", { xmlns: "http://www.w3.org/2000/svg", width: "100%", height: "32", viewBox: "0 0 280.781 32", children: [
  /* @__PURE__ */ jsx14("title", { children: "DXC Logo" }),
  /* @__PURE__ */ jsxs7("g", { children: [
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M171.5-54.124v12.539h-3.6V-54.124h-4.973v-3.191h13.54v3.191H171.5",
        transform: "translate(-68.528 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M189.96-41.585V-57.315h12.326v3.079h-8.753v3.191h7.7v3.078h-7.7v3.3h8.87v3.078H189.96",
        transform: "translate(-77.56 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M223.558-41.438a8.1,8.1,0,0,1-8.382-8.1v-.045a8.161,8.161,0,0,1,8.522-8.146,8.6,8.6,0,0,1,6.444,2.431l-2.289,2.543a6.133,6.133,0,0,0-4.178-1.778,4.743,4.743,0,0,0-4.738,4.905v.045a4.752,4.752,0,0,0,4.738,4.95,6,6,0,0,0,4.295-1.845l2.288,2.228a8.491,8.491,0,0,1-6.7,2.813",
        transform: "translate(-86.019 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M254.988-41.585V-47.9h-6.63v6.315h-3.6V-57.315h3.6v6.225h6.63v-6.225h3.594v15.731h-3.594",
        transform: "translate(-95.903 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M285.991-41.585l-7.914-10v10h-3.549V-57.315h3.316l7.657,9.685v-9.685h3.549v15.731h-3.058",
        transform: "translate(-105.869 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M317.2-49.583a4.869,4.869,0,0,0-4.949-4.95,4.793,4.793,0,0,0-4.9,4.905v.045a4.869,4.869,0,0,0,4.949,4.95,4.793,4.793,0,0,0,4.9-4.905Zm-4.949,8.145c-5.043,0-8.661-3.623-8.661-8.1v-.045c0-4.478,3.666-8.146,8.708-8.146s8.66,3.623,8.66,8.1v.045c0,4.477-3.664,8.145-8.708,8.145",
        transform: "translate(-115.631 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M336.786-41.585V-57.315h3.6v12.584h8.148v3.146H336.786",
        transform: "translate(-126.654 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M372.78-49.583a4.87,4.87,0,0,0-4.949-4.95,4.794,4.794,0,0,0-4.9,4.905v.045a4.869,4.869,0,0,0,4.949,4.95,4.794,4.794,0,0,0,4.9-4.905Zm-4.949,8.145c-5.043,0-8.662-3.623-8.662-8.1v-.045c0-4.478,3.666-8.146,8.708-8.146s8.661,3.623,8.661,8.1v.045c0,4.477-3.666,8.145-8.708,8.145",
        transform: "translate(-135.016 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M399.735-41.438c-5.09,0-8.592-3.443-8.592-8.1v-.045a8.243,8.243,0,0,1,8.568-8.146,9.18,9.18,0,0,1,6.42,2.16l-2.265,2.634a6.141,6.141,0,0,0-4.272-1.6,4.807,4.807,0,0,0-4.692,4.905v.045a4.8,4.8,0,0,0,4.949,4.995,5.89,5.89,0,0,0,3.384-.945v-2.25h-3.618v-2.992h7.1v6.841a10.837,10.837,0,0,1-6.98,2.5",
        transform: "translate(-145.284 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M428.664-47.855v6.27h-3.6v-6.2l-6.28-9.528h4.2L426.89-51l3.968-6.315h4.085l-6.28,9.46",
        transform: "translate(-154.162 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M84.218-55.737a10.063,10.063,0,0,1,2.589-4.4,9.792,9.792,0,0,1,6.985-2.77h11.328V-69.3H93.792a17.041,17.041,0,0,0-11.8,4.759,16.344,16.344,0,0,0-3.547,5.115,13.247,13.247,0,0,0-1.122,3.688Zm0,4.877a10.065,10.065,0,0,0,2.589,4.4,9.793,9.793,0,0,0,6.985,2.77h11.328V-37.3H93.792a17.042,17.042,0,0,1-11.8-4.759,16.339,16.339,0,0,1-3.547-5.114,13.251,13.251,0,0,1-1.122-3.688ZM63.1-47.98,54.45-37.3H45.873l12.957-16-12.957-16H54.45L63.1-58.619l8.65-10.68h8.578l-12.957,16,12.957,16H71.749ZM48.875-55.737a13.212,13.212,0,0,0-1.122-3.688,16.359,16.359,0,0,0-3.546-5.115,17.043,17.043,0,0,0-11.8-4.759H21.08v6.393H32.408a9.79,9.79,0,0,1,6.985,2.77,10.072,10.072,0,0,1,2.59,4.4Zm0,4.877a13.215,13.215,0,0,1-1.122,3.688,16.353,16.353,0,0,1-3.546,5.114,17.044,17.044,0,0,1-11.8,4.759H21.08v-6.393H32.408a9.791,9.791,0,0,0,6.985-2.77,10.074,10.074,0,0,0,2.59-4.4h6.892",
        transform: "translate(-21.08 69.298)",
        fill: "#fff"
      }
    )
  ] })
] });
var dxcSmallLogo = /* @__PURE__ */ jsxs7("svg", { xmlns: "http://www.w3.org/2000/svg", width: "100%", height: "16", viewBox: "0 0 280.781 32", children: [
  /* @__PURE__ */ jsx14("title", { children: "DXC Logo" }),
  /* @__PURE__ */ jsxs7("g", { children: [
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M171.5-54.124v12.539h-3.6V-54.124h-4.973v-3.191h13.54v3.191H171.5",
        transform: "translate(-68.528 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M189.96-41.585V-57.315h12.326v3.079h-8.753v3.191h7.7v3.078h-7.7v3.3h8.87v3.078H189.96",
        transform: "translate(-77.56 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M223.558-41.438a8.1,8.1,0,0,1-8.382-8.1v-.045a8.161,8.161,0,0,1,8.522-8.146,8.6,8.6,0,0,1,6.444,2.431l-2.289,2.543a6.133,6.133,0,0,0-4.178-1.778,4.743,4.743,0,0,0-4.738,4.905v.045a4.752,4.752,0,0,0,4.738,4.95,6,6,0,0,0,4.295-1.845l2.288,2.228a8.491,8.491,0,0,1-6.7,2.813",
        transform: "translate(-86.019 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M254.988-41.585V-47.9h-6.63v6.315h-3.6V-57.315h3.6v6.225h6.63v-6.225h3.594v15.731h-3.594",
        transform: "translate(-95.903 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M285.991-41.585l-7.914-10v10h-3.549V-57.315h3.316l7.657,9.685v-9.685h3.549v15.731h-3.058",
        transform: "translate(-105.869 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M317.2-49.583a4.869,4.869,0,0,0-4.949-4.95,4.793,4.793,0,0,0-4.9,4.905v.045a4.869,4.869,0,0,0,4.949,4.95,4.793,4.793,0,0,0,4.9-4.905Zm-4.949,8.145c-5.043,0-8.661-3.623-8.661-8.1v-.045c0-4.478,3.666-8.146,8.708-8.146s8.66,3.623,8.66,8.1v.045c0,4.477-3.664,8.145-8.708,8.145",
        transform: "translate(-115.631 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M336.786-41.585V-57.315h3.6v12.584h8.148v3.146H336.786",
        transform: "translate(-126.654 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M372.78-49.583a4.87,4.87,0,0,0-4.949-4.95,4.794,4.794,0,0,0-4.9,4.905v.045a4.869,4.869,0,0,0,4.949,4.95,4.794,4.794,0,0,0,4.9-4.905Zm-4.949,8.145c-5.043,0-8.662-3.623-8.662-8.1v-.045c0-4.478,3.666-8.146,8.708-8.146s8.661,3.623,8.661,8.1v.045c0,4.477-3.666,8.145-8.708,8.145",
        transform: "translate(-135.016 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M399.735-41.438c-5.09,0-8.592-3.443-8.592-8.1v-.045a8.243,8.243,0,0,1,8.568-8.146,9.18,9.18,0,0,1,6.42,2.16l-2.265,2.634a6.141,6.141,0,0,0-4.272-1.6,4.807,4.807,0,0,0-4.692,4.905v.045a4.8,4.8,0,0,0,4.949,4.995,5.89,5.89,0,0,0,3.384-.945v-2.25h-3.618v-2.992h7.1v6.841a10.837,10.837,0,0,1-6.98,2.5",
        transform: "translate(-145.284 65.583)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M428.664-47.855v6.27h-3.6v-6.2l-6.28-9.528h4.2L426.89-51l3.968-6.315h4.085l-6.28,9.46",
        transform: "translate(-154.162 65.45)",
        fill: "#fff"
      }
    ),
    /* @__PURE__ */ jsx14(
      "path",
      {
        d: "M84.218-55.737a10.063,10.063,0,0,1,2.589-4.4,9.792,9.792,0,0,1,6.985-2.77h11.328V-69.3H93.792a17.041,17.041,0,0,0-11.8,4.759,16.344,16.344,0,0,0-3.547,5.115,13.247,13.247,0,0,0-1.122,3.688Zm0,4.877a10.065,10.065,0,0,0,2.589,4.4,9.793,9.793,0,0,0,6.985,2.77h11.328V-37.3H93.792a17.042,17.042,0,0,1-11.8-4.759,16.339,16.339,0,0,1-3.547-5.114,13.251,13.251,0,0,1-1.122-3.688ZM63.1-47.98,54.45-37.3H45.873l12.957-16-12.957-16H54.45L63.1-58.619l8.65-10.68h8.578l-12.957,16,12.957,16H71.749ZM48.875-55.737a13.212,13.212,0,0,0-1.122-3.688,16.359,16.359,0,0,0-3.546-5.115,17.043,17.043,0,0,0-11.8-4.759H21.08v6.393H32.408a9.79,9.79,0,0,1,6.985,2.77,10.072,10.072,0,0,1,2.59,4.4Zm0,4.877a13.215,13.215,0,0,1-1.122,3.688,16.353,16.353,0,0,1-3.546,5.114,17.044,17.044,0,0,1-11.8,4.759H21.08v-6.393H32.408a9.791,9.791,0,0,0,6.985-2.77,10.074,10.074,0,0,0,2.59-4.4h6.892",
        transform: "translate(-21.08 69.298)",
        fill: "#fff"
      }
    )
  ] })
] });

// src/footer/Footer.tsx
import { jsx as jsx15, jsxs as jsxs8 } from "react/jsx-runtime";
var DxcFooter = ({
  socialLinks: socialLinks2,
  bottomLinks: bottomLinks2,
  copyright,
  children,
  margin,
  tabIndex = 0,
  mode = "default"
}) => {
  const colorsTheme = useContext6(HalstackContext);
  const translatedLabels = useContext6(HalstackLanguageContext);
  const footerLogo = useMemo4(
    () => !colorsTheme.footer.logo ? mode === "default" ? dxcLogo : dxcSmallLogo : typeof colorsTheme.footer.logo === "string" ? /* @__PURE__ */ jsx15(LogoImg, { mode, alt: translatedLabels.formFields.logoAlternativeText, src: colorsTheme.footer.logo }) : colorsTheme.footer.logo,
    [colorsTheme, translatedLabels]
  );
  return /* @__PURE__ */ jsx15(ThemeProvider5, { theme: colorsTheme.footer, children: /* @__PURE__ */ jsxs8(FooterContainer, { margin, mode, children: [
    /* @__PURE__ */ jsxs8(Flex_default, { justifyContent: "space-between", alignItems: "center", wrap: "wrap", gap: "1.5rem", children: [
      /* @__PURE__ */ jsx15(LogoContainer, { mode, children: footerLogo }),
      mode === "default" && /* @__PURE__ */ jsx15(Flex_default, { gap: colorsTheme.footer.socialLinksGutter, children: socialLinks2?.map((link, index) => /* @__PURE__ */ jsx15(Tooltip, { label: link.title, children: /* @__PURE__ */ jsx15(
        SocialAnchor,
        {
          href: link.href,
          tabIndex,
          "aria-label": link.title,
          index,
          children: /* @__PURE__ */ jsx15(SocialIconContainer, { children: typeof link.logo === "string" ? /* @__PURE__ */ jsx15(Icon_default, { icon: link.logo }) : link.logo })
        },
        `social${index}${link.href}`
      ) }, `social${index}${link.href}`)) })
    ] }),
    /* @__PURE__ */ jsx15(ChildComponents, { children }),
    mode === "default" && /* @__PURE__ */ jsxs8(BottomContainer, { children: [
      /* @__PURE__ */ jsx15(BottomLinks, { children: bottomLinks2?.map((link, index) => /* @__PURE__ */ jsx15("span", { children: /* @__PURE__ */ jsx15(BottomLink, { href: link.href, tabIndex, children: link.text }) }, `bottom${index}${link.text}`)) }),
      /* @__PURE__ */ jsx15(Copyright, { children: copyright ?? translatedLabels.footer.copyrightText((/* @__PURE__ */ new Date()).getFullYear()) })
    ] })
  ] }) });
};
var FooterContainer = styled12.footer`
  background-color: ${(props) => props.theme.backgroundColor};
  box-sizing: border-box;
  display: flex;
  flex-direction: ${(props) => props?.mode === "default" ? "column" : "row"};
  justify-content: space-between;
  margin-top: ${(props) => props.margin ? spaces[props.margin] : "0px"};
  min-height: ${(props) => props?.mode === "default" ? props.theme.height : "40px"};
  width: 100%;
  gap: ${(props) => props?.mode === "default" ? "0px" : "32px"};
  @media (min-width: ${responsiveSizes.small}rem) {
    padding: ${(props) => props?.mode === "default" ? "24px 32px" : "12px 32px"};
  }
  @media (max-width: ${responsiveSizes.small}rem) {
    padding: 20px;
    flex-direction: column;
  }
`;
var BottomContainer = styled12.div`
  display: flex;
  justify-content: space-between;
  align-items: flex-end;

  @media (min-width: ${responsiveSizes.small}rem) {
    flex-direction: row;
  }
  @media (max-width: ${responsiveSizes.small}rem) {
    flex-direction: column;
    align-items: center;
  }

  border-top: ${(props) => `${props.theme.bottomLinksDividerThickness} ${props.theme.bottomLinksDividerStyle} ${props.theme.bottomLinksDividerColor}`};
  margin-top: 16px;
`;
var ChildComponents = styled12.div`
  min-height: 16px;
  overflow: hidden;
`;
var Copyright = styled12.div`
  padding-top: ${(props) => props.theme.bottomLinksDividerSpacing};
  font-family: ${(props) => props.theme.copyrightFontFamily};
  font-size: ${(props) => props.theme.copyrightFontSize};
  font-style: ${(props) => props.theme.copyrightFontStyle};
  font-weight: ${(props) => props.theme.copyrightFontWeight};
  color: ${(props) => props.theme.copyrightFontColor};

  @media (min-width: ${responsiveSizes.small}rem) {
    max-width: 40%;
    text-align: right;
  }

  @media (max-width: ${responsiveSizes.small}rem) {
    max-width: 100%;
    width: 100%;
    text-align: left;
  }
`;
var LogoContainer = styled12.span`
  max-height: ${(props) => props?.mode === "default" ? props.theme.logoHeight : "16px"};
  width: ${(props) => props.theme.logoWidth};
`;
var LogoImg = styled12.img`
  max-height: ${(props) => props?.mode === "default" ? props.theme.logoHeight : "16px"};
  width: ${(props) => props.theme.logoWidth};
`;
var SocialAnchor = styled12.a`
  border-radius: 4px;

  &:focus {
    outline: 2px solid #0095ff;
    outline-offset: 2px;
  }
`;
var SocialIconContainer = styled12.div`
  display: flex;
  align-items: center;
  color: ${(props) => props.theme.socialLinksColor};
  overflow: hidden;
  font-size: ${(props) => props.theme.socialLinksSize};

  svg {
    height: ${(props) => props.theme.socialLinksSize};
    width: ${(props) => props.theme.socialLinksSize};
  }
`;
var BottomLinks = styled12.div`
  display: inline-flex;
  flex-wrap: wrap;
  align-self: center;
  padding-top: ${(props) => props.theme.bottomLinksDividerSpacing};
  color: #fff;

  @media (min-width: ${responsiveSizes.small}rem) {
    max-width: 60%;
  }
  @media (max-width: ${responsiveSizes.small}rem) {
    max-width: 100%;
    width: 100%;
  }

  & > span:not(:first-child):before {
    content: "·";
    padding: 0 0.5rem;
  }
`;
var BottomLink = styled12.a`
  text-decoration: ${(props) => props.theme.bottomLinksTextDecoration};
  color: ${(props) => props.theme.bottomLinksFontColor};
  font-family: ${(props) => props.theme.bottomLinksFontFamily};
  font-size: ${(props) => props.theme.bottomLinksFontSize};
  font-style: ${(props) => props.theme.bottomLinksFontStyle};
  font-weight: ${(props) => props.theme.bottomLinksFontWeight};
  border-radius: 2px;

  &:focus {
    outline: 2px solid #0095ff;
  }
`;
var Footer_default = DxcFooter;

// src/header/Header.tsx
import { useEffect as useEffect3, useMemo as useMemo5, useRef as useRef3, useState as useState6 } from "react";
import styled16, { ThemeProvider as ThemeProvider7 } from "styled-components";

// src/dropdown/Dropdown.tsx
import * as Popover from "@radix-ui/react-popover";
import { useCallback as useCallback4, useId as useId3, useLayoutEffect as useLayoutEffect2, useRef as useRef2, useState as useState5, useContext as useContext7 } from "react";
import styled15, { ThemeProvider as ThemeProvider6 } from "styled-components";

// src/utils/useWidth.tsx
import { useLayoutEffect, useState as useState4 } from "react";
var useWidth = (target) => {
  const [width, setWidth] = useState4(0);
  useLayoutEffect(() => {
    if (target != null) {
      setWidth(target.getBoundingClientRect().width);
      const triggerObserver = new ResizeObserver((entries) => {
        const rect = entries[0]?.target.getBoundingClientRect();
        if (rect) {
          setWidth(rect.width);
        }
      });
      triggerObserver.observe(target);
      return () => {
        triggerObserver.unobserve(target);
      };
    }
  }, [target]);
  return width;
};
var useWidth_default = useWidth;

// src/dropdown/DropdownMenu.tsx
import { forwardRef as forwardRef2, memo as memo3 } from "react";
import styled14 from "styled-components";

// src/dropdown/DropdownMenuItem.tsx
import { memo as memo2 } from "react";
import styled13 from "styled-components";
import { jsx as jsx16, jsxs as jsxs9 } from "react/jsx-runtime";
var DropdownMenuItem = ({
  id,
  visuallyFocused,
  iconPosition,
  onClick,
  option
}) => /* @__PURE__ */ jsxs9(
  DropdownMenuItemContainer,
  {
    visuallyFocused,
    onClick: () => {
      onClick(option.value);
    },
    id,
    role: "menuitem",
    tabIndex: -1,
    children: [
      iconPosition === "after" && /* @__PURE__ */ jsx16(DropdownMenuItemLabel, { children: option.label }),
      option.icon && /* @__PURE__ */ jsx16(DropdownMenuItemIcon, { role: typeof option.icon === "string" ? void 0 : "img", "aria-hidden": true, children: typeof option.icon === "string" ? /* @__PURE__ */ jsx16(Icon_default, { icon: option.icon }) : option.icon }),
      iconPosition === "before" && /* @__PURE__ */ jsx16(DropdownMenuItemLabel, { children: option.label })
    ]
  }
);
var DropdownMenuItemContainer = styled13.li`
  box-sizing: border-box;
  display: flex;
  align-items: center;
  gap: ${(props) => props.theme.optionIconSpacing};
  min-height: 36px;
  padding-top: ${(props) => props.theme.optionPaddingTop};
  padding-bottom: ${(props) => props.theme.optionPaddingBottom};
  padding-left: ${(props) => props.theme.optionPaddingLeft};
  padding-right: ${(props) => props.theme.optionPaddingRight};
  cursor: pointer;

  ${(props) => props.visuallyFocused && `outline: ${props.theme.focusColor} solid 2px; outline-offset: -2px;`}
  &:hover {
    background-color: ${(props) => props.theme.hoverOptionBackgroundColor};
  }
  &:active {
    background-color: ${(props) => props.theme.activeOptionBackgroundColor};
  }
`;
var DropdownMenuItemLabel = styled13.span`
  font-family: ${(props) => props.theme.optionFontFamily};
  font-size: ${(props) => props.theme.optionFontSize};
  font-style: ${(props) => props.theme.optionFontStyle};
  font-weight: ${(props) => props.theme.optionFontWeight};
  line-height: 1.5rem;
  color: ${(props) => props.theme.optionFontColor};
  white-space: nowrap;
`;
var DropdownMenuItemIcon = styled13.div`
  display: flex;
  color: ${(props) => props.theme.optionIconColor};
  font-size: ${(props) => props.theme.optionIconSize};

  svg {
    width: ${(props) => props.theme.optionIconSize};
    height: ${(props) => props.theme.optionIconSize};
  }
`;
var DropdownMenuItem_default = memo2(DropdownMenuItem);

// src/dropdown/DropdownMenu.tsx
import { jsx as jsx17 } from "react/jsx-runtime";
var DropdownMenu = forwardRef2(
  ({ id, dropdownTriggerId, iconsPosition, visualFocusIndex, menuItemOnClick, onKeyDown, options, styles }, ref) => /* @__PURE__ */ jsx17(
    DropdownMenuContainer,
    {
      onMouseDown: (event) => {
        event.preventDefault();
      },
      onKeyDown,
      id,
      role: "menu",
      "aria-labelledby": dropdownTriggerId,
      "aria-orientation": "vertical",
      "aria-activedescendant": visualFocusIndex !== -1 ? `${id}-option-${visualFocusIndex}` : void 0,
      tabIndex: -1,
      ref,
      style: styles,
      children: options.map((option, index) => /* @__PURE__ */ jsx17(
        DropdownMenuItem_default,
        {
          id: `${id}-option-${index}`,
          visuallyFocused: index === visualFocusIndex,
          iconPosition: iconsPosition,
          onClick: menuItemOnClick,
          option
        },
        `${id}-option-${index}`
      ))
    }
  )
);
var DropdownMenuContainer = styled14.ul`
  box-sizing: border-box;
  max-height: 230px;
  min-width: min-content;
  padding: 0;
  margin: 0;
  background-color: ${(props) => props.theme.optionBackgroundColor};
  border-width: ${(props) => props.theme.borderThickness};
  border-style: ${(props) => props.theme.borderStyle};
  border-color: ${(props) => props.theme.borderColor};
  border-radius: ${(props) => props.theme.borderRadius};
  border-top-right-radius: 0;
  border-top-left-radius: 0;
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1);
  outline: none;

  overflow-y: auto;
  &::-webkit-scrollbar {
    width: 8px;
    height: 8px;
  }
  &::-webkit-scrollbar-thumb {
    background-color: ${(props) => props.theme.scrollBarThumbColor};
    border-radius: 6px;
  }
  &::-webkit-scrollbar-track {
    background-color: ${(props) => props.theme.scrollBarTrackColor};
    border-radius: 6px;
  }
`;
var DropdownMenu_default = memo3(DropdownMenu);

// src/dropdown/Dropdown.tsx
import { jsx as jsx18, jsxs as jsxs10 } from "react/jsx-runtime";
var DxcDropdown = ({
  options,
  optionsIconPosition = "before",
  icon,
  iconPosition = "before",
  label = "",
  caretHidden = false,
  disabled = false,
  expandOnHover = false,
  onSelectOption,
  margin,
  size = "fitContent",
  tabIndex = 0,
  title
}) => {
  const id = useId3();
  const triggerId = `trigger-${id}`;
  const menuId = `menu-${id}`;
  const [isOpen, changeIsOpen] = useState5(false);
  const [visualFocusIndex, setVisualFocusIndex] = useState5(0);
  const colorsTheme = useContext7(HalstackContext);
  const triggerRef = useRef2(null);
  const menuRef = useRef2(null);
  const width = useWidth_default(triggerRef.current);
  const handleOnOpenMenu = () => {
    changeIsOpen(true);
  };
  const handleOnCloseMenu = () => {
    changeIsOpen(false);
    setVisualFocusIndex(0);
  };
  const handleMenuItemOnClick = useCallback4(
    (value) => {
      if (value) onSelectOption(value);
      handleOnCloseMenu();
      triggerRef.current?.focus();
    },
    [onSelectOption]
  );
  const handleOnBlur = (event) => {
    if (!event.currentTarget.contains(event.relatedTarget)) {
      handleOnCloseMenu();
    }
  };
  const handleTriggerOnClick = () => {
    changeIsOpen((isCurrentlyOpen) => !isCurrentlyOpen);
  };
  const handleTriggerOnKeyDown = (event) => {
    switch (event.key) {
      case "Up":
      case "ArrowUp":
        event.preventDefault();
        setVisualFocusIndex(options.length - 1);
        handleOnOpenMenu();
        break;
      case " ":
      case "Down":
      case "ArrowDown":
      case "Enter":
        event.preventDefault();
        handleOnOpenMenu();
        break;
      default:
        break;
    }
  };
  const setPreviousIndexFocus = () => {
    setVisualFocusIndex((currentFocusIndex) => {
      const index = currentFocusIndex === 0 ? options.length - 1 : currentFocusIndex - 1;
      return index;
    });
  };
  const setNextIndexFocus = () => {
    setVisualFocusIndex((currentFocusIndex) => {
      const index = currentFocusIndex === options.length - 1 ? 0 : currentFocusIndex + 1;
      return index;
    });
  };
  const handleMenuOnKeyDown = useCallback4(
    (event) => {
      switch (event.key) {
        case "Up":
        case "ArrowUp":
          event.preventDefault();
          setPreviousIndexFocus();
          break;
        case "Down":
        case "ArrowDown":
          event.preventDefault();
          setNextIndexFocus();
          break;
        case " ":
        case "Enter":
          event.preventDefault();
          handleMenuItemOnClick(options[visualFocusIndex]?.value);
          break;
        case "Esc":
        case "Escape":
          event.preventDefault();
          if (isOpen) {
            event.stopPropagation();
          }
          handleOnCloseMenu();
          triggerRef.current?.focus();
          break;
        case "Home":
        case "PageUp":
          event.preventDefault();
          setVisualFocusIndex(0);
          break;
        case "End":
        case "PageDown":
          event.preventDefault();
          setVisualFocusIndex(options.length - 1);
          break;
        case "Tab":
          handleOnCloseMenu();
          triggerRef.current?.focus();
          break;
        default:
          break;
      }
    },
    [onSelectOption, visualFocusIndex, options]
  );
  useLayoutEffect2(() => {
    const visualFocusedMenuItem = menuRef.current?.querySelectorAll("[role='menuitem']")[visualFocusIndex];
    visualFocusedMenuItem?.scrollIntoView?.({
      block: "nearest",
      inline: "start"
    });
  }, [visualFocusIndex]);
  return /* @__PURE__ */ jsx18(ThemeProvider6, { theme: colorsTheme.dropdown, children: /* @__PURE__ */ jsx18(
    DropdownContainer,
    {
      onMouseEnter: !disabled && expandOnHover ? handleOnOpenMenu : void 0,
      onMouseLeave: !disabled && expandOnHover ? handleOnCloseMenu : void 0,
      onBlur: !disabled ? handleOnBlur : void 0,
      margin,
      size,
      children: /* @__PURE__ */ jsxs10(Popover.Root, { open: isOpen, children: [
        /* @__PURE__ */ jsx18(Tooltip, { label: title, children: /* @__PURE__ */ jsx18(Popover.Trigger, { asChild: true, type: void 0, children: /* @__PURE__ */ jsxs10(
          DropdownTrigger,
          {
            onClick: handleTriggerOnClick,
            onKeyDown: handleTriggerOnKeyDown,
            onBlur: (event) => {
              event.stopPropagation();
            },
            disabled,
            label,
            margin,
            size,
            id: triggerId,
            "aria-haspopup": "true",
            "aria-controls": isOpen ? menuId : void 0,
            "aria-expanded": isOpen ? true : void 0,
            "aria-label": "Show options",
            tabIndex,
            ref: triggerRef,
            children: [
              /* @__PURE__ */ jsxs10(DropdownTriggerContent, { children: [
                label && iconPosition === "after" && /* @__PURE__ */ jsx18(DropdownTriggerLabel, { children: label }),
                icon && /* @__PURE__ */ jsx18(
                  DropdownTriggerIcon,
                  {
                    disabled,
                    role: typeof icon === "string" ? void 0 : "img",
                    "aria-hidden": true,
                    children: typeof icon === "string" ? /* @__PURE__ */ jsx18(Icon_default, { icon }) : icon
                  }
                ),
                label && iconPosition === "before" && /* @__PURE__ */ jsx18(DropdownTriggerLabel, { children: label })
              ] }),
              !caretHidden && /* @__PURE__ */ jsxs10(CaretIcon, { disabled, children: [
                /* @__PURE__ */ jsx18(Icon_default, { icon: isOpen ? "arrow_drop_up" : "arrow_drop_down" }),
                " "
              ] })
            ]
          }
        ) }) }),
        /* @__PURE__ */ jsx18(Popover.Portal, { children: /* @__PURE__ */ jsx18(Popover.Content, { asChild: true, sideOffset: 1, children: /* @__PURE__ */ jsx18(
          DropdownMenu_default,
          {
            id: menuId,
            dropdownTriggerId: triggerId,
            options,
            iconsPosition: optionsIconPosition,
            visualFocusIndex,
            menuItemOnClick: handleMenuItemOnClick,
            onKeyDown: handleMenuOnKeyDown,
            styles: { width, zIndex: "2147483647" },
            ref: menuRef
          }
        ) }) })
      ] })
    }
  ) });
};
var sizes = {
  small: "60px",
  medium: "240px",
  large: "480px",
  fillParent: "100%",
  fitContent: "fit-content"
};
var calculateWidth3 = (margin, size) => size != null && (size === "fillParent" ? `calc(${sizes[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : sizes[size]);
var DropdownContainer = styled15.div`
  width: ${(props) => calculateWidth3(props.margin, props.size)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var DropdownTrigger = styled15.button`
  display: flex;
  justify-content: space-between;
  align-items: center;
  gap: ${(props) => props.theme.caretIconSpacing};
  width: 100%;
  height: ${(props) => props.theme.buttonHeight};
  min-width: ${(props) => props.label === "" ? "0px" : calculateWidth3(props.margin, props.size)};
  border-radius: ${(props) => props.theme.buttonBorderRadius};
  border-width: ${(props) => props.theme.buttonBorderThickness};
  border-style: ${(props) => props.theme.buttonBorderStyle};
  border-color: ${(props) => props.disabled ? props.theme.disabledButtonBorderColor : props.theme.buttonBorderColor};
  padding-top: ${(props) => props.theme.buttonPaddingTop};
  padding-bottom: ${(props) => props.theme.buttonPaddingBottom};
  padding-left: ${(props) => props.theme.buttonPaddingLeft};
  padding-right: ${(props) => props.theme.buttonPaddingRight};
  background-color: ${(props) => props.disabled ? props.theme.disabledButtonBackgroundColor : props.theme.buttonBackgroundColor};
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.buttonFontColor};
  cursor: ${(props) => props.disabled ? "not-allowed" : "pointer"};

  ${(props) => !props.disabled && `
      &:focus {
        outline: 2px solid ${props.theme.focusColor};
      }
      &:hover {
        background-color: ${props.theme.hoverButtonBackgroundColor};
      }
      &:active {
        background-color: ${props.theme.activeButtonBackgroundColor};
      }
  `};
`;
var DropdownTriggerContent = styled15.span`
  display: flex;
  align-items: center;
  gap: ${(props) => props.theme.buttonIconSpacing};
  margin-left: 0px;
  margin-right: 0px;
  width: 100%;
  overflow: hidden;
  white-space: nowrap;
`;
var DropdownTriggerLabel = styled15.span`
  font-family: ${(props) => props.theme.buttonFontFamily};
  font-size: ${(props) => props.theme.buttonFontSize};
  font-style: ${(props) => props.theme.buttonFontStyle};
  font-weight: ${(props) => props.theme.buttonFontWeight};
  text-overflow: ellipsis;
  overflow: hidden;
`;
var DropdownTriggerIcon = styled15.span`
  display: flex;
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.buttonIconColor};
  font-size: ${(props) => props.theme.buttonIconSize};

  svg {
    width: ${(props) => props.theme.buttonIconSize};
    height: ${(props) => props.theme.buttonIconSize};
  }
`;
var CaretIcon = styled15.span`
  display: flex;
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.caretIconColor};
  font-size: ${(props) => props.theme.caretIconSize};

  svg {
    width: ${(props) => props.theme.caretIconSize};
    height: ${(props) => props.theme.caretIconSize};
  }
`;
var Dropdown_default = DxcDropdown;

// src/header/Header.tsx
import { useContext as useContext8 } from "react";
import { jsx as jsx19, jsxs as jsxs11 } from "react/jsx-runtime";
var Dropdown = (props) => /* @__PURE__ */ jsx19(HeaderDropdown, { children: /* @__PURE__ */ jsx19(Dropdown_default, { ...props }) });
var getLogoElement = (themeInput, logoLabel) => {
  if (!themeInput) {
    return /* @__PURE__ */ jsxs11("svg", { xmlns: "http://www.w3.org/2000/svg", width: "73", height: "40", viewBox: "0 0 73 40", children: [
      /* @__PURE__ */ jsx19("title", { children: "DXC Logo" }),
      /* @__PURE__ */ jsx19("g", { transform: "translate(0)", children: /* @__PURE__ */ jsxs11("g", { children: [
        /* @__PURE__ */ jsx19(
          "path",
          {
            d: "M91.613-28.177v2.514H90.231V-28.15l-2.415-3.82h1.616l1.5,2.532,1.526-2.532h1.571ZM83.9-25.555A3.15,3.15,0,0,1,80.6-28.8v-.018a3.231,3.231,0,0,1,3.294-3.262,3.442,3.442,0,0,1,2.469.865l-.87,1.054a2.311,2.311,0,0,0-1.643-.64,1.891,1.891,0,0,0-1.8,1.964v.018a1.886,1.886,0,0,0,1.9,2,2.2,2.2,0,0,0,1.3-.378v-.9H83.858v-1.2h2.729v2.738A4.071,4.071,0,0,1,83.9-25.555Zm-6.416-3.261a1.913,1.913,0,0,0-1.9-1.982A1.883,1.883,0,0,0,73.7-28.835v.018a1.913,1.913,0,0,0,1.9,1.982A1.883,1.883,0,0,0,77.486-28.8Zm-1.9,3.261a3.225,3.225,0,0,1-3.33-3.243v-.018A3.255,3.255,0,0,1,75.6-32.078a3.225,3.225,0,0,1,3.331,3.243v.018A3.255,3.255,0,0,1,75.583-25.555Zm-9.173-.108V-31.97h1.382v5.045h3.133v1.261Zm-3.433-3.153a1.913,1.913,0,0,0-1.9-1.982,1.883,1.883,0,0,0-1.886,1.964v.018a1.913,1.913,0,0,0,1.9,1.982A1.883,1.883,0,0,0,62.978-28.8Zm-1.9,3.261a3.225,3.225,0,0,1-3.33-3.243v-.018a3.255,3.255,0,0,1,3.348-3.262,3.225,3.225,0,0,1,3.331,3.243v.018A3.255,3.255,0,0,1,61.075-25.555Zm-6.508-.108-3.043-4.009v4.009H50.159V-31.97h1.275l2.944,3.883V-31.97h1.364v6.306Zm-8.246,0v-2.531h-2.55v2.531H42.389V-31.97h1.382v2.5h2.55v-2.5H47.7v6.306Zm-8.432.108A3.178,3.178,0,0,1,34.666-28.8v-.018a3.2,3.2,0,0,1,3.276-3.262,3.237,3.237,0,0,1,2.478.973l-.88,1.018a2.315,2.315,0,0,0-1.606-.712,1.866,1.866,0,0,0-1.822,1.964v.018a1.87,1.87,0,0,0,1.822,1.982,2.265,2.265,0,0,0,1.651-.739l.88.891A3.206,3.206,0,0,1,37.889-25.555Zm-9.805-.108V-31.97h4.739v1.235H29.458v1.279h2.962v1.234H29.458V-26.9h3.411v1.234ZM24.322-30.69v5.027H22.939V-30.69H21.028v-1.28h5.206v1.28H24.322",
            transform: "translate(-21.028 65.555)",
            fill: "#010101"
          }
        ),
        /* @__PURE__ */ jsx19(
          "path",
          {
            d: "M75.836-76.712a8.975,8.975,0,0,1,2.246-3.9,8.393,8.393,0,0,1,6.058-2.457h9.824v-5.67H84.139a14.611,14.611,0,0,0-10.232,4.221,14.509,14.509,0,0,0-3.076,4.536,11.913,11.913,0,0,0-.973,3.271Zm0,4.325a8.978,8.978,0,0,0,2.246,3.9,8.394,8.394,0,0,0,6.058,2.457h9.824v5.67H84.139A14.611,14.611,0,0,1,73.907-64.58a14.506,14.506,0,0,1-3.076-4.536,11.91,11.91,0,0,1-.973-3.271ZM57.522-69.832l-7.5,9.473H42.581L53.818-74.55,42.581-88.739H50.02l7.5,9.472,7.5-9.472h7.439L61.225-74.55l11.237,14.19H65.023Zm-12.336-6.88a11.935,11.935,0,0,0-.973-3.271,14.515,14.515,0,0,0-3.076-4.536A14.612,14.612,0,0,0,30.9-88.739H21.081v5.67H30.9a8.394,8.394,0,0,1,6.058,2.457,8.978,8.978,0,0,1,2.246,3.9Zm0,4.325a11.932,11.932,0,0,1-.973,3.271,14.511,14.511,0,0,1-3.076,4.536A14.611,14.611,0,0,1,30.9-60.359H21.081v-5.67H30.9a8.4,8.4,0,0,0,6.058-2.457,8.981,8.981,0,0,0,2.246-3.9h5.978",
            transform: "translate(-21.049 88.739)",
            fill: "#603494"
          }
        )
      ] }) })
    ] });
  } else if (typeof themeInput === "string") return /* @__PURE__ */ jsx19(LogoImg2, { alt: logoLabel, src: themeInput });
  else return themeInput;
};
var Content3 = ({ isResponsive, responsiveContent, handleMenu, content }) => isResponsive ? /* @__PURE__ */ jsx19(MenuContent, { children: responsiveContent?.(handleMenu) }) : /* @__PURE__ */ jsx19(ContentContainer, { children: content });
var DxcHeader = ({
  underlined = false,
  content,
  responsiveContent,
  onClick,
  margin,
  tabIndex = 0
}) => {
  const [isResponsive, setIsResponsive] = useState6(false);
  const [isMenuVisible, setIsMenuVisible] = useState6(false);
  const colorsTheme = useContext8(HalstackContext);
  const translatedLabels = useContext8(HalstackLanguageContext);
  const ref = useRef3(null);
  const handleMenu = () => {
    if (isResponsive && !isMenuVisible) {
      setIsMenuVisible(!isMenuVisible);
    } else {
      setIsMenuVisible(!isMenuVisible);
    }
  };
  const headerLogo = useMemo5(
    () => getLogoElement(colorsTheme.header.logo, translatedLabels.formFields.logoAlternativeText),
    [colorsTheme, translatedLabels]
  );
  const headerResponsiveLogo = useMemo5(
    () => getLogoElement(colorsTheme.header.logoResponsive, translatedLabels.formFields.logoAlternativeText),
    [colorsTheme, translatedLabels]
  );
  useEffect3(() => {
    const handleResize = () => {
      setIsResponsive(window.matchMedia(`(max-width: ${responsiveSizes.medium}rem)`).matches);
    };
    handleResize();
    window.addEventListener("resize", handleResize);
    return () => {
      window.removeEventListener("resize", handleResize);
    };
  }, []);
  useEffect3(() => {
    if (!isResponsive) {
      setIsMenuVisible(false);
    }
  }, [isResponsive]);
  return /* @__PURE__ */ jsx19(ThemeProvider7, { theme: colorsTheme.header, children: /* @__PURE__ */ jsxs11(HeaderContainer, { underlined, margin, ref, children: [
    /* @__PURE__ */ jsx19(LogoAnchor, { tabIndex: onClick ? tabIndex : -1, interactive: !!onClick, onClick, children: /* @__PURE__ */ jsx19(LogoContainer2, { children: headerLogo }) }),
    isResponsive && responsiveContent && /* @__PURE__ */ jsxs11(Flex_default, { grow: 1, children: [
      /* @__PURE__ */ jsx19(ChildContainer, { children: /* @__PURE__ */ jsxs11(HamburgerTrigger, { tabIndex, onClick: handleMenu, "aria-label": "Show options", children: [
        /* @__PURE__ */ jsx19(Icon_default, { icon: "menu" }),
        translatedLabels.header.hamburgerTitle
      ] }) }),
      /* @__PURE__ */ jsxs11(ResponsiveMenu, { hasVisibility: isMenuVisible, children: [
        /* @__PURE__ */ jsxs11(Flex_default, { justifyContent: "space-between", alignItems: "center", children: [
          /* @__PURE__ */ jsx19(ResponsiveLogoContainer, { children: headerResponsiveLogo }),
          /* @__PURE__ */ jsx19(Tooltip, { label: translatedLabels.header.closeIcon, children: /* @__PURE__ */ jsx19(CloseAction, { tabIndex, onClick: handleMenu, "aria-label": translatedLabels.header.closeIcon, children: /* @__PURE__ */ jsx19(Icon_default, { icon: "close" }) }) })
        ] }),
        /* @__PURE__ */ jsx19(
          Content3,
          {
            isResponsive,
            responsiveContent,
            handleMenu,
            content
          }
        )
      ] }),
      /* @__PURE__ */ jsx19(Overlay2, { onClick: handleMenu, hasVisibility: isMenuVisible })
    ] }),
    !isResponsive && /* @__PURE__ */ jsx19(
      Content3,
      {
        isResponsive,
        responsiveContent,
        handleMenu,
        content
      }
    )
  ] }) });
};
DxcHeader.Dropdown = Dropdown;
var HeaderDropdown = styled16.div`
  display: flex;
  button {
    background-color: transparent;
    :hover {
      background-color: transparent;
    }
  }
`;
var HeaderContainer = styled16.header`
  box-sizing: border-box;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
  min-height: ${(props) => props.theme.minHeight};
  margin-bottom: ${(props) => props.margin ? spaces[props.margin] : "0px"};
  padding: ${(props) => `${props.theme.paddingTop} ${props.theme.paddingRight} ${props.theme.paddingBottom} ${props.theme.paddingLeft}`};
  background-color: ${(props) => props.theme.backgroundColor};
  border-bottom: ${(props) => props.underlined && `${props.theme.underlinedThickness} ${props.theme.underlinedStyle} ${props.theme.underlinedColor}`};
`;
var LogoAnchor = styled16.a`
  ${(props) => props.interactive ? "cursor: pointer" : "cursor: default; outline:none;"};
`;
var LogoImg2 = styled16.img`
  max-height: ${(props) => props.theme.logoHeight};
  width: ${(props) => props.theme.logoWidth};
`;
var LogoContainer2 = styled16.div`
  max-height: ${(props) => props.theme.logoHeight};
  width: ${(props) => props.theme.logoWidth};
  vertical-align: middle;
`;
var ChildContainer = styled16.div`
  display: flex;
  align-items: center;
  justify-content: flex-end;
  flex-grow: 1;
  width: calc(100% - 186px);
`;
var ContentContainer = styled16.div`
  display: flex;
  align-items: center;
  flex-grow: 1;
  justify-content: flex-end;
  width: calc(100% - 186px);
  color: ${(props) => props.theme.contentColor};
`;
var HamburgerTrigger = styled16.button`
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 54px;
  cursor: pointer;
  border: 1px solid transparent;
  border-radius: 2px;
  background-color: transparent;
  :hover {
    background-color: ${(props) => props.theme.hamburgerHoverColor};
  }
  &:focus {
    outline: ${(props) => props.theme.hamburgerFocusColor} auto 1px;
  }
  & > svg {
    fill: ${(props) => props.theme.hamburgerIconColor};
  }
  & > span {
    font-size: 24px;
  }
  font-family: ${(props) => props.theme.hamburgerFontFamily};
  font-style: ${(props) => props.theme.hamburgerFontStyle};
  font-size: ${(props) => props.theme.hamburgerFontSize};
  text-transform: ${(props) => props.theme.hamburgerTextTransform};
  font-weight: ${(props) => props.theme.hamburgerFontWeight};
  color: ${(props) => props.theme.hamburgerFontColor};
`;
var ResponsiveMenu = styled16.div`
  display: flex;
  flex-direction: column;
  background-color: ${(props) => props.theme.menuBackgroundColor};
  position: fixed;
  top: 0;
  right: 0;
  z-index: ${(props) => props.theme.menuZindex};

  @media (max-width: ${responsiveSizes.large}rem) and (min-width: ${responsiveSizes.small}rem) {
    width: ${(props) => props.theme.menuTabletWidth};
  }

  @media (not((max-width: ${responsiveSizes.large}rem) and (min-width: ${responsiveSizes.small}rem))) {
    width: ${(props) => props.theme.menuMobileWidth};
  }

  height: 100vh;
  padding: 20px;
  transform: ${(props) => props.hasVisibility ? "translateX(0)" : "translateX(100vw)"};
  opacity: ${(props) => props.hasVisibility ? "1" : "0.96"};
  transition-property: transform, opacity;
  transition-duration: 0.6s;
  transition-timing-function: ease-in-out;
  box-sizing: border-box;
`;
var ResponsiveLogoContainer = styled16.div`
  max-height: ${(props) => props.theme.logoHeight};
  width: ${(props) => props.theme.logoWidth};
  display: flex;
`;
var CloseAction = styled16.button`
  display: flex;
  justify-content: center;
  align-content: center;
  padding: 6px;
  border: unset;
  border-radius: 2px;
  background-color: transparent;
  cursor: pointer;

  :focus,
  :focus-visible {
    outline: ${(props) => props.theme.hamburgerFocusColor} auto 1px;
  }
  font-size: 24px;
  svg {
    height: 24px;
    width: 24px;
  }
`;
var MenuContent = styled16.div`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  height: 100%;
  color: ${(props) => props.theme.contentColor};
`;
var Overlay2 = styled16.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100vw;
  height: 100vh;
  background-color: ${(props) => props.theme.overlayColor};
  opacity: ${(props) => props.theme.overlayOpacity} !important;
  visibility: ${(props) => props.hasVisibility ? "visible" : "hidden"};
  opacity: ${(props) => props.hasVisibility ? "1" : "0"};

  @media (max-width: ${responsiveSizes.small}rem) {
    display: none;
  }

  transition: opacity 0.2s 0.2s ease-in-out;
  z-index: ${(props) => props.theme.overlayZindex};
`;
var Header_default = DxcHeader;

// src/sidenav/Sidenav.tsx
import { forwardRef as forwardRef3, useContext as useContext10, useEffect as useEffect4, useState as useState7 } from "react";
import styled18, { ThemeProvider as ThemeProvider8 } from "styled-components";

// src/bleed/Bleed.tsx
import styled17 from "styled-components";
import { jsx as jsx20 } from "react/jsx-runtime";
var getSpacingValue = (spacingName) => spacingName ?? "0rem";
var StyledBleed = styled17.div`
  ${({ space, horizontal, vertical, top, right, bottom, left }) => `
    margin: -${getSpacingValue(top || vertical || space)} -${getSpacingValue(
  right || horizontal || space
)} -${getSpacingValue(bottom || vertical || space)} -${getSpacingValue(left || horizontal || space)};
  `}
`;
var Bleed = ({ space, horizontal, vertical, top, right, bottom, left, children }) => /* @__PURE__ */ jsx20(
  StyledBleed,
  {
    space,
    horizontal,
    vertical,
    top,
    right,
    bottom,
    left,
    children
  }
);
var Bleed_default = Bleed;

// src/sidenav/SidenavContext.tsx
import { createContext as createContext4, useContext as useContext9 } from "react";
var SidenavContext = createContext4(null);
var GroupContext = createContext4(null);
var SidenavContextProvider = SidenavContext.Provider;
var GroupContextProvider = GroupContext.Provider;
var useResponsiveSidenavVisibility = () => {
  const changeResponsiveSidenavVisibility = useContext9(SidenavContext);
  return changeResponsiveSidenavVisibility;
};

// src/sidenav/Sidenav.tsx
import { Fragment as Fragment6, jsx as jsx21, jsxs as jsxs12 } from "react/jsx-runtime";
var DxcSidenav = ({ title, children }) => {
  const colorsTheme = useContext10(HalstackContext);
  return /* @__PURE__ */ jsx21(ThemeProvider8, { theme: colorsTheme.sidenav, children: /* @__PURE__ */ jsxs12(SidenavContainer, { children: [
    title,
    /* @__PURE__ */ jsx21(Flex_default, { direction: "column", gap: "1rem", children })
  ] }) });
};
var Title2 = ({ children }) => /* @__PURE__ */ jsx21(Bleed_default, { horizontal: "1rem", children: /* @__PURE__ */ jsx21(SidenavTitle, { children }) });
var Section = ({ children }) => /* @__PURE__ */ jsxs12(Fragment6, { children: [
  /* @__PURE__ */ jsx21(Bleed_default, { horizontal: "1rem", children: /* @__PURE__ */ jsx21(Flex_default, { direction: "column", children }) }),
  /* @__PURE__ */ jsx21(Divider, {})
] });
var Group = ({ title, collapsable = false, icon, children }) => {
  const [collapsed, setCollapsed] = useState7(false);
  const [isSelected, changeIsSelected] = useState7(false);
  return /* @__PURE__ */ jsx21(GroupContextProvider, { value: changeIsSelected, children: /* @__PURE__ */ jsxs12(SidenavGroup, { children: [
    collapsable && title ? /* @__PURE__ */ jsxs12(
      SidenavGroupTitleButton,
      {
        "aria-expanded": !collapsed,
        onClick: () => setCollapsed(!collapsed),
        selectedGroup: collapsed && isSelected,
        children: [
          /* @__PURE__ */ jsxs12(Flex_default, { alignItems: "center", gap: "0.5rem", children: [
            typeof icon === "string" ? /* @__PURE__ */ jsx21(Icon_default, { icon }) : icon,
            title
          ] }),
          /* @__PURE__ */ jsx21(Icon_default, { icon: collapsed ? "expand_more" : "expand_less" })
        ]
      }
    ) : title && /* @__PURE__ */ jsxs12(SidenavGroupTitle, { children: [
      typeof icon === "string" ? /* @__PURE__ */ jsx21(Icon_default, { icon }) : icon,
      title
    ] }),
    !collapsed && children
  ] }) });
};
var Link = forwardRef3(
  ({ href, newWindow = false, selected = false, icon, onClick, tabIndex = 0, children, ...otherProps }, ref) => {
    const changeIsGroupSelected = useContext10(GroupContext);
    const setIsSidenavVisibleResponsive = useResponsiveSidenavVisibility();
    const handleClick = ($event) => {
      onClick?.($event);
      setIsSidenavVisibleResponsive?.(false);
    };
    useEffect4(() => {
      changeIsGroupSelected?.((isGroupSelected2) => !isGroupSelected2 ? selected : isGroupSelected2);
    }, [selected, changeIsGroupSelected]);
    return /* @__PURE__ */ jsxs12(
      SidenavLink,
      {
        selected,
        href: href ? href : void 0,
        target: href ? newWindow ? "_blank" : "_self" : void 0,
        ref,
        tabIndex,
        onClick: handleClick,
        ...otherProps,
        children: [
          /* @__PURE__ */ jsxs12(Flex_default, { alignItems: "center", gap: "0.5rem", children: [
            typeof icon === "string" ? /* @__PURE__ */ jsx21(Icon_default, { icon }) : icon,
            children
          ] }),
          newWindow && /* @__PURE__ */ jsx21(Icon_default, { icon: "open_in_new" })
        ]
      }
    );
  }
);
var SidenavContainer = styled18.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  width: 280px;
  @media (max-width: ${responsiveSizes.large}rem) {
    width: 100vw;
  }
  padding: 2rem 1rem;
  background-color: ${(props) => props.theme.backgroundColor};

  overflow-y: auto;
  overflow-x: hidden;
  ::-webkit-scrollbar {
    width: 2px;
  }
  ::-webkit-scrollbar-track {
    background-color: ${(props) => props.theme.scrollBarTrackColor};
    border-radius: 3px;
  }
  ::-webkit-scrollbar-thumb {
    background-color: ${(props) => props.theme.scrollBarThumbColor};
    border-radius: 3px;
  }
`;
var SidenavTitle = styled18.div`
  display: flex;
  align-items: center;
  padding: 0.5rem 1.2rem;
  font-family: ${(props) => props.theme.titleFontFamily};
  font-style: ${(props) => props.theme.titleFontStyle};
  font-weight: ${(props) => props.theme.titleFontWeight};
  font-size: ${(props) => props.theme.titleFontSize};
  color: ${(props) => props.theme.titleFontColor};
  letter-spacing: ${(props) => props.theme.titleFontLetterSpacing};
  text-transform: ${(props) => props.theme.titleFontTextTransform};
`;
var Divider = styled18.div`
  width: 100%;
  height: 1px;
  background-color: ${coreTokens_default.color_grey_400};

  &:last-child {
    display: none;
  }
`;
var SidenavGroup = styled18.div`
  a {
    padding: 0.5rem 1.2rem 0.5rem 2.25rem;
  }
`;
var SidenavGroupTitle = styled18.span`
  box-sizing: border-box;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  padding: 0.5rem 1.2rem;
  font-family: ${(props) => props.theme.groupTitleFontFamily};
  font-style: ${(props) => props.theme.groupTitleFontStyle};
  font-weight: ${(props) => props.theme.groupTitleFontWeight};
  font-size: ${(props) => props.theme.groupTitleFontSize};
  span::before {
    font-size: 16px;
  }
  svg {
    height: 16px;
    width: 16px;
  }
`;
var SidenavGroupTitleButton = styled18.button`
  all: unset;
  box-sizing: border-box;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  padding: 0.5rem 1.2rem;
  font-family: ${(props) => props.theme.groupTitleFontFamily};
  font-style: ${(props) => props.theme.groupTitleFontStyle};
  font-weight: ${(props) => props.theme.groupTitleFontWeight};
  font-size: ${(props) => props.theme.groupTitleFontSize};
  cursor: pointer;

  ${(props) => props.selectedGroup ? `color: ${props.theme.groupTitleSelectedFontColor}; background-color: ${props.theme.groupTitleSelectedBackgroundColor};` : `color: ${props.theme.groupTitleFontColor}; background-color: transparent;`}

  &:focus, &:focus-visible {
    outline: 2px solid ${(props) => props.theme.linkFocusColor};
    outline-offset: -2px;
  }
  &:hover {
    ${(props) => props.selectedGroup ? `color: ${props.theme.groupTitleSelectedHoverFontColor}; background-color: ${props.theme.groupTitleSelectedHoverBackgroundColor};` : `color: ${props.theme.groupTitleFontColor}; background-color: ${props.theme.groupTitleHoverBackgroundColor};`}
  }
  &:active {
    color: #fff;
    background-color: ${(props) => props.selectedGroup ? "#333" : props.theme.groupTitleActiveBackgroundColor};
  }
  span::before {
    font-size: 16px;
  }
  svg {
    height: 16px;
    width: 16px;
  }
`;
var SidenavLink = styled18.a`
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 0.5rem;
  padding: 0.5rem 1.2rem;
  box-shadow: 0 0 0 2px transparent;
  font-family: ${(props) => props.theme.linkFontFamily};
  font-style: ${(props) => props.theme.linkFontStyle};
  font-weight: ${(props) => props.theme.linkFontWeight};
  font-size: ${(props) => props.theme.linkFontSize};
  letter-spacing: ${(props) => props.theme.linkFontLetterSpacing};
  text-transform: ${(props) => props.theme.linkFontTextTransform};
  text-decoration: ${(props) => props.theme.linkTextDecoration};
  cursor: pointer;

  ${(props) => props.selected ? `color: ${props.theme.linkSelectedFontColor}; background-color: ${props.theme.linkSelectedBackgroundColor};` : `color: ${props.theme.linkFontColor}; background-color: transparent;`}

  &:focus, &:focus-visible {
    outline: 2px solid ${(props) => props.theme.linkFocusColor};
    outline-offset: -2px;
  }
  &:hover {
    ${(props) => props.selected ? `color: ${props.theme.linkSelectedHoverFontColor}; background-color: ${props.theme.linkSelectedHoverBackgroundColor};` : `color: ${props.theme.linkFontColor}; background-color: ${props.theme.linkHoverBackgroundColor};`}
  }
  &:active {
    color: #fff;
    background-color: ${(props) => props.selected ? "#333" : "#4d4d4d"};
    outline: 2px solid #0095ff;
    outline-offset: -2px;
  }
  span::before {
    font-size: 16px;
  }
  svg {
    height: 16px;
    width: 16px;
  }
`;
DxcSidenav.Section = Section;
DxcSidenav.Group = Group;
DxcSidenav.Link = Link;
DxcSidenav.Title = Title2;
var Sidenav_default = DxcSidenav;

// src/layout/utils.tsx
import { Children as Children2, isValidElement, useState as useState8, useEffect as useEffect5 } from "react";

// src/layout/Icons.tsx
import { jsx as jsx22, jsxs as jsxs13 } from "react/jsx-runtime";
var layoutIcons = {
  facebookLogo: /* @__PURE__ */ jsx22(
    "svg",
    {
      version: "1.1",
      x: "0px",
      y: "0px",
      width: "438.536px",
      height: "438.536px",
      viewBox: "0 0 438.536 438.536",
      fill: "#FFFFFF",
      children: /* @__PURE__ */ jsx22("g", { children: /* @__PURE__ */ jsx22(
        "path",
        {
          d: "M414.41,24.123C398.333,8.042,378.963,0,356.315,0H82.228C59.58,0,40.21,8.042,24.126,24.123\n      C8.045,40.207,0.003,59.576,0.003,82.225v274.084c0,22.647,8.042,42.018,24.123,58.102c16.084,16.084,35.454,24.126,58.102,24.126\n      h274.084c22.648,0,42.018-8.042,58.095-24.126c16.084-16.084,24.126-35.454,24.126-58.102V82.225\n      C438.532,59.576,430.49,40.204,414.41,24.123z M373.155,225.548h-49.963V406.84h-74.802V225.548H210.99V163.02h37.401v-37.402\n      c0-26.838,6.283-47.107,18.843-60.813c12.559-13.706,33.304-20.555,62.242-20.555h49.963v62.526h-31.401\n      c-10.663,0-17.467,1.853-20.417,5.568c-2.949,3.711-4.428,10.23-4.428,19.558v31.119h56.534L373.155,225.548z"
        }
      ) })
    }
  ),
  xLogo: /* @__PURE__ */ jsxs13("svg", { width: "256", height: "256", viewBox: "0 0 256 256", fill: "none", xmlns: "http://www.w3.org/2000/svg", children: [
    /* @__PURE__ */ jsx22("rect", { width: "256", height: "256", rx: "40", fill: "white" }),
    /* @__PURE__ */ jsx22(
      "path",
      {
        d: "M140.192 118.205L187.848 64H176.556L135.158 111.056L102.117 64H64L113.975 135.163L64 192H75.2914L118.982 142.296L153.883 192H192L140.192 118.205ZM124.722 135.787L119.65 128.697L79.3634 72.3294H96.7094L129.232 117.837L134.282 124.927L176.551 184.076H159.205L124.722 135.787Z",
        fill: "#0F1419"
      }
    )
  ] }),
  linkedinLogo: /* @__PURE__ */ jsx22(
    "svg",
    {
      version: "1.1",
      x: "0px",
      y: "0px",
      width: "438.536px",
      height: "438.536px",
      viewBox: "0 0 438.536 438.536",
      fill: "#FFFFFF",
      children: /* @__PURE__ */ jsx22("g", { children: /* @__PURE__ */ jsx22(
        "path",
        {
          d: "M414.41,24.123C398.333,8.042,378.963,0,356.315,0H82.228C59.58,0,40.21,8.042,24.126,24.123\n        C8.045,40.207,0.003,59.576,0.003,82.225v274.084c0,22.647,8.042,42.018,24.123,58.102c16.084,16.084,35.454,24.126,58.102,24.126\n        h274.084c22.648,0,42.018-8.042,58.095-24.126c16.084-16.084,24.126-35.454,24.126-58.102V82.225\n        C438.532,59.576,430.49,40.204,414.41,24.123z M133.618,367.157H67.666V169.016h65.952V367.157z M127.626,132.332\n        c-6.851,6.567-15.893,9.851-27.124,9.851h-0.288c-10.848,0-19.648-3.284-26.407-9.851c-6.76-6.567-10.138-14.703-10.138-24.41\n        c0-9.897,3.476-18.083,10.421-24.556c6.95-6.471,15.942-9.708,26.98-9.708c11.039,0,19.89,3.237,26.553,9.708\n        c6.661,6.473,10.088,14.659,10.277,24.556C137.899,117.625,134.477,125.761,127.626,132.332z M370.873,367.157h-65.952v-105.92\n        c0-29.879-11.036-44.823-33.116-44.823c-8.374,0-15.42,2.331-21.128,6.995c-5.715,4.661-9.996,10.324-12.847,16.991\n        c-1.335,3.422-1.999,8.75-1.999,15.981v110.775h-65.952c0.571-119.529,0.571-185.579,0-198.142h65.952v27.974\n        c13.867-21.681,33.558-32.544,59.101-32.544c22.84,0,41.21,7.52,55.104,22.554c13.895,15.037,20.841,37.214,20.841,66.519v113.64\n        H370.873z"
        }
      ) })
    }
  )
};
var Icons_default = layoutIcons;

// src/layout/utils.tsx
var year = (/* @__PURE__ */ new Date()).getFullYear();
var bottomLinks = [
  {
    href: "https://www.linkedin.com/company/dxctechnology",
    text: "Linkedin"
  },
  {
    href: "https://x.com/dxctechnology",
    text: "X"
  },
  {
    href: "https://www.facebook.com/DXCTechnology/",
    text: "Facebook"
  }
];
var socialLinks = [
  {
    href: "https://www.linkedin.com/company/dxctechnology",
    logo: Icons_default.linkedinLogo,
    title: "Linkedin"
  },
  {
    href: "https://x.com/dxctechnology",
    logo: Icons_default.xLogo,
    title: "X"
  },
  {
    href: "https://www.facebook.com/DXCTechnology/",
    logo: Icons_default.facebookLogo,
    title: "Facebook"
  }
];
var findChildType = (children, childType) => Children2.toArray(children).find((child) => isValidElement(child) && child.type === childType);
var useResponsive = (breakpoint) => {
  const [isResponsive, setIsResponsive] = useState8(false);
  useEffect5(() => {
    const handleResize = () => {
      setIsResponsive(window.matchMedia(`(max-width: ${breakpoint}rem)`).matches);
    };
    handleResize();
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, [breakpoint]);
  return isResponsive;
};

// src/layout/ApplicationLayout.tsx
import { Fragment as Fragment7, jsx as jsx23, jsxs as jsxs14 } from "react/jsx-runtime";
var ApplicationLayoutContainer = styled19.div`
  position: absolute;
  top: 64px;
  bottom: 0;
  left: 0;
  right: 0;
  display: flex;
  flex-direction: column;

  @media (max-width: ${responsiveSizes.large}rem) {
    ${(props) => props.hasSidenav && "top: 116px"};
    ${(props) => props.isSidenavVisible && "overflow: hidden;"}
  }
`;
var HeaderContainer2 = styled19.div`
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  z-index: 3;
`;
var VisibilityToggle = styled19.div`
  position: fixed;
  top: 64px;
  left: 0;
  right: 0;
  box-sizing: border-box;
  display: flex;
  align-items: center;
  padding: 4px 16px;
  width: 100%;
  background-color: #f2f2f2;
  user-select: none;
  z-index: 2;
`;
var HamburgerTrigger2 = styled19.button`
  display: flex;
  flex-wrap: wrap;
  gap: 10px;
  border: 0px solid transparent;
  border-radius: 2px;
  padding: 12px 4px;
  background-color: transparent;
  box-shadow: 0 0 0 2px transparent;
  font-family:
    Open Sans,
    sans-serif;
  font-weight: 600;
  font-size: 14px;
  color: #000;
  cursor: pointer;

  :active {
    background-color: #cccccc;
  }
  :focus,
  :focus-visible {
    outline: none;
    box-shadow: 0 0 0 2px #0095ff;
  }
  span::before {
    font-size: 20px;
  }
`;
var BodyContainer = styled19.div`
  display: flex;
  flex-direction: row;
  flex: 1;
`;
var SidenavContainer2 = styled19.div`
  position: sticky;
  top: 64px;
  display: flex;
  height: calc(100vh - 64px);
  z-index: 1;

  @media (max-width: ${responsiveSizes.large}rem) {
    position: absolute;
    top: 0px;
    height: 100%;
  }
`;
var MainContainer = styled19.div`
  display: flex;
  flex-direction: column;
  width: 100%;
`;
var MainContentContainer = styled19.main`
  flex: 1;
  background-color: #fff;
`;
var Main = ({ children }) => /* @__PURE__ */ jsx23(Fragment7, { children });
var DxcApplicationLayout = ({
  visibilityToggleLabel = "",
  header,
  sidenav,
  footer,
  children
}) => {
  const [isSidenavVisibleResponsive, setIsSidenavVisibleResponsive] = useState9(false);
  const isResponsive = useResponsive(responsiveSizes.large);
  const ref = useRef4(null);
  const translatedLabels = useContext11(HalstackLanguageContext);
  const handleSidenavVisibility = () => {
    setIsSidenavVisibleResponsive((currentIsSidenavVisibleResponsive) => !currentIsSidenavVisibleResponsive);
  };
  useEffect6(() => {
    if (!isResponsive) {
      setIsSidenavVisibleResponsive(false);
    }
  }, [isResponsive]);
  return /* @__PURE__ */ jsxs14(ApplicationLayoutContainer, { hasSidenav: !!sidenav, isSidenavVisible: isSidenavVisibleResponsive, ref, children: [
    /* @__PURE__ */ jsx23(HeaderContainer2, { children: header ?? /* @__PURE__ */ jsx23(Header_default, { underlined: true }) }),
    sidenav && isResponsive && /* @__PURE__ */ jsx23(VisibilityToggle, { children: /* @__PURE__ */ jsx23(Tooltip, { label: translatedLabels.applicationLayout.visibilityToggleTitle, children: /* @__PURE__ */ jsxs14(
      HamburgerTrigger2,
      {
        onClick: handleSidenavVisibility,
        "aria-label": visibilityToggleLabel ? void 0 : translatedLabels.applicationLayout.visibilityToggleTitle,
        children: [
          /* @__PURE__ */ jsx23(Icon_default, { icon: "Menu" }),
          visibilityToggleLabel
        ]
      }
    ) }) }),
    /* @__PURE__ */ jsxs14(BodyContainer, { children: [
      /* @__PURE__ */ jsx23(SidenavContextProvider, { value: setIsSidenavVisibleResponsive, children: sidenav && (isResponsive ? isSidenavVisibleResponsive : true) && /* @__PURE__ */ jsx23(SidenavContainer2, { children: sidenav }) }),
      /* @__PURE__ */ jsxs14(MainContainer, { children: [
        /* @__PURE__ */ jsx23(MainContentContainer, { children: findChildType(children, Main) }),
        footer ?? /* @__PURE__ */ jsx23(
          Footer_default,
          {
            copyright: `\xA9 DXC Technology ${year}. All rights reserved.`,
            bottomLinks,
            socialLinks
          }
        )
      ] })
    ] })
  ] });
};
DxcApplicationLayout.Footer = Footer_default;
DxcApplicationLayout.Header = Header_default;
DxcApplicationLayout.Main = Main;
DxcApplicationLayout.SideNav = Sidenav_default;
DxcApplicationLayout.useResponsiveSidenavVisibility = useResponsiveSidenavVisibility;
var ApplicationLayout_default = DxcApplicationLayout;

// src/badge/Badge.tsx
import styled20 from "styled-components";
import { jsx as jsx24, jsxs as jsxs15 } from "react/jsx-runtime";
var contextualColorMap = {
  grey: {
    background: coreTokens_default.color_grey_200,
    text: coreTokens_default.color_grey_900
  },
  blue: {
    background: coreTokens_default.color_blue_200,
    text: coreTokens_default.color_blue_900
  },
  green: {
    background: coreTokens_default.color_green_200,
    text: coreTokens_default.color_green_900
  },
  orange: {
    background: coreTokens_default.color_orange_200,
    text: coreTokens_default.color_orange_900
  },
  red: {
    background: coreTokens_default.color_red_200,
    text: coreTokens_default.color_red_900
  },
  yellow: {
    background: coreTokens_default.color_yellow_200,
    text: coreTokens_default.color_yellow_900
  },
  purple: {
    background: coreTokens_default.color_purple_200,
    text: coreTokens_default.color_purple_900
  }
};
var sizeMap = {
  small: {
    height: "20px",
    width: "20px",
    minWidth: "20px",
    fontSize: coreTokens_default.type_scale_01,
    borderRadius: coreTokens_default.spacing_12,
    iconSize: "14px",
    padding: {
      contextual: `${coreTokens_default.spacing_4}`,
      notification: `${coreTokens_default.spacing_0} ${coreTokens_default.spacing_4}`
    }
  },
  medium: {
    height: "24px",
    width: "24px",
    minWidth: "24px",
    fontSize: coreTokens_default.type_scale_02,
    borderRadius: coreTokens_default.spacing_12,
    iconSize: "16px",
    padding: {
      contextual: `${coreTokens_default.spacing_4} ${coreTokens_default.spacing_8}`,
      notification: `${coreTokens_default.spacing_0} ${coreTokens_default.spacing_4}`
    }
  },
  large: {
    height: "32px",
    width: "32px",
    minWidth: "32px",
    fontSize: coreTokens_default.type_scale_04,
    borderRadius: coreTokens_default.spacing_24,
    iconSize: "24px",
    padding: {
      contextual: `${coreTokens_default.spacing_4} ${coreTokens_default.spacing_8}`,
      notification: `${coreTokens_default.spacing_0} ${coreTokens_default.spacing_8}`
    }
  }
};
var DxcBadge = ({
  label,
  title,
  mode = "contextual",
  color = "grey",
  icon,
  notificationLimit = 99,
  size = "medium"
}) => /* @__PURE__ */ jsx24(Tooltip, { label: title, children: /* @__PURE__ */ jsxs15(
  BadgeContainer,
  {
    label,
    mode,
    color: mode === "contextual" && color || void 0,
    size,
    "aria-label": title,
    children: [
      mode === "contextual" && icon && /* @__PURE__ */ jsx24(IconContainer4, { size, children: typeof icon === "string" ? /* @__PURE__ */ jsx24(Icon_default, { icon }) : icon }),
      label && /* @__PURE__ */ jsx24(Label, { size, children: typeof label === "number" ? label > notificationLimit ? `+${notificationLimit}` : label : label })
    ]
  }
) });
var getColor = (mode, color) => mode === "contextual" && color ? contextualColorMap[color].text : coreTokens_default.color_white;
var getBackgroundColor = (mode, color) => mode === "contextual" && color ? contextualColorMap[color].background : coreTokens_default.color_red_700;
var getPadding = (mode, size) => size && (mode === "contextual" ? sizeMap[size].padding.contextual : sizeMap[size].padding.notification);
var BadgeContainer = styled20.div`
  box-sizing: border-box;
  border-radius: ${(props) => props.size && sizeMap[props.size].borderRadius};
  padding: ${(props) => props.label ? getPadding(props.mode, props.size) : ""};
  width: ${(props) => !props.label && props.mode === "notification" ? props.size && sizeMap[props.size].width : "fit-content"};
  min-width: ${(props) => props.mode === "notification" && props.size && sizeMap[props.size].minWidth};
  height: ${(props) => props.size && sizeMap[props.size].height};
  display: flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_2};
  justify-content: center;
  background-color: ${(props) => getBackgroundColor(props.mode, props.color)};
  color: ${(props) => getColor(props.mode, props.color)};
`;
var IconContainer4 = styled20.div`
  display: flex;
  font-size: ${(props) => props.size && sizeMap[props.size].iconSize};

  svg {
    height: ${(props) => props.size && sizeMap[props.size].iconSize};
    width: ${(props) => props.size && sizeMap[props.size].iconSize};
  }
`;
var Label = styled20.span`
  font-family: ${coreTokens_default.type_sans};
  font-size: ${(props) => props.size && sizeMap[props.size].fontSize};
  font-weight: ${coreTokens_default.type_semibold};
  white-space: nowrap;
`;
var Badge_default = DxcBadge;

// src/breadcrumbs/Breadcrumbs.tsx
import { useCallback as useCallback5 } from "react";
import styled22 from "styled-components";

// src/breadcrumbs/dropdownTheme.ts
var dropdownTheme_default = {
  dropdown: {
    // Breadcrumbs tokens
    buttonIconSize: coreTokens_default.spacing_16,
    buttonPaddingTop: coreTokens_default.spacing_4,
    buttonPaddingBottom: coreTokens_default.spacing_4,
    buttonPaddingLeft: coreTokens_default.spacing_4,
    buttonPaddingRight: coreTokens_default.spacing_4,
    buttonHeight: "24px",
    buttonBorderRadius: "2px",
    buttonBorderColor: coreTokens_default.color_transparent,
    optionFontSize: "14px",
    optionPaddingTop: coreTokens_default.spacing_0,
    optionPaddingBottom: coreTokens_default.spacing_0,
    optionPaddingLeft: coreTokens_default.spacing_16,
    optionPaddingRight: coreTokens_default.spacing_16,
    // Dropdown tokens
    buttonBackgroundColor: coreTokens_default.color_white,
    hoverButtonBackgroundColor: coreTokens_default.color_grey_100,
    activeButtonBackgroundColor: coreTokens_default.color_grey_300,
    buttonFontFamily: coreTokens_default.type_sans,
    buttonFontSize: coreTokens_default.type_scale_03,
    buttonFontStyle: coreTokens_default.type_normal,
    buttonFontWeight: coreTokens_default.type_regular,
    buttonFontColor: coreTokens_default.color_black,
    buttonIconSpacing: "10px",
    buttonIconColor: coreTokens_default.color_black,
    buttonBorderStyle: coreTokens_default.border_none,
    buttonBorderThickness: coreTokens_default.border_width_0,
    disabledColor: coreTokens_default.color_grey_500,
    disabledButtonBackgroundColor: coreTokens_default.color_transparent,
    disabledButtonBorderColor: coreTokens_default.color_transparent,
    optionBackgroundColor: coreTokens_default.color_white,
    hoverOptionBackgroundColor: coreTokens_default.color_grey_100,
    activeOptionBackgroundColor: coreTokens_default.color_grey_300,
    optionFontFamily: coreTokens_default.type_sans,
    optionFontStyle: coreTokens_default.type_normal,
    optionFontWeight: coreTokens_default.type_regular,
    optionFontColor: coreTokens_default.color_black,
    optionIconSize: "20px",
    optionIconSpacing: "10px",
    optionIconColor: coreTokens_default.color_black,
    caretIconSize: "24px",
    caretIconColor: coreTokens_default.color_black,
    caretIconSpacing: "12px",
    borderRadius: "4px",
    borderStyle: coreTokens_default.border_none,
    borderThickness: coreTokens_default.border_width_0,
    borderColor: coreTokens_default.color_transparent,
    scrollBarThumbColor: coreTokens_default.color_grey_700,
    scrollBarTrackColor: coreTokens_default.color_grey_300,
    focusColor: coreTokens_default.color_blue_600
  }
};

// src/breadcrumbs/Item.tsx
import { useRef as useRef5 } from "react";
import styled21 from "styled-components";
import { jsx as jsx25 } from "react/jsx-runtime";
var Item = ({ isCurrentPage = false, href, label, onClick }) => {
  const currentItemRef = useRef5(null);
  const handleOnMouseEnter = (event) => {
    const labelContainer = event.currentTarget;
    const optionElement = currentItemRef.current;
    if (optionElement?.title === "" && labelContainer.scrollWidth > labelContainer.clientWidth) {
      optionElement.title = label;
    }
  };
  const handleOnClick = (event) => {
    event.preventDefault();
    if (href) {
      onClick?.(href);
    }
  };
  return /* @__PURE__ */ jsx25(ListItem, { "aria-current": isCurrentPage ? "page" : void 0, isCurrentPage, children: isCurrentPage ? /* @__PURE__ */ jsx25(CurrentPage, { ref: currentItemRef, onMouseEnter: handleOnMouseEnter, children: label }) : /* @__PURE__ */ jsx25(Link2, { href, onClick: handleOnClick, children: /* @__PURE__ */ jsx25(Text, { children: label }) }) });
};
var ListItem = styled21.li`
  display: flex;
  align-items: center;
  font-family: ${coreTokens_default.type_sans};
  font-size: ${coreTokens_default.type_scale_02};
  color: ${coreTokens_default.color_black};
  ${({ isCurrentPage }) => isCurrentPage && "overflow: hidden;"}
`;
var CurrentPage = styled21.span`
  font-weight: ${coreTokens_default.type_semibold};
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  cursor: default;
`;
var Link2 = styled21.a`
  border-radius: ${coreTokens_default.border_radius_small};
  padding: ${coreTokens_default.spacing_0} ${coreTokens_default.spacing_2};
  display: inline-flex;
  align-items: center;
  height: 24px;
  color: ${coreTokens_default.color_black};
  text-decoration: ${coreTokens_default.type_no_line};
  cursor: pointer;

  &:focus {
    outline: ${coreTokens_default.border_width_2} solid ${coreTokens_default.color_blue_600};
  }
`;
var Text = styled21.span`
  border: ${coreTokens_default.border_width_1} solid ${coreTokens_default.color_transparent};
  &:hover {
    border-bottom-color: ${coreTokens_default.color_black};
  }
`;
var Item_default = Item;

// src/breadcrumbs/Breadcrumbs.tsx
import { Fragment as Fragment8, jsx as jsx26, jsxs as jsxs16 } from "react/jsx-runtime";
var DxcBreadcrumbs = ({
  ariaLabel = "Breadcrumbs",
  items,
  itemsBeforeCollapse = 4,
  onItemClick,
  showRoot = true
}) => {
  const handleOnSelectOption = useCallback5(
    (href) => {
      if (onItemClick) {
        onItemClick(href);
      } else {
        window.location.href = href;
      }
    },
    [items]
  );
  return /* @__PURE__ */ jsx26("nav", { "aria-label": ariaLabel, children: /* @__PURE__ */ jsx26(OrderedList, { children: items && items.length > Math.max(itemsBeforeCollapse, 2) ? /* @__PURE__ */ jsxs16(Fragment8, { children: [
    showRoot && /* @__PURE__ */ jsx26(Item_default, { href: items[0]?.href, label: items[0]?.label ?? "" }, 0),
    /* @__PURE__ */ jsx26(Flex_default, { alignItems: "center", as: "li", children: /* @__PURE__ */ jsx26(HalstackProvider, { advancedTheme: dropdownTheme_default, children: /* @__PURE__ */ jsx26(
      Dropdown_default,
      {
        caretHidden: true,
        icon: /* @__PURE__ */ jsx26(Icon_default, { icon: "more_horiz" }),
        margin: showRoot ? { left: "small" } : void 0,
        onSelectOption: handleOnSelectOption,
        options: items.slice(showRoot ? 1 : 0, -1).map(({ label, href }) => ({ label, value: href }))
      }
    ) }) }, 1),
    /* @__PURE__ */ jsx26(Item_default, { isCurrentPage: true, label: items[items.length - 1]?.label ?? "" }, 2)
  ] }) : items.map((item, index, { length }) => /* @__PURE__ */ jsx26(
    Item_default,
    {
      href: item.href,
      isCurrentPage: index === length - 1,
      label: item.label,
      onClick: onItemClick
    },
    index
  )) }) });
};
var OrderedList = styled22.ol`
  margin: ${coreTokens_default.spacing_0};
  padding-left: ${coreTokens_default.spacing_0};
  display: flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_12};
  list-style-type: none;

  > li:not(:first-child) {
    > a,
    > span {
      margin-left: ${coreTokens_default.spacing_12};
    }
    &::before {
      margin: ${coreTokens_default.spacing_0} ${coreTokens_default.spacing_2};
      transform: rotate(15deg);
      border-right: ${coreTokens_default.border_width_1} solid ${coreTokens_default.color_grey_500};
      height: 1rem;
      content: "";
    }
  }
`;
var Breadcrumbs_default = DxcBreadcrumbs;

// src/bulleted-list/BulletedList.tsx
import { Children as Children3, useContext as useContext13 } from "react";
import styled24, { ThemeProvider as ThemeProvider9 } from "styled-components";

// src/typography/Typography.tsx
import { useContext as useContext12, useMemo as useMemo6 } from "react";
import styled23 from "styled-components";

// src/typography/TypographyContext.tsx
import { createContext as createContext5 } from "react";
var TypographyContext_default = createContext5({
  as: "span",
  color: "#000000",
  display: "inline",
  fontFamily: "Open Sans, sans-serif",
  fontSize: "1rem",
  fontStyle: "normal",
  fontWeight: "400",
  letterSpacing: "0em",
  lineHeight: "1.5em",
  textAlign: "left",
  textDecoration: "none",
  textOverflow: "unset",
  whiteSpace: "normal"
});

// src/typography/Typography.tsx
import { jsx as jsx27 } from "react/jsx-runtime";
var Typography = styled23.span`
  margin: 0px;
  display: ${({ display }) => display};
  color: ${({ color }) => color};
  font-family: ${({ fontFamily }) => fontFamily};
  font-size: ${({ fontSize }) => fontSize};
  font-style: ${({ fontStyle }) => fontStyle};
  font-weight: ${({ fontWeight }) => fontWeight};
  letter-spacing: ${({ letterSpacing }) => letterSpacing};
  text-align: ${({ textAlign }) => textAlign};
  line-height: ${({ lineHeight }) => lineHeight};
  text-decoration: ${({ textDecoration }) => textDecoration};
  text-overflow: ${({ textOverflow }) => textOverflow};
  white-space: ${({ whiteSpace, textOverflow }) => whiteSpace !== "normal" ? whiteSpace : textOverflow !== "unset" ? "nowrap" : "normal"};
  overflow: ${({ textOverflow }) => textOverflow !== "unset" ? "hidden" : "visible"};
`;
function DxcTypography({ children, ...props }) {
  const componentContext = useContext12(TypographyContext_default);
  const contextValue = useMemo6(
    () => ({
      ...componentContext,
      ...props
    }),
    [componentContext, props]
  );
  return /* @__PURE__ */ jsx27(TypographyContext_default.Provider, { value: contextValue, children: /* @__PURE__ */ jsx27(Typography, { ...contextValue, children }) });
}

// src/bulleted-list/BulletedList.tsx
import { Fragment as Fragment9, jsx as jsx28, jsxs as jsxs17 } from "react/jsx-runtime";
var BulletedListItem = ({ children }) => /* @__PURE__ */ jsx28(Fragment9, { children });
var DxcBulletedList = ({ children, type = "disc", icon = "" }) => {
  const colorsTheme = useContext13(HalstackContext);
  return /* @__PURE__ */ jsx28(ThemeProvider9, { theme: colorsTheme.bulletedList, children: /* @__PURE__ */ jsx28(ListContainer, { children: /* @__PURE__ */ jsx28(Flex_default, { direction: "column", as: type === "number" ? "ol" : "ul", gap: "0.125rem", children: Children3.map(children, (child, index) => /* @__PURE__ */ jsx28(ListItem2, { children: /* @__PURE__ */ jsxs17(GeneralContent, { children: [
    type === "number" ? /* @__PURE__ */ jsx28(Number2, { children: /* @__PURE__ */ jsxs17(DxcTypography, { color: colorsTheme.bulletedList.fontColor, children: [
      index + 1,
      "."
    ] }) }) : type === "square" ? /* @__PURE__ */ jsx28(Bullet, { children: /* @__PURE__ */ jsx28(Square, {}) }) : type === "circle" ? /* @__PURE__ */ jsx28(Bullet, { children: /* @__PURE__ */ jsx28(Circle, {}) }) : type === "icon" ? /* @__PURE__ */ jsx28(Bullet, { children: /* @__PURE__ */ jsx28(Icon, { children: typeof icon === "string" ? /* @__PURE__ */ jsx28(Icon_default, { icon }) : icon }) }) : /* @__PURE__ */ jsx28(Bullet, { children: /* @__PURE__ */ jsx28(Disc, {}) }),
    /* @__PURE__ */ jsx28(DxcTypography, { color: colorsTheme.bulletedList.fontColor, children: child })
  ] }) })) }) }) });
};
DxcBulletedList.Item = BulletedListItem;
var ListContainer = styled24.div`
  ul,
  ol {
    padding: 0;
    margin: 0;
  }
`;
var Bullet = styled24.div`
  display: flex;
  align-self: flex-start;
  align-items: center;
  height: 1.5rem;
`;
var GeneralContent = styled24.div`
  display: grid;
  grid-template-columns: auto 1fr;
  align-items: center;
`;
var Icon = styled24.div`
  height: 1.5rem;
  width: auto;
  margin-right: ${(props) => props.theme.bulletMarginRight};
  align-content: center;
  color: ${(props) => props.theme.fontColor};

  font-size: ${(props) => props.theme.bulletIconHeight};
  svg {
    height: ${(props) => props.theme.bulletIconHeight};
    width: ${(props) => props.theme.bulletIconWidth};
  }
`;
var Number2 = styled24.div`
  user-select: none;
  margin-right: ${(props) => props.theme.bulletMarginRight};
  display: flex;
  box-sizing: border-box;
  align-self: flex-start;
  min-width: 0;
`;
var Square = styled24.div`
  background-color: ${(props) => props.theme.fontColor};
  height: ${(props) => props.theme.bulletHeight};
  width: ${(props) => props.theme.bulletWidth};
  margin-right: ${(props) => props.theme.bulletMarginRight};
`;
var Circle = styled24.div`
  height: ${(props) => props.theme.bulletHeight};
  width: ${(props) => props.theme.bulletWidth};
  border-radius: 50%;
  border: 1px solid;
  border-color: ${(props) => props.theme.fontColor};
  margin-right: ${(props) => props.theme.bulletMarginRight};
`;
var Disc = styled24.div`
  background-color: ${(props) => props.theme.fontColor};
  height: ${(props) => props.theme.bulletHeight};
  width: ${(props) => props.theme.bulletWidth};
  border-radius: 50%;
  margin-right: ${(props) => props.theme.bulletMarginRight};
`;
var ListItem2 = styled24.li`
  display: flex;
  margin: 0px;
  padding: 0px;
  list-style: none;
  font-size: 1em;
`;
var BulletedList_default = DxcBulletedList;

// src/card/Card.tsx
import { useContext as useContext14, useState as useState10 } from "react";
import styled25, { ThemeProvider as ThemeProvider10 } from "styled-components";
import { jsx as jsx29, jsxs as jsxs18 } from "react/jsx-runtime";
var DxcCard = ({
  imageSrc,
  imageBgColor = "black",
  imagePadding,
  imagePosition = "before",
  linkHref,
  onClick,
  imageCover = false,
  margin,
  tabIndex = 0,
  outlined = true,
  children
}) => {
  const colorsTheme = useContext14(HalstackContext);
  const [isHovered, changeIsHovered] = useState10(false);
  return /* @__PURE__ */ jsx29(ThemeProvider10, { theme: colorsTheme.card, children: /* @__PURE__ */ jsx29(
    Card,
    {
      hasAction: onClick || linkHref ? true : false,
      margin,
      onMouseEnter: () => changeIsHovered(true),
      onMouseLeave: () => changeIsHovered(false),
      onClick,
      tabIndex: onClick || linkHref ? tabIndex : -1,
      as: linkHref && "a",
      href: linkHref,
      shadowDepth: !outlined ? 0 : isHovered && (onClick || linkHref) ? 2 : 1,
      children: /* @__PURE__ */ jsxs18(CardContainer, { hasAction: onClick || linkHref ? true : false, imagePosition: imageSrc ? imagePosition : "none", children: [
        imageSrc && /* @__PURE__ */ jsx29(ImageContainer, { imageBgColor, children: /* @__PURE__ */ jsx29(TagImage, { imagePadding, imageCover, src: imageSrc, alt: "Card image" }) }),
        /* @__PURE__ */ jsx29(CardContent, { children })
      ] })
    }
  ) });
};
var Card = styled25.div`
  display: inline-flex;
  cursor: ${({ hasAction }) => hasAction && "pointer" || "unset"};
  outline: ${({ hasAction }) => !hasAction && "none"};
  margin: ${({ margin }) => margin && typeof margin !== "object" ? spaces[margin] : "0px"};
  margin-top: ${({ margin }) => margin && typeof margin === "object" && margin.top ? spaces[margin.top] : ""};
  margin-right: ${({ margin }) => margin && typeof margin === "object" && margin.right ? spaces[margin.right] : ""};
  margin-bottom: ${({ margin }) => margin && typeof margin === "object" && margin.bottom ? spaces[margin.bottom] : ""};
  margin-left: ${({ margin }) => margin && typeof margin === "object" && margin.left ? spaces[margin.left] : ""};
  text-decoration: none;
  ${({ hasAction }) => hasAction && `:focus {
      outline: #0095ff auto 1px;
    }`}

  box-shadow: ${({ shadowDepth }) => shadowDepth === 1 ? `0px 3px 6px ${coreTokens_default.color_grey_300_a}` : shadowDepth === 2 ? `0px 3px 10px ${coreTokens_default.color_grey_300_a}` : "none"};
`;
var CardContainer = styled25.div`
  display: inline-flex;
  flex-direction: ${(props) => props.imagePosition === "after" ? "row-reverse" : "row"};
  height: ${(props) => props.theme.height};
  width: ${(props) => props.theme.width};
  &:hover {
    border-color: ${({ hasAction }) => hasAction ? "" : "unset"};
  }
`;
var TagImage = styled25.img`
  height: ${({ imagePadding }) => !imagePadding ? "100%" : typeof imagePadding !== "object" && `calc(100% - ${spaces[imagePadding]} - ${spaces[imagePadding]})`};
  width: ${({ imagePadding }) => !imagePadding ? "100%" : typeof imagePadding !== "object" && `calc(100% - ${spaces[imagePadding]} - ${spaces[imagePadding]})`};
  object-fit: ${({ imageCover }) => imageCover ? "cover" : "contain"};
`;
var ImageContainer = styled25.div`
  display: inline-flex;
  justify-content: center;
  align-items: center;
  flex-shrink: 0;
  width: 35%;
  height: 100%;
  background-color: ${({ imageBgColor }) => imageBgColor};
`;
var CardContent = styled25.div`
  flex-grow: 1;
  overflow: hidden;
`;
var Card_default = DxcCard;

// src/checkbox/Checkbox.tsx
import { useContext as useContext15, useState as useState11, useRef as useRef6, useId as useId4, forwardRef as forwardRef4 } from "react";
import styled26, { ThemeProvider as ThemeProvider11 } from "styled-components";
import { jsx as jsx30, jsxs as jsxs19 } from "react/jsx-runtime";
var checkedIcon = /* @__PURE__ */ jsx30("svg", { fill: "currentColor", focusable: "false", viewBox: "0 0 24 24", children: /* @__PURE__ */ jsx30("path", { d: "M19 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.11 0 2-.9 2-2V5c0-1.1-.89-2-2-2zm-9 14-5-5 1.41-1.41L10 14.17l7.59-7.59L19 8l-9 9z" }) });
var DxcCheckbox = forwardRef4(
  ({
    checked,
    defaultChecked = false,
    value,
    label = "",
    labelPosition = "before",
    name = "",
    disabled = false,
    optional = false,
    readOnly = false,
    onChange,
    margin,
    size = "fitContent",
    tabIndex = 0,
    ariaLabel = "Checkbox"
  }, ref) => {
    const labelId = `label-checkbox-${useId4()}`;
    const [innerChecked, setInnerChecked] = useState11(defaultChecked);
    const checkboxRef = useRef6(null);
    const colorsTheme = useContext15(HalstackContext);
    const translatedLabels = useContext15(HalstackLanguageContext);
    const handleCheckboxChange = () => {
      if (!disabled && !readOnly) {
        if (document.activeElement !== checkboxRef.current) {
          checkboxRef.current?.focus();
        }
        if (checked == null) {
          setInnerChecked((innerCurrentlyChecked) => !innerCurrentlyChecked);
        }
        onChange?.(!(checked ?? innerChecked));
      }
    };
    const handleKeyboard = (event) => {
      switch (event.key) {
        case " ":
          event.preventDefault();
          handleCheckboxChange();
          break;
        default:
          break;
      }
    };
    return /* @__PURE__ */ jsx30(ThemeProvider11, { theme: colorsTheme.checkbox, children: /* @__PURE__ */ jsxs19(
      MainContainer2,
      {
        disabled,
        readOnly,
        onClick: handleCheckboxChange,
        margin,
        size,
        checked: checked ?? innerChecked,
        ref,
        children: [
          label && /* @__PURE__ */ jsxs19(LabelContainer2, { id: labelId, disabled, labelPosition, "aria-label": label, children: [
            label,
            optional && ` ${translatedLabels.formFields.optionalLabel}`
          ] }),
          /* @__PURE__ */ jsx30(
            ValueInput,
            {
              type: "checkbox",
              checked: checked ?? innerChecked,
              name,
              value,
              disabled,
              readOnly: true
            }
          ),
          /* @__PURE__ */ jsx30(CheckboxContainer, { children: /* @__PURE__ */ jsx30(
            Checkbox,
            {
              onKeyDown: handleKeyboard,
              role: "checkbox",
              tabIndex: disabled ? -1 : tabIndex,
              "aria-checked": checked ?? innerChecked,
              "aria-disabled": disabled,
              "aria-readonly": readOnly,
              "aria-required": !disabled && !optional,
              "aria-labelledby": label ? labelId : void 0,
              "aria-label": label ? void 0 : ariaLabel,
              checked: checked ?? innerChecked,
              disabled,
              readOnly,
              ref: checkboxRef,
              children: (checked ?? innerChecked) && checkedIcon
            }
          ) })
        ]
      }
    ) });
  }
);
var sizes2 = {
  small: "120px",
  medium: "240px",
  large: "480px",
  fillParent: "100%",
  fitContent: "fit-content"
};
var calculateWidth4 = (margin, size) => size === "fillParent" ? `calc(${sizes2[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes2[size];
var getDisabledColor = (theme, element) => {
  switch (element) {
    case "check":
      return theme.disabledCheckColor;
    case "background":
      return theme.disabledBackgroundColorChecked;
    case "border":
      return theme.disabledBorderColor;
    case "label":
      return theme.disabledFontColor;
    default:
      return void 0;
  }
};
var getReadOnlyColor = (theme, element) => {
  switch (element) {
    case "check":
      return theme.readOnlyCheckColor;
    case "background":
      return theme.readOnlyBackgroundColorChecked;
    case "hoverBackground":
      return theme.hoverReadOnlyBackgroundColorChecked;
    case "border":
      return theme.readOnlyBorderColor;
    case "hoverBorder":
      return theme.hoverReadOnlyBorderColor;
    default:
      return void 0;
  }
};
var getEnabledColor = (theme, element) => {
  switch (element) {
    case "check":
      return theme.checkColor;
    case "background":
      return theme.backgroundColorChecked;
    case "hoverBackground":
      return theme.hoverBackgroundColorChecked;
    case "border":
      return theme.borderColor;
    case "hoverBorder":
      return theme.hoverBorderColor;
    case "label":
      return theme.fontColor;
    default:
      return void 0;
  }
};
var LabelContainer2 = styled26.span`
  order: ${(props) => props.labelPosition === "before" ? 0 : 1};
  color: ${(props) => props.disabled ? getDisabledColor(props.theme, "label") : getEnabledColor(props.theme, "label")};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-weight: ${(props) => props.theme.fontWeight};
`;
var ValueInput = styled26.input`
  display: none;
`;
var CheckboxContainer = styled26.span`
  display: flex;
  align-items: center;
  justify-content: center;
  height: 24px;
  width: 24px;
`;
var Checkbox = styled26.span`
  position: relative;
  box-sizing: border-box;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 18px;
  width: 18px;
  border: 2px solid
    ${(props) => props.disabled ? getDisabledColor(props.theme, "border") : props.readOnly ? getReadOnlyColor(props.theme, "border") : getEnabledColor(props.theme, "border")};
  border-radius: 2px;
  background-color: ${(props) => props.checked ? props.disabled ? getDisabledColor(props.theme, "check") : props.readOnly ? getReadOnlyColor(props.theme, "check") : getEnabledColor(props.theme, "check") : "transparent"};
  color: ${(props) => props.disabled ? getDisabledColor(props.theme, "background") : props.readOnly ? getReadOnlyColor(props.theme, "background") : getEnabledColor(props.theme, "background")};

  &:focus {
    outline: 2px solid ${(props) => props.theme.focusColor};
    outline-offset: 2px;
  }
  svg {
    position: absolute;
    width: 22px;
    height: 22px;
  }
  ${(props) => props.disabled && "pointer-events: none;"}
`;
var MainContainer2 = styled26.div`
  display: inline-flex;
  align-items: center;
  gap: ${(props) => props.theme.checkLabelSpacing};
  width: ${(props) => calculateWidth4(props.margin, props.size)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  cursor: ${(props) => props.disabled ? "not-allowed" : props.readOnly ? "default" : "pointer"};

  &:hover ${Checkbox} {
    border: 2px solid
      ${(props) => {
  if (!props.disabled)
    return props.readOnly ? getReadOnlyColor(props.theme, "hoverBorder") : getEnabledColor(props.theme, "hoverBorder");
}};
    color: ${(props) => {
  if (!props.disabled)
    return props.readOnly ? getReadOnlyColor(props.theme, "hoverBackground") : getEnabledColor(props.theme, "hoverBackground");
}};
  }
`;
var Checkbox_default = DxcCheckbox;

// src/chip/Chip.tsx
import { useContext as useContext16 } from "react";
import styled27, { ThemeProvider as ThemeProvider12 } from "styled-components";
import { jsx as jsx31, jsxs as jsxs20 } from "react/jsx-runtime";
var DxcChip = ({
  label,
  suffixIcon,
  prefixIcon,
  onClickSuffix,
  onClickPrefix,
  disabled,
  margin,
  tabIndex = 0
}) => {
  const colorsTheme = useContext16(HalstackContext);
  return /* @__PURE__ */ jsx31(ThemeProvider12, { theme: colorsTheme.chip, children: /* @__PURE__ */ jsxs20(Chip, { disabled, margin, children: [
    prefixIcon && /* @__PURE__ */ jsx31(
      IconContainer5,
      {
        role: typeof onClickPrefix === "function" ? "button" : void 0,
        "aria-label": typeof onClickPrefix === "function" ? "Prefix Action" : void 0,
        disabled,
        interactive: typeof onClickPrefix === "function" && !disabled,
        tabIndex: typeof onClickPrefix === "function" && !disabled ? tabIndex : -1,
        onClick: () => onClickPrefix && !disabled && onClickPrefix(),
        children: typeof prefixIcon === "string" ? /* @__PURE__ */ jsx31(Icon_default, { icon: prefixIcon }) : prefixIcon
      }
    ),
    label && /* @__PURE__ */ jsx31(LabelContainer3, { disabled, children: label }),
    suffixIcon && /* @__PURE__ */ jsx31(
      IconContainer5,
      {
        role: typeof onClickSuffix === "function" ? "button" : void 0,
        "aria-label": typeof onClickSuffix === "function" ? "Suffix Action" : void 0,
        disabled,
        interactive: typeof onClickSuffix === "function" && !disabled,
        tabIndex: typeof onClickSuffix === "function" && !disabled ? tabIndex : -1,
        onClick: () => !disabled && onClickSuffix?.(),
        children: typeof suffixIcon === "string" ? /* @__PURE__ */ jsx31(Icon_default, { icon: suffixIcon }) : suffixIcon
      }
    )
  ] }) });
};
var calculateWidth5 = (margin) => `calc(100% - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})`;
var Chip = styled27.div`
  box-sizing: border-box;
  display: inline-flex;
  align-items: center;
  gap: ${(props) => props.theme.iconSpacing};
  min-height: 40px;
  max-width: ${(props) => calculateWidth5(props.margin)};
  background-color: ${(props) => props.disabled && props.theme.disabledBackgroundColor || props.theme.backgroundColor};
  border-radius: ${(props) => props.theme.borderRadius};
  border-width: ${(props) => props.theme.borderThickness};
  border-style: ${(props) => props.theme.borderStyle};
  border-color: ${(props) => props.theme.borderColor};

  padding-top: ${(props) => props.theme.contentPaddingTop};
  padding-bottom: ${(props) => props.theme.contentPaddingBottom};
  padding-left: ${(props) => props.theme.contentPaddingLeft};
  padding-right: ${(props) => props.theme.contentPaddingRight};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  cursor: ${({ disabled }) => disabled && "not-allowed"};
`;
var LabelContainer3 = styled27.span`
  font-size: ${(props) => props.theme.fontSize};
  font-family: ${(props) => props.theme.fontFamily};
  font-weight: ${(props) => props.theme.fontWeight};
  font-style: ${(props) => props.theme.fontStyle};
  color: ${(props) => props.disabled ? props.theme.disabledFontColor : props.theme.fontColor};
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
`;
var IconContainer5 = styled27.div`
  display: flex;
  border-radius: 0.25rem;
  color: ${(props) => props.disabled ? props.theme.disabledIconColor : props.theme.iconColor};
  ${({ interactive }) => interactive && "cursor: pointer;"}

  ${(props) => props.interactive && `
      &:hover {
        color: ${props.theme.hoverIconColor};
      }
      &:focus,
      &:focus-visible {
        outline: ${props.theme.focusBorderThickness} ${props.theme.focusBorderStyle} ${props.theme.focusColor};
      }
      &:active {
        color: ${props.theme.activeIconColor};
      }
    `}

  font-size: ${(props) => props.theme.iconSize};
  svg {
    width: ${(props) => props.theme.iconSize};
    height: ${(props) => props.theme.iconSize};
  }
`;
var Chip_default = DxcChip;

// src/contextual-menu/ContextualMenu.tsx
import { useContext as useContext19, useLayoutEffect as useLayoutEffect3, useMemo as useMemo8, useRef as useRef7, useState as useState14 } from "react";
import styled31, { ThemeProvider as ThemeProvider13 } from "styled-components";

// src/contextual-menu/MenuItem.tsx
import styled29 from "styled-components";

// src/contextual-menu/GroupItem.tsx
import { useContext as useContext17, useMemo as useMemo7, useState as useState13, memo as memo4, useId as useId5 } from "react";

// src/contextual-menu/ItemAction.tsx
import { cloneElement as cloneElement2, useState as useState12 } from "react";
import styled28 from "styled-components";
import { jsx as jsx32, jsxs as jsxs21 } from "react/jsx-runtime";
var ItemAction = ({ badge, collapseIcon, icon, label, depthLevel, ...props }) => {
  const [hasTooltip, setHasTooltip] = useState12(false);
  const modifiedBadge = badge && cloneElement2(badge, { size: "small" });
  return /* @__PURE__ */ jsx32(TooltipWrapper, { condition: hasTooltip, label, children: /* @__PURE__ */ jsxs21(Action, { depthLevel, ...props, children: [
    /* @__PURE__ */ jsxs21(Label2, { children: [
      collapseIcon && /* @__PURE__ */ jsx32(Icon2, { children: collapseIcon }),
      icon && depthLevel === 0 && /* @__PURE__ */ jsx32(Icon2, { children: typeof icon === "string" ? /* @__PURE__ */ jsx32(Icon_default, { icon }) : icon }),
      /* @__PURE__ */ jsx32(
        Text2,
        {
          selected: props.selected,
          onMouseEnter: (event) => {
            const text = event.currentTarget;
            setHasTooltip(text.scrollWidth > text.clientWidth);
          },
          children: label
        }
      )
    ] }),
    modifiedBadge
  ] }) });
};
var Action = styled28.button`
  border: none;
  border-radius: 4px;
  padding: ${(props) => `${coreTokens_default.spacing_4} ${coreTokens_default.spacing_8} ${coreTokens_default.spacing_4} ${`
    calc(${coreTokens_default.spacing_8} + (${coreTokens_default.spacing_24} * ${props.depthLevel}))
  `};`};
  box-shadow: inset 0 0 0 2px transparent;
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: ${coreTokens_default.spacing_16};
  ${({ selected, theme }) => selected ? `background-color: ${theme.selectedMenuItemBackgroundColor};` : `background-color: ${coreTokens_default.color_transparent}`};
  cursor: pointer;
  overflow: hidden;

  &:hover {
    ${({ selected, theme }) => selected ? `background-color: ${theme.hoverSelectedMenuItemBackgroundColor};` : `background-color: ${theme.hoverMenuItemBackgroundColor};`};
  }
  &:active {
    ${({ selected, theme }) => selected ? `background-color: ${theme.activeSelectedMenuItemBackgroundColor};` : `background-color: ${theme.activeMenuItemBackgroundColor};`};
  }
  &:focus {
    outline: 2px solid ${coreTokens_default.color_blue_600};
    outline-offset: -1px;
  }
`;
var Icon2 = styled28.span`
  display: flex;
  font-size: ${({ theme }) => theme.iconSize};
  color: ${({ theme }) => theme.iconColor};

  svg {
    height: ${({ theme }) => theme.iconSize};
    width: ${({ theme }) => theme.iconSize};
  }
`;
var Label2 = styled28.span`
  display: flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_8};
  overflow: hidden;
`;
var Text2 = styled28.span`
  color: ${({ theme }) => theme.menuItemFontColor};
  font-family: ${({ theme }) => theme.fontFamily};
  font-size: ${({ theme }) => theme.menuItemFontSize};
  font-style: ${({ theme }) => theme.menuItemFontStyle};
  font-weight: ${({ selected, theme }) => selected ? theme.selectedMenuItemFontWeight : theme.menuItemFontWeight};
  line-height: ${({ theme }) => theme.menuItemLineHeight};
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
`;
var ItemAction_default = ItemAction;

// src/contextual-menu/ContextualMenuContext.tsx
import { createContext as createContext6 } from "react";
var ContextualMenuContext_default = createContext6(null);

// src/contextual-menu/GroupItem.tsx
import { Fragment as Fragment10, jsx as jsx33, jsxs as jsxs22 } from "react/jsx-runtime";
var isGroupSelected = (items, selectedItemId) => items.some((item) => {
  if ("items" in item) return isGroupSelected(item.items, selectedItemId);
  else if (selectedItemId !== -1) return item.id === selectedItemId;
  else return item.selectedByDefault;
});
var GroupItem = ({ items, ...props }) => {
  const groupMenuId = `group-menu-${useId5()}`;
  const { selectedItemId } = useContext17(ContextualMenuContext_default) ?? {};
  const groupSelected = useMemo7(() => isGroupSelected(items, selectedItemId), [items, selectedItemId]);
  const [isOpen, setIsOpen] = useState13(groupSelected && selectedItemId === -1);
  return /* @__PURE__ */ jsxs22(Fragment10, { children: [
    /* @__PURE__ */ jsx33(
      ItemAction_default,
      {
        "aria-controls": isOpen ? groupMenuId : void 0,
        "aria-expanded": isOpen ? true : void 0,
        "aria-pressed": groupSelected && !isOpen,
        collapseIcon: isOpen ? /* @__PURE__ */ jsx33(Icon_default, { icon: "filled_expand_less" }) : /* @__PURE__ */ jsx33(Icon_default, { icon: "filled_expand_more" }),
        onClick: () => {
          setIsOpen((isCurrentlyOpen) => !isCurrentlyOpen);
        },
        selected: groupSelected && !isOpen,
        ...props
      }
    ),
    isOpen && /* @__PURE__ */ jsx33(SubMenu, { id: groupMenuId, children: items.map((item, index) => /* @__PURE__ */ jsx33(MenuItem_default, { item, depthLevel: props.depthLevel + 1 }, `${item.label}-${index}`)) })
  ] });
};
var GroupItem_default = memo4(GroupItem);

// src/contextual-menu/SingleItem.tsx
import { useContext as useContext18, useEffect as useEffect7 } from "react";
import { jsx as jsx34 } from "react/jsx-runtime";
var SingleItem = ({ id, onSelect, selectedByDefault = false, ...props }) => {
  const { selectedItemId, setSelectedItemId } = useContext18(ContextualMenuContext_default) ?? {};
  const handleClick = () => {
    setSelectedItemId?.(id);
    onSelect?.();
  };
  useEffect7(() => {
    if (selectedItemId === -1 && selectedByDefault) {
      setSelectedItemId?.(id);
    }
  }, [selectedItemId, selectedByDefault, id]);
  return /* @__PURE__ */ jsx34(
    ItemAction_default,
    {
      "aria-pressed": selectedItemId === -1 ? selectedByDefault : selectedItemId === id,
      onClick: handleClick,
      selected: selectedItemId === -1 ? selectedByDefault : selectedItemId === id,
      ...props
    }
  );
};
var SingleItem_default = SingleItem;

// src/contextual-menu/MenuItem.tsx
import { jsx as jsx35 } from "react/jsx-runtime";
var MenuItem = ({ item, depthLevel = 0 }) => /* @__PURE__ */ jsx35(StyledMenuItem, { role: "menuitem", children: "items" in item ? /* @__PURE__ */ jsx35(GroupItem_default, { ...item, depthLevel }) : /* @__PURE__ */ jsx35(SingleItem_default, { ...item, depthLevel }) });
var StyledMenuItem = styled29.li`
  display: grid;
  gap: ${coreTokens_default.spacing_4};
`;
var MenuItem_default = MenuItem;

// src/contextual-menu/Section.tsx
import styled30 from "styled-components";
import { useId as useId6 } from "react";
import { jsx as jsx36, jsxs as jsxs23 } from "react/jsx-runtime";
var Section2 = ({ section, index, length }) => {
  const id = `section-${useId6()}`;
  return /* @__PURE__ */ jsxs23("section", { "aria-label": section.title ?? id, "aria-labelledby": id, children: [
    section.title && /* @__PURE__ */ jsx36(Title3, { id, children: section.title }),
    /* @__PURE__ */ jsx36(SubMenu, { children: section.items.map((item, index2) => /* @__PURE__ */ jsx36(MenuItem_default, { item }, `${item.label}-${index2}`)) }),
    index !== length - 1 && /* @__PURE__ */ jsx36(Inset_default, { top: "0.25rem", bottom: "0.25rem", children: /* @__PURE__ */ jsx36(Divider_default, { color: "lightGrey" }) })
  ] });
};
var Title3 = styled30.h2`
  margin: 0 0 ${coreTokens_default.spacing_4} 0;
  padding: ${coreTokens_default.spacing_4};
  color: ${({ theme }) => theme.sectionTitleFontColor};
  font-family: ${({ theme }) => theme.fontFamily};
  font-size: ${({ theme }) => theme.sectionTitleFontSize};
  font-style: ${({ theme }) => theme.sectionTitleFontStyle};
  font-weight: ${({ theme }) => theme.sectionTitleFontWeight};
  line-height: ${({ theme }) => theme.sectionTitleLineHeight};
`;
var Section_default = Section2;

// src/contextual-menu/ContextualMenu.tsx
import { jsx as jsx37 } from "react/jsx-runtime";
var ContextualMenu = styled31.div`
  box-sizing: border-box;
  margin: 0;
  border: 1px solid ${({ theme }) => theme.borderColor};
  border-radius: 0.25rem;
  padding: ${coreTokens_default.spacing_16} ${coreTokens_default.spacing_8};
  display: grid;
  gap: ${coreTokens_default.spacing_4};
  min-width: 248px;
  max-height: 100%;
  background-color: ${({ theme }) => theme.backgroundColor};
  overflow-y: auto;
  overflow-x: hidden;
  &::-webkit-scrollbar {
    width: 8px;
    height: 8px;
  }
  &::-webkit-scrollbar-thumb {
    background-color: ${coreTokens_default.color_grey_700};
    border-radius: 0.25rem;
  }
  &::-webkit-scrollbar-track {
    background-color: ${coreTokens_default.color_grey_300};
    border-radius: 0.25rem;
  }
`;
var StyledSubMenu = styled31.ul`
  margin: 0;
  padding: 0;
  display: grid;
  gap: ${coreTokens_default.spacing_4};
  list-style: none;
`;
var isGroupItem = (item) => "items" in item;
var isSection = (item) => "items" in item && !("label" in item);
var addIdToItems = (items) => {
  let accId = 0;
  const innerAddIdToItems = (items2) => {
    return items2.map(
      (item) => isSection(item) ? { ...item, items: innerAddIdToItems(item.items) } : isGroupItem(item) ? { ...item, items: innerAddIdToItems(item.items) } : { ...item, id: accId++ }
    );
  };
  return innerAddIdToItems(items);
};
var SubMenu = ({ children, id }) => /* @__PURE__ */ jsx37(StyledSubMenu, { id, role: "menu", children });
function DxcContextualMenu({ items }) {
  const [selectedItemId, setSelectedItemId] = useState14(-1);
  const contextualMenuRef = useRef7(null);
  const itemsWithId = useMemo8(() => addIdToItems(items), [items]);
  const contextValue = useMemo8(() => ({ selectedItemId, setSelectedItemId }), [selectedItemId, setSelectedItemId]);
  const colorsTheme = useContext19(HalstackContext);
  const [firstUpdate, setFirstUpdate] = useState14(true);
  useLayoutEffect3(() => {
    if (selectedItemId !== -1 && firstUpdate) {
      const contextualMenuEl = contextualMenuRef.current;
      const selectedItemEl = contextualMenuEl?.querySelector("[aria-pressed='true']");
      contextualMenuEl?.scrollTo?.({
        top: (selectedItemEl?.offsetTop ?? 0) - (contextualMenuEl?.clientHeight ?? 0) / 2
      });
      setFirstUpdate(false);
    }
  }, [firstUpdate, selectedItemId]);
  return /* @__PURE__ */ jsx37(ThemeProvider13, { theme: colorsTheme.contextualMenu, children: /* @__PURE__ */ jsx37(ContextualMenu, { ref: contextualMenuRef, children: /* @__PURE__ */ jsx37(ContextualMenuContext_default.Provider, { value: contextValue, children: itemsWithId[0] && isSection(itemsWithId[0]) ? itemsWithId.map((item, index) => /* @__PURE__ */ jsx37(Section_default, { section: item, index, length: itemsWithId.length }, `section-${index}`)) : /* @__PURE__ */ jsx37(SubMenu, { children: itemsWithId.map((item, index) => /* @__PURE__ */ jsx37(MenuItem_default, { item }, `${item.label}-${index}`)) }) }) }) });
}

// src/data-grid/DataGrid.tsx
import { useContext as useContext24, useEffect as useEffect8, useMemo as useMemo10, useState as useState17 } from "react";
import DataGrid from "react-data-grid";
import styled37, { ThemeProvider as ThemeProvider17 } from "styled-components";
import "react-data-grid/lib/styles.css";

// src/data-grid/utils.tsx
import { textEditor } from "react-data-grid";
import { jsx as jsx38, jsxs as jsxs24 } from "react/jsx-runtime";
var overwriteTheme = (theme) => {
  const newTheme = {
    checkbox: {
      backgroundColorChecked: theme?.dataGrid?.headerCheckboxBackgroundColorChecked,
      hoverBackgroundColorChecked: theme?.dataGrid?.headerCheckboxHoverBackgroundColorChecked,
      borderColor: theme?.dataGrid?.headerCheckboxBorderColor,
      hoverBorderColor: theme?.dataGrid?.headerCheckboxHoverBorderColor,
      checkColor: theme?.dataGrid?.headerCheckboxCheckColor,
      focusColor: theme?.dataGrid?.focusColor
    }
  };
  return newTheme;
};
var convertToRDGColumns = (gridColumn, summaryRow) => ({
  key: gridColumn.key,
  name: gridColumn.label,
  resizable: gridColumn.resizable,
  sortable: gridColumn.sortable,
  draggable: gridColumn.draggable,
  editable: gridColumn.textEditable,
  headerCellClass: gridColumn.alignment ? `header-align-${gridColumn.alignment}` : `header-align-left`,
  renderEditCell: gridColumn.textEditable ? textEditor : void 0,
  renderCell: ({ row }) => /* @__PURE__ */ jsx38("div", { className: `ellipsis-cell ${gridColumn.alignment ? `align-${gridColumn.alignment}` : "align-left"}`, children: row[gridColumn.key] }),
  renderSummaryCell: () => gridColumn.summaryKey ? /* @__PURE__ */ jsx38("div", { className: `ellipsis-cell ${gridColumn.alignment ? `align-${gridColumn.alignment}` : "align-left"}`, children: summaryRow?.[gridColumn.summaryKey] }) : void 0
});
var renderSortStatus = ({ sortDirection }) => /* @__PURE__ */ jsx38("div", { className: "sortIconContainer", children: sortDirection !== void 0 ? sortDirection === "ASC" ? /* @__PURE__ */ jsx38(Icon_default, { icon: "Keyboard_Arrow_Up" }) : /* @__PURE__ */ jsx38(Icon_default, { icon: "Keyboard_Arrow_Down" }) : /* @__PURE__ */ jsx38(Icon_default, { icon: "Expand_All" }) });
var renderExpandableTrigger = (row, rows, uniqueRowId, setRowsToRender) => /* @__PURE__ */ jsx38(
  ActionIcon_default,
  {
    icon: row.contentIsExpanded ? "arrow_drop_down" : "arrow_right",
    title: "Expand content",
    "aria-expanded": row.contentIsExpanded,
    onClick: () => {
      row.contentIsExpanded = !row.contentIsExpanded;
      if (row.contentIsExpanded) {
        const rowIndex = rows.findIndex((rowToRender) => row === rowToRender);
        setRowsToRender((currentRows) => {
          const newRows = [...currentRows];
          addRow(newRows, rowIndex + 1, {
            isExpandedChildContent: row.contentIsExpanded,
            [uniqueRowId]: `${rowKeyGetter(row, uniqueRowId)}_expanded`,
            expandedChildContent: row.expandedContent,
            triggerRowKey: rowKeyGetter(row, uniqueRowId),
            expandedContentHeight: row.expandedContentHeight
          });
          return newRows;
        });
      } else {
        const rowIndex = rows.findIndex((rowToRender) => row === rowToRender);
        setRowsToRender((currentRows) => {
          const newRows = [...currentRows];
          deleteRow(newRows, rowIndex + 1);
          return newRows;
        });
      }
    },
    disabled: !rows.some((row2) => uniqueRowId in row2)
  }
);
var renderHierarchyTrigger = (rows, triggerRow, uniqueRowId, columnKey, setRowsToRender) => /* @__PURE__ */ jsxs24(
  "button",
  {
    type: "button",
    disabled: !rows.some((row) => uniqueRowId in row),
    onClick: () => {
      let newRowsToRender = [...rows];
      if (!triggerRow.visibleChildren) {
        const rowIndex = rows.findIndex((rowToRender) => triggerRow === rowToRender);
        triggerRow.childRows?.forEach((childRow, index) => {
          childRow.rowLevel = triggerRow.rowLevel && typeof triggerRow.rowLevel === "number" ? triggerRow.rowLevel + 1 : 1;
          childRow.parentKey = rowKeyGetter(triggerRow, uniqueRowId);
          addRow(newRowsToRender, rowIndex + 1 + index, childRow);
        });
      } else {
        const rowsToRemove = [
          ...rows.filter(
            (rowToRender) => rowToRender.parentKey && rowToRender.parentKey === rowKeyGetter(triggerRow, uniqueRowId)
          )
        ];
        const rowsToCheck = [...rowsToRemove];
        while (rowsToCheck.length > 0) {
          const currentRow = rowsToCheck.pop();
          const childRows = currentRow?.visibleChildren && currentRow?.childRows ? currentRow.childRows : [];
          rowsToRemove.push(...childRows);
          rowsToCheck.push(...childRows);
        }
        newRowsToRender = rows.filter(
          (row) => !rowsToRemove.map((rowToRemove) => {
            if (rowToRemove.visibleChildren) {
              rowToRemove.visibleChildren = false;
            }
            return rowKeyGetter(rowToRemove, uniqueRowId);
          }).includes(rowKeyGetter(row, uniqueRowId))
        );
      }
      triggerRow.visibleChildren = !triggerRow.visibleChildren;
      setRowsToRender(newRowsToRender);
    },
    children: [
      /* @__PURE__ */ jsx38(Icon_default, { icon: triggerRow.visibleChildren ? "Keyboard_Arrow_Down" : "Chevron_Right" }),
      /* @__PURE__ */ jsx38("span", { className: "ellipsis-cell", children: triggerRow[columnKey] })
    ]
  }
);
var renderCheckbox = (rows, row, uniqueRowId, selectedRows, onSelectRows) => /* @__PURE__ */ jsx38(
  Checkbox_default,
  {
    checked: selectedRows.has(rowKeyGetter(row, uniqueRowId)),
    onChange: (checked) => {
      const selected = new Set(selectedRows);
      if (checked) {
        selected.add(rowKeyGetter(row, uniqueRowId));
      } else {
        selected.delete(rowKeyGetter(row, uniqueRowId));
      }
      if (row.childRows && Array.isArray(row.childRows)) {
        getChildrenSelection(row.childRows, uniqueRowId, selected, checked);
      }
      if (row.parentKey) {
        getParentSelectedState(rows, row.parentKey, uniqueRowId, selected, checked);
      }
      onSelectRows(selected);
    },
    disabled: !rows.some((row2) => uniqueRowId in row2)
  }
);
var renderHeaderCheckbox = (rows, uniqueRowId, selectedRows, colorsTheme, onSelectRows) => /* @__PURE__ */ jsx38(HalstackProvider, { advancedTheme: overwriteTheme(colorsTheme), children: /* @__PURE__ */ jsx38(
  Checkbox_default,
  {
    checked: rows.length > 0 && !rows.some((row) => !selectedRows.has(rowKeyGetter(row, uniqueRowId))),
    onChange: (checked) => {
      const updatedSelection = new Set(selectedRows);
      if (checked) {
        rows.forEach((row) => {
          updatedSelection.add(rowKeyGetter(row, uniqueRowId));
          if (row.childRows && Array.isArray(row.childRows)) {
            getChildrenSelection(row.childRows, uniqueRowId, updatedSelection, checked);
          }
        });
      } else {
        rows.forEach((row) => {
          updatedSelection.delete(rowKeyGetter(row, uniqueRowId));
          if (row.childRows && Array.isArray(row.childRows)) {
            getChildrenSelection(row.childRows, uniqueRowId, updatedSelection, checked);
          }
        });
      }
      onSelectRows(updatedSelection);
    },
    disabled: rows.length === 0 || !rows.some((row) => uniqueRowId in row)
  }
) });
var rowKeyGetter = (row, uniqueRowId) => {
  const keyValue = row[uniqueRowId];
  return typeof keyValue === "string" || typeof keyValue === "number" ? keyValue : "";
};
var getCustomSortFn = (columns) => {
  const customSortFunctions = [...columns].filter((column) => column.sortFn).map((column) => ({ column: column.key, sortFn: column.sortFn }));
  return customSortFunctions;
};
var compareRows = (rowA, rowB, sortFn) => {
  if (rowA != null && rowB != null) {
    if (!sortFn) {
      return rowA > rowB ? 1 : rowA < rowB ? -1 : 0;
    }
    return sortFn(rowA, rowB);
  }
  return 0;
};
var sortRows = (rows, sortColumns, sortFunctions, reversed) => [...rows].sort(
  (a, b) => sortColumns.reduce((compResult, sort) => {
    if (compResult !== 0) {
      return compResult;
    }
    const sortValueA = a[sort.columnKey];
    const sortValueB = b[sort.columnKey];
    let newCompResult = compResult;
    if (sortValueA && sortValueB) {
      const sortFn = sortFunctions?.find(({ column }) => column === sort.columnKey)?.sortFn;
      newCompResult = compareRows(sortValueA, sortValueB, sortFn);
    }
    if (newCompResult !== 0) {
      return reversed ? sort.direction === "ASC" ? -newCompResult : newCompResult : sort.direction === "ASC" ? newCompResult : -newCompResult;
    }
    return newCompResult;
  }, 0)
);
var sortHierarchyRows = (rows, sortColumns, sortFunctions, uniqueRowId) => {
  const parentsSorted = sortRows(
    rows.filter((row) => !row.parentKey),
    sortColumns,
    sortFunctions
  );
  if (rows.length === parentsSorted.length) {
    return parentsSorted;
  }
  let sortedChildren = sortRows(
    rows.filter((row) => row.parentKey),
    sortColumns,
    sortFunctions,
    true
  );
  while (sortedChildren.length) {
    if (uniqueRowId && sortedChildren.some((row) => uniqueRowId in row)) {
      sortedChildren = sortedChildren.reduce(
        (remainingChilds, child) => {
          const parentIndex = parentsSorted.findIndex(
            (parent) => rowKeyGetter(parent, uniqueRowId) === child.parentKey
          );
          if (parentIndex >= 0) {
            parentsSorted.splice(parentIndex + 1, 0, child);
          } else {
            remainingChilds.push(child);
          }
          return remainingChilds;
        },
        []
      );
    }
  }
  return parentsSorted;
};
var addRow = (rowList, index, row) => {
  rowList.splice(index, 0, row);
};
var deleteRow = (rowList, index) => {
  rowList.splice(index, 1);
};
var rowFinderBasedOnId = (rowList, uniqueRowId, uniqueRowIdValue) => {
  let foundRow;
  rowList.forEach((row) => {
    if (rowKeyGetter(row, uniqueRowId) === uniqueRowIdValue) {
      foundRow = { ...row };
    }
    if (row.childRows && Array.isArray(row.childRows) && !foundRow) {
      foundRow = rowFinderBasedOnId(row.childRows, uniqueRowId, uniqueRowIdValue);
    }
  });
  if (foundRow) {
    return foundRow;
  }
  return void 0;
};
var getChildrenSelection = (rowList, uniqueRowId, selectedRows, checked) => {
  rowList.forEach((row) => {
    if (row.childRows) {
      getChildrenSelection(row.childRows, uniqueRowId, selectedRows, checked);
    }
    if (checked) {
      selectedRows.add(rowKeyGetter(row, uniqueRowId));
    } else {
      selectedRows.delete(rowKeyGetter(row, uniqueRowId));
    }
  });
};
var getParentSelectedState = (rowList, parentKeyValue, uniqueRowId, selectedRows, checkedStateToMatch) => {
  if (!rowList.some((row) => uniqueRowId in row)) {
    return;
  }
  const parentRow = rowFinderBasedOnId(rowList, uniqueRowId, parentKeyValue);
  if (!parentRow) {
    return;
  }
  const isAnyChildUnselected = parentRow.childRows?.some((row) => !selectedRows.has(rowKeyGetter(row, uniqueRowId)));
  if (!checkedStateToMatch || isAnyChildUnselected) {
    if (selectedRows.has(rowKeyGetter(parentRow, uniqueRowId))) {
      selectedRows.delete(rowKeyGetter(parentRow, uniqueRowId));
    }
  } else if (parentRow.childRows && !isAnyChildUnselected) {
    selectedRows.add(rowKeyGetter(parentRow, uniqueRowId));
  }
  if (parentRow.parentKey) {
    getParentSelectedState(rowList, parentRow.parentKey, uniqueRowId, selectedRows, checkedStateToMatch);
  }
};
var getMinItemsPerPageIndex = (currentPageInternal, itemsPerPage, page) => currentPageInternal === 1 ? 0 : itemsPerPage * (page - 1);
var getMaxItemsPerPageIndex = (minItemsPerPageIndex, itemsPerPage, rows, page) => minItemsPerPageIndex + itemsPerPage > rows.length ? rows.length : itemsPerPage * page - 1;
var getPaginatedNodes = (rows, uniqueRowId, start, end) => {
  if (!uniqueRowId) {
    return rows.slice(start, end);
  }
  const rowsToPaginate = start != null && end != null ? rows.filter(({ parentKey, isExpandedChildContent }) => parentKey == null && isExpandedChildContent == null).slice(start, end) : [...rows];
  const isRowInHierarchy = (row, targetId) => {
    if (row[uniqueRowId] === targetId) {
      return true;
    }
    return !!row?.childRows?.some((child) => isRowInHierarchy(child, targetId));
  };
  return rows.filter(
    (row) => rowsToPaginate.some(
      (rowToPaginate) => rowToPaginate[uniqueRowId] === row[uniqueRowId] || rowToPaginate.contentIsExpanded && row?.triggerRowKey === rowToPaginate[uniqueRowId] && row?.isExpandedChildContent || rowToPaginate?.childRows?.some((child) => isRowInHierarchy(child, row[uniqueRowId]))
    )
  );
};

// src/paginator/Paginator.tsx
import { useContext as useContext22 } from "react";
import styled35, { ThemeProvider as ThemeProvider15 } from "styled-components";

// src/select/Select.tsx
import * as Popover2 from "@radix-ui/react-popover";
import {
  forwardRef as forwardRef5,
  useCallback as useCallback6,
  useContext as useContext21,
  useId as useId7,
  useMemo as useMemo9,
  useRef as useRef9,
  useState as useState16
} from "react";
import styled34, { ThemeProvider as ThemeProvider14 } from "styled-components";

// src/select/Listbox.tsx
import { useContext as useContext20, useLayoutEffect as useLayoutEffect4, useRef as useRef8 } from "react";
import styled33 from "styled-components";

// src/select/ListOption.tsx
import styled32 from "styled-components";
import { useState as useState15 } from "react";
import { jsx as jsx39, jsxs as jsxs25 } from "react/jsx-runtime";
var ListOption = ({
  id,
  option,
  onClick,
  multiple,
  visualFocused,
  isGroupedOption = false,
  isLastOption,
  isSelected
}) => {
  const [hasTooltip, setHasTooltip] = useState15(false);
  const handleOnMouseEnter = (event) => {
    const text = event.currentTarget;
    setHasTooltip(text.scrollWidth > text.clientWidth);
  };
  return /* @__PURE__ */ jsx39(TooltipWrapper, { condition: hasTooltip, label: option.label, children: /* @__PURE__ */ jsx39(
    OptionItem,
    {
      id,
      onClick: () => {
        onClick(option);
      },
      visualFocused,
      selected: isSelected,
      role: "option",
      "aria-selected": !multiple ? isSelected : void 0,
      children: /* @__PURE__ */ jsxs25(
        StyledOption,
        {
          visualFocused,
          selected: isSelected,
          last: isLastOption,
          grouped: isGroupedOption,
          multiple,
          children: [
            multiple && /* @__PURE__ */ jsx39("div", { style: { display: "flex", pointerEvents: "none" }, children: /* @__PURE__ */ jsx39(Checkbox_default, { checked: isSelected, tabIndex: -1 }) }),
            option.icon && /* @__PURE__ */ jsx39(OptionIcon, { grouped: isGroupedOption, multiple, children: typeof option.icon === "string" ? /* @__PURE__ */ jsx39(Icon_default, { icon: option.icon }) : option.icon }),
            /* @__PURE__ */ jsxs25(OptionContent, { grouped: isGroupedOption, hasIcon: option.icon ? true : false, multiple, children: [
              /* @__PURE__ */ jsx39(OptionLabel, { onMouseEnter: handleOnMouseEnter, children: option.label }),
              !multiple && isSelected && /* @__PURE__ */ jsx39(OptionSelectedIndicator, { children: /* @__PURE__ */ jsx39(Icon_default, { icon: "done" }) })
            ] })
          ]
        }
      )
    }
  ) });
};
var OptionItem = styled32.li`
  padding: 0 0.5rem;
  box-shadow: inset 0 0 0 2px transparent;
  ${(props) => props.visualFocused && `box-shadow: inset 0 0 0 2px ${props.theme.focusListOptionBorderColor};`}
  ${(props) => props.selected && `background-color: ${props.theme.selectedListOptionBackgroundColor}`};
  cursor: pointer;

  &:hover {
    ${(props) => props.selected ? `background-color: ${props.theme.selectedHoverListOptionBackgroundColor};` : `background-color: ${props.theme.unselectedHoverListOptionBackgroundColor};`};
  }
  &:active {
    ${(props) => props.selected ? `background-color: ${props.theme.selectedActiveListOptionBackgroundColor};` : `background-color: ${props.theme.unselectedActiveListOptionBackgroundColor};`};
  }
`;
var StyledOption = styled32.span`
  box-sizing: border-box;
  display: flex;
  align-items: center;
  height: 32px;
  padding: 4px 8px 4px 0;
  ${(props) => props.grouped && props.multiple && `padding-left: 16px;`}
  ${(props) => props.last || props.visualFocused || props.selected ? `border-bottom: 1px solid transparent` : `border-bottom: 1px solid ${props.theme.listOptionDividerColor}`};
`;
var OptionIcon = styled32.span`
  margin-left: ${(props) => props.grouped && !props.multiple ? "16px" : "8px"};
  display: grid;
  place-items: center;
  color: ${(props) => props.theme.listOptionIconColor};
  font-size: 24px;
  svg {
    height: 24px;
    width: 24px;
  }
`;
var OptionContent = styled32.span`
  margin-left: ${(props) => props.grouped && !props.multiple && !props.hasIcon ? "16px" : "8px"};
  display: flex;
  justify-content: space-between;
  gap: 0.25rem;
  width: 100%;
  overflow: hidden;
`;
var OptionLabel = styled32.span`
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
`;
var OptionSelectedIndicator = styled32.span`
  display: flex;
  align-items: center;
  color: ${(props) => props.theme.selectedListOptionIconColor};
  font-size: 16px;
`;
var ListOption_default = ListOption;

// src/select/utils.ts
var notOptionalCheck = (value, multiple, optional) => !optional && (multiple ? value.length === 0 : value === "");
var isOptionGroup = (option) => "options" in option && option.options != null;
var isArrayOfOptionGroups = (options) => options[0] != null && isOptionGroup(options[0]);
var groupsHaveOptions = (options) => isArrayOfOptionGroups(options) ? options.some((groupOption) => groupOption.options.length > 0) : true;
var canOpenListbox = (options, disabled) => !disabled && options.length > 0 && groupsHaveOptions(options);
var filterOptionsBySearchValue = (options, searchValue) => {
  if (options.length > 0) {
    if (isArrayOfOptionGroups(options))
      return options.map((optionGroup) => {
        const group = {
          label: optionGroup.label,
          options: optionGroup.options.filter(
            (option) => option.label.toUpperCase().includes(searchValue.toUpperCase())
          )
        };
        return group;
      });
    else return options.filter((option) => option.label.toUpperCase().includes(searchValue.toUpperCase()));
  } else {
    return [];
  }
};
var getLastOptionIndex = (options, filteredOptions, searchable, optional, multiple) => {
  let last = 0;
  const reducer = (acc, current) => acc + (current.options.length ?? 0);
  if (searchable && filteredOptions.length > 0) {
    if (isArrayOfOptionGroups(filteredOptions)) {
      last = filteredOptions.reduce(reducer, 0) - 1;
    } else {
      last = filteredOptions.length - 1;
    }
  } else if (options.length > 0) {
    if (isArrayOfOptionGroups(options)) {
      last = options.reduce(reducer, 0) - 1;
    } else {
      last = options.length - 1;
    }
  }
  return optional && !multiple ? last + 1 : last;
};
var getSelectedOption = (value, options, multiple, optional, optionalItem) => {
  let selectedOption = multiple ? [] : {};
  let singleSelectionIndex = null;
  if (multiple) {
    if (options.length > 0) {
      options.forEach((option) => {
        if (isOptionGroup(option)) {
          option.options.forEach((singleOption) => {
            if (value.includes(singleOption.value) && Array.isArray(selectedOption)) {
              selectedOption.push(singleOption);
            }
          });
        } else if (value.includes(option.value) && Array.isArray(selectedOption)) {
          selectedOption.push(option);
        }
      });
    }
  } else if (optional && value === "") {
    selectedOption = optionalItem;
    singleSelectionIndex = 0;
  } else if (options.length > 0) {
    let groupIndex = 0;
    options.some((option, index) => {
      if (isOptionGroup(option)) {
        option.options.some((singleOption) => {
          if (singleOption.value === value) {
            selectedOption = singleOption;
            singleSelectionIndex = optional ? groupIndex + 1 : groupIndex;
            return true;
          }
          groupIndex++;
          return false;
        });
      } else if (option.value === value) {
        selectedOption = option;
        singleSelectionIndex = optional ? index + 1 : index;
        return true;
      }
      return false;
    });
  }
  return {
    selectedOption,
    singleSelectionIndex
  };
};
var getSelectedOptionLabel = (placeholder, selectedOption) => Array.isArray(selectedOption) ? selectedOption.length === 0 ? placeholder : selectedOption.map((option) => option.label).join(", ") : selectedOption.label ?? placeholder;

// src/select/Listbox.tsx
import { jsx as jsx40, jsxs as jsxs26 } from "react/jsx-runtime";
var Listbox = ({
  id,
  currentValue,
  options,
  visualFocusIndex,
  lastOptionIndex,
  multiple,
  optional,
  optionalItem,
  searchable,
  handleOptionOnClick,
  styles
}) => {
  const translatedLabels = useContext20(HalstackLanguageContext);
  const listboxRef = useRef8(null);
  let globalIndex = optional && !multiple ? 0 : -1;
  const mapOptionFunc = (option, mapIndex) => {
    const groupId = `${id}-group-${mapIndex}`;
    if ("options" in option) {
      return option.options.length > 0 && /* @__PURE__ */ jsx40("li", { children: /* @__PURE__ */ jsxs26("ul", { role: "listbox", "aria-labelledby": groupId, style: { padding: 0 }, children: [
        /* @__PURE__ */ jsx40(GroupLabel, { role: "presentation", id: groupId, children: option.label }),
        option.options.map((singleOption) => {
          globalIndex++;
          return /* @__PURE__ */ jsx40(
            ListOption_default,
            {
              id: `${id}-option-${globalIndex}`,
              option: singleOption,
              onClick: handleOptionOnClick,
              multiple,
              visualFocused: visualFocusIndex === globalIndex,
              isGroupedOption: true,
              isLastOption: lastOptionIndex === globalIndex,
              isSelected: multiple ? currentValue.includes(singleOption.value) : currentValue === singleOption.value
            },
            `${id}-option-${singleOption.value}`
          );
        })
      ] }) }, groupId);
    } else {
      globalIndex++;
      return /* @__PURE__ */ jsx40(
        ListOption_default,
        {
          id: `${id}-option-${globalIndex}`,
          option,
          onClick: handleOptionOnClick,
          multiple,
          visualFocused: visualFocusIndex === globalIndex,
          isLastOption: lastOptionIndex === globalIndex,
          isSelected: multiple ? currentValue.includes(option.value) : currentValue === option.value
        },
        `${id}-option-${option.value}`
      );
    }
  };
  useLayoutEffect4(() => {
    if (currentValue && !multiple) {
      const listEl = listboxRef?.current;
      const selectedListOptionEl = listEl?.querySelector("[aria-selected='true']");
      listEl?.scrollTo?.({
        top: (selectedListOptionEl.offsetTop ?? 0) - (listEl.clientHeight ?? 0) / 2
      });
    }
  }, [currentValue, multiple]);
  useLayoutEffect4(() => {
    const visualFocusedOptionEl = listboxRef.current?.querySelectorAll("[role='option']")[visualFocusIndex];
    visualFocusedOptionEl?.scrollIntoView?.({
      block: "nearest",
      inline: "start"
    });
  }, [visualFocusIndex]);
  const hasOptionGroups = options.some((option) => "options" in option && option.options.length > 0);
  return /* @__PURE__ */ jsxs26(
    ListboxContainer,
    {
      id,
      onClick: (event) => {
        event.stopPropagation();
      },
      onMouseDown: (event) => {
        event.preventDefault();
      },
      ref: listboxRef,
      "aria-multiselectable": !hasOptionGroups ? multiple : void 0,
      style: styles,
      role: hasOptionGroups ? "list" : "listbox",
      "aria-label": "List of options",
      children: [
        searchable && (options.length === 0 || !groupsHaveOptions(options)) ? /* @__PURE__ */ jsxs26(OptionsSystemMessage, { children: [
          /* @__PURE__ */ jsx40(NoMatchesFoundIcon, { children: /* @__PURE__ */ jsx40(Icon_default, { icon: "search_off" }) }),
          translatedLabels.select.noMatchesErrorMessage
        ] }) : optional && !multiple && /* @__PURE__ */ jsx40(
          ListOption_default,
          {
            id: `${id}-option-${0}`,
            option: optionalItem,
            onClick: handleOptionOnClick,
            multiple,
            visualFocused: visualFocusIndex === 0,
            isGroupedOption: false,
            isLastOption: lastOptionIndex === 0,
            isSelected: multiple ? currentValue.includes(optionalItem.value) : currentValue === optionalItem.value
          },
          `${id}-option-${optionalItem.value}`
        ),
        options.map(mapOptionFunc)
      ]
    }
  );
};
var ListboxContainer = styled33.ul`
  box-sizing: border-box;
  max-height: 304px;
  overflow-y: auto;
  margin: 0;
  padding: 0.25rem 0;
  background-color: ${(props) => props.theme.listDialogBackgroundColor};
  border: 1px solid ${(props) => props.theme.listDialogBorderColor};
  border-radius: 0.25rem;
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1);
  color: ${(props) => props.theme.listOptionFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.listOptionFontSize};
  font-style: ${(props) => props.theme.listOptionFontStyle};
  font-weight: ${(props) => props.theme.listOptionFontWeight};
  line-height: 24px;
  cursor: default;
`;
var OptionsSystemMessage = styled33.span`
  display: flex;
  padding: 4px 16px;
  color: ${(props) => props.theme.systemMessageFontColor};
  font-size: 0.875rem;
  line-height: 1.715em;
`;
var NoMatchesFoundIcon = styled33.span`
  display: flex;
  flex-wrap: wrap;
  align-content: center;
  height: 16px;
  width: 16px;
  padding: 4px;
  margin-right: 0.25rem;
  font-size: 16px;
`;
var GroupLabel = styled33.li`
  padding: 4px 16px;
  font-weight: ${(props) => props.theme.listGroupLabelFontWeight};
  line-height: 1.715em;
`;
var Listbox_default = Listbox;

// src/select/Select.tsx
import { jsx as jsx41, jsxs as jsxs27 } from "react/jsx-runtime";
var DxcSelect = forwardRef5(
  ({
    label,
    name = "",
    defaultValue,
    value,
    options,
    helperText,
    placeholder = "",
    disabled = false,
    multiple = false,
    optional = false,
    searchable = false,
    onChange,
    onBlur,
    error,
    margin,
    size = "medium",
    tabIndex = 0,
    ariaLabel = "Select"
  }, ref) => {
    const selectId = `select-${useId7()}`;
    const selectLabelId = `label-${selectId}`;
    const errorId = `error-${selectId}`;
    const listboxId = `${selectId}-listbox`;
    const [innerValue, setInnerValue] = useState16(defaultValue ?? (multiple ? [] : ""));
    const [searchValue, setSearchValue] = useState16("");
    const [visualFocusIndex, changeVisualFocusIndex] = useState16(-1);
    const [isOpen, changeIsOpen] = useState16(false);
    const [hasTooltip, setHasTooltip] = useState16(false);
    const selectRef = useRef9(null);
    const selectSearchInputRef = useRef9(null);
    const width = useWidth_default(selectRef.current);
    const colorsTheme = useContext21(HalstackContext);
    const translatedLabels = useContext21(HalstackLanguageContext);
    const optionalItem = { label: placeholder, value: "" };
    const filteredOptions = useMemo9(() => filterOptionsBySearchValue(options, searchValue), [options, searchValue]);
    const lastOptionIndex = useMemo9(
      () => getLastOptionIndex(options, filteredOptions, searchable, optional, multiple),
      [options, filteredOptions, searchable, optional, multiple]
    );
    const { selectedOption, singleSelectionIndex } = useMemo9(
      () => getSelectedOption(value ?? innerValue, options, multiple, optional, optionalItem),
      [value, innerValue, options, multiple, optional, optionalItem]
    );
    const openListbox = () => {
      if (!isOpen && canOpenListbox(options, disabled)) {
        changeIsOpen(true);
      }
    };
    const closeListbox = () => {
      if (isOpen) {
        changeIsOpen(false);
        changeVisualFocusIndex(-1);
      }
    };
    const handleSelectChangeValue = useCallback6(
      (newOption) => {
        if (newOption) {
          let newValue;
          if (multiple) {
            const currentValue = value ?? innerValue;
            newValue = currentValue.includes(newOption.value) ? currentValue.filter((optionVal) => optionVal !== newOption.value) : [...currentValue, newOption.value];
          } else newValue = newOption.value;
          if (value == null) {
            setInnerValue(newValue);
          }
          onChange?.({
            value: newValue,
            error: notOptionalCheck(newValue, multiple, optional) ? translatedLabels.formFields.requiredValueErrorMessage : void 0
          });
        }
      },
      [multiple, value, innerValue, onChange, optional, translatedLabels]
    );
    const handleSelectOnClick = () => {
      if (searchable) {
        selectSearchInputRef?.current?.focus();
      }
      if (isOpen) {
        closeListbox();
        setSearchValue("");
      } else {
        openListbox();
      }
    };
    const handleSelectOnFocus = (event) => {
      if (!event.currentTarget.contains(event.relatedTarget) && searchable) {
        selectSearchInputRef?.current?.focus();
      }
    };
    const handleSelectOnBlur = (event) => {
      if (!event.currentTarget.contains(event.relatedTarget)) {
        closeListbox();
        setSearchValue("");
        const currentValue = value ?? innerValue;
        if (notOptionalCheck(currentValue, multiple, optional)) {
          onBlur?.({
            value: currentValue,
            error: translatedLabels.formFields.requiredValueErrorMessage
          });
        } else {
          onBlur?.({ value: currentValue });
        }
      }
    };
    const handleSelectOnKeyDown = (event) => {
      switch (event.key) {
        case "Down":
        case "ArrowDown":
          event.preventDefault();
          if (singleSelectionIndex != null && (!isOpen || visualFocusIndex === -1 && singleSelectionIndex > -1 && singleSelectionIndex <= lastOptionIndex)) {
            changeVisualFocusIndex(singleSelectionIndex);
          } else {
            changeVisualFocusIndex((currentVisualFocusIndex) => {
              if (currentVisualFocusIndex < lastOptionIndex) {
                return currentVisualFocusIndex + 1;
              }
              return 0;
            });
          }
          openListbox();
          break;
        case "Up":
        case "ArrowUp":
          event.preventDefault();
          if (singleSelectionIndex != null && (!isOpen || visualFocusIndex === -1 && singleSelectionIndex > -1 && singleSelectionIndex <= lastOptionIndex)) {
            changeVisualFocusIndex(singleSelectionIndex);
          } else {
            changeVisualFocusIndex(
              (currentVisualFocusIndex) => currentVisualFocusIndex === 0 || currentVisualFocusIndex === -1 ? lastOptionIndex : currentVisualFocusIndex - 1
            );
          }
          openListbox();
          break;
        case "Esc":
        case "Escape":
          event.preventDefault();
          if (isOpen) {
            event.stopPropagation();
          }
          closeListbox();
          setSearchValue("");
          break;
        case "Enter":
          if (isOpen && visualFocusIndex >= 0) {
            let accLength = optional && !multiple ? 1 : 0;
            if (searchable) {
              if (filteredOptions.length > 0) {
                if (optional && !multiple && visualFocusIndex === 0 && groupsHaveOptions(filteredOptions)) {
                  handleSelectChangeValue(optionalItem);
                } else if (isArrayOfOptionGroups(filteredOptions)) {
                  if (groupsHaveOptions(filteredOptions)) {
                    filteredOptions.some((groupOption) => {
                      const groupLength = accLength + groupOption.options.length;
                      if (groupLength > visualFocusIndex) {
                        handleSelectChangeValue(groupOption.options[visualFocusIndex - accLength]);
                      }
                      accLength = groupLength;
                      return groupLength > visualFocusIndex;
                    });
                  }
                } else {
                  handleSelectChangeValue(filteredOptions[visualFocusIndex - accLength]);
                }
              }
            } else if (optional && !multiple && visualFocusIndex === 0) {
              handleSelectChangeValue(optionalItem);
            } else if (isArrayOfOptionGroups(options)) {
              options.some((groupOption) => {
                const groupLength = accLength + groupOption.options.length;
                if (groupLength > visualFocusIndex) {
                  handleSelectChangeValue(groupOption.options[visualFocusIndex - accLength]);
                }
                accLength = groupLength;
                return groupLength > visualFocusIndex;
              });
            } else {
              handleSelectChangeValue(options[visualFocusIndex - accLength]);
            }
            if (!multiple) {
              closeListbox();
            }
            setSearchValue("");
          }
          break;
        default:
          break;
      }
    };
    const handleSearchIOnChange = (event) => {
      setSearchValue(event.target.value);
      changeVisualFocusIndex(-1);
      openListbox();
    };
    const handleClearOptionsActionOnClick = (event) => {
      event.stopPropagation();
      if (value == null) {
        setInnerValue([]);
      }
      if (!optional) {
        onChange?.({
          value: [],
          error: translatedLabels.formFields.requiredValueErrorMessage
        });
      } else {
        onChange?.({ value: [] });
      }
    };
    const handleClearSearchActionOnClick = (event) => {
      event.stopPropagation();
      setSearchValue("");
    };
    const handleOptionOnClick = useCallback6(
      (option) => {
        handleSelectChangeValue(option);
        if (!multiple) {
          closeListbox();
        }
        setSearchValue("");
      },
      [handleSelectChangeValue, closeListbox, multiple]
    );
    const handleOnMouseEnter = (event) => {
      const text = event.currentTarget;
      setHasTooltip(text.scrollWidth > text.clientWidth);
    };
    return /* @__PURE__ */ jsx41(ThemeProvider14, { theme: colorsTheme.select, children: /* @__PURE__ */ jsxs27(SelectContainer, { margin, size, ref, children: [
      label && /* @__PURE__ */ jsxs27(
        Label3,
        {
          id: selectLabelId,
          disabled,
          onClick: () => {
            selectRef?.current?.focus();
          },
          helperText,
          children: [
            label,
            " ",
            optional && /* @__PURE__ */ jsx41(OptionalLabel, { children: translatedLabels.formFields.optionalLabel })
          ]
        }
      ),
      helperText && /* @__PURE__ */ jsx41(HelperText, { disabled, children: helperText }),
      /* @__PURE__ */ jsxs27(Popover2.Root, { open: isOpen, children: [
        /* @__PURE__ */ jsx41(Popover2.Trigger, { asChild: true, type: void 0, children: /* @__PURE__ */ jsxs27(
          Select,
          {
            id: selectId,
            disabled,
            error,
            onBlur: handleSelectOnBlur,
            onClick: handleSelectOnClick,
            onFocus: handleSelectOnFocus,
            onKeyDown: handleSelectOnKeyDown,
            ref: selectRef,
            tabIndex: disabled ? -1 : tabIndex,
            role: "combobox",
            "aria-controls": isOpen ? listboxId : void 0,
            "aria-disabled": disabled,
            "aria-expanded": isOpen,
            "aria-haspopup": "listbox",
            "aria-labelledby": label ? selectLabelId : void 0,
            "aria-activedescendant": visualFocusIndex >= 0 ? `option-${visualFocusIndex}` : void 0,
            "aria-invalid": !!error,
            "aria-errormessage": error ? errorId : void 0,
            "aria-required": !disabled && !optional,
            "aria-label": label ? void 0 : ariaLabel,
            children: [
              multiple && Array.isArray(selectedOption) && selectedOption.length > 0 && /* @__PURE__ */ jsxs27(SelectionIndicator, { children: [
                /* @__PURE__ */ jsx41(SelectionNumber, { disabled, children: selectedOption.length }),
                /* @__PURE__ */ jsx41(Tooltip, { label: translatedLabels.select.actionClearSelectionTitle, children: /* @__PURE__ */ jsx41(
                  ClearOptionsAction,
                  {
                    disabled,
                    onMouseDown: (event) => {
                      event.preventDefault();
                    },
                    onClick: handleClearOptionsActionOnClick,
                    tabIndex: -1,
                    "aria-label": translatedLabels.select.actionClearSelectionTitle,
                    children: /* @__PURE__ */ jsx41(Icon_default, { icon: "clear" })
                  }
                ) })
              ] }),
              /* @__PURE__ */ jsx41(TooltipWrapper, { condition: hasTooltip, label: getSelectedOptionLabel(placeholder, selectedOption), children: /* @__PURE__ */ jsxs27(SearchableValueContainer, { children: [
                /* @__PURE__ */ jsx41(
                  "input",
                  {
                    style: { display: "none" },
                    name,
                    disabled,
                    value: multiple ? (Array.isArray(value) ? value : Array.isArray(innerValue) ? innerValue : []).join(",") : value ?? innerValue,
                    readOnly: true,
                    "aria-hidden": "true"
                  }
                ),
                searchable && /* @__PURE__ */ jsx41(
                  SearchInput,
                  {
                    value: searchValue,
                    disabled,
                    onChange: handleSearchIOnChange,
                    ref: selectSearchInputRef,
                    autoComplete: "nope",
                    autoCorrect: "nope",
                    size: 1,
                    "aria-labelledby": label ? selectLabelId : void 0
                  }
                ),
                (!searchable || searchValue === "") && /* @__PURE__ */ jsx41(
                  SelectedOption,
                  {
                    disabled,
                    atBackground: (multiple ? (value ?? innerValue).length === 0 : !(value ?? innerValue)) || searchable && isOpen,
                    children: /* @__PURE__ */ jsx41(SelectedOptionLabel, { onMouseEnter: handleOnMouseEnter, children: getSelectedOptionLabel(placeholder, selectedOption) })
                  }
                )
              ] }) }),
              !disabled && error && /* @__PURE__ */ jsx41(ErrorIcon, { children: /* @__PURE__ */ jsx41(Icon_default, { icon: "filled_error" }) }),
              searchable && searchValue.length > 0 && /* @__PURE__ */ jsx41(Tooltip, { label: translatedLabels.select.actionClearSelectionTitle, children: /* @__PURE__ */ jsx41(
                ClearSearchAction,
                {
                  onMouseDown: (event) => {
                    event.preventDefault();
                  },
                  onClick: handleClearSearchActionOnClick,
                  tabIndex: -1,
                  "aria-label": translatedLabels.select.actionClearSearchTitle,
                  children: /* @__PURE__ */ jsx41(Icon_default, { icon: "clear" })
                }
              ) }),
              /* @__PURE__ */ jsx41(CollapseIndicator2, { disabled, children: /* @__PURE__ */ jsx41(Icon_default, { icon: isOpen ? "keyboard_arrow_up" : "keyboard_arrow_down" }) })
            ]
          }
        ) }),
        /* @__PURE__ */ jsx41(Popover2.Portal, { children: /* @__PURE__ */ jsx41(
          Popover2.Content,
          {
            sideOffset: 4,
            style: { zIndex: "2147483647" },
            onOpenAutoFocus: (event) => {
              event.preventDefault();
            },
            onCloseAutoFocus: (event) => {
              event.preventDefault();
            },
            children: /* @__PURE__ */ jsx41(
              Listbox_default,
              {
                id: listboxId,
                currentValue: value ?? innerValue,
                options: searchable ? filteredOptions : options,
                visualFocusIndex,
                lastOptionIndex,
                multiple,
                optional,
                optionalItem,
                searchable,
                handleOptionOnClick,
                styles: { width }
              }
            )
          }
        ) })
      ] }),
      !disabled && typeof error === "string" && /* @__PURE__ */ jsx41(Error2, { id: errorId, role: "alert", "aria-live": error ? "assertive" : "off", children: error })
    ] }) });
  }
);
var sizes3 = {
  small: "240px",
  medium: "360px",
  large: "480px",
  fillParent: "100%"
};
var calculateWidth6 = (margin, size) => size === "fillParent" ? `calc(${sizes3[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes3[size];
var SelectContainer = styled34.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  width: ${(props) => calculateWidth6(props.margin, props.size)};
  ${(props) => props.size !== "fillParent" && `min-width:${calculateWidth6(props.margin, props.size)}`};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  font-family: ${(props) => props.theme.fontFamily};
`;
var Label3 = styled34.label`
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.labelFontColor};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
  cursor: default;
  ${(props) => !props.helperText && `margin-bottom: 0.25rem`}
`;
var OptionalLabel = styled34.span`
  font-weight: ${(props) => props.theme.optionalLabelFontWeight};
`;
var HelperText = styled34.span`
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.helperTextFontColor};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
  margin-bottom: 0.25rem;
`;
var Select = styled34.div`
  display: flex;
  position: relative;
  align-items: center;
  height: calc(2.5rem - 2px);
  padding: 0 0.5rem;
  outline: none;
  ${(props) => props.disabled && `background-color: ${props.theme.disabledInputBackgroundColor}`};
  box-shadow: 0 0 0 2px transparent;
  border-radius: 4px;
  border: 1px solid
    ${(props) => props.disabled ? props.theme.disabledInputBorderColor : props.theme.enabledInputBorderColor};
  ${(props) => props.error && !props.disabled && `border-color: transparent;
     box-shadow: 0 0 0 2px ${props.theme.errorInputBorderColor};
  `}
  ${(props) => props.disabled ? "cursor: not-allowed;" : "cursor: pointer;"};

  ${(props) => !props.disabled && `
      &:hover {
        border-color: ${props.error ? "transparent" : props.theme.hoverInputBorderColor};
        ${props.error && `box-shadow: 0 0 0 2px ${props.theme.hoverInputErrorBorderColor};`}
      }
      &:focus-within {
        border-color: transparent;
        box-shadow: 0 0 0 2px ${props.theme.focusInputBorderColor};
      }
    `};
`;
var SelectionIndicator = styled34.div`
  box-sizing: border-box;
  display: grid;
  grid-template-columns: 1fr 1fr;
  min-width: 48px;
  min-height: 24px;
  border-radius: 2px;
  border: 1px solid ${(props) => props.theme.selectionIndicatorBorderColor};
`;
var SelectionNumber = styled34.span`
  display: grid;
  place-items: center;
  border-right: 1px solid ${(props) => props.theme.selectionIndicatorBorderColor};
  user-select: none;
  ${(props) => !props.disabled && `background-color: ${props.theme.selectionIndicatorBackgroundColor}`};
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.selectionIndicatorFontColor};
  font-size: ${(props) => props.theme.selectionIndicatorFontSize};
  font-style: ${(props) => props.theme.selectionIndicatorFontStyle};
  font-weight: ${(props) => props.theme.selectionIndicatorFontWeight};
  ${(props) => props.disabled ? `cursor: not-allowed;` : `cursor: default;`}
`;
var ClearOptionsAction = styled34.button`
  display: grid;
  place-items: center;
  border: none;
  padding: 0;
  ${(props) => props.disabled ? `cursor: not-allowed;` : `cursor: pointer;`}
  background-color: ${(props) => props.disabled ? "transparent" : props.theme.enabledSelectionIndicatorActionBackgroundColor};
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.enabledSelectionIndicatorActionIconColor};
  font-size: 16px;
  width: 100%;

  :focus-visible {
    outline: none;
  }
  ${(props) => !props.disabled && `
      &:hover {
        background-color: ${props.theme.hoverSelectionIndicatorActionBackgroundColor};
        color: ${props.theme.hoverSelectionIndicatorActionIconColor};
      }
      &:active {
        background-color: ${props.theme.activeSelectionIndicatorActionBackgroundColor};
        color: ${props.theme.activeSelectionIndicatorActionIconColor};
      }
    `}
`;
var SearchableValueContainer = styled34.div`
  display: grid;
  width: 100%;
`;
var SelectedOption = styled34.span`
  grid-area: 1 / 1 / 1 / 1;
  display: inline-flex;
  align-items: center;
  height: calc(2.5rem - 2px);
  padding: 0 0.5rem;
  user-select: none;
  overflow: hidden;

  color: ${(props) => props.disabled ? props.theme.disabledColor : props.atBackground ? props.theme.placeholderFontColor : props.theme.valueFontColor};

  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.valueFontSize};
  font-style: ${(props) => props.theme.valueFontStyle};
  font-weight: ${(props) => props.theme.valueFontWeight};
`;
var SelectedOptionLabel = styled34.span`
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
`;
var SearchInput = styled34.input`
  grid-area: 1 / 1 / 1 / 1;
  height: calc(2.5rem - 2px);
  background: none;
  border: none;
  outline: none;
  padding: 0 0.5rem;
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.valueFontColor};
  font-size: ${(props) => props.theme.valueFontSize};
  font-style: ${(props) => props.theme.valueFontStyle};
  font-weight: ${(props) => props.theme.valueFontWeight};
  line-height: 1.5em;
`;
var ErrorIcon = styled34.span`
  display: flex;
  flex-wrap: wrap;
  align-content: center;
  padding: 3px;
  height: 18px;
  width: 18px;
  margin-left: 0.25rem;
  color: ${(props) => props.theme.errorIconColor};
  font-size: 1.25rem;
`;
var Error2 = styled34.span`
  min-height: 1.5em;
  color: ${(props) => props.theme.errorMessageColor};
  font-size: 0.75rem;
  line-height: 1.5em;
  margin-top: 0.25rem;
`;
var CollapseIndicator2 = styled34.span`
  display: grid;
  place-items: center;
  padding: 4px;
  font-size: 16px;
  margin-left: 0.25rem;
  color: ${(props) => props.disabled ? props.theme.disabledColor : props.theme.collapseIndicatorColor};
`;
var ClearSearchAction = styled34.button`
  display: grid;
  place-items: center;
  min-height: 24px;
  min-width: 24px;
  margin-left: 0.25rem;
  border: none;
  border-radius: 2px;
  padding: 0;
  background-color: ${(props) => props.theme.actionBackgroundColor};
  color: ${(props) => props.theme.actionIconColor};
  font-size: 1rem;
  cursor: pointer;

  &:hover {
    background-color: ${(props) => props.theme.hoverActionBackgroundColor};
    color: ${(props) => props.theme.hoverActionIconColor};
  }
  &:active {
    background-color: ${(props) => props.theme.activeActionBackgroundColor};
    color: ${(props) => props.theme.activeActionIconColor};
  }
`;
var Select_default = DxcSelect;

// src/paginator/Paginator.tsx
import { jsx as jsx42, jsxs as jsxs28 } from "react/jsx-runtime";
var DxcPaginator = ({
  currentPage = 1,
  itemsPerPage = 5,
  itemsPerPageOptions,
  totalItems = 1,
  showGoToPage,
  onPageChange,
  itemsPerPageFunction,
  tabIndex = 0
}) => {
  const totalPages = itemsPerPage > 0 ? Math.ceil(totalItems / itemsPerPage) : 0;
  const currentPageInternal = currentPage === -1 ? totalPages : currentPage;
  const minItemsPerPage = currentPageInternal === 1 || currentPageInternal === 0 ? currentPageInternal : (currentPageInternal - 1) * itemsPerPage + 1;
  const maxItemsPerPage = minItemsPerPage - 1 + itemsPerPage > totalItems ? totalItems : minItemsPerPage - 1 + itemsPerPage;
  const colorsTheme = useContext22(HalstackContext);
  const translatedLabels = useContext22(HalstackLanguageContext);
  return /* @__PURE__ */ jsx42(ThemeProvider15, { theme: colorsTheme.paginator, children: /* @__PURE__ */ jsx42(DxcPaginatorContainer, { children: /* @__PURE__ */ jsxs28(LabelsContainer2, { children: [
    itemsPerPageOptions && /* @__PURE__ */ jsxs28(ItemsPageContainer, { children: [
      /* @__PURE__ */ jsx42(ItemsLabel, { children: translatedLabels.paginator.itemsPerPageText }),
      /* @__PURE__ */ jsx42(SelectContainer2, { children: /* @__PURE__ */ jsx42(
        Select_default,
        {
          options: itemsPerPageOptions.map((num) => ({
            label: num.toString(),
            value: num.toString()
          })),
          onChange: (newValue) => {
            itemsPerPageFunction?.(Number(newValue.value));
          },
          value: itemsPerPage.toString(),
          size: "fillParent",
          tabIndex
        }
      ) })
    ] }),
    /* @__PURE__ */ jsx42(TotalItemsContainer, { children: translatedLabels.paginator.minToMaxOfText(minItemsPerPage, maxItemsPerPage, totalItems) }),
    onPageChange && /* @__PURE__ */ jsx42(
      Button_default,
      {
        mode: "secondary",
        disabled: currentPageInternal === 1 || currentPageInternal === 0,
        icon: "first_page",
        tabIndex,
        onClick: () => {
          onPageChange(1);
        },
        title: "First results"
      }
    ),
    onPageChange && /* @__PURE__ */ jsx42(
      Button_default,
      {
        mode: "secondary",
        disabled: currentPageInternal === 1 || currentPageInternal === 0,
        icon: "navigate_before",
        tabIndex,
        onClick: () => {
          onPageChange(currentPage - 1);
        },
        title: "Previous results"
      }
    ),
    showGoToPage ? /* @__PURE__ */ jsxs28(PageToSelectContainer, { children: [
      /* @__PURE__ */ jsxs28(GoToLabel, { children: [
        translatedLabels.paginator.goToPageText,
        " "
      ] }),
      /* @__PURE__ */ jsx42(SelectContainer2, { children: /* @__PURE__ */ jsx42(
        Select_default,
        {
          options: Array.from(Array(totalPages), (e, num) => ({
            label: (num + 1).toString(),
            value: (num + 1).toString()
          })),
          onChange: (newValue) => {
            onPageChange?.(Number(newValue.value));
          },
          value: currentPage.toString(),
          size: "fillParent",
          tabIndex
        }
      ) })
    ] }) : /* @__PURE__ */ jsx42("span", { children: translatedLabels.paginator.pageOfText(currentPageInternal, totalPages) }),
    onPageChange && /* @__PURE__ */ jsx42(
      Button_default,
      {
        mode: "secondary",
        disabled: currentPageInternal === totalPages,
        icon: "navigate_next",
        tabIndex,
        onClick: () => {
          onPageChange(currentPage + 1);
        },
        title: "Next results"
      }
    ),
    onPageChange && /* @__PURE__ */ jsx42(
      Button_default,
      {
        mode: "secondary",
        disabled: currentPageInternal === totalPages,
        icon: "last_page",
        tabIndex,
        onClick: () => {
          onPageChange(totalPages);
        },
        title: "Last results"
      }
    )
  ] }) }) });
};
var DxcPaginatorContainer = styled35.div`
  display: flex;
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-weight: ${(props) => props.theme.fontWeight};
  font-style: ${(props) => props.theme.fontStyle};
  text-transform: ${(props) => props.theme.fontTextTransform};
  background-color: ${(props) => props.theme.backgroundColor};
  color: ${(props) => props.theme.fontColor};
  padding: ${(props) => props.theme.verticalPadding} ${(props) => props.theme.horizontalPadding};

  button {
    &:disabled {
      background-color: transparent !important;
      opacity: 0.3 !important;
    }
  }
`;
var SelectContainer2 = styled35.div`
  min-width: 5.25rem;
`;
var ItemsPageContainer = styled35.span`
  display: flex;
  align-items: center;
  margin-right: ${(props) => props.theme.itemsPerPageSelectorMarginRight};
  margin-left: ${(props) => props.theme.itemsPerPageSelectorMarginLeft};
`;
var ItemsLabel = styled35.span`
  margin-right: 0.5rem;
`;
var GoToLabel = styled35.span`
  margin-right: 0.5rem;
  margin-left: 0.5rem;
`;
var TotalItemsContainer = styled35.span`
  margin-right: ${(props) => props.theme.totalItemsContainerMarginRight};
  margin-left: ${(props) => props.theme.totalItemsContainerMarginLeft};
`;
var LabelsContainer2 = styled35.div`
  display: flex;
  gap: 0.5rem;
  width: 100%;
  justify-content: flex-end;
  align-items: center;
`;
var PageToSelectContainer = styled35.span`
  display: flex;
  align-items: center;
  margin-right: 0.5rem;
`;
var Paginator_default = DxcPaginator;

// src/table/Table.tsx
import { useContext as useContext23 } from "react";
import styled36, { ThemeProvider as ThemeProvider16 } from "styled-components";

// src/table/dropdownTheme.ts
var dropdownTheme_default2 = {
  dropdown: {
    // ActionIcon size tokens
    buttonIconSize: "16px",
    buttonPaddingTop: "4px",
    buttonPaddingBottom: "4px",
    buttonPaddingLeft: "4px",
    buttonPaddingRight: "4px",
    buttonHeight: "24px",
    buttonBorderRadius: "2px",
    buttonBorderStyle: "none",
    buttonBorderThickness: "0px",
    buttonBorderColor: "transparent",
    optionFontSize: "14px",
    optionPaddingTop: "0px",
    optionPaddingBottom: "0px",
    optionPaddingLeft: "16px",
    optionPaddingRight: "16px",
    // Table tokens
    buttonBackgroundColor: componentTokens.table.actionBackgroundColor,
    hoverButtonBackgroundColor: componentTokens.table.hoverActionBackgroundColor,
    activeButtonBackgroundColor: componentTokens.table.activeActionBackgroundColor,
    buttonIconColor: componentTokens.table.actionIconColor,
    disabledColor: componentTokens.table.disabledActionIconColor,
    disabledButtonBackgroundColor: componentTokens.table.disabledActionBackgroundColor,
    focusColor: componentTokens.table.focusActionBorderColor,
    // Dropdown tokens
    buttonFontFamily: componentTokens.dropdown.buttonFontFamily,
    buttonFontSize: componentTokens.dropdown.buttonFontSize,
    buttonFontStyle: componentTokens.dropdown.buttonFontStyle,
    buttonFontWeight: componentTokens.dropdown.buttonFontWeight,
    buttonFontColor: componentTokens.dropdown.buttonFontColor,
    buttonIconSpacing: componentTokens.dropdown.buttonIconSpacing,
    disabledButtonBorderColor: componentTokens.dropdown.disabledButtonBorderColor,
    optionBackgroundColor: componentTokens.dropdown.optionBackgroundColor,
    hoverOptionBackgroundColor: componentTokens.dropdown.hoverOptionBackgroundColor,
    activeOptionBackgroundColor: componentTokens.dropdown.activeOptionBackgroundColor,
    optionFontFamily: componentTokens.dropdown.optionFontFamily,
    optionFontStyle: componentTokens.dropdown.optionFontStyle,
    optionFontWeight: componentTokens.dropdown.optionFontWeight,
    optionFontColor: componentTokens.dropdown.optionFontColor,
    optionIconSize: componentTokens.dropdown.optionIconSize,
    optionIconSpacing: componentTokens.dropdown.optionIconSpacing,
    optionIconColor: componentTokens.dropdown.optionIconColor,
    caretIconSize: componentTokens.dropdown.caretIconSize,
    caretIconColor: componentTokens.dropdown.caretIconColor,
    caretIconSpacing: componentTokens.dropdown.caretIconSpacing,
    borderRadius: componentTokens.dropdown.borderRadius,
    borderStyle: componentTokens.dropdown.borderStyle,
    borderThickness: componentTokens.dropdown.borderThickness,
    borderColor: componentTokens.dropdown.borderColor,
    scrollBarThumbColor: componentTokens.dropdown.scrollBarThumbColor,
    scrollBarTrackColor: componentTokens.dropdown.scrollBarTrackColor
  }
};

// src/table/Table.tsx
import { jsx as jsx43, jsxs as jsxs29 } from "react/jsx-runtime";
var overwriteTheme2 = (theme) => {
  const newTheme = dropdownTheme_default2;
  newTheme.dropdown.buttonBackgroundColor = theme.table.actionBackgroundColor;
  newTheme.dropdown.hoverButtonBackgroundColor = theme.table.hoverActionBackgroundColor;
  newTheme.dropdown.activeButtonBackgroundColor = theme.table.activeActionBackgroundColor;
  newTheme.dropdown.buttonIconColor = theme.table.actionIconColor;
  newTheme.dropdown.disabledColor = theme.table.disabledActionIconColor;
  newTheme.dropdown.disabledButtonBackgroundColor = theme.table.disabledActionBackgroundColor;
  return newTheme;
};
var DxcActionsCell = ({ actions }) => {
  const actionIcons = actions.filter((action) => !action.options);
  const actionDropdown = actions.find((action) => action.options);
  const maxNumberOfActions = actionDropdown ? 2 : 3;
  const colorsTheme = useContext23(HalstackContext);
  return /* @__PURE__ */ jsxs29(Flex_default, { gap: "0.5rem", alignItems: "center", children: [
    actionIcons.map(
      (action, index) => index < maxNumberOfActions && /* @__PURE__ */ jsx43(
        ActionIcon_default,
        {
          icon: action.icon,
          title: action.title,
          onClick: action.onClick,
          disabled: action.disabled ?? false,
          tabIndex: action.tabIndex ?? 0
        },
        `action-${index}`
      )
    ),
    actionDropdown && /* @__PURE__ */ jsx43(HalstackProvider, { advancedTheme: overwriteTheme2(colorsTheme), children: /* @__PURE__ */ jsx43(
      Dropdown_default,
      {
        options: actionDropdown.options ?? [],
        onSelectOption: actionDropdown.onClick,
        disabled: actionDropdown.disabled,
        icon: "more_vert",
        tabIndex: actionDropdown.tabIndex,
        caretHidden: true
      }
    ) }, "provider-dropdown")
  ] });
};
var DxcTable = ({ children, margin, mode = "default" }) => {
  const colorsTheme = useContext23(HalstackContext);
  return /* @__PURE__ */ jsx43(ThemeProvider16, { theme: colorsTheme.table, children: /* @__PURE__ */ jsx43(DxcTableContainer, { margin, children: /* @__PURE__ */ jsx43(DxcTableContent, { mode, children }) }) });
};
var calculateWidth7 = (margin) => `calc(100% - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})`;
var DxcTableContainer = styled36.div`
  width: ${(props) => calculateWidth7(props.margin)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};

  overflow: auto;
  &::-webkit-scrollbar {
    width: 8px;
    height: 8px;
  }
  &::-webkit-scrollbar-thumb {
    background-color: ${(props) => props.theme.scrollBarThumbColor};
    border-radius: 6px;
  }
  &::-webkit-scrollbar-track {
    background-color: ${(props) => props.theme.scrollBarTrackColor};
    border-radius: 6px;
  }
`;
var DxcTableContent = styled36.table`
  border-collapse: collapse;
  width: 100%;

  & tr {
    border-bottom: ${(props) => `${props.theme.rowSeparatorThickness} ${props.theme.rowSeparatorStyle} ${props.theme.rowSeparatorColor}`};
    height: ${(props) => props.mode === "default" ? "60px" : "36px"};
  }
  & td {
    background-color: ${(props) => props.theme.dataBackgroundColor};
    font-family: ${(props) => props.theme.dataFontFamily};
    font-size: ${(props) => props.theme.dataFontSize};
    font-style: ${(props) => props.theme.dataFontStyle};
    font-weight: ${(props) => props.theme.dataFontWeight};
    color: ${(props) => props.theme.dataFontColor};
    text-transform: ${(props) => props.theme.dataFontTextTransform};
    text-align: ${(props) => props.theme.dataTextAlign};
    line-height: ${(props) => props.theme.dataTextLineHeight};
    padding: ${(props) => props.mode === "default" ? `${props.theme.dataPaddingTop} ${props.theme.dataPaddingRight} ${props.theme.dataPaddingBottom} ${props.theme.dataPaddingLeft}` : `${props.theme.dataPaddingTopReduced} ${props.theme.dataPaddingRightReduced} ${props.theme.dataPaddingBottomReduced} ${props.theme.dataPaddingLeftReduced}`};
  }
  & th {
    background-color: ${(props) => props.theme.headerBackgroundColor};
    font-family: ${(props) => props.theme.headerFontFamily};
    font-size: ${(props) => props.theme.headerFontSize};
    font-style: ${(props) => props.theme.headerFontStyle};
    font-weight: ${(props) => props.theme.headerFontWeight};
    color: ${(props) => props.theme.headerFontColor};
    text-transform: ${(props) => props.theme.headerFontTextTransform};
    text-align: ${(props) => props.theme.headerTextAlign};
    line-height: ${(props) => props.theme.headerTextLineHeight};
    padding: ${(props) => props.mode === "default" ? `${props.theme.headerPaddingTop} ${props.theme.headerPaddingRight} ${props.theme.headerPaddingBottom} ${props.theme.headerPaddingLeft}` : `${props.theme.headerPaddingTopReduced} ${props.theme.headerPaddingRightReduced} ${props.theme.headerPaddingBottomReduced} ${props.theme.headerPaddingLeftReduced}`};
  }
  & th:first-child {
    border-top-left-radius: ${(props) => props.theme.headerBorderRadius};
    padding-left: ${(props) => props.mode === "default" ? props.theme.firstChildPaddingLeft : props.theme.firstChildPaddingLeftReduced};
  }
  & th:last-child {
    border-top-right-radius: ${(props) => props.theme.headerBorderRadius};
    padding-right: ${(props) => props.mode === "default" ? props.theme.lastChildPaddingRight : props.theme.lastChildPaddingRightReduced};
  }
  & td:first-child {
    padding-left: ${(props) => props.mode === "default" ? props.theme.firstChildPaddingLeft : props.theme.firstChildPaddingLeftReduced};
  }
  & td:last-child {
    padding-right: ${(props) => props.mode === "default" ? props.theme.lastChildPaddingRight : props.theme.lastChildPaddingRightReduced};
  }
`;
DxcTable.ActionsCell = DxcActionsCell;
var Table_default = DxcTable;

// src/data-grid/DataGrid.tsx
import { jsx as jsx44, jsxs as jsxs30 } from "react/jsx-runtime";
var ActionContainer = styled37.div`
  display: flex;
  height: 100%;
  align-items: center;
  justify-content: center;
  font-size: 14px;
  width: 100%;
`;
var HierarchyContainer = styled37.div`
  padding-left: ${(props) => `calc(${props.theme.dataPaddingLeft} * ${props.level})`};
  button {
    display: grid;
    grid-template-columns: auto 1fr;
    align-items: center;
    gap: 0.5rem;
    padding: 0px;
    border: 0px;
    width: 100%;
    height: ${(props) => props.theme.dataRowHeight}px;
    background: transparent;
    text-align: left;
    font-size: ${(props) => props.theme.dataFontSize};
    font-family: inherit;
    color: inherit;
    cursor: pointer;
  }
`;
var DataGridContainer = styled37.div`
  width: 100%;
  height: ${(props) => props.paginatorRendered ? `calc(100% - 50px)` : `100%`};
  .rdg {
    border-radius: 4px;
    height: 100%;
    border: 0px;
    &::-webkit-scrollbar {
      width: 8px;
      height: 8px;
    }
    &::-webkit-scrollbar-thumb {
      background-color: ${(props) => props.theme.scrollBarThumbColor};
      border-radius: 6px;
    }
    &::-webkit-scrollbar-track {
      background-color: ${(props) => props.theme.scrollBarTrackColor};
      border-radius: 6px;
    }
  }
  .rdg-cell:has(> #action) {
    padding: 0px;
  }
  .rdg-cell {
    display: grid;
    align-items: center;
    width: 100%;
    padding: 0px ${(props) => props.theme.dataPaddingRight} 0 ${(props) => props.theme.dataPaddingLeft};
    font-family: ${(props) => props.theme.dataFontFamily};
    font-size: ${(props) => props.theme.dataFontSize};
    font-style: ${(props) => props.theme.dataFontStyle};
    font-weight: ${(props) => props.theme.dataFontWeight};
    color: ${(props) => props.theme.dataFontColor};
    text-transform: ${(props) => props.theme.dataFontTextTransform};
    line-height: ${(props) => props.theme.dataTextLineHeight};
    border-bottom: ${(props) => `${props.theme.rowSeparatorThickness} ${props.theme.rowSeparatorStyle} ${props.theme.rowSeparatorColor}`};
    border-right: ${(props) => `${props.theme.rowSeparatorThickness} ${props.theme.rowSeparatorStyle} ${props.theme.rowSeparatorColor}`};
    background-color: ${(props) => props.theme.dataBackgroundColor};
    outline-color: ${(props) => props.theme.focusColor} !important;
    .rdg-text-editor:focus {
      border-color: transparent;
      background-color: transparent;
      color: ${(props) => props.theme.dataFontColor};
    }
  }
  .rdg-header-row {
    border-top-left-radius: ${(props) => props.theme.headerBorderRadius};
    border-top-right-radius: ${(props) => props.theme.headerBorderRadius};
    .rdg-cell {
      font-family: ${(props) => props.theme.headerFontFamily};
      font-size: ${(props) => props.theme.headerFontSize};
      font-style: ${(props) => props.theme.headerFontStyle};
      font-weight: ${(props) => props.theme.headerFontWeight};
      color: ${(props) => props.theme.headerFontColor};
      text-transform: ${(props) => props.theme.headerFontTextTransform};
      padding: 0px ${(props) => props.theme.headerPaddingRight} 0 ${(props) => props.theme.headerPaddingLeft};
      line-height: ${(props) => props.theme.headerTextLineHeight};
      background-color: ${(props) => props.theme.headerBackgroundColor};
      .sortIconContainer {
        margin-left: 0.5rem;
        display: flex;
        height: 100%;
        align-items: center;
      }
    }
  }
  .rdg-row {
    .rdg-cell:last-child {
      border-right: 0px;
    }
  }
  .rdg-summary-row {
    background-color: #fafafa;
    .rdg-cell {
      border: 0px;
      font-weight: 600;
    }
  }
  .ellipsis-cell {
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    width: 100%;
    height: 100%;
    display: flex;
    align-items: center;
  }
  .align-left {
    text-align: left;
    justify-content: flex-start;
  }
  .align-center {
    text-align: center;
    justify-content: center;
  }
  .align-right {
    text-align: right;
    justify-content: flex-end;
  }
  .header-align-left {
    text-align: left;
  }
  .header-align-center {
    text-align: center;
  }
  .header-align-right {
    text-align: right;
  }
`;
var DxcDataGrid = ({
  columns,
  rows,
  selectable,
  expandable,
  onSelectRows,
  selectedRows,
  uniqueRowId,
  summaryRow,
  onGridRowsChange,
  showPaginator = false,
  showGoToPage = true,
  itemsPerPage = 5,
  itemsPerPageOptions,
  itemsPerPageFunction,
  onSort,
  onPageChange,
  totalItems,
  defaultPage = 1
}) => {
  const [rowsToRender, setRowsToRender] = useState17(rows);
  const colorsTheme = useContext24(HalstackContext);
  const [page, changePage] = useState17(defaultPage);
  const goToPage = (newPage) => {
    if (onPageChange) {
      onPageChange(newPage);
    }
    changePage(newPage);
  };
  const handleSortChange = (newSortColumns) => {
    if (onSort) {
      if (newSortColumns[0]) {
        const { columnKey, direction } = newSortColumns[0];
        onSort({ columnKey, direction });
      } else {
        onSort();
      }
    }
    setSortColumns(newSortColumns);
  };
  const columnsToRender = useMemo10(() => {
    let expectedColumns = columns.map((column) => convertToRDGColumns(column, summaryRow));
    if (expandable) {
      expectedColumns = [
        {
          key: "expanded",
          name: "",
          maxWidth: 36,
          width: 36,
          minWidth: 36,
          colSpan(args) {
            return args.type === "ROW" && args.row.isExpandedChildContent ? columns.length + 1 : void 0;
          },
          renderCell({ row }) {
            if (row.isExpandedChildContent) {
              return row.expandedChildContent || null;
            }
            return /* @__PURE__ */ jsx44(ActionContainer, { id: "action", children: row.expandedContent && renderExpandableTrigger(row, rowsToRender, uniqueRowId, setRowsToRender) });
          }
        },
        ...expectedColumns
      ];
    }
    if (!expandable && rows.some((row) => Array.isArray(row.childRows) && row.childRows.length > 0) && uniqueRowId) {
      const firstColumnKey = expectedColumns[0]?.key;
      if (firstColumnKey) {
        expectedColumns[0] = {
          ...expectedColumns[0],
          renderCell({ row }) {
            if (row.childRows?.length) {
              return /* @__PURE__ */ jsx44(HierarchyContainer, { level: typeof row.rowLevel === "number" ? row.rowLevel : 0, children: renderHierarchyTrigger(rowsToRender, row, uniqueRowId, firstColumnKey, setRowsToRender) });
            }
            return /* @__PURE__ */ jsx44(HierarchyContainer, { level: typeof row.rowLevel === "number" ? row.rowLevel : 0, className: "ellipsis-cell", children: row[firstColumnKey] });
          }
        };
      }
    }
    if (selectable) {
      expectedColumns = [
        {
          key: "selected",
          name: "",
          maxWidth: 36,
          width: 36,
          minWidth: 36,
          renderCell({ row }) {
            if (!row.isExpandedChildContent) {
              return /* @__PURE__ */ jsx44(ActionContainer, { id: "action", children: renderCheckbox(rows, row, uniqueRowId, selectedRows, onSelectRows) });
            }
            return null;
          },
          renderHeaderCell: () => /* @__PURE__ */ jsx44(ActionContainer, { id: "action", children: renderHeaderCheckbox(rows, uniqueRowId, selectedRows, colorsTheme, onSelectRows) })
        },
        ...expectedColumns
      ];
    }
    return expectedColumns;
  }, [selectable, expandable, columns, rowsToRender, onSelectRows, rows, summaryRow, uniqueRowId, selectedRows]);
  const [columnsOrder, setColumnsOrder] = useState17(() => columnsToRender.map((_, index) => index));
  const [sortColumns, setSortColumns] = useState17([]);
  useEffect8(() => {
    setColumnsOrder(Array.from({ length: columnsToRender.length }, (_, index) => index));
  }, [columnsToRender.length]);
  useEffect8(() => {
    const finalRows = [...rows];
    if (expandable) {
      rows.forEach((row, index) => {
        if (row.contentIsExpanded && !rows.some((row2) => row2[uniqueRowId] === `${rowKeyGetter(row2, uniqueRowId)}_expanded`)) {
          addRow(finalRows, index + 1, {
            isExpandedChildContent: row.contentIsExpanded,
            [uniqueRowId]: `${rowKeyGetter(row, uniqueRowId)}_expanded`,
            expandedChildContent: row.expandedContent,
            triggerRowKey: rowKeyGetter(row, uniqueRowId),
            expandedContentHeight: row.expandedContentHeight
          });
        }
      });
    }
    setRowsToRender(finalRows);
  }, [rows]);
  const reorderedColumns = useMemo10(
    () => (
      // Array ordered by columnsOrder
      columnsOrder.map((index) => columnsToRender[index])
    ),
    [columnsOrder, columnsToRender]
  );
  const onColumnsReorder = (sourceKey, targetKey) => {
    setColumnsOrder((currentColumnsOrder) => {
      const sourceColumnOrderIndex = currentColumnsOrder.findIndex(
        (index) => columnsToRender[index]?.key === sourceKey
      );
      const targetColumnOrderIndex = currentColumnsOrder.findIndex(
        (index) => columnsToRender[index]?.key === targetKey
      );
      const newColumnsOrder = currentColumnsOrder.slice();
      if (sourceColumnOrderIndex === -1 || targetColumnOrderIndex === -1) {
        return currentColumnsOrder;
      }
      const itemToMove = currentColumnsOrder[sourceColumnOrderIndex];
      if (itemToMove != null) {
        newColumnsOrder.splice(sourceColumnOrderIndex, 1);
        newColumnsOrder.splice(targetColumnOrderIndex, 0, itemToMove);
      }
      return newColumnsOrder;
    });
  };
  const onRowsChange = (newRows) => {
    if (typeof onGridRowsChange === "function") {
      onGridRowsChange(newRows);
    }
  };
  const sortedRows = useMemo10(() => {
    const sortFunctions = getCustomSortFn(columns);
    if (!onSort) {
      if (sortColumns.length > 0 && uniqueRowId) {
        if (expandable) {
          const innerSortedRows = sortRows(
            rowsToRender.filter((row) => !row.isExpandedChildContent),
            sortColumns,
            sortFunctions
          );
          if (innerSortedRows.some((row) => uniqueRowId in row)) {
            rowsToRender.filter((row) => row.isExpandedChildContent).map(
              (expandedRow) => addRow(
                innerSortedRows,
                innerSortedRows.findIndex(
                  (trigger) => rowKeyGetter(trigger, uniqueRowId) === expandedRow.triggerRowKey
                ) + 1,
                expandedRow
              )
            );
            return innerSortedRows;
          }
        } else {
          return sortHierarchyRows(rowsToRender, sortColumns, sortFunctions, uniqueRowId);
        }
      }
    }
    return rowsToRender;
  }, [expandable, rowsToRender, sortColumns, uniqueRowId]);
  const minItemsPerPageIndex = useMemo10(() => getMinItemsPerPageIndex(page, itemsPerPage, page), [itemsPerPage, page]);
  const maxItemsPerPageIndex = useMemo10(
    () => getMaxItemsPerPageIndex(minItemsPerPageIndex, itemsPerPage, rows, page),
    [itemsPerPage, minItemsPerPageIndex, page, rows]
  );
  const filteredRows = useMemo10(() => {
    if (onSort && sortColumns?.length > 0) {
      onSort?.(sortColumns?.[0]);
    }
    return !showPaginator || onPageChange ? sortedRows : getPaginatedNodes(sortedRows, uniqueRowId, minItemsPerPageIndex, maxItemsPerPageIndex + 1);
  }, [sortedRows, minItemsPerPageIndex, maxItemsPerPageIndex]);
  return /* @__PURE__ */ jsx44(ThemeProvider17, { theme: colorsTheme.dataGrid, children: /* @__PURE__ */ jsxs30(DataGridContainer, { paginatorRendered: showPaginator && (totalItems ?? rows.length) > itemsPerPage, children: [
    /* @__PURE__ */ jsx44(
      DataGrid,
      {
        columns: reorderedColumns,
        rows: filteredRows,
        onColumnsReorder,
        onRowsChange,
        renderers: { renderSortStatus },
        sortColumns,
        onSortColumnsChange: handleSortChange,
        rowKeyGetter: (row) => uniqueRowId ? rowKeyGetter(row, uniqueRowId) : "",
        rowHeight: (row) => row.isExpandedChildContent && typeof row.expandedContentHeight === "number" && row.expandedContentHeight > 0 ? row.expandedContentHeight : colorsTheme.dataGrid?.dataRowHeight ?? 0,
        selectedRows,
        bottomSummaryRows: summaryRow ? [summaryRow] : void 0,
        headerRowHeight: colorsTheme.dataGrid.headerRowHeight,
        summaryRowHeight: colorsTheme.dataGrid.summaryRowHeight,
        className: "fill-grid"
      }
    ),
    showPaginator && (totalItems ?? rows.length) > itemsPerPage && /* @__PURE__ */ jsx44(
      Paginator_default,
      {
        totalItems: totalItems ?? rows.length,
        itemsPerPage,
        itemsPerPageOptions,
        itemsPerPageFunction,
        currentPage: page,
        showGoToPage,
        onPageChange: goToPage
      }
    )
  ] }) });
};
DxcDataGrid.ActionsCell = DxcActionsCell;
var DataGrid_default = DxcDataGrid;

// src/date-input/DateInput.tsx
import {
  useState as useState22,
  useRef as useRef12,
  useEffect as useEffect13,
  useId as useId11,
  useCallback as useCallback7,
  useContext as useContext29,
  forwardRef as forwardRef7
} from "react";
import dayjs3 from "dayjs";
import styled44, { ThemeProvider as ThemeProvider19 } from "styled-components";
import * as Popover4 from "@radix-ui/react-popover";
import customParseFormat from "dayjs/plugin/customParseFormat";

// src/date-input/DatePicker.tsx
import { memo as memo7, useContext as useContext26, useState as useState20 } from "react";
import dayjs2 from "dayjs";
import styled40 from "styled-components";

// src/date-input/Calendar.tsx
import { useContext as useContext25, useState as useState18, useMemo as useMemo11, useEffect as useEffect9, useId as useId8, memo as memo5 } from "react";
import styled38 from "styled-components";
import { jsx as jsx45, jsxs as jsxs31 } from "react/jsx-runtime";
var getDays = (innerDate) => {
  const monthDayCells = [];
  const lastMonthNumberOfDays = innerDate.set("month", innerDate.get("month") - 1).endOf("month");
  const firstDayOfMonth = innerDate.startOf("month").day() === 0 ? 6 : innerDate.startOf("month").day() - 1;
  const daysInMonth = firstDayOfMonth + innerDate.daysInMonth();
  for (let i = 0; i < 42; i++) {
    if (i < firstDayOfMonth) {
      monthDayCells.push({
        day: lastMonthNumberOfDays.get("date") - firstDayOfMonth + i + 1,
        month: innerDate.get("month") ? innerDate.get("month") - 1 : 11,
        year: innerDate.set("month", innerDate.get("month") - 1).get("year")
      });
    } else if (i < daysInMonth) {
      monthDayCells.push({
        day: i - firstDayOfMonth + 1,
        month: innerDate.get("month"),
        year: innerDate.get("year")
      });
    } else {
      monthDayCells.push({
        day: i - daysInMonth + 1,
        month: innerDate.get("month") === 11 ? 0 : innerDate.get("month") + 1,
        year: innerDate.set("month", innerDate.get("month") + 1).get("year")
      });
    }
  }
  return monthDayCells;
};
var getDateToFocus = (selectedDate, innerDate, today2) => selectedDate?.get("month") === innerDate.get("month") && selectedDate?.get("year") === innerDate.get("year") ? selectedDate : today2.get("month") === innerDate.get("month") && today2.get("year") === innerDate.get("year") ? today2 : innerDate.set("date", 1);
var isDaySelected = (date, selectedDate) => selectedDate?.get("month") === date.month && selectedDate?.get("year") === date.year && selectedDate?.get("date") === date.day;
var divideDaysIntoWeeks = (data, weekSize) => Array.from(
  { length: Math.ceil(data.length / weekSize) },
  (_, rowIndex) => data.slice(rowIndex * weekSize, (rowIndex + 1) * weekSize)
);
var Calendar = ({
  selectedDate,
  innerDate,
  onInnerDateChange,
  onDaySelect,
  today: today2
}) => {
  const [dateToFocus, setDateToFocus] = useState18(getDateToFocus(selectedDate, innerDate, today2));
  const [isFocusable, setIsFocusable] = useState18(false);
  const id = useId8();
  const translatedLabels = useContext25(HalstackLanguageContext);
  const dayCells = useMemo11(() => getDays(innerDate), [innerDate]);
  const onDateClickHandler = (date) => {
    const newDate = innerDate.set("month", date.month).set("date", date.day);
    onDaySelect(newDate);
    setDateToFocus(newDate);
  };
  const handleOnBlur = (event) => {
    if (!event?.currentTarget.contains(event.relatedTarget)) {
      setDateToFocus(getDateToFocus(selectedDate, innerDate, today2));
    }
  };
  const focusDate = (date) => {
    if (innerDate.get("month") !== date.get("month") || innerDate.get("year") !== date.get("year")) {
      onInnerDateChange(date);
    }
    setDateToFocus(date);
    setIsFocusable(true);
  };
  useEffect9(() => {
    if (isFocusable) {
      document.getElementById(`${id}_day_${dateToFocus.get("date")}_month${dateToFocus.get("month")}`)?.focus();
      setIsFocusable(false);
    }
  }, [dateToFocus, isFocusable]);
  useEffect9(() => {
    if (dateToFocus.get("month") !== innerDate.get("month") || dateToFocus.get("year") !== innerDate.get("year")) {
      setDateToFocus(getDateToFocus(selectedDate, innerDate, today2));
    }
  }, [innerDate, dateToFocus, selectedDate, today2]);
  const handleDayKeyboardEvent = (event, date) => {
    let dateToFocusTemp = date.month === innerDate.get("month") ? innerDate.set("date", date.day) : innerDate.set("date", date.day).set("month", date.month);
    switch (event.key) {
      case "PageUp":
        event.preventDefault();
        if (event.shiftKey) {
          dateToFocusTemp = dateToFocusTemp.set("year", dateToFocusTemp.get("year") - 1);
        } else {
          dateToFocusTemp = dateToFocusTemp.set("month", dateToFocusTemp.get("month") - 1);
        }
        focusDate(dateToFocusTemp);
        break;
      case "PageDown":
        event.preventDefault();
        if (event.shiftKey) {
          dateToFocusTemp = dateToFocusTemp.set("year", dateToFocusTemp.get("year") + 1);
        } else {
          dateToFocusTemp = dateToFocusTemp.set("month", dateToFocusTemp.get("month") + 1);
        }
        focusDate(dateToFocusTemp);
        break;
      case "ArrowLeft":
        event.preventDefault();
        dateToFocusTemp = dateToFocusTemp.set("date", dateToFocusTemp.get("date") - 1);
        focusDate(dateToFocusTemp);
        break;
      case "ArrowRight":
        event.preventDefault();
        dateToFocusTemp = dateToFocusTemp.set("date", dateToFocusTemp.get("date") + 1);
        focusDate(dateToFocusTemp);
        break;
      case "ArrowUp":
        event.preventDefault();
        dateToFocusTemp = dateToFocusTemp.set("date", dateToFocusTemp.get("date") - 7);
        focusDate(dateToFocusTemp);
        break;
      case "ArrowDown":
        event.preventDefault();
        dateToFocusTemp = dateToFocusTemp.set("date", dateToFocusTemp.get("date") + 7);
        focusDate(dateToFocusTemp);
        break;
      case "Home":
        event.preventDefault();
        if (dateToFocus.get("day") !== 0) {
          dateToFocusTemp = dateToFocusTemp.day(1);
        } else {
          dateToFocusTemp = innerDate.date(date.day - 1).day(1);
        }
        focusDate(dateToFocusTemp);
        break;
      case "End":
        event.preventDefault();
        if (dateToFocusTemp.get("day") !== 0) {
          dateToFocusTemp = dateToFocusTemp.day(7);
        }
        focusDate(dateToFocusTemp);
        break;
      case " ":
        event.preventDefault();
        onDaySelect(dateToFocusTemp);
        break;
      default:
        break;
    }
  };
  return /* @__PURE__ */ jsxs31(CalendarContainer, { role: "grid", children: [
    /* @__PURE__ */ jsx45(CalendarHeaderRow, { role: "row", children: translatedLabels.calendar.daysShort.map((weekDay) => /* @__PURE__ */ jsx45(WeekHeaderCell, { role: "columnheader", children: weekDay }, weekDay)) }),
    /* @__PURE__ */ jsx45(MonthContainer, { onBlur: handleOnBlur, role: "rowgroup", children: divideDaysIntoWeeks(dayCells, translatedLabels.calendar.daysShort.length).map((week, rowIndex) => /* @__PURE__ */ jsx45(WeekContainer, { role: "row", children: week.map((date) => /* @__PURE__ */ jsx45(
      DayCellButton,
      {
        id: `${id}_day_${date.day}_month${date.month}`,
        role: "gridcell",
        "aria-selected": isDaySelected(date, selectedDate),
        onKeyDown: (event) => handleDayKeyboardEvent(event, date),
        onClick: () => onDateClickHandler(date),
        selected: isDaySelected(date, selectedDate),
        actualMonth: date.month === innerDate.get("month"),
        autoFocus: date.day === dateToFocus.get("date") && date.month === dateToFocus.get("month"),
        tabIndex: date.day === dateToFocus.get("date") && date.month === dateToFocus.get("month") ? 0 : -1,
        isCurrentDay: today2.get("date") === date.day && today2.get("month") === innerDate.get("month") && today2.get("month") === date.month && today2.get("year") === innerDate.get("year"),
        children: date.day
      },
      `${id}_day_${date.day}_month${date.month}`
    )) }, `${id}_week_${rowIndex}`)) })
  ] });
};
var CalendarContainer = styled38.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 0px 8px 8px 8px;
  width: 292px;
  font-family: ${(props) => props.theme.dateInput.pickerFontFamily};
  font-size: ${(props) => props.theme.dateInput.pickerFontSize};
  color: ${(props) => props.theme.dateInput.pickerFontColor};
  font-weight: ${(props) => props.theme.dateInput.pickerFontWeight};
`;
var CalendarHeaderRow = styled38.div`
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
  justify-content: space-between;
  align-items: center;
`;
var WeekHeaderCell = styled38.span`
  display: flex;
  align-items: center;
  justify-content: center;
  width: 36px;
  height: 36px;
`;
var MonthContainer = styled38.div`
  box-sizing: border-box;
  display: flex;
  gap: 4px;
  flex-direction: column;
  justify-content: space-between;
`;
var WeekContainer = styled38.div`
  box-sizing: border-box;
  display: flex;
  gap: 4px;
  justify-content: space-between;
`;
var DayCellButton = styled38.button`
  display: inline-flex;
  justify-content: center;
  align-items: center;
  width: 36px;
  height: 36px;
  padding: 0;
  border: none;
  border-radius: 50%;
  cursor: pointer;
  font-family: ${(props) => props.theme.dateInput.pickerFontFamily};
  font-size: ${(props) => props.theme.dateInput.pickerFontSize};
  color: ${(props) => props.theme.dateInput.pickerFontColor};
  font-weight: ${(props) => props.theme.dateInput.pickerFontWeight};

  &:focus {
    outline: ${(props) => props.theme.dateInput.pickerFocusColor} solid 2px;
  }
  &:hover {
    background-color: ${(props) => props.selected ? props.theme.dateInput.pickerSelectedBackgroundColor : props.theme.dateInput.pickerHoverBackgroundColor};
    color: ${(props) => props.selected ? props.theme.dateInput.pickerSelectedFontColor : props.theme.dateInput.pickerHoverFontColor};
  }
  &:active {
    background-color: ${(props) => props.theme.dateInput.pickerActiveBackgroundColor};
    color: ${(props) => props.theme.dateInput.pickerActiveFontColor};
  }

  ${(props) => props.isCurrentDay && !props.selected && `border: ${props.theme.dateInput.pickerCurrentDateBorderWidth} solid ${props.theme.dateInput.pickerCurrentDateBorderColor};`}
  background-color: ${(props) => props.selected ? props.theme.dateInput.pickerSelectedBackgroundColor : "transparent"};
  color: ${(props) => props.selected ? props.theme.dateInput.pickerSelectedFontColor : props.isCurrentDay ? props.theme.dateInput.pickerCurrentDateFontColor : !props.actualMonth ? props.theme.dateInput.pickerNonCurrentMonthFontColor : props.theme.dateInput.pickerFontColor};
`;
var Calendar_default = memo5(Calendar);

// src/date-input/YearPicker.tsx
import dayjs from "dayjs";
import { useEffect as useEffect10, useId as useId9, useState as useState19, memo as memo6 } from "react";
import styled39 from "styled-components";
import { jsx as jsx46 } from "react/jsx-runtime";
var getYearsArray = () => {
  const yearList2 = [];
  for (let i = 1899; i <= 2100; i++) {
    yearList2.push(i);
  }
  return yearList2;
};
var yearList = getYearsArray();
var YearPicker = ({ onYearSelect, selectedDate, today: today2 }) => {
  const id = useId9();
  const [yearToFocus, setYearToFocus] = useState19(selectedDate ? selectedDate.get("year") : dayjs().get("year"));
  useEffect10(() => {
    const yearToFocusEl = document.getElementById(`${id}_year_${yearToFocus}`);
    yearToFocusEl?.scrollIntoView?.({ block: "nearest", inline: "start" });
    yearToFocusEl?.focus();
  }, [yearToFocus]);
  const handleDayKeyboardEvent = (event) => {
    switch (event.key) {
      case "ArrowUp":
        setYearToFocus((prev) => prev > 1899 ? prev - 1 : prev);
        break;
      case "ArrowDown":
        setYearToFocus((prev) => prev < 2100 ? prev + 1 : prev);
        break;
      default:
        break;
    }
  };
  return /* @__PURE__ */ jsx46(YearPickerContainer, { role: "listbox", "aria-label": "Year Picker", children: yearList.map((year2) => /* @__PURE__ */ jsx46(
    YearPickerButton,
    {
      "aria-label": year2.toString(),
      selected: selectedDate?.get("year") === year2,
      "aria-selected": selectedDate?.get("year") === year2,
      tabIndex: yearToFocus === year2 ? 0 : -1,
      isCurrentYear: today2.get("year") === year2,
      onKeyDown: (event) => handleDayKeyboardEvent(event),
      id: `${id}_year_${year2}`,
      onClick: () => {
        onYearSelect(year2);
      },
      role: "option",
      children: year2
    },
    year2
  )) });
};
var YearPickerContainer = styled39.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  gap: 4px;
  align-items: center;
  overflow-y: scroll;
  width: 292px;
  height: 312px;
  padding: 2px 8px 8px 8px;
`;
var YearPickerButton = styled39.button`
  display: flex;
  align-items: center;
  justify-content: center;
  width: 80px;
  min-height: 40px;
  line-height: 21px;
  background-color: transparent;
  border: none;
  border-radius: 50px;
  cursor: pointer;
  font-family: ${(props) => props.theme.dateInput.pickerFontFamily};
  font-size: ${(props) => props.theme.dateInput.pickerFontSize};
  color: ${(props) => props.theme.dateInput.pickerFontColor};
  font-weight: ${(props) => props.theme.dateInput.pickerFontWeight};

  ${(props) => props.selected ? `font-size: ${props.theme.dateInput.pickerInteractedYearFontSize};
         line-height: 36px;
         color: ${props.theme.dateInput.pickerSelectedFontColor} !important;
         background-color: ${props.theme.dateInput.pickerSelectedBackgroundColor} !important;` : props.isCurrentYear ? `border: 1px solid ${props.theme.dateInput.pickerCurrentDateBorderColor}; 
         color: ${props.theme.dateInput.pickerCurrentYearFontColor};` : ``}

  &:hover, &:focus, &:active {
    font-size: ${(props) => props.theme.dateInput.pickerInteractedYearFontSize};
    line-height: 36px;
  }
  &:hover {
    color: ${(props) => props.theme.dateInput.pickerHoverFontColor};
    background-color: ${(props) => props.theme.dateInput.pickerHoverBackgroundColor};
  }
  &:focus {
    color: ${(props) => props.theme.dateInput.pickerHoverFontColor};
    outline: ${(props) => `${props.theme.dateInput.pickerFocusColor} solid
      ${props.theme.dateInput.pickerFocusWidth}`};
  }
  &:active {
    color: ${(props) => props.theme.dateInput.pickerActiveFontColor};
    background-color: ${(props) => props.theme.dateInput.pickerActiveBackgroundColor} !important;
  }
`;
var YearPicker_default = memo6(YearPicker);

// src/date-input/DatePicker.tsx
import { jsx as jsx47, jsxs as jsxs32 } from "react/jsx-runtime";
var today = dayjs2();
var DatePicker = ({ date, onDateSelect, id }) => {
  const [innerDate, setInnerDate] = useState20(date?.isValid() ? date : dayjs2());
  const [content, setContent] = useState20("calendar");
  const selectedDate = date?.isValid() ? date : dayjs2(null);
  const translatedLabels = useContext26(HalstackLanguageContext);
  const handleDateSelect = (chosenDate) => {
    setInnerDate(chosenDate);
    onDateSelect(chosenDate);
  };
  const handleOnYearSelect = (year2) => {
    setInnerDate(innerDate.set("year", year2));
    setContent("calendar");
  };
  const handleMonthChange = (chosenDate) => {
    setInnerDate(chosenDate);
  };
  return /* @__PURE__ */ jsxs32(DatePickerContainer, { id, children: [
    /* @__PURE__ */ jsxs32(PickerHeader, { children: [
      /* @__PURE__ */ jsx47(Tooltip, { label: translatedLabels.calendar.previousMonthTitle, children: /* @__PURE__ */ jsx47(
        HeaderButton,
        {
          "aria-label": translatedLabels.calendar.previousMonthTitle,
          onClick: () => handleMonthChange(innerDate.set("month", innerDate.get("month") - 1)),
          children: /* @__PURE__ */ jsx47(Icon_default, { icon: "keyboard_arrow_left" })
        }
      ) }),
      /* @__PURE__ */ jsxs32(
        HeaderYearTrigger,
        {
          "aria-live": "polite",
          onClick: () => setContent((currentContent) => currentContent === "yearPicker" ? "calendar" : "yearPicker"),
          children: [
            /* @__PURE__ */ jsxs32(HeaderYearTriggerLabel, { children: [
              translatedLabels.calendar.months[innerDate.get("month")],
              " ",
              innerDate.format("YYYY")
            ] }),
            /* @__PURE__ */ jsx47(Icon_default, { icon: content === "yearPicker" ? "arrow_drop_up" : "arrow_drop_down" })
          ]
        }
      ),
      /* @__PURE__ */ jsx47(Tooltip, { label: translatedLabels.calendar.nextMonthTitle, children: /* @__PURE__ */ jsx47(
        HeaderButton,
        {
          "aria-label": translatedLabels.calendar.nextMonthTitle,
          onClick: () => handleMonthChange(innerDate.set("month", innerDate.get("month") + 1)),
          children: /* @__PURE__ */ jsx47(Icon_default, { icon: "keyboard_arrow_right" })
        }
      ) })
    ] }),
    content === "calendar" && /* @__PURE__ */ jsx47(
      Calendar_default,
      {
        innerDate,
        selectedDate,
        onInnerDateChange: setInnerDate,
        onDaySelect: handleDateSelect,
        today
      }
    ),
    content === "yearPicker" && /* @__PURE__ */ jsx47(YearPicker_default, { selectedDate, onYearSelect: handleOnYearSelect, today })
  ] });
};
var DatePickerContainer = styled40.div`
  padding-top: 16px;
  background-color: ${(props) => props.theme.dateInput.pickerBackgroundColor};
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1);
  border: ${(props) => `${props.theme.dateInput.pickerBorderWidth} ${props.theme.dateInput.pickerBorderStyle}
      ${props.theme.dateInput.pickerBorderColor}`};
  border-radius: 4px;
  width: fit-content;
  font-family: ${(props) => props.theme.dateInput.pickerFontFamily};
  font-size: ${(props) => props.theme.dateInput.pickerFontSize};
  color: ${(props) => props.theme.dateInput.pickerFontColor};
  font-weight: ${(props) => props.theme.dateInput.pickerFontWeight};
`;
var PickerHeader = styled40.div`
  box-sizing: border-box;
  display: flex;
  gap: 8px;
  align-items: center;
  justify-content: space-between;
  padding: 0px 16px;
`;
var HeaderButton = styled40.button`
  display: flex;
  align-items: center;
  justify-content: center;
  width: 24px;
  height: 24px;
  padding: 0px;
  color: ${(props) => props.theme.dateInput.pickerHeaderFontColor};
  background-color: ${(props) => props.theme.dateInput.pickerHeaderBackgroundColor};
  border-radius: 4px;
  border: none;
  cursor: pointer;

  &:hover {
    color: ${(props) => props.theme.dateInput.pickerHeaderHoverFontColor};
    background-color: ${(props) => props.theme.dateInput.pickerHeaderHoverBackgroundColor};
  }
  &:focus {
    outline: ${(props) => `${props.theme.dateInput.pickerFocusColor} solid
      ${props.theme.dateInput.pickerFocusWidth}`};
  }
  &:active {
    color: ${(props) => props.theme.dateInput.pickerHeaderActiveFontColor};
    background-color: ${(props) => props.theme.dateInput.pickerHeaderActiveBackgroundColor};
  }

  span::before {
    font-size: 24px;
  }
`;
var HeaderYearTrigger = styled40(HeaderButton)`
  gap: 8px;
  height: 40px;
  width: 172px;
  font-size: 24px;
  span::before {
    font-size: 24px;
  }
`;
var HeaderYearTriggerLabel = styled40.span`
  display: flex;
  align-items: center;
  justify-content: center;
  font-family: ${(props) => props.theme.dateInput.pickerFontFamily};
  font-size: ${(props) => props.theme.dateInput.pickerHeaderFontSize};
`;
var DatePicker_default = memo7(DatePicker);

// src/text-input/TextInput.tsx
import * as Popover3 from "@radix-ui/react-popover";
import {
  forwardRef as forwardRef6,
  useContext as useContext28,
  useEffect as useEffect12,
  useId as useId10,
  useRef as useRef11,
  useState as useState21
} from "react";
import styled43, { ThemeProvider as ThemeProvider18 } from "styled-components";

// src/number-input/NumberInputContext.tsx
import { createContext as createContext7 } from "react";
var NumberInputContext_default = createContext7(null);

// src/text-input/Suggestions.tsx
import { memo as memo9, useContext as useContext27, useEffect as useEffect11, useRef as useRef10 } from "react";
import styled42 from "styled-components";

// src/text-input/Suggestion.tsx
import { memo as memo8, useMemo as useMemo12 } from "react";
import styled41 from "styled-components";

// src/text-input/utils.ts
var sizes4 = {
  small: "240px",
  medium: "360px",
  large: "480px",
  fillParent: "100%"
};
var calculateWidth8 = (margin, size) => size === "fillParent" ? `calc(${sizes4[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes4[size];
var makeCancelable = (promise) => {
  let hasCanceled_ = false;
  const wrappedPromise = new Promise((resolve, reject) => {
    promise.then(
      (val) => hasCanceled_ ? reject(Error("Is canceled")) : resolve(val),
      (promiseError) => hasCanceled_ ? reject(Error("Is canceled")) : reject(promiseError)
    );
  });
  return {
    promise: wrappedPromise,
    cancel() {
      hasCanceled_ = true;
    }
  };
};
var hasSuggestions = (suggestions) => typeof suggestions === "function" || (suggestions ? suggestions.length > 0 : false);
var isRequired = (value, optional) => value === "" && !optional;
var isLengthIncorrect = (value, minLength, maxLength) => value != null && (minLength != null && value.length < minLength || maxLength != null && value.length > maxLength);
var isNumberIncorrect = (value, minNumber, maxNumber) => minNumber != null && value < minNumber || maxNumber != null && value > maxNumber;
var patternMismatch = (pattern, value) => pattern != null && !new RegExp(pattern).test(value);
var transformSpecialChars = (str) => {
  const specialCharsRegex = /[\\*()[\]{}+?/]/;
  let value = str;
  if (specialCharsRegex.test(value)) {
    const regexAsString = specialCharsRegex.toString().split("");
    const uniqueSpecialChars = regexAsString.filter((item, index) => regexAsString.indexOf(item) === index);
    uniqueSpecialChars.forEach((specialChar) => {
      if (str.includes(specialChar)) value = value.replace(specialChar, "\\" + specialChar);
    });
  }
  return value;
};

// src/text-input/Suggestion.tsx
import { Fragment as Fragment11, jsx as jsx48, jsxs as jsxs33 } from "react/jsx-runtime";
var SuggestionContainer = styled41.li`
  display: flex;
  padding: 0 0.5rem;
  line-height: 1.715em;
  cursor: pointer;
  box-shadow: inset 0 0 0 2px
    ${(props) => props.visuallyFocused ? props.theme.focusListOptionBorderColor : "transparent"};

  &:hover {
    background-color: ${(props) => props.theme.hoverListOptionBackgroundColor};
  }
  &:active {
    background-color: ${(props) => props.theme.activeListOptionBackgroundColor};
  }
`;
var StyledSuggestion = styled41.span`
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  padding: 0.25rem 0.5rem 0.188rem 0.5rem;
  ${(props) => props.isLast || props.visuallyFocused ? `border-bottom: 1px solid transparent` : `border-bottom: 1px solid ${props.theme.listOptionDividerColor}`};
`;
var Suggestion = ({
  id,
  value,
  onClick,
  suggestion,
  isLast,
  visuallyFocused,
  highlighted
}) => {
  const matchedSuggestion = useMemo12(() => {
    const regEx = new RegExp(transformSpecialChars(value), "i");
    return { matchedWords: suggestion.match(regEx), noMatchedWords: suggestion.replace(regEx, "") };
  }, [value, suggestion]);
  return /* @__PURE__ */ jsx48(
    SuggestionContainer,
    {
      id,
      onClick: () => {
        onClick(suggestion);
      },
      visuallyFocused,
      role: "option",
      "aria-selected": visuallyFocused ? true : void 0,
      children: /* @__PURE__ */ jsx48(StyledSuggestion, { isLast, visuallyFocused, children: highlighted ? /* @__PURE__ */ jsxs33(Fragment11, { children: [
        /* @__PURE__ */ jsx48("strong", { children: matchedSuggestion.matchedWords }),
        matchedSuggestion.noMatchedWords
      ] }) : suggestion })
    }
  );
};
var Suggestion_default = memo8(Suggestion);

// src/text-input/Suggestions.tsx
import { jsx as jsx49, jsxs as jsxs34 } from "react/jsx-runtime";
var SuggestionsContainer = styled42.ul`
  box-sizing: border-box;
  max-height: 304px;
  overflow-y: auto;
  margin: 0;
  padding: 0.25rem 0;
  background-color: ${(props) => props.error ? props.theme.errorListDialogBackgroundColor : props.theme.listDialogBackgroundColor};
  border: 1px solid
    ${(props) => props.error ? props.theme.errorListDialogBorderColor : props.theme.listDialogBorderColor};

  border-radius: 0.25rem;
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1);
  color: ${(props) => props.theme.listOptionFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.listOptionFontSize};
  font-style: ${(props) => props.theme.listOptionFontStyle};
  font-weight: ${(props) => props.theme.listOptionFontWeight};
`;
var SuggestionsSystemMessage = styled42.span`
  display: flex;
  padding: 0.25rem 1rem;
  color: ${(props) => props.theme.systemMessageFontColor};
  line-height: 1.715em;
`;
var SuggestionsErrorIcon = styled42.span`
  display: flex;
  flex-wrap: wrap;
  align-content: center;
  margin-right: 0.5rem;
  height: 18px;
  width: 18px;
  font-size: 18px;
  color: ${(props) => props.theme.errorIconColor};
`;
var SuggestionsError = styled42.span`
  display: flex;
  padding: 0.25rem 1rem;
  align-items: center;
  line-height: 1.715em;
  color: ${(props) => props.theme.errorListDialogFontColor};
`;
var Suggestions = ({
  id,
  value,
  suggestions,
  visualFocusIndex,
  highlightedSuggestions,
  searchHasErrors,
  isSearching,
  suggestionOnClick,
  styles
}) => {
  const translatedLabels = useContext27(HalstackLanguageContext);
  const listboxRef = useRef10(null);
  useEffect11(() => {
    const visualFocusedOptionEl = listboxRef?.current?.querySelectorAll("[role='option']")[visualFocusIndex];
    visualFocusedOptionEl?.scrollIntoView?.({
      block: "nearest",
      inline: "start"
    });
  }, [visualFocusIndex]);
  return /* @__PURE__ */ jsxs34(
    SuggestionsContainer,
    {
      id,
      error: !!searchHasErrors,
      onMouseDown: (event) => {
        event.preventDefault();
      },
      ref: listboxRef,
      role: "listbox",
      style: styles,
      "aria-label": "Suggestions",
      children: [
        !isSearching && !searchHasErrors && suggestions.length > 0 && suggestions.map((suggestion, index) => /* @__PURE__ */ jsx49(
          Suggestion_default,
          {
            id: `${id}-suggestion-${index}`,
            value,
            onClick: suggestionOnClick,
            suggestion,
            isLast: index === suggestions.length - 1,
            visuallyFocused: visualFocusIndex === index,
            highlighted: highlightedSuggestions
          },
          `${id}-suggestion-${index}`
        )),
        isSearching && /* @__PURE__ */ jsx49(SuggestionsSystemMessage, { role: "option", children: translatedLabels.textInput.searchingMessage }),
        searchHasErrors && /* @__PURE__ */ jsx49("span", { role: "option", children: /* @__PURE__ */ jsxs34(SuggestionsError, { role: "alert", "aria-live": "assertive", children: [
          /* @__PURE__ */ jsx49(SuggestionsErrorIcon, { children: /* @__PURE__ */ jsx49(Icon_default, { icon: "filled_error" }) }),
          translatedLabels.textInput.fetchingDataErrorMessage
        ] }) })
      ]
    }
  );
};
var Suggestions_default = memo9(Suggestions);

// src/text-input/TextInput.tsx
import { Fragment as Fragment12, jsx as jsx50, jsxs as jsxs35 } from "react/jsx-runtime";
var TextInputContainer = styled43.div`
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  width: ${(props) => calculateWidth8(props.margin, props.size)};
  ${(props) => props.size !== "fillParent" && `min-width:${calculateWidth8(props.margin, props.size)}`};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  font-family: ${(props) => props.theme.fontFamily};
`;
var Label4 = styled43.label`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
  ${(props) => !props.hasHelperText && `margin-bottom: 0.25rem`}
`;
var OptionalLabel2 = styled43.span`
  font-weight: ${(props) => props.theme.optionalLabelFontWeight};
`;
var HelperText2 = styled43.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
  margin-bottom: 0.25rem;
`;
var InputContainer = styled43.div`
  position: relative;
  display: flex;
  align-items: center;
  height: calc(2.5rem - 2px);
  padding: 0 0.5rem;

  ${(props) => props.disabled && `background-color: ${props.theme.disabledContainerFillColor};`}
  box-shadow: 0 0 0 2px transparent;
  border-radius: 4px;
  border: 1px solid
    ${(props) => props.disabled ? props.theme.disabledBorderColor : props.readOnly ? props.theme.readOnlyBorderColor : props.theme.enabledBorderColor};
  ${(props) => props.error && !props.disabled && `border-color: transparent;
     box-shadow: 0 0 0 2px ${props.theme.errorBorderColor};
  `}
  ${(props) => !props.disabled ? `
      &:hover {
        border-color: ${props.error ? "transparent" : props.readOnly ? props.theme.hoverReadOnlyBorderColor : props.theme.hoverBorderColor};
        ${props.error ? `box-shadow: 0 0 0 2px ${props.theme.hoverErrorBorderColor};` : ""}
      }
      &:focus-within {
        border-color: transparent;
        box-shadow: 0 0 0 2px ${props.theme.focusBorderColor};
      }
    ` : "cursor: not-allowed;"};
`;
var Input = styled43.input`
  height: calc(2.5rem - 2px);
  width: 100%;
  background: none;
  border: none;
  outline: none;
  padding: 0 0.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: ${(props) => props.disabled ? props.theme.disabledValueFontColor : props.theme.valueFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.valueFontSize};
  font-style: ${(props) => props.theme.valueFontStyle};
  font-weight: ${(props) => props.theme.valueFontWeight};
  line-height: 1.5em;
  ${(props) => props.disabled && `cursor: not-allowed;`}

  ::placeholder {
    color: ${(props) => props.disabled ? props.theme.disabledPlaceholderFontColor : props.theme.placeholderFontColor};
  }
`;
var Prefix = styled43.span`
  height: 1.5rem;
  margin-left: 0.25rem;
  padding-right: ${(props) => props.theme.prefixDividerPaddingRight};
  ${(props) => {
  const color = props.disabled ? props.theme.disabledPrefixColor : props.theme.prefixColor;
  return `color: ${color}; border-right: ${props.theme.prefixDividerBorderWidth} ${props.theme.prefixDividerBorderStyle} ${color};`;
}};
  font-size: 1rem;
  line-height: 1.5rem;
  pointer-events: none;
`;
var Suffix = styled43.span`
  height: 1.5rem;
  margin: 0 0.25rem;
  padding-left: ${(props) => props.theme.suffixDividerPaddingLeft};
  ${(props) => {
  const color = props.disabled ? props.theme.disabledSuffixColor : props.theme.suffixColor;
  return `color: ${color}; border-left: ${props.theme.suffixDividerBorderWidth} ${props.theme.suffixDividerBorderStyle} ${color};`;
}};
  font-size: 1rem;
  line-height: 1.5rem;
  pointer-events: none;
`;
var ErrorIcon2 = styled43.span`
  display: flex;
  flex-wrap: wrap;
  align-content: center;
  padding: 3px;
  height: 18px;
  width: 18px;
  font-size: 18px;
  color: ${(props) => props.theme.errorIconColor};
`;
var ErrorMessageContainer = styled43.span`
  min-height: 1.5em;
  color: ${(props) => props.theme.errorMessageColor};
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.5em;
  margin-top: 0.25rem;
`;
var AutosuggestWrapper = ({ condition, wrapper, children }) => /* @__PURE__ */ jsx50(Fragment12, { children: condition ? wrapper(children) : children });
var DxcTextInput = forwardRef6(
  ({
    label,
    name = "",
    defaultValue = "",
    value,
    helperText,
    placeholder = "",
    action,
    clearable = false,
    disabled = false,
    readOnly = false,
    optional = false,
    prefix = "",
    suffix = "",
    onChange,
    onBlur,
    error,
    suggestions,
    pattern,
    minLength,
    maxLength,
    autocomplete = "off",
    margin,
    size = "medium",
    tabIndex = 0,
    ariaLabel = "Text input"
  }, ref) => {
    const inputId = `input-${useId10()}`;
    const autosuggestId = `suggestions-${inputId}`;
    const errorId = `error-${inputId}`;
    const colorsTheme = useContext28(HalstackContext);
    const translatedLabels = useContext28(HalstackLanguageContext);
    const numberInputContext = useContext28(NumberInputContext_default);
    const inputRef = useRef11(null);
    const inputContainerRef = useRef11(null);
    const actionRef = useRef11(null);
    const [innerValue, setInnerValue] = useState21(defaultValue);
    const [isOpen, changeIsOpen] = useState21(false);
    const [isSearching, changeIsSearching] = useState21(false);
    const [isAutosuggestError, changeIsAutosuggestError] = useState21(false);
    const [filteredSuggestions, changeFilteredSuggestions] = useState21([]);
    const [visualFocusIndex, changeVisualFocusIndex] = useState21(-1);
    const width = useWidth_default(inputContainerRef.current);
    const getNumberErrorMessage = (checkedValue) => numberInputContext?.minNumber != null && checkedValue < numberInputContext?.minNumber ? translatedLabels.numberInput.valueGreaterThanOrEqualToErrorMessage?.(numberInputContext.minNumber) : numberInputContext?.maxNumber != null && checkedValue > numberInputContext?.maxNumber ? translatedLabels.numberInput.valueLessThanOrEqualToErrorMessage?.(numberInputContext.maxNumber) : void 0;
    const openSuggestions = () => {
      if (hasSuggestions(suggestions)) {
        changeIsOpen(true);
      }
    };
    const closeSuggestions = () => {
      if (hasSuggestions(suggestions)) {
        changeIsOpen(false);
        changeVisualFocusIndex(-1);
      }
    };
    const changeValue = (newValue) => {
      const formattedValue = typeof newValue === "number" ? newValue.toString() : newValue;
      if (value == null) {
        setInnerValue(formattedValue);
      }
      if (isRequired(formattedValue, optional)) {
        onChange?.({
          value: formattedValue,
          error: translatedLabels.formFields.requiredValueErrorMessage
        });
      } else if (isLengthIncorrect(formattedValue, minLength, maxLength)) {
        onChange?.({
          value: formattedValue,
          error: translatedLabels.formFields.lengthErrorMessage?.(minLength, maxLength)
        });
      } else if (patternMismatch(pattern, formattedValue)) {
        onChange?.({ value: formattedValue, error: translatedLabels.formFields.formatRequestedErrorMessage });
      } else if (numberInputContext?.typeNumber === "number" && isNumberIncorrect(Number(newValue), numberInputContext?.minNumber, numberInputContext?.maxNumber)) {
        onChange?.({ value: formattedValue, error: getNumberErrorMessage(Number(newValue)) });
      } else {
        onChange?.({ value: formattedValue });
      }
    };
    const decrementNumber = (currentValue = value ?? innerValue) => {
      if (!disabled && !readOnly) {
        const numberValue = Number(currentValue);
        const steppedValue = Math.round((numberValue - (numberInputContext?.stepNumber ?? 0) + Number.EPSILON) * 100) / 100;
        if (currentValue !== "") {
          if (numberInputContext?.minNumber != null && (numberValue < numberInputContext?.minNumber || steppedValue < numberInputContext?.minNumber)) {
            changeValue(numberValue);
          } else if (numberInputContext?.maxNumber != null && numberValue > numberInputContext?.maxNumber) {
            changeValue(numberInputContext?.maxNumber);
          } else if (numberValue === numberInputContext?.minNumber) {
            changeValue(numberInputContext?.minNumber);
          } else {
            changeValue(steppedValue);
          }
        } else if (numberInputContext?.minNumber != null && numberInputContext?.minNumber >= 0) {
          changeValue(numberInputContext?.minNumber);
        } else if (numberInputContext?.maxNumber != null && numberInputContext?.maxNumber < 0) {
          changeValue(numberInputContext?.maxNumber);
        } else if (numberInputContext?.stepNumber != null) {
          changeValue(-numberInputContext.stepNumber);
        }
      }
    };
    const incrementNumber = (currentValue = value ?? innerValue) => {
      if (!disabled && !readOnly) {
        const numberValue = Number(currentValue);
        const steppedValue = Math.round((numberValue + (numberInputContext?.stepNumber ?? 0) + Number.EPSILON) * 100) / 100;
        if (currentValue !== "") {
          if (numberInputContext?.maxNumber != null && (numberValue > numberInputContext?.maxNumber || steppedValue > numberInputContext?.maxNumber)) {
            changeValue(numberValue);
          } else if (numberInputContext?.minNumber != null && numberValue < numberInputContext?.minNumber) {
            changeValue(numberInputContext?.minNumber);
          } else if (numberValue === numberInputContext?.maxNumber) {
            changeValue(numberInputContext?.maxNumber);
          } else {
            changeValue(steppedValue);
          }
        } else if (numberInputContext?.minNumber != null && numberInputContext?.minNumber > 0) {
          changeValue(numberInputContext?.minNumber);
        } else if (numberInputContext?.maxNumber != null && numberInputContext?.maxNumber <= 0) {
          changeValue(numberInputContext?.maxNumber);
        } else if (numberInputContext?.stepNumber != null) {
          changeValue(numberInputContext.stepNumber);
        }
      }
    };
    const handleInputContainerOnClick = () => {
      if (document.activeElement !== actionRef.current) {
        inputRef.current?.focus();
      }
    };
    const handleInputContainerOnMouseDown = (event) => {
      if (document.activeElement === inputRef.current) {
        event.preventDefault();
      }
    };
    const handleInputOnChange = (event) => {
      openSuggestions();
      changeValue(event.target.value);
    };
    const handleInputOnBlur = (event) => {
      closeSuggestions();
      if (isRequired(event.target.value, optional)) {
        onBlur?.({ value: event.target.value, error: translatedLabels.formFields.requiredValueErrorMessage });
      } else if (isLengthIncorrect(event.target.value, minLength, maxLength)) {
        onBlur?.({
          value: event.target.value,
          error: translatedLabels.formFields.lengthErrorMessage?.(minLength, maxLength)
        });
      } else if (patternMismatch(pattern, event.target.value)) {
        onBlur?.({ value: event.target.value, error: translatedLabels.formFields.formatRequestedErrorMessage });
      } else if (numberInputContext?.typeNumber === "number" && isNumberIncorrect(Number(event.target.value), numberInputContext?.minNumber, numberInputContext?.maxNumber)) {
        onBlur?.({ value: event.target.value, error: getNumberErrorMessage(Number(event.target.value)) });
      } else {
        onBlur?.({ value: event.target.value });
      }
    };
    const handleInputOnKeyDown = (event) => {
      switch (event.key) {
        case "Down":
        case "ArrowDown":
          event.preventDefault();
          if (numberInputContext?.typeNumber === "number") {
            decrementNumber();
          } else {
            openSuggestions();
            if (!isAutosuggestError && !isSearching && filteredSuggestions.length > 0) {
              changeVisualFocusIndex(
                (visualFocusedSuggestionIndex) => visualFocusedSuggestionIndex < filteredSuggestions.length - 1 ? visualFocusedSuggestionIndex + 1 : visualFocusedSuggestionIndex === filteredSuggestions.length - 1 ? 0 : -1
              );
            }
          }
          break;
        case "Up":
        case "ArrowUp":
          event.preventDefault();
          if (numberInputContext?.typeNumber === "number") {
            incrementNumber();
          } else {
            openSuggestions();
            if (!isAutosuggestError && !isSearching && filteredSuggestions.length > 0) {
              changeVisualFocusIndex(
                (visualFocusedSuggestionIndex) => visualFocusedSuggestionIndex === 0 || visualFocusedSuggestionIndex === -1 ? filteredSuggestions.length > 0 ? filteredSuggestions.length - 1 : (suggestions?.length ?? 0) - 1 : visualFocusedSuggestionIndex - 1
              );
            }
          }
          break;
        case "Esc":
        case "Escape":
          event.preventDefault();
          if (isOpen) {
            event.stopPropagation();
          }
          if (hasSuggestions(suggestions)) {
            changeValue("");
            if (isOpen) {
              closeSuggestions();
            }
          }
          break;
        case "Enter":
          if (hasSuggestions(suggestions) && !isSearching) {
            const validFocusedSuggestion = filteredSuggestions.length > 0 && visualFocusIndex >= 0 && visualFocusIndex < filteredSuggestions.length;
            if (validFocusedSuggestion && filteredSuggestions[visualFocusIndex] != null) {
              changeValue(filteredSuggestions[visualFocusIndex]);
            }
            if (isOpen) {
              closeSuggestions();
            }
          }
          break;
        default:
          break;
      }
    };
    const handleNumberInputWheel = (event) => {
      if (document.activeElement === inputRef.current) {
        if (event.deltaY < 0) {
          incrementNumber(inputRef.current?.value);
        } else {
          decrementNumber(inputRef.current?.value);
        }
      }
    };
    const handleClearActionOnClick = () => {
      changeValue("");
      inputRef.current?.focus();
      if (suggestions) {
        closeSuggestions();
      }
    };
    const handleDecrementActionOnClick = () => {
      decrementNumber();
      inputRef.current?.focus();
    };
    const handleIncrementActionOnClick = () => {
      incrementNumber();
      inputRef.current?.focus();
    };
    const setNumberProps = (type, min, max, step) => {
      if (min != null) {
        inputRef.current?.setAttribute("min", min.toString());
      }
      if (max != null) {
        inputRef.current?.setAttribute("max", max.toString());
      }
      if (step != null) {
        inputRef.current?.setAttribute("step", step.toString());
      }
      if (type != null) {
        inputRef.current?.setAttribute("type", type);
      }
    };
    useEffect12(() => {
      if (typeof suggestions === "function") {
        changeIsSearching(true);
        changeIsAutosuggestError(false);
        changeFilteredSuggestions([]);
        const cancelablePromise = makeCancelable(suggestions(value ?? innerValue));
        cancelablePromise.promise.then((promiseResponse) => {
          changeIsSearching(false);
          changeIsAutosuggestError(false);
          changeFilteredSuggestions(promiseResponse);
        }).catch((err) => {
          if (err.message !== "Is canceled") {
            changeIsSearching(false);
            changeIsAutosuggestError(true);
          }
        });
        return () => {
          cancelablePromise.cancel();
        };
      }
      if (suggestions && suggestions.length > 0) {
        changeFilteredSuggestions(
          suggestions.filter((suggestion) => suggestion.toUpperCase().startsWith((value ?? innerValue).toUpperCase()))
        );
        changeVisualFocusIndex(-1);
      }
      if (numberInputContext != null) {
        setNumberProps(
          numberInputContext.typeNumber,
          numberInputContext.minNumber,
          numberInputContext.maxNumber,
          numberInputContext.stepNumber
        );
      }
      return void 0;
    }, [value, innerValue, suggestions, numberInputContext]);
    return /* @__PURE__ */ jsx50(ThemeProvider18, { theme: colorsTheme.textInput, children: /* @__PURE__ */ jsxs35(TextInputContainer, { margin, size, ref, children: [
      label && /* @__PURE__ */ jsxs35(Label4, { htmlFor: inputId, disabled, hasHelperText: !!helperText, children: [
        label,
        " ",
        optional && /* @__PURE__ */ jsx50(OptionalLabel2, { children: translatedLabels.formFields.optionalLabel })
      ] }),
      helperText && /* @__PURE__ */ jsx50(HelperText2, { disabled, children: helperText }),
      /* @__PURE__ */ jsx50(
        AutosuggestWrapper,
        {
          condition: hasSuggestions(suggestions),
          wrapper: (children) => /* @__PURE__ */ jsxs35(Popover3.Root, { open: isOpen && (filteredSuggestions.length > 0 || isSearching || isAutosuggestError), children: [
            /* @__PURE__ */ jsx50(
              Popover3.Trigger,
              {
                asChild: true,
                type: void 0,
                "aria-controls": void 0,
                "aria-haspopup": void 0,
                "aria-expanded": void 0,
                children
              }
            ),
            /* @__PURE__ */ jsx50(Popover3.Portal, { children: /* @__PURE__ */ jsx50(
              Popover3.Content,
              {
                sideOffset: 5,
                style: { zIndex: "2147483647" },
                onOpenAutoFocus: (event) => {
                  event.preventDefault();
                },
                onCloseAutoFocus: (event) => {
                  event.preventDefault();
                },
                children: /* @__PURE__ */ jsx50(
                  Suggestions_default,
                  {
                    id: autosuggestId,
                    value: value ?? innerValue,
                    suggestions: filteredSuggestions,
                    visualFocusIndex,
                    highlightedSuggestions: typeof suggestions !== "function",
                    searchHasErrors: isAutosuggestError,
                    isSearching,
                    suggestionOnClick: (suggestion) => {
                      changeValue(suggestion);
                      closeSuggestions();
                    },
                    styles: { width }
                  }
                )
              }
            ) })
          ] }),
          children: /* @__PURE__ */ jsxs35(
            InputContainer,
            {
              error: !!error,
              disabled,
              readOnly,
              onClick: handleInputContainerOnClick,
              onMouseDown: handleInputContainerOnMouseDown,
              ref: inputContainerRef,
              children: [
                prefix && /* @__PURE__ */ jsx50(Prefix, { disabled, children: prefix }),
                /* @__PURE__ */ jsxs35(Flex_default, { gap: "0.25rem", alignItems: "center", grow: 1, children: [
                  /* @__PURE__ */ jsx50(
                    Input,
                    {
                      id: inputId,
                      name,
                      value: value ?? innerValue,
                      placeholder,
                      onBlur: handleInputOnBlur,
                      onChange: handleInputOnChange,
                      onFocus: !readOnly ? openSuggestions : void 0,
                      onKeyDown: !readOnly ? handleInputOnKeyDown : void 0,
                      onMouseDown: (event) => {
                        event.stopPropagation();
                      },
                      onWheel: numberInputContext?.typeNumber === "number" ? handleNumberInputWheel : void 0,
                      disabled,
                      readOnly,
                      ref: inputRef,
                      pattern,
                      minLength,
                      maxLength,
                      autoComplete: autocomplete === "off" ? "nope" : autocomplete,
                      tabIndex,
                      type: "text",
                      role: hasSuggestions(suggestions) ? "combobox" : void 0,
                      "aria-autocomplete": hasSuggestions(suggestions) ? "list" : void 0,
                      "aria-controls": hasSuggestions(suggestions) ? autosuggestId : void 0,
                      "aria-expanded": hasSuggestions(suggestions) ? isOpen : void 0,
                      "aria-haspopup": hasSuggestions(suggestions) ? "listbox" : void 0,
                      "aria-activedescendant": hasSuggestions(suggestions) && isOpen && visualFocusIndex !== -1 ? `suggestion-${visualFocusIndex}` : void 0,
                      "aria-invalid": !!error,
                      "aria-errormessage": error ? errorId : void 0,
                      "aria-required": !disabled && !optional,
                      "aria-label": label ? void 0 : ariaLabel
                    }
                  ),
                  !disabled && error && /* @__PURE__ */ jsx50(ErrorIcon2, { "aria-hidden": "true", children: /* @__PURE__ */ jsx50(Icon_default, { icon: "filled_error" }) }),
                  !disabled && !readOnly && clearable && (value ?? innerValue).length > 0 && /* @__PURE__ */ jsx50(
                    ActionIcon_default,
                    {
                      onClick: handleClearActionOnClick,
                      icon: "close",
                      tabIndex,
                      title: translatedLabels.textInput.clearFieldActionTitle
                    }
                  ),
                  numberInputContext?.typeNumber === "number" && numberInputContext?.showControls && /* @__PURE__ */ jsxs35(Fragment12, { children: [
                    /* @__PURE__ */ jsx50(
                      ActionIcon_default,
                      {
                        onClick: !readOnly ? handleDecrementActionOnClick : void 0,
                        icon: "remove",
                        tabIndex,
                        ref: actionRef,
                        title: translatedLabels.numberInput.decrementValueTitle,
                        disabled
                      }
                    ),
                    /* @__PURE__ */ jsx50(
                      ActionIcon_default,
                      {
                        onClick: !readOnly ? handleIncrementActionOnClick : void 0,
                        icon: "add",
                        tabIndex,
                        ref: actionRef,
                        title: translatedLabels.numberInput.incrementValueTitle,
                        disabled
                      }
                    )
                  ] }),
                  action && /* @__PURE__ */ jsx50(
                    ActionIcon_default,
                    {
                      onClick: !readOnly ? action.onClick : void 0,
                      icon: action.icon,
                      tabIndex,
                      ref: actionRef,
                      title: action.title ?? "",
                      disabled
                    }
                  )
                ] }),
                suffix && /* @__PURE__ */ jsx50(Suffix, { disabled, children: suffix })
              ]
            }
          )
        }
      ),
      !disabled && typeof error === "string" && /* @__PURE__ */ jsx50(ErrorMessageContainer, { id: errorId, role: "alert", "aria-live": error ? "assertive" : "off", children: error })
    ] }) });
  }
);
var TextInput_default = DxcTextInput;

// src/date-input/DateInput.tsx
import { jsx as jsx51, jsxs as jsxs36 } from "react/jsx-runtime";
dayjs3.extend(customParseFormat);
var SIDEOFFSET = 4;
var getValueForPicker = (value, format) => dayjs3(value, format.toUpperCase(), true);
var getDate = (value, format, lastValidYear, setLastValidYear) => {
  if ((value || value === "") && format.toUpperCase().includes("YYYY")) {
    return getValueForPicker(value, format);
  }
  let newDate = getValueForPicker(value, format);
  if (lastValidYear == null) {
    if (+newDate.format("YY") < 68) {
      setLastValidYear(2e3 + +newDate.format("YY"));
      newDate = newDate.set("year", 2e3 + +newDate.format("YY"));
    } else {
      setLastValidYear(1900 + +newDate.format("YY"));
      newDate = newDate.set("year", 1900 + +newDate.format("YY"));
    }
  } else {
    newDate = newDate.set("year", (lastValidYear <= 1999 ? 1900 : 2e3) + +newDate.format("YY"));
  }
  return newDate;
};
var DxcDateInput = forwardRef7(
  ({
    label,
    name,
    defaultValue = "",
    value,
    format = "dd-MM-yyyy",
    helperText,
    placeholder = false,
    clearable,
    disabled,
    readOnly,
    optional,
    onChange,
    onBlur,
    error,
    autocomplete,
    margin,
    size,
    tabIndex,
    ariaLabel = "Date input"
  }, ref) => {
    const [innerValue, setInnerValue] = useState22(defaultValue);
    const [isOpen, setIsOpen] = useState22(false);
    const calendarId = `date-picker-${useId11()}`;
    const [dayjsDate, setDayjsDate] = useState22(getValueForPicker(value ?? defaultValue ?? "", format));
    const [lastValidYear, setLastValidYear] = useState22(
      innerValue || value ? !format.toUpperCase().includes("YYYY") && +getValueForPicker(value ?? innerValue, format).format("YY") < 68 ? 2e3 : 1900 : null
    );
    const [sideOffset, setSideOffset] = useState22(SIDEOFFSET);
    const colorsTheme = useContext29(HalstackContext);
    const translatedLabels = useContext29(HalstackLanguageContext);
    const dateRef = useRef12(null);
    const popoverContentRef = useRef12(null);
    const handleCalendarOnClick = (newDate) => {
      const newValue = newDate.format(format.toUpperCase());
      if (!value) {
        setDayjsDate(newDate);
        setInnerValue(newValue);
      }
      setLastValidYear(newDate.get("year"));
      if (newDate.set("day", newDate.get("date")).toJSON()) {
        onChange?.({
          value: newValue,
          date: newDate.toDate()
        });
      } else {
        onChange?.({
          value: newValue
        });
      }
    };
    const handleOnChange = ({ value: newValue, error: inputError }) => {
      if (value == null) {
        setInnerValue(newValue);
      }
      const newDate = getDate(newValue, format, lastValidYear, setLastValidYear);
      const invalidDateMessage = newValue !== "" && !newDate.isValid() && translatedLabels.dateInput.invalidDateErrorMessage;
      const callbackParams = {
        value: newValue,
        error: inputError || invalidDateMessage || void 0
      };
      if (newDate.isValid()) {
        setDayjsDate(newDate);
        onChange?.({
          ...callbackParams,
          date: newDate.toDate()
        });
      } else {
        onChange?.(callbackParams);
        setLastValidYear((validYear) => dayjsDate.get("year") ?? validYear);
        setDayjsDate(dayjs3(null));
      }
    };
    const handleOnBlur = ({ value: blurValue, error: inputError }) => {
      const date = getDate(blurValue, format, lastValidYear, setLastValidYear);
      const invalidDateMessage = blurValue !== "" && !date.isValid() && translatedLabels.dateInput.invalidDateErrorMessage;
      const callbackParams = {
        value: blurValue,
        error: inputError || invalidDateMessage || void 0
      };
      if (date.isValid()) {
        onBlur?.({
          ...callbackParams,
          date: date.toDate()
        });
      } else {
        onBlur?.(callbackParams);
      }
    };
    const adjustSideOffset = useCallback7(() => {
      if (error != null) {
        setTimeout(() => {
          if (popoverContentRef.current && dateRef.current) {
            const popoverRect = popoverContentRef.current.getBoundingClientRect();
            const triggerRect = dateRef.current.querySelector('[id^="input"]')?.getBoundingClientRect();
            const errorMessageHeight = dateRef.current.querySelector('[id^="error-input"]')?.getBoundingClientRect().height;
            setSideOffset(
              triggerRect?.bottom != null && popoverRect.top > triggerRect.bottom ? errorMessageHeight != null ? -errorMessageHeight : 0 : SIDEOFFSET
            );
          }
        }, 0);
      }
    }, [error]);
    const openCalendar = () => {
      setIsOpen(!isOpen);
      adjustSideOffset();
    };
    const closeCalendar = () => {
      setIsOpen(false);
    };
    const handleDatePickerEscKeydown = (event) => {
      if (event.key === "Escape") {
        event.preventDefault();
        if (isOpen) {
          event.stopPropagation();
        }
        closeCalendar();
        dateRef.current?.getElementsByTagName("input")[0]?.focus();
      }
    };
    const handleDatePickerOnBlur = (event) => {
      if (!event.currentTarget.contains(event.relatedTarget)) {
        closeCalendar();
      }
    };
    useEffect13(() => {
      window.addEventListener("scroll", adjustSideOffset);
      return () => {
        window.removeEventListener("scroll", adjustSideOffset);
      };
    }, [adjustSideOffset]);
    useEffect13(() => {
      if (value || value === "") {
        setDayjsDate(getDate(value, format, lastValidYear, setLastValidYear));
      }
    }, [value, format, lastValidYear]);
    useEffect13(() => {
      if (!disabled) {
        const actionButtonElement = dateRef.current?.querySelector("[aria-label='Select date']");
        actionButtonElement?.setAttribute("aria-haspopup", "true");
        actionButtonElement?.setAttribute("role", "combobox");
        actionButtonElement?.setAttribute("aria-expanded", `${isOpen}`);
        actionButtonElement?.setAttribute("aria-controls", calendarId);
        if (isOpen) {
          actionButtonElement?.setAttribute("aria-describedby", calendarId);
        }
      }
    }, [isOpen, disabled, calendarId]);
    return /* @__PURE__ */ jsx51(ThemeProvider19, { theme: colorsTheme, children: /* @__PURE__ */ jsxs36(DateInputContainer, { margin, size, ref, children: [
      label && /* @__PURE__ */ jsxs36(
        Label5,
        {
          htmlFor: dateRef.current?.getElementsByTagName("input")[0]?.id,
          disabled,
          hasHelperText: !!helperText,
          children: [
            label,
            " ",
            optional && /* @__PURE__ */ jsx51(OptionalLabel3, { children: translatedLabels.formFields.optionalLabel })
          ]
        }
      ),
      helperText && /* @__PURE__ */ jsx51(HelperText3, { disabled, children: helperText }),
      /* @__PURE__ */ jsxs36(Popover4.Root, { open: isOpen, children: [
        /* @__PURE__ */ jsx51(Popover4.Trigger, { asChild: true, "aria-controls": void 0, children: /* @__PURE__ */ jsx51(
          TextInput_default,
          {
            name,
            defaultValue,
            value: value ?? innerValue,
            placeholder: placeholder ? format.toUpperCase() : void 0,
            action: {
              onClick: openCalendar,
              icon: "filled_calendar_today",
              title: "Select date"
            },
            clearable,
            disabled,
            readOnly,
            optional,
            onChange: handleOnChange,
            onBlur: handleOnBlur,
            error,
            autocomplete,
            size,
            tabIndex,
            ref: dateRef,
            ariaLabel
          }
        ) }),
        /* @__PURE__ */ jsx51(Popover4.Portal, { children: /* @__PURE__ */ jsx51(
          StyledPopoverContent,
          {
            sideOffset,
            align: "end",
            "aria-modal": true,
            onBlur: handleDatePickerOnBlur,
            onKeyDown: handleDatePickerEscKeydown,
            ref: popoverContentRef,
            children: /* @__PURE__ */ jsx51(DatePicker_default, { id: calendarId, onDateSelect: handleCalendarOnClick, date: dayjsDate })
          }
        ) })
      ] })
    ] }) });
  }
);
var sizes5 = {
  small: "240px",
  medium: "360px",
  large: "480px",
  fillParent: "100%"
};
var calculateWidth9 = (margin, size) => size === "fillParent" ? `calc(${sizes5[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes5[size];
var DateInputContainer = styled44.div`
  ${(props) => props.size === "fillParent" && "width: 100%;"}
  display: flex;
  flex-direction: column;
  width: ${(props) => calculateWidth9(props.margin, props.size)};
  ${(props) => props.size !== "fillParent" && `min-width:${calculateWidth9(props.margin, props.size)}`};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  font-family: ${(props) => props.theme.textInput.fontFamily};
`;
var Label5 = styled44.label`
  color: ${(props) => props.disabled ? props.theme.textInput.disabledLabelFontColor : props.theme.textInput.labelFontColor};
  font-size: ${(props) => props.theme.textInput.labelFontSize};
  font-style: ${(props) => props.theme.textInput.labelFontStyle};
  font-weight: ${(props) => props.theme.textInput.labelFontWeight};
  line-height: ${(props) => props.theme.textInput.labelLineHeight};
  ${(props) => !props.hasHelperText && `margin-bottom: 0.25rem`}
`;
var OptionalLabel3 = styled44.span`
  font-weight: ${(props) => props.theme.textInput.optionalLabelFontWeight};
`;
var HelperText3 = styled44.span`
  color: ${(props) => props.disabled ? props.theme.textInput.disabledHelperTextFontColor : props.theme.textInput.helperTextFontColor};
  font-size: ${(props) => props.theme.textInput.helperTextFontSize};
  font-style: ${(props) => props.theme.textInput.helperTextFontStyle};
  font-weight: ${(props) => props.theme.textInput.helperTextFontWeight};
  line-height: ${(props) => props.theme.textInput.helperTextLineHeight};
  margin-bottom: 0.25rem;
`;
var StyledPopoverContent = styled44(Popover4.Content)`
  z-index: 2147483647;
  &:focus-visible {
    outline: none;
  }
`;
var DateInput_default = DxcDateInput;

// src/dialog/Dialog.tsx
import { useContext as useContext30, useEffect as useEffect14 } from "react";
import { createPortal as createPortal2 } from "react-dom";
import styled45, { createGlobalStyle as createGlobalStyle2, ThemeProvider as ThemeProvider20 } from "styled-components";
import { jsx as jsx52, jsxs as jsxs37 } from "react/jsx-runtime";
var BodyStyle2 = createGlobalStyle2`
  body {
    overflow: hidden;
  }
`;
var DialogContainer = styled45.div`
  position: fixed;
  inset: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  z-index: 2147483647;
`;
var Overlay3 = styled45.div`
  position: fixed;
  inset: 0;
  height: 100%;
  background-color: ${(props) => props.theme.overlayColor};
`;
var Dialog = styled45.div`
  position: relative;
  box-sizing: border-box;
  max-width: 80%;
  min-width: 696px;
  border-radius: 4px;
  background-color: ${(props) => props.theme.backgroundColor};
  ${(props) => props.closable && "min-height: 72px;"}
  box-shadow: ${(props) => `${props.theme.boxShadowOffsetX} ${props.theme.boxShadowOffsetY} ${props.theme.boxShadowBlur} ${props.theme.boxShadowColor}`};
  z-index: 2147483647;

  @media (max-width: ${responsiveSizes.medium}rem) {
    max-width: 92%;
    min-width: 92%;
  }
`;
var CloseIconActionContainer = styled45.div`
  position: absolute;
  top: 24px;
  right: 24px;
`;
var DxcDialog = ({
  children,
  closable = true,
  onBackgroundClick,
  onCloseClick,
  overlay = true,
  tabIndex = 0
}) => {
  const colorsTheme = useContext30(HalstackContext);
  const translatedLabels = useContext30(HalstackLanguageContext);
  useEffect14(() => {
    const handleKeyDown = (event) => {
      if (event.key === "Escape") {
        event.preventDefault();
        onCloseClick?.();
      }
    };
    document.addEventListener("keydown", handleKeyDown);
    return () => {
      document.removeEventListener("keydown", handleKeyDown);
    };
  }, [onCloseClick]);
  return /* @__PURE__ */ jsxs37(ThemeProvider20, { theme: colorsTheme.dialog, children: [
    /* @__PURE__ */ jsx52(BodyStyle2, {}),
    createPortal2(
      /* @__PURE__ */ jsxs37(DialogContainer, { children: [
        overlay && /* @__PURE__ */ jsx52(Overlay3, { onClick: onBackgroundClick }),
        /* @__PURE__ */ jsx52(Dialog, { "aria-label": "Dialog", "aria-modal": overlay, closable, role: "dialog", children: /* @__PURE__ */ jsxs37(FocusLock_default, { children: [
          children,
          closable && /* @__PURE__ */ jsx52(
            ThemeProvider20,
            {
              theme: {
                actionBackgroundColor: colorsTheme.dialog.closeIconBackgroundColor,
                actionIconColor: colorsTheme.dialog.closeIconColor
              },
              children: /* @__PURE__ */ jsx52(CloseIconActionContainer, { children: /* @__PURE__ */ jsx52(
                ActionIcon_default,
                {
                  icon: "close",
                  onClick: onCloseClick,
                  tabIndex,
                  title: translatedLabels.dialog.closeIconAriaLabel
                }
              ) })
            }
          )
        ] }) })
      ] }),
      document.body
    )
  ] });
};
var Dialog_default = DxcDialog;

// src/file-input/FileInput.tsx
import { useCallback as useCallback8, useContext as useContext32, useEffect as useEffect15, useId as useId13, useState as useState23, forwardRef as forwardRef8 } from "react";
import styled47, { ThemeProvider as ThemeProvider21 } from "styled-components";

// src/file-input/FileItem.tsx
import { memo as memo10, useContext as useContext31, useId as useId12 } from "react";
import styled46 from "styled-components";
import { jsx as jsx53, jsxs as jsxs38 } from "react/jsx-runtime";
var MainContainer3 = styled46.div`
  box-sizing: border-box;
  display: flex;
  justify-content: center;
  gap: 0.75rem;
  width: ${(props) => props.singleFileMode ? "230px" : "320px"};
  padding: ${(props) => props.showPreview ? `calc(8px - ${props.theme.fileItemBorderThickness})` : `calc(8px - ${props.theme.fileItemBorderThickness}) calc(8px - ${props.theme.fileItemBorderThickness}) calc(8px - ${props.theme.fileItemBorderThickness}) 16px`};
  ${(props) => props.error ? `background-color: ${props.theme.errorFileItemBackgroundColor};` : ""};
  border-color: ${(props) => props.error ? props.theme.errorFileItemBorderColor : props.theme.fileItemBorderColor};
  border-width: ${(props) => props.theme.fileItemBorderThickness};
  border-style: ${(props) => props.theme.fileItemBorderStyle};
  border-radius: ${(props) => props.theme.fileItemBorderRadius};
`;
var ImagePreview = styled46.img`
  width: 48px;
  height: 48px;
  border-radius: 2px;
  object-fit: contain;
`;
var IconPreview = styled46.span`
  box-sizing: border-box;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: ${(props) => props.error ? props.theme.errorFilePreviewBackgroundColor : props.theme.filePreviewBackgroundColor};
  width: 48px;
  height: 48px;
  padding: 15px;
  border-radius: 2px;
  color: ${(props) => props.error ? props.theme.errorFilePreviewIconColor : props.theme.filePreviewIconColor};
  font-size: 18px;
  svg {
    height: 18px;
    width: 18px;
  }
`;
var FileItemContent = styled46.div`
  flex-grow: 1;
  display: grid;
  grid-template-columns: auto min-content;
  grid-template-rows: min-content auto;
  column-gap: 0.25rem;
`;
var FileName = styled46.span`
  align-self: center;
  color: ${(props) => props.theme.fileNameFontColor};
  font-family: ${(props) => props.theme.fileItemFontFamily};
  font-size: ${(props) => props.theme.fileItemFontSize};
  font-weight: ${(props) => props.theme.fileItemFontWeight};
  line-height: ${(props) => props.theme.fileItemLineHeight};
  white-space: pre;
  overflow: hidden;
  text-overflow: ellipsis;
`;
var ErrorIcon3 = styled46.span`
  display: flex;
  flex-wrap: wrap;
  align-content: center;
  padding: 3px;
  height: 18px;
  width: 18px;
  font-size: 18px;
  color: #d0011b;
`;
var ErrorMessage = styled46.span`
  color: ${(props) => props.theme.errorMessageFontColor};
  font-family: ${(props) => props.theme.errorMessageFontFamily};
  font-size: ${(props) => props.theme.errorMessageFontSize};
  font-weight: ${(props) => props.theme.errorMessageFontWeight};
  line-height: ${(props) => props.theme.errorMessageLineHeight};
`;
var FileItem = ({
  fileName = "",
  error = "",
  singleFileMode,
  showPreview,
  preview,
  type,
  onDelete,
  tabIndex
}) => {
  const translatedLabels = useContext31(HalstackLanguageContext);
  const fileNameId = useId12();
  return /* @__PURE__ */ jsxs38(MainContainer3, { error, role: "listitem", singleFileMode, showPreview, children: [
    showPreview && (type.includes("image") ? /* @__PURE__ */ jsx53(ImagePreview, { src: preview, alt: fileName }) : /* @__PURE__ */ jsx53(IconPreview, { "aria-labelledby": fileNameId, error, role: "img", children: /* @__PURE__ */ jsx53(Icon_default, { icon: preview }) })),
    /* @__PURE__ */ jsxs38(FileItemContent, { children: [
      /* @__PURE__ */ jsx53(FileName, { id: fileNameId, children: fileName }),
      /* @__PURE__ */ jsxs38(Flex_default, { gap: "0.25rem", children: [
        error && /* @__PURE__ */ jsx53(ErrorIcon3, { children: /* @__PURE__ */ jsx53(Icon_default, { icon: "filled_error" }) }),
        /* @__PURE__ */ jsx53(
          ActionIcon_default,
          {
            onClick: () => onDelete(fileName),
            icon: "close",
            tabIndex,
            title: translatedLabels.fileInput.deleteFileActionTitle
          }
        )
      ] }),
      error && !singleFileMode && /* @__PURE__ */ jsx53(ErrorMessage, { role: "alert", "aria-live": "assertive", children: error })
    ] })
  ] });
};
var FileItem_default = memo10(FileItem);

// src/file-input/utils.ts
var getFilePreview = async (file) => {
  if (file.type.includes("video")) return "filled_movie";
  else if (file.type.includes("audio")) return "music_video";
  else if (file.type.includes("image")) {
    return new Promise((resolve) => {
      const reader = new FileReader();
      reader.readAsDataURL(file);
      reader.onload = (e) => {
        resolve(e.target?.result);
      };
    });
  } else return "draft";
};
var isFileIncluded = (file, fileList) => {
  const fileListInfo = fileList.map((existingFile) => existingFile.file);
  return fileListInfo.some(
    ({ name, size, type, lastModified, webkitRelativePath }) => name === file.file.name && size === file.file.size && type === file.file.type && lastModified === file.file.lastModified && webkitRelativePath === file.file.webkitRelativePath
  );
};

// src/file-input/FileInput.tsx
import { jsx as jsx54, jsxs as jsxs39 } from "react/jsx-runtime";
var FileInputContainer = styled47.div`
  display: flex;
  flex-direction: column;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  width: fit-content;
`;
var Label6 = styled47.label`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};
  font-family: ${(props) => props.theme.labelFontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
`;
var HelperText4 = styled47.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};
  font-family: ${(props) => props.theme.helperTextFontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
`;
var FileContainer = styled47.div`
  display: flex;
  ${(props) => props.singleFileMode ? "flex-direction: row; column-gap: 0.25rem;" : "flex-direction: column; row-gap: 0.25rem;"}
  margin-top: 0.25rem;
`;
var ValueInput2 = styled47.input`
  display: none;
`;
var FileItemListContainer = styled47.div`
  display: flex;
  flex-direction: column;
  row-gap: 0.25rem;
`;
var Container2 = styled47.div`
  display: flex;
  flex-direction: column;
  row-gap: 0.25rem;
  margin-top: 0.25rem;
`;
var DragDropArea = styled47.div`
  box-sizing: border-box;
  display: flex;
  ${(props) => props.mode === "filedrop" ? "flex-direction: row; column-gap: 0.75rem; height: 48px;" : "justify-content: center; flex-direction: column; row-gap: 0.5rem; height: 160px;"}
  align-items: center;
  width: 320px;
  padding: ${(props) => props.mode === "filedrop" ? `calc(4px - ${props.theme.dropBorderThickness}) 1rem calc(4px - ${props.theme.dropBorderThickness}) calc(4px - ${props.theme.dropBorderThickness})` : "1rem"};
  overflow: hidden;
  box-shadow: 0 0 0 2px transparent;
  border-radius: ${(props) => props.theme.dropBorderRadius};
  border-width: ${(props) => props.theme.dropBorderThickness};
  border-style: ${(props) => props.theme.dropBorderStyle};
  border-color: ${(props) => props.disabled ? props.theme.disabledDropBorderColor : props.theme.dropBorderColor};
  ${(props) => props.isDragging && `
      background-color: ${props.theme.dragoverDropBackgroundColor};
      border-color: transparent;
      box-shadow: 0 0 0 2px ${props.theme.focusDropBorderColor};
    `}
  cursor: ${(props) => props.disabled && "not-allowed"};
`;
var DropzoneLabel = styled47.div`
  display: -webkit-box;
  -webkit-box-orient: vertical;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-line-clamp: 3;
  text-align: center;
  color: ${(props) => props.disabled ? props.theme.disabledDropLabelFontColor : props.theme.dropLabelFontColor};
  font-family: ${(props) => props.theme.dropLabelFontFamily};
  font-size: ${(props) => props.theme.dropLabelFontSize};
  font-weight: ${(props) => props.theme.dropLabelFontWeight};
`;
var FiledropLabel = styled47.span`
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  color: ${(props) => props.disabled ? props.theme.disabledDropLabelFontColor : props.theme.dropLabelFontColor};
  font-family: ${(props) => props.theme.dropLabelFontFamily};
  font-size: ${(props) => props.theme.dropLabelFontSize};
  font-weight: ${(props) => props.theme.dropLabelFontWeight};
`;
var ErrorMessage2 = styled47.div`
  color: ${(props) => props.theme.errorMessageFontColor};
  font-family: ${(props) => props.theme.errorMessageFontFamily};
  font-size: ${(props) => props.theme.errorMessageFontSize};
  font-weight: ${(props) => props.theme.errorMessageFontWeight};
  line-height: ${(props) => props.theme.errorMessageLineHeight};
  margin-top: 0.25rem;
`;
var DxcFileInput = forwardRef8(
  ({
    mode = "file",
    label = "",
    buttonLabel,
    dropAreaLabel,
    helperText = "",
    accept,
    minSize,
    maxSize,
    showPreview = false,
    multiple = true,
    disabled = false,
    callbackFile,
    value,
    margin,
    tabIndex = 0
  }, ref) => {
    const [isDragging, setIsDragging] = useState23(false);
    const [files, setFiles] = useState23([]);
    const fileInputId = `file-input-${useId13()}`;
    const colorsTheme = useContext32(HalstackContext);
    const translatedLabels = useContext32(HalstackLanguageContext);
    const checkFileSize = (file) => {
      if (minSize && file.size < minSize) return translatedLabels.fileInput.fileSizeGreaterThanErrorMessage;
      else if (maxSize && file.size > maxSize) return translatedLabels.fileInput.fileSizeLessThanErrorMessage;
    };
    const getFilesToAdd = async (selectedFiles) => {
      const filesToAdd = await Promise.all(selectedFiles.map((selectedFile) => getFilePreview(selectedFile))).then(
        (previews) => selectedFiles.map((file, index) => {
          const fileInfo = {
            file,
            error: checkFileSize(file),
            preview: previews[index]
          };
          return fileInfo;
        })
      );
      return filesToAdd.filter((file) => !isFileIncluded(file, files));
    };
    const addFile = async (selectedFiles) => {
      const filesToAdd = await getFilesToAdd(
        multiple ? selectedFiles : selectedFiles.length === 1 ? selectedFiles : [selectedFiles[0]]
      );
      const finalFiles = multiple ? [...files, ...filesToAdd] : filesToAdd;
      callbackFile?.(finalFiles);
    };
    const selectFiles = (e) => {
      const selectedFiles = e.target.files;
      if (selectedFiles) {
        const filesArray = Array.from(selectedFiles);
        addFile(filesArray);
        e.target.value = "";
      }
    };
    const onDelete = useCallback8(
      (fileName) => {
        const filesCopy = [...files];
        const fileToRemove = filesCopy.find((file) => file.file.name === fileName);
        if (fileToRemove) {
          const fileIndex = filesCopy.indexOf(fileToRemove);
          filesCopy.splice(fileIndex, 1);
          callbackFile?.(filesCopy);
        }
      },
      [files, callbackFile]
    );
    const handleClick = () => {
      document.getElementById(fileInputId)?.click();
    };
    const handleDrag = (e) => {
      e.preventDefault();
      e.stopPropagation();
    };
    const handleDragIn = (e) => {
      if (e.dataTransfer.items.length > 0) {
        setIsDragging(true);
      }
    };
    const handleDragOut = (e) => {
      if (!e.currentTarget.contains(e.relatedTarget)) {
        setIsDragging(false);
      }
    };
    const handleDrop = (e) => {
      e.preventDefault();
      e.stopPropagation();
      setIsDragging(false);
      const filesObject = e.dataTransfer.files;
      if (filesObject.length > 0) {
        const filesArray = Array.from(filesObject);
        addFile(filesArray);
      }
    };
    useEffect15(() => {
      const getFiles = async () => {
        if (value) {
          const valueFiles = await Promise.all(
            value.map(async (file) => {
              if (file.preview) {
                return file;
              }
              const preview = await getFilePreview(file.file);
              return { ...file, preview };
            })
          );
          setFiles(valueFiles);
        }
      };
      getFiles();
    }, [value]);
    return /* @__PURE__ */ jsx54(ThemeProvider21, { theme: colorsTheme.fileInput, children: /* @__PURE__ */ jsxs39(FileInputContainer, { margin, ref, children: [
      /* @__PURE__ */ jsx54(Label6, { htmlFor: fileInputId, disabled, children: label }),
      /* @__PURE__ */ jsx54(HelperText4, { disabled, children: helperText }),
      mode === "file" ? /* @__PURE__ */ jsxs39(FileContainer, { singleFileMode: !multiple && files.length === 1, children: [
        /* @__PURE__ */ jsx54(
          ValueInput2,
          {
            id: fileInputId,
            type: "file",
            accept,
            multiple,
            onChange: selectFiles,
            disabled,
            readOnly: true
          }
        ),
        /* @__PURE__ */ jsx54(
          Button_default,
          {
            mode: "secondary",
            label: buttonLabel ?? (multiple ? translatedLabels.fileInput.multipleButtonLabelDefault : translatedLabels.fileInput.singleButtonLabelDefault),
            onClick: handleClick,
            disabled,
            size: { width: "fitContent" },
            tabIndex
          }
        ),
        files.length > 0 && /* @__PURE__ */ jsx54(FileItemListContainer, { role: "list", children: files.map((file, index) => /* @__PURE__ */ jsx54(
          FileItem_default,
          {
            fileName: file.file.name,
            error: file.error,
            singleFileMode: !multiple && files.length === 1,
            showPreview: mode === "file" && !multiple ? false : showPreview,
            preview: file.preview ?? "",
            type: file.file.type,
            onDelete,
            tabIndex
          },
          `file-${index}`
        )) })
      ] }) : /* @__PURE__ */ jsxs39(Container2, { children: [
        /* @__PURE__ */ jsx54(
          ValueInput2,
          {
            id: fileInputId,
            type: "file",
            accept,
            multiple,
            onChange: selectFiles,
            disabled,
            readOnly: true
          }
        ),
        /* @__PURE__ */ jsxs39(
          DragDropArea,
          {
            isDragging,
            disabled,
            mode,
            onDrop: handleDrop,
            onDragEnter: handleDragIn,
            onDragOver: handleDrag,
            onDragLeave: handleDragOut,
            children: [
              /* @__PURE__ */ jsx54(
                Button_default,
                {
                  mode: "secondary",
                  label: buttonLabel ?? translatedLabels.fileInput.dropAreaButtonLabelDefault,
                  onClick: handleClick,
                  disabled,
                  size: { width: "fitContent" }
                }
              ),
              mode === "dropzone" ? /* @__PURE__ */ jsx54(DropzoneLabel, { disabled, children: dropAreaLabel ?? (multiple ? translatedLabels.fileInput.multipleDropAreaLabelDefault : translatedLabels.fileInput.singleDropAreaLabelDefault) }) : /* @__PURE__ */ jsx54(FiledropLabel, { disabled, children: dropAreaLabel ?? (multiple ? translatedLabels.fileInput.multipleDropAreaLabelDefault : translatedLabels.fileInput.singleDropAreaLabelDefault) })
            ]
          }
        ),
        files.length > 0 && /* @__PURE__ */ jsx54(FileItemListContainer, { role: "list", children: files.map((file, index) => /* @__PURE__ */ jsx54(
          FileItem_default,
          {
            fileName: file.file.name,
            error: file.error,
            singleFileMode: false,
            showPreview,
            preview: file.preview ?? "",
            type: file.file.type,
            onDelete,
            tabIndex
          },
          `file-${index}`
        )) })
      ] }),
      mode === "file" && !multiple && files.length === 1 && files[0]?.error && /* @__PURE__ */ jsx54(ErrorMessage2, { children: files[0].error })
    ] }) });
  }
);
var FileInput_default = DxcFileInput;

// src/grid/Grid.tsx
import styled48 from "styled-components";
import { jsx as jsx55 } from "react/jsx-runtime";
var Grid = styled48.div`
  display: grid;
  ${(props) => `
    ${props.templateColumns ? `grid-template-columns: ${props.templateColumns.join(" ")};` : ""}
    ${props.templateRows ? `grid-template-rows: ${props.templateRows.join(" ")};` : ""}
    ${props.templateAreas ? `grid-template-areas: ${props.templateAreas.map((row) => `"${row}"`).join(" ")};` : ""}
    ${props.autoColumns ? `grid-auto-columns: ${props.autoColumns};` : ""}
    ${props.autoRows ? `grid-auto-rows: ${props.autoRows};` : ""}
    ${props.autoFlow ? `grid-auto-flow: ${props.autoFlow};` : ""}
    ${props.areaName ? `grid-area: ${props.areaName};` : ""}
    ${props.gap != null ? typeof props.gap === "string" ? `gap: ${props.gap};` : `row-gap: ${props.gap.rowGap ?? ""}; column-gap: ${props.gap.columnGap ?? ""};` : ""}
    ${props.placeItems ? typeof props.placeItems === "string" ? `place-items: ${props.placeItems};` : `align-items: ${props.placeItems.alignItems ?? ""}; justify-items: ${props.placeItems.justifyItems ?? ""};` : ""}
    ${props.placeContent ? typeof props.placeContent === "string" ? `place-content: ${props.placeContent};` : `align-content: ${props.placeContent.alignContent ?? ""}; justify-content: ${props.placeContent.justifyContent ?? ""};` : ""}
    ${props.column ? `grid-column: ${typeof props.column === "string" || typeof props.column === "number" ? props.column : `${props.column.start} / ${props.column.end};`};` : ""}
    ${props.row ? `grid-row: ${typeof props.row === "string" || typeof props.row === "number" ? props.row : `${props.row.start} / ${props.row.end};`};` : ""}
    ${props.placeSelf ? typeof props.placeSelf === "string" ? `place-self: ${props.placeSelf};` : `align-self: ${props.placeSelf.alignSelf ?? ""}; justify-self: ${props.placeSelf.justifySelf ?? ""};` : ""}
  `}
`;
var GridItem = styled48.div`
  ${(props) => `
    ${props.areaName ? `grid-area: ${props.areaName};` : ""}
    ${props.column ? `grid-column: ${typeof props.column === "string" || typeof props.column === "number" ? props.column : `${props.column.start} / ${props.column.end};`};` : ""}
    ${props.row ? `grid-row: ${typeof props.row === "string" || typeof props.row === "number" ? props.row : `${props.row.start} / ${props.row.end};`};` : ""}
    ${props.placeSelf ? typeof props.placeSelf === "string" ? `place-self: ${props.placeSelf};` : `align-self: ${props.placeSelf.alignSelf ?? ""}; justify-self: ${props.placeSelf.justifySelf ?? ""};` : ""}
  `}
`;
var DxcGrid = (props) => /* @__PURE__ */ jsx55(Grid, { ...props });
DxcGrid.Item = GridItem;
var Grid_default = DxcGrid;

// src/heading/Heading.tsx
import styled49, { ThemeProvider as ThemeProvider22 } from "styled-components";
import { useContext as useContext33 } from "react";
import { jsx as jsx56 } from "react/jsx-runtime";
var DxcHeading = ({ level = 1, text = "", as, weight, margin }) => {
  const colorsTheme = useContext33(HalstackContext);
  const checkValidAs = () => {
    if (as === "h1" || as === "h2" || as === "h3" || as === "h4" || as === "h5") return as;
  };
  return /* @__PURE__ */ jsx56(ThemeProvider22, { theme: colorsTheme.heading, children: /* @__PURE__ */ jsx56(HeadingContainer, { margin, children: level === 1 ? /* @__PURE__ */ jsx56(HeadingLevel1, { as: checkValidAs(), weight, children: text }) : level === 2 ? /* @__PURE__ */ jsx56(HeadingLevel2, { as: checkValidAs(), weight, children: text }) : level === 3 ? /* @__PURE__ */ jsx56(HeadingLevel3, { as: checkValidAs(), weight, children: text }) : level === 4 ? /* @__PURE__ */ jsx56(HeadingLevel4, { as: checkValidAs(), weight, children: text }) : /* @__PURE__ */ jsx56(HeadingLevel5, { as: checkValidAs(), weight, children: text }) }) });
};
var HeadingContainer = styled49.div`
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var HeadingLevel1 = styled49.h1`
  font-family: ${(props) => props.theme.level1FontFamily};
  font-style: ${(props) => props.theme.level1FontStyle};
  font-size: ${(props) => props.theme.level1FontSize};
  line-height: ${(props) => props.theme.level1LineHeight};
  font-weight: ${(props) => props.weight === "normal" ? "400" : props.weight === "light" ? "300" : props.weight === "bold" ? "600" : props.theme.level1FontWeight};
  letter-spacing: ${(props) => props.theme.level1LetterSpacing};
  color: ${(props) => props.theme.level1FontColor};
  margin: 0;
`;
var HeadingLevel2 = styled49.h2`
  font-family: ${(props) => props.theme.level2FontFamily};
  font-style: ${(props) => props.theme.level2FontStyle};
  font-size: ${(props) => props.theme.level2FontSize};
  line-height: ${(props) => props.theme.level2LineHeight};
  font-weight: ${(props) => props.weight === "normal" ? "400" : props.weight === "light" ? "300" : props.weight === "bold" ? "600" : props.theme.level2FontWeight};
  letter-spacing: ${(props) => props.theme.level2LetterSpacing};
  color: ${(props) => props.theme.level2FontColor};
  margin: 0;
`;
var HeadingLevel3 = styled49.h3`
  font-family: ${(props) => props.theme.level3FontFamily};
  font-style: ${(props) => props.theme.level3FontStyle};
  font-size: ${(props) => props.theme.level3FontSize};
  line-height: ${(props) => props.theme.level3LineHeight};
  font-weight: ${(props) => props.weight === "normal" ? "400" : props.weight === "light" ? "300" : props.weight === "bold" ? "600" : props.theme.level3FontWeight};
  letter-spacing: ${(props) => props.theme.level3LetterSpacing};
  color: ${(props) => props.theme.level3FontColor};
  margin: 0;
`;
var HeadingLevel4 = styled49.h4`
  font-family: ${(props) => props.theme.level4FontFamily};
  font-style: ${(props) => props.theme.level4FontStyle};
  font-size: ${(props) => props.theme.level4FontSize};
  line-height: ${(props) => props.theme.level4LineHeight};
  font-weight: ${(props) => props.weight === "normal" ? "400" : props.weight === "light" ? "300" : props.weight === "bold" ? "600" : props.theme.level4FontWeight};
  letter-spacing: ${(props) => props.theme.level4LetterSpacing};
  color: ${(props) => props.theme.level4FontColor};
  margin: 0;
`;
var HeadingLevel5 = styled49.h5`
  font-family: ${(props) => props.theme.level5FontFamily};
  font-style: ${(props) => props.theme.level5FontStyle};
  font-size: ${(props) => props.theme.level5FontSize};
  line-height: ${(props) => props.theme.level5LineHeight};
  font-weight: ${(props) => props.weight === "normal" ? "400" : props.weight === "light" ? "300" : props.weight === "bold" ? "600" : props.theme.level5FontWeight};
  letter-spacing: ${(props) => props.theme.level5LetterSpacing};
  color: ${(props) => props.theme.level5FontColor};
  margin: 0;
`;
var Heading_default = DxcHeading;

// src/image/Image.tsx
import styled50, { ThemeProvider as ThemeProvider23 } from "styled-components";
import { useContext as useContext34 } from "react";
import { jsx as jsx57, jsxs as jsxs40 } from "react/jsx-runtime";
var Figure = styled50.figure`
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: fit-content;
  margin: 0;
  padding: 0;
`;
var CaptionContainer = styled50.figcaption`
  color: ${(props) => props.theme.captionFontColor};
  font-family: ${(props) => props.theme.captionFontFamily};
  font-size: ${(props) => props.theme.captionFontSize};
  font-style: ${(props) => props.theme.captionFontStyle};
  font-weight: ${(props) => props.theme.captionFontWeight};
  line-height: ${(props) => props.theme.captionLineHeight};
`;
var CaptionWrapper = ({ caption, children }) => caption != null ? /* @__PURE__ */ jsxs40(Figure, { children: [
  children,
  /* @__PURE__ */ jsx57(CaptionContainer, { children: caption })
] }) : children;
function DxcImage({
  alt,
  caption,
  lazyLoading = false,
  src,
  srcSet,
  sizes: sizes10,
  width,
  height,
  objectFit,
  objectPosition,
  onLoad,
  onError
}) {
  const colorsTheme = useContext34(HalstackContext);
  return /* @__PURE__ */ jsx57(ThemeProvider23, { theme: colorsTheme.image, children: /* @__PURE__ */ jsx57(CaptionWrapper, { caption, children: /* @__PURE__ */ jsx57(
    "img",
    {
      alt,
      loading: lazyLoading ? "lazy" : void 0,
      onLoad,
      onError,
      src,
      srcSet,
      sizes: sizes10,
      style: {
        objectFit,
        objectPosition,
        width,
        height
      }
    }
  ) }) });
}

// src/inset/Inset.tsx
import styled51 from "styled-components";
import { jsx as jsx58 } from "react/jsx-runtime";
var getSpacingValue2 = (spacingName) => spacingName ?? "0rem";
var StyledInset = styled51.div`
  ${({ space, horizontal, vertical, top, right, bottom, left }) => `
  padding: ${getSpacingValue2(top || vertical || space)} ${getSpacingValue2(right || horizontal || space)}
    ${getSpacingValue2(bottom || vertical || space)} ${getSpacingValue2(left || horizontal || space)};
`}
`;
var Inset = ({ space, horizontal, vertical, top, right, bottom, left, children }) => /* @__PURE__ */ jsx58(
  StyledInset,
  {
    space,
    horizontal,
    vertical,
    top,
    right,
    bottom,
    left,
    children
  }
);
var Inset_default = Inset;

// src/link/Link.tsx
import { forwardRef as forwardRef9, useContext as useContext35 } from "react";
import styled52, { ThemeProvider as ThemeProvider24 } from "styled-components";
import { jsx as jsx59, jsxs as jsxs41 } from "react/jsx-runtime";
var StyledLink = styled52.a`
  all: unset;
  display: inline-flex;
  align-items: baseline;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  background: none;
  border: none;
  border-radius: 4px;
  width: fit-content;
  ${(props) => `padding-bottom: ${props.theme.underlineSpacing};`}
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  line-height: ${coreTokens_default.type_leading_compact_02};
  text-decoration: none;
  color: ${(props) => props.inheritColor ? "inherit" : !props.disabled ? props.theme.fontColor : props.theme.disabledFontColor};
  ${(props) => props.disabled ? "cursor: default;" : "cursor: pointer;"}
  ${(props) => props.disabled ? "pointer-events: none;" : ""}

  &:visited {
    color: ${(props) => !props.inheritColor && !props.disabled ? props.theme.visitedFontColor : ""};
    & > span:hover {
      ${(props) => `color: ${props.theme.visitedFontColor};
                    border-bottom-color: ${props.theme.visitedUnderlineColor};`}
    }
  }
  &:focus {
    outline: 2px solid ${(props) => props.theme.focusColor};
    outline-offset: 2px;
    ${(props) => props.disabled && "outline: none"}
  }
`;
var LinkContainer = styled52.span`
  ${(props) => `border-bottom: ${props.theme.underlineThickness} ${props.theme.underlineStyle} transparent;`}
  display: inline-flex;
  align-items: center;
  ${(props) => props.iconPosition === "before" ? "flex-direction: row-reverse;" : ""}
  gap: ${(props) => props.theme.iconSpacing};

  &:hover {
    ${(props) => `color: ${props.theme.hoverFontColor};
       cursor: pointer;
       border-bottom-color: ${props.theme.hoverUnderlineColor};`}
  }
  &:active {
    ${(props) => `color: ${props.theme.activeFontColor} !important;
                  border-bottom-color: ${props.theme.activeUnderlineColor} !important;`}
  }
`;
var LinkIconContainer = styled52.div`
  display: flex;
  font-size: ${(props) => props.theme.iconSize};
  svg {
    width: ${(props) => props.theme.iconSize};
    height: ${(props) => props.theme.iconSize};
  }
`;
var DxcLink = forwardRef9(
  ({
    inheritColor = false,
    disabled = false,
    icon,
    iconPosition = "before",
    href = "",
    newWindow = false,
    onClick,
    margin,
    tabIndex = 0,
    children,
    ...otherProps
  }, ref) => {
    const colorsTheme = useContext35(HalstackContext);
    return /* @__PURE__ */ jsx59(ThemeProvider24, { theme: colorsTheme.link, children: /* @__PURE__ */ jsx59(
      StyledLink,
      {
        as: onClick && !href ? "button" : "a",
        tabIndex,
        onClick: !disabled ? onClick : void 0,
        href: !disabled && href ? href : void 0,
        target: href ? newWindow ? "_blank" : "_self" : void 0,
        disabled,
        inheritColor,
        margin,
        ref,
        ...otherProps,
        children: /* @__PURE__ */ jsxs41(LinkContainer, { iconPosition, inheritColor, children: [
          children,
          icon && /* @__PURE__ */ jsx59(LinkIconContainer, { children: typeof icon === "string" ? /* @__PURE__ */ jsx59(Icon_default, { icon }) : icon })
        ] })
      }
    ) });
  }
);
var Link_default = DxcLink;

// src/nav-tabs/NavTabs.tsx
import { Children as Children4, useContext as useContext37, useEffect as useEffect17, useMemo as useMemo13, useRef as useRef14, useState as useState24 } from "react";
import styled54, { ThemeProvider as ThemeProvider25 } from "styled-components";

// src/nav-tabs/Tab.tsx
import { useEffect as useEffect16, forwardRef as forwardRef10, useContext as useContext36, useRef as useRef13, useImperativeHandle } from "react";
import styled53 from "styled-components";

// src/nav-tabs/NavTabsContext.tsx
import { createContext as createContext8 } from "react";
var NavTabsContext_default = createContext8(null);

// src/nav-tabs/Tab.tsx
import { jsx as jsx60, jsxs as jsxs42 } from "react/jsx-runtime";
var DxcTab = forwardRef10(
  ({ href, active = false, icon, disabled = false, notificationNumber = false, children, ...otherProps }, ref) => {
    const tabRef = useRef13();
    const { iconPosition, tabIndex, focusedLabel } = useContext36(NavTabsContext_default) ?? {};
    const innerRef = useRef13(null);
    useImperativeHandle(ref, () => innerRef.current, []);
    useEffect16(() => {
      if (focusedLabel === children.toString()) {
        tabRef?.current?.focus();
      }
    }, [focusedLabel]);
    const handleOnKeyDown = (event) => {
      switch (event.key) {
        case " ":
        case "Enter":
          event.preventDefault();
          tabRef?.current?.click();
          break;
        default:
          break;
      }
    };
    return /* @__PURE__ */ jsx60(TabContainer, { active, children: /* @__PURE__ */ jsxs42(
      Tab,
      {
        href: !disabled ? href : void 0,
        disabled,
        active,
        iconPosition,
        hasIcon: icon != null,
        ref: (anchorRef) => {
          tabRef.current = anchorRef;
          if (ref) {
            if (typeof ref === "function") {
              ref(anchorRef);
            } else {
              innerRef.current = anchorRef;
            }
          }
        },
        onKeyDown: handleOnKeyDown,
        tabIndex: active ? tabIndex : -1,
        role: "tab",
        "aria-selected": active,
        "aria-disabled": disabled,
        ...otherProps,
        children: [
          icon && /* @__PURE__ */ jsx60(TabIconContainer, { iconPosition, active, disabled, children: typeof icon === "string" ? /* @__PURE__ */ jsx60(Icon_default, { icon }) : icon }),
          /* @__PURE__ */ jsxs42(Flex_default, { alignItems: "center", gap: "0.5rem", children: [
            /* @__PURE__ */ jsx60(Label7, { active, disabled, children }),
            notificationNumber && !disabled && /* @__PURE__ */ jsx60(
              Badge_default,
              {
                mode: "notification",
                size: "small",
                label: typeof notificationNumber === "number" ? notificationNumber : void 0
              }
            )
          ] })
        ]
      }
    ) });
  }
);
var TabContainer = styled53.div`
  align-items: stretch;
  border-bottom: 2px solid ${(props) => props.active ? props.theme.selectedUnderlineColor : "transparent"};
  padding: 0.5rem;
`;
var Tab = styled53.a`
  box-sizing: border-box;
  display: flex;
  flex-direction: ${(props) => props.hasIcon && props.iconPosition === "top" ? "column" : "row"};
  justify-content: center;
  align-items: center;
  gap: ${(props) => props.hasIcon && props.iconPosition === "top" ? "0.375rem" : "0.625rem"};
  height: ${(props) => props.hasIcon && props.iconPosition === "top" ? "78px" : "100%"};
  min-width: 176px;
  min-height: 44px;
  padding: 0.375rem;
  border-radius: 4px;
  background: ${(props) => props.active ? props.theme.selectedBackgroundColor : props.theme.unselectedBackgroundColor};
  text-decoration-color: transparent;
  text-decoration-line: none;
  cursor: ${(props) => props.disabled ? "not-allowed" : "pointer"};

  ${(props) => !props.disabled && `
      :hover {
        background: ${props.theme.hoverBackgroundColor};
      }
      :focus {
        outline: 2px solid ${props.theme.focusOutline};
      }
      :active {
        background: ${props.theme.pressedBackgroundColor};
        outline: 2px solid #33aaff};
      }
  `}
`;
var Label7 = styled53.span`
  display: inline;
  color: ${(props) => props.disabled ? props.theme.disabledFontColor : props.active ? props.theme.selectedFontColor : props.theme.unselectedFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  text-align: center;
  letter-spacing: 0.025em;
  line-height: 1.715em;
  text-decoration: none;
  text-overflow: unset;
  white-space: normal;
  margin: 0;
`;
var TabIconContainer = styled53.div`
  display: flex;
  font-size: 24px;
  color: ${(props) => props.active ? props.theme.selectedIconColor : props.disabled ? props.theme.disabledIconColor : props.theme.unselectedIconColor};
  svg {
    height: 24px;
    width: 24px;
  }
`;
var Tab_default = DxcTab;

// src/nav-tabs/NavTabs.tsx
import { jsx as jsx61, jsxs as jsxs43 } from "react/jsx-runtime";
var getPropInChild = (child, propName) => {
  if (child && typeof child === "object" && "props" in child) {
    const childWithProps = child;
    if (childWithProps.props[propName]) {
      return childWithProps.props[propName];
    } else if (childWithProps.props.children) {
      return getPropInChild(childWithProps.props.children, propName);
    }
  }
};
var getLabelFromTab = (child) => {
  if (typeof child === "string") {
    return child;
  } else if (child && typeof child === "object" && "props" in child) {
    const childWithProps = child;
    if (Array.isArray(childWithProps.props.children)) {
      return getLabelFromTab(childWithProps.props.children[0]);
    } else {
      return getLabelFromTab(childWithProps.props.children);
    }
  }
};
var getPreviousTabIndex = (array, initialIndex) => {
  let index = initialIndex === 0 ? array.length - 1 : initialIndex - 1;
  while (getPropInChild(array[index], "disabled")) {
    index = index === 0 ? array.length - 1 : index - 1;
  }
  return index;
};
var getNextTabIndex = (array, initialIndex) => {
  let index = initialIndex === array.length - 1 ? 0 : initialIndex + 1;
  while (getPropInChild(array[index], "disabled")) {
    index = index === array.length - 1 ? 0 : index + 1;
  }
  return index;
};
var DxcNavTabs = ({ iconPosition = "top", tabIndex = 0, children }) => {
  const [innerFocusIndex, setInnerFocusIndex] = useState24(null);
  const [underlineWidth, setUnderlineWidth] = useState24(null);
  const refNavTabList = useRef14(null);
  const colorsTheme = useContext37(HalstackContext);
  const childArray = Children4.toArray(children).filter(
    (child) => typeof child === "object" && "props" in child
  );
  useEffect17(() => {
    setUnderlineWidth(refNavTabList?.current?.scrollWidth ?? null);
  }, [children]);
  const contextValue = useMemo13(
    () => ({
      iconPosition,
      tabIndex,
      focusedLabel: innerFocusIndex === null ? void 0 : getLabelFromTab(childArray[innerFocusIndex])
    }),
    [iconPosition, tabIndex, innerFocusIndex]
  );
  const handleOnKeyDown = (event) => {
    const activeTab = childArray.findIndex((child) => getPropInChild(child, "active"));
    switch (event.key) {
      case "Left":
      case "ArrowLeft":
        event.preventDefault();
        setInnerFocusIndex(getPreviousTabIndex(childArray, innerFocusIndex === null ? activeTab : innerFocusIndex));
        break;
      case "Right":
      case "ArrowRight":
        event.preventDefault();
        setInnerFocusIndex(getNextTabIndex(childArray, innerFocusIndex === null ? activeTab : innerFocusIndex));
        break;
      default:
        break;
    }
  };
  return /* @__PURE__ */ jsx61(ThemeProvider25, { theme: colorsTheme.navTabs, children: /* @__PURE__ */ jsxs43(NavTabsContainer, { onKeyDown: handleOnKeyDown, ref: refNavTabList, role: "tablist", "aria-label": "Navigation tabs", children: [
    /* @__PURE__ */ jsx61(NavTabsContext_default.Provider, { value: contextValue, children }),
    /* @__PURE__ */ jsx61(Underline, { underlineWidth: underlineWidth ?? 0 })
  ] }) });
};
var Underline = styled54.div`
  position: absolute;
  bottom: 0;
  left: 0;
  height: 2px;
  background-color: ${(props) => props.theme.dividerColor};
  z-index: -1;
  width: ${(props) => props.underlineWidth}px;
`;
DxcNavTabs.Tab = Tab_default;
var NavTabsContainer = styled54.div`
  display: flex;
  position: relative;
  overflow: auto;
  z-index: 0;
`;
var NavTabs_default = DxcNavTabs;

// src/number-input/NumberInput.tsx
import { forwardRef as forwardRef11, useEffect as useEffect18, useMemo as useMemo14, useRef as useRef15 } from "react";
import styled55 from "styled-components";
import { jsx as jsx62 } from "react/jsx-runtime";
var DxcNumberInput = forwardRef11(
  ({
    label,
    name,
    defaultValue,
    value,
    helperText,
    placeholder,
    disabled,
    optional,
    readOnly,
    prefix,
    suffix,
    min,
    max,
    step = 1,
    onChange,
    onBlur,
    error,
    autocomplete,
    margin,
    size,
    tabIndex,
    ariaLabel = "Number input",
    showControls = true
  }, ref) => {
    const numberInputRef = useRef15(null);
    const contextValue = useMemo14(
      () => ({
        maxNumber: max,
        minNumber: min,
        showControls,
        stepNumber: step,
        typeNumber: "number"
      }),
      [max, min, showControls, step]
    );
    useEffect18(() => {
      const input = numberInputRef.current?.getElementsByTagName("input")[0];
      const preventDefault = (event) => {
        event.preventDefault();
      };
      input?.addEventListener("wheel", preventDefault, { passive: false });
      return () => {
        input?.removeEventListener("wheel", preventDefault);
      };
    }, []);
    return /* @__PURE__ */ jsx62(NumberInputContext_default.Provider, { value: contextValue, children: /* @__PURE__ */ jsx62(NumberInputContainer, { ref: numberInputRef, size, children: /* @__PURE__ */ jsx62(
      TextInput_default,
      {
        label,
        name,
        defaultValue,
        value,
        helperText,
        placeholder,
        disabled,
        optional,
        readOnly,
        prefix,
        suffix,
        error,
        onChange,
        onBlur,
        autocomplete,
        margin,
        size,
        tabIndex,
        ref,
        ariaLabel
      }
    ) }) });
  }
);
var NumberInputContainer = styled55.div`
  ${(props) => props.size === "fillParent" && "width: 100%;"}
  // Chrome, Safari, Edge, Opera
  input::-webkit-outer-spin-button,
  input::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0;
  }

  // Firefox
  input[type="number"] {
    -moz-appearance: textfield;
  }
`;
var NumberInput_default = DxcNumberInput;

// src/paragraph/Paragraph.tsx
import { useContext as useContext38 } from "react";
import styled56, { ThemeProvider as ThemeProvider26 } from "styled-components";
import { jsx as jsx63 } from "react/jsx-runtime";
var Paragraph = styled56.p`
  display: ${(props) => props.theme.display};
  font-family: "Open Sans", sans-serif;
  font-size: ${(props) => props.theme.fontSize};
  font-style: "normal";
  font-weight: ${(props) => props.theme.fontWeight};
  letter-spacing: 0em;
  line-height: 1.5em;
  text-align: "left";
  color: ${(props) => props.theme.fontColor};
  text-decoration: none;
  text-overflow: unset;
  white-space: normal;
  margin: 0;
`;
function DxcParagraph({ children }) {
  const colorsTheme = useContext38(HalstackContext);
  return /* @__PURE__ */ jsx63(ThemeProvider26, { theme: colorsTheme.paragraph, children: /* @__PURE__ */ jsx63(Paragraph, { children }) });
}

// src/password-input/PasswordInput.tsx
import { forwardRef as forwardRef12, useContext as useContext39, useEffect as useEffect19, useRef as useRef16, useState as useState25 } from "react";
import styled57 from "styled-components";
import { jsx as jsx64 } from "react/jsx-runtime";
var setInputType = (type, element) => {
  element?.getElementsByTagName("input")[0]?.setAttribute("type", type);
};
var setAriaAttributes = (ariaExpanded, element) => {
  const buttonElement = element?.getElementsByTagName("button")[0];
  buttonElement?.setAttribute("aria-expanded", ariaExpanded);
};
var DxcPasswordInput = forwardRef12(
  ({
    label,
    name = "",
    value,
    helperText,
    clearable = false,
    onChange,
    onBlur,
    error,
    pattern,
    minLength,
    maxLength,
    autocomplete = "off",
    margin,
    size = "medium",
    tabIndex = 0,
    ariaLabel = "Password input"
  }, ref) => {
    const [isPasswordVisible, setIsPasswordVisible] = useState25(false);
    const inputRef = useRef16(null);
    const { passwordInput } = useContext39(HalstackLanguageContext);
    useEffect19(() => {
      (() => {
        if (isPasswordVisible) {
          setInputType("text", inputRef.current);
          if (passwordInput.inputHidePasswordTitle) {
            setAriaAttributes("true", inputRef.current);
          }
        } else {
          setInputType("password", inputRef.current);
          if (passwordInput.inputShowPasswordTitle) {
            setAriaAttributes("false", inputRef.current);
          }
        }
      })();
    }, [isPasswordVisible, passwordInput]);
    return /* @__PURE__ */ jsx64(PasswordInput, { ref, role: "group", size, children: /* @__PURE__ */ jsx64(
      TextInput_default,
      {
        label,
        name,
        value,
        helperText,
        action: {
          onClick: () => {
            setIsPasswordVisible((isPasswordCurrentlyVisible) => !isPasswordCurrentlyVisible);
          },
          icon: isPasswordVisible ? "Visibility_Off" : "Visibility",
          title: isPasswordVisible ? passwordInput.inputHidePasswordTitle : passwordInput.inputShowPasswordTitle
        },
        error,
        clearable,
        onChange,
        onBlur,
        margin,
        size,
        pattern,
        minLength,
        maxLength,
        autocomplete,
        ref: inputRef,
        tabIndex,
        ariaLabel
      }
    ) });
  }
);
var PasswordInput = styled57.div`
  ${(props) => props.size === "fillParent" && "width: 100%;"}
  & ::-ms-reveal {
    display: none;
  }
`;
var PasswordInput_default = DxcPasswordInput;

// src/progress-bar/ProgressBar.tsx
import { useContext as useContext40, useEffect as useEffect20, useId as useId14, useState as useState26 } from "react";
import styled58, { ThemeProvider as ThemeProvider27 } from "styled-components";
import { jsx as jsx65, jsxs as jsxs44 } from "react/jsx-runtime";
var Overlay4 = styled58.div`
  ${({ overlay, theme }) => overlay ? `background-color: ${theme.overlayColor};
      width: 100%;
      justify-content: center;
      height: 100vh;
      align-items: center;
      max-width: 100%;
      position: fixed;
      top: 0;
      bottom: 0;
      left: 0;
      right: 0;
      z-index: 1300;` : `background-color: transparent;`}
  display: flex;
  flex-wrap: wrap;
  min-width: 100px;
  width: 100%;
`;
var MainContainer4 = styled58.div`
  width: ${(props) => props.overlay ? "80%" : "100%"};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  z-index: ${(props) => props.overlay ? "100" : "0"};
`;
var ProgressBarLabel = styled58.div`
  font-family: ${(props) => props.theme.labelFontFamily};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-size: ${(props) => props.theme.labelFontSize};
  font-weight: ${(props) => props.theme.labelFontWeight};
  text-transform: ${(props) => props.theme.labelFontTextTransform};
  color: ${(props) => props.overlay ? props.theme.overlayFontColor : props.theme.labelFontColor};
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  text-overflow: ellipsis;
`;
var ProgressBarProgress = styled58.div`
  flex-shrink: 0;
  color: ${(props) => props.overlay ? props.theme.overlayFontColor : props.theme.valueFontColor};
  font-family: ${(props) => props.theme.valueFontFamily};
  font-style: ${(props) => props.theme.valueFontStyle};
  font-size: ${(props) => props.theme.valueFontSize};
  font-weight: ${(props) => props.theme.valueFontWeight};
  text-transform: ${(props) => props.theme.valueFontTextTransform};
`;
var HelperText5 = styled58.span`
  color: ${(props) => props.overlay ? props.theme.overlayFontColor : props.theme.helperTextFontColor};
  font-family: ${(props) => props.theme.helperTextFontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: 1.5em;
`;
var LinearProgress = styled58.div`
  position: relative;
  border-radius: ${(props) => props.theme.borderRadius};
  height: ${(props) => props.theme.thickness};
  background-color: ${(props) => props.theme.totalLineColor};
  overflow: hidden;
`;
var LinearProgressBar = styled58.span`
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: ${(props) => props.variant === "indeterminate" ? "auto" : "100%"};
  transform: ${(props) => `translateX(-${props.variant === "determinate" ? 100 - (props.value ?? 0) : 0}%)`};
  transition: ${(props) => props.variant === "determinate" ? "transform .4s linear" : "transform 0.2s linear"};
  transform-origin: left;
  background-color: ${(props) => props.theme.trackLineColor};
  ${(props) => props.variant === "indeterminate" ? "animation: keyframes-indeterminate-first 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite;" : ""};

  @keyframes keyframes-indeterminate-first {
    0% {
      left: -35%;
      right: 100%;
    }
    60% {
      left: 100%;
      right: -90%;
    }
    100% {
      left: 100%;
      right: -90%;
    }
  }

  @keyframes keyframes-indeterminate-second {
    0% {
      left: -200%;
      right: 100%;
    }
    60% {
      left: 107%;
      right: -8%;
    }
    100% {
      left: 107%;
      right: -8%;
    }
  }
`;
var DxcProgressBar = ({
  label,
  helperText,
  overlay,
  value,
  showValue,
  margin,
  ariaLabel = "Progress bar"
}) => {
  const colorsTheme = useContext40(HalstackContext);
  const labelId = `label-${useId14()}`;
  const [innerValue, setInnerValue] = useState26();
  useEffect20(() => {
    if (value != null) setInnerValue(value < 0 ? 0 : value > 100 ? 100 : value);
  }, [value]);
  return /* @__PURE__ */ jsx65(ThemeProvider27, { theme: colorsTheme.progressBar, children: /* @__PURE__ */ jsx65(Overlay4, { overlay, children: /* @__PURE__ */ jsxs44(MainContainer4, { overlay, margin, children: [
    /* @__PURE__ */ jsxs44(Flex_default, { justifyContent: "space-between", gap: "0.5rem", children: [
      label && /* @__PURE__ */ jsx65(ProgressBarLabel, { id: labelId, overlay, children: label }),
      innerValue != null && showValue && /* @__PURE__ */ jsxs44(ProgressBarProgress, { overlay, children: [
        innerValue,
        " %"
      ] })
    ] }),
    /* @__PURE__ */ jsx65(
      LinearProgress,
      {
        role: "progressbar",
        helperText,
        "aria-label": label ? void 0 : ariaLabel,
        "aria-labelledby": label ? labelId : void 0,
        "aria-valuenow": innerValue,
        "aria-valuemin": 0,
        "aria-valuemax": 100,
        children: /* @__PURE__ */ jsx65(LinearProgressBar, { variant: innerValue == null ? "indeterminate" : "determinate", value: innerValue })
      }
    ),
    helperText && /* @__PURE__ */ jsx65(HelperText5, { overlay, children: helperText })
  ] }) }) });
};
var ProgressBar_default = DxcProgressBar;

// src/quick-nav/QuickNav.tsx
import { useContext as useContext41 } from "react";
import slugify from "slugify";
import styled59, { ThemeProvider as ThemeProvider28 } from "styled-components";
import { jsx as jsx66, jsxs as jsxs45 } from "react/jsx-runtime";
var DxcQuickNav = ({ title, links }) => {
  const translatedLabels = useContext41(HalstackLanguageContext);
  const colorsTheme = useContext41(HalstackContext);
  return /* @__PURE__ */ jsx66(ThemeProvider28, { theme: colorsTheme.quickNav, children: /* @__PURE__ */ jsx66(QuickNavContainer, { children: /* @__PURE__ */ jsxs45(Flex_default, { direction: "column", gap: "0.5rem", children: [
    /* @__PURE__ */ jsx66(Heading_default, { level: 4, text: title || translatedLabels.quickNav.contentTitle }),
    /* @__PURE__ */ jsx66(ListColumn, { children: links.map((link) => /* @__PURE__ */ jsx66("li", { children: /* @__PURE__ */ jsx66(Inset_default, { space: "0.25rem", children: /* @__PURE__ */ jsxs45(DxcTypography, { children: [
      /* @__PURE__ */ jsx66(Link3, { href: `#${slugify(link.label, { lower: true })}`, children: link.label }),
      /* @__PURE__ */ jsx66(ListSecondColumn, { children: link.links?.map((sublink) => /* @__PURE__ */ jsx66("li", { children: /* @__PURE__ */ jsx66(Inset_default, { horizontal: "0.5rem", children: /* @__PURE__ */ jsx66(DxcTypography, { children: /* @__PURE__ */ jsx66(
        Link3,
        {
          href: `#${slugify(link?.label, { lower: true })}-${slugify(sublink?.label, {
            lower: true
          })}`,
          children: sublink.label
        }
      ) }) }) }, sublink.label)) })
    ] }) }) }, link.label)) })
  ] }) }) });
};
var QuickNavContainer = styled59.div`
  padding-top: ${(props) => props.theme.paddingTop};
  padding-bottom: ${(props) => props.theme.paddingBottom};
  padding-left: ${(props) => props.theme.paddingLeft};
  padding-right: ${(props) => props.theme.paddingRight};
  border-left: 2px solid ${(props) => props.theme.dividerBorderColor};
`;
var ListColumn = styled59.ul`
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  margin: 0;
  padding: 0;
  list-style-type: none;
`;
var ListSecondColumn = styled59.ul`
  display: flex;
  flex-direction: column;
  margin: 0;
  padding: 0;
  list-style-type: none;
`;
var Link3 = styled59.a`
  text-decoration: none;
  font-size: ${(props) => props.theme.fontSize};
  font-family: ${(props) => props.theme.fontFamily};
  font-style: ${(props) => props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  color: ${(props) => props.theme.fontColor};
  display: block;
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  width: fit-content;
  max-width: 100%;

  &:hover {
    color: ${(props) => props.theme.hoverFontColor};
  }
  &:focus {
    outline-color: ${(props) => props.theme.focusBorderColor};
    outline-style: ${(props) => props.theme.focusBorderStyle};
    outline-width: ${(props) => props.theme.focusBorderThickness};
    border-radius: ${(props) => props.theme.focusBorderRadius};
  }
`;
var QuickNav_default = DxcQuickNav;

// src/radio-group/RadioGroup.tsx
import { forwardRef as forwardRef13, useCallback as useCallback10, useContext as useContext43, useId as useId16, useMemo as useMemo15, useState as useState28 } from "react";
import styled61, { ThemeProvider as ThemeProvider30 } from "styled-components";

// src/radio-group/Radio.tsx
import { memo as memo11, useContext as useContext42, useEffect as useEffect21, useId as useId15, useRef as useRef17, useState as useState27 } from "react";
import styled60, { ThemeProvider as ThemeProvider29 } from "styled-components";
import { jsx as jsx67, jsxs as jsxs46 } from "react/jsx-runtime";
var DxcRadio = ({
  label,
  checked,
  onClick,
  error,
  disabled,
  focused,
  readOnly,
  tabIndex
}) => {
  const radioLabelId = `radio-${useId15()}`;
  const ref = useRef17(null);
  const colorsTheme = useContext42(HalstackContext);
  const handleOnClick = () => {
    onClick();
    document.activeElement !== ref.current && ref.current?.focus();
  };
  const [firstUpdate, setFirstUpdate] = useState27(true);
  useEffect21(() => {
    if (firstUpdate) {
      setFirstUpdate(false);
      return;
    }
    focused && ref.current?.focus();
  }, [focused]);
  return /* @__PURE__ */ jsx67(ThemeProvider29, { theme: colorsTheme.radioGroup, children: /* @__PURE__ */ jsx67(Flex_default, { children: /* @__PURE__ */ jsxs46(
    RadioContainer,
    {
      error,
      disabled,
      readOnly,
      onClick: disabled ? void 0 : handleOnClick,
      children: [
        /* @__PURE__ */ jsx67(RadioInputContainer, { children: /* @__PURE__ */ jsx67(
          RadioInput,
          {
            error,
            disabled,
            readOnly,
            role: "radio",
            "aria-checked": checked,
            "aria-disabled": disabled,
            "aria-labelledby": radioLabelId,
            tabIndex: disabled ? -1 : focused ? tabIndex : -1,
            ref,
            children: checked && /* @__PURE__ */ jsx67(Dot, { disabled, readOnly, error })
          }
        ) }),
        /* @__PURE__ */ jsx67(Label8, { id: radioLabelId, disabled, children: label })
      ]
    }
  ) }) });
};
var getRadioInputStateColor = (props, state) => {
  switch (state) {
    case "enabled":
      return props.disabled ? props.theme.disabledRadioInputColor : props.error ? props.theme.errorRadioInputColor : props.readOnly ? props.theme.readOnlyRadioInputColor : props.theme.radioInputColor;
    case "hover":
      return props.error ? props.theme.hoverErrorRadioInputColor : props.readOnly ? props.theme.hoverReadOnlyRadioInputColor : props.theme.hoverRadioInputColor;
    case "active":
      return props.error ? props.theme.activeErrorRadioInputColor : props.readOnly ? props.theme.activeReadOnlyRadioInputColor : props.theme.activeRadioInputColor;
  }
};
var RadioInputContainer = styled60.span`
  display: flex;
  align-items: center;
  justify-content: center;
  height: 24px;
  width: 24px;
`;
var RadioInput = styled60.span`
  box-sizing: border-box;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 18px;
  height: 18px;
  border: 2px solid ${(props) => getRadioInputStateColor(props, "enabled")};
  border-radius: 50%;

  &:focus {
    outline: 2px solid ${(props) => props.theme.focusBorderColor};
    outline-offset: 1px;
  }
  ${(props) => props.disabled && "pointer-events: none;"}
`;
var Dot = styled60.span`
  height: 10px;
  width: 10px;
  border-radius: 50%;
  background-color: ${(props) => getRadioInputStateColor(props, "enabled")};
`;
var Label8 = styled60.span`
  margin-left: ${(props) => props.theme.radioInputLabelMargin};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.radioInputLabelFontSize};
  font-style: ${(props) => props.theme.radioInputLabelFontStyle};
  font-weight: ${(props) => props.theme.radioInputLabelFontWeight};
  line-height: ${(props) => props.theme.radioInputLabelLineHeight};
  ${(props) => props.disabled ? `color: ${props.theme.disabledRadioInputLabelFontColor};` : `color: ${props.theme.radioInputLabelFontColor}`}
`;
var RadioContainer = styled60.span`
  display: inline-flex;
  align-items: center;
  cursor: ${(props) => props.disabled ? "not-allowed" : props.readOnly ? "default" : "pointer"};

  &:hover {
    ${RadioInput} {
      border-color: ${(props) => !props.disabled && getRadioInputStateColor(props, "hover")};
    }
    ${Dot} {
      background-color: ${(props) => !props.disabled && getRadioInputStateColor(props, "hover")};
    }
  }
  &:active {
    ${RadioInput} {
      border-color: ${(props) => !props.disabled && getRadioInputStateColor(props, "active")};
    }
    ${Dot} {
      background-color: ${(props) => !props.disabled && getRadioInputStateColor(props, "active")};
    }
  }
`;
var Radio_default = memo11(DxcRadio);

// src/radio-group/RadioGroup.tsx
import { jsx as jsx68, jsxs as jsxs47 } from "react/jsx-runtime";
var getInitialFocusIndex = (innerOptions, value) => {
  const initialSelectedOptionIndex = innerOptions.findIndex((option) => option.value === value);
  return initialSelectedOptionIndex !== -1 ? initialSelectedOptionIndex : 0;
};
var DxcRadioGroup = forwardRef13(
  ({
    label,
    name,
    helperText,
    options,
    disabled = false,
    optional = false,
    optionalItemLabel,
    readOnly = false,
    stacking = "column",
    defaultValue,
    value,
    onChange,
    onBlur,
    error,
    tabIndex = 0,
    ariaLabel = "Radio group"
  }, ref) => {
    const radioGroupId = `radio-group-${useId16()}`;
    const radioGroupLabelId = `label-${radioGroupId}`;
    const errorId = `error-${radioGroupId}`;
    const [innerValue, setInnerValue] = useState28(defaultValue);
    const [firstTimeFocus, setFirstTimeFocus] = useState28(true);
    const colorsTheme = useContext43(HalstackContext);
    const translatedLabels = useContext43(HalstackLanguageContext);
    const innerOptions = useMemo15(
      () => optional ? [
        ...options,
        {
          label: optionalItemLabel ?? translatedLabels.radioGroup.optionalItemLabelDefault,
          value: "",
          disabled
        }
      ] : options,
      [optional, options, optionalItemLabel, translatedLabels]
    );
    const [currentFocusIndex, setCurrentFocusIndex] = useState28(getInitialFocusIndex(innerOptions, value ?? innerValue));
    const handleOnChange = useCallback10(
      (newValue) => {
        const currentValue = value ?? innerValue;
        if (newValue !== currentValue && !readOnly) {
          if (value == null) {
            setInnerValue(newValue);
          }
          onChange?.(newValue);
        }
      },
      [value, innerValue, onChange]
    );
    const handleOnBlur = (event) => {
      if (!event.currentTarget.contains(event.relatedTarget)) {
        setFirstTimeFocus(true);
        const currentValue = value ?? innerValue;
        if (!optional && !currentValue) {
          onBlur?.({
            value: currentValue,
            error: translatedLabels.formFields.requiredSelectionErrorMessage
          });
        } else {
          onBlur?.({ value: currentValue });
        }
      }
    };
    const handleOnFocus = () => {
      if (firstTimeFocus) {
        setFirstTimeFocus(false);
      }
    };
    const setPreviousRadioChecked = () => {
      setCurrentFocusIndex((currentFocusIndexValue) => {
        let index = currentFocusIndexValue === 0 ? innerOptions.length - 1 : currentFocusIndexValue - 1;
        while (innerOptions[index]?.disabled) {
          index = index === 0 ? innerOptions.length - 1 : index - 1;
        }
        const option = innerOptions[index];
        if (option != null) {
          handleOnChange(option.value);
        }
        return index;
      });
    };
    const setNextRadioChecked = () => {
      setCurrentFocusIndex((currentFocusIndexValue) => {
        let index = currentFocusIndexValue === innerOptions.length - 1 ? 0 : currentFocusIndexValue + 1;
        while (innerOptions[index]?.disabled) {
          index = index === innerOptions.length - 1 ? 0 : index + 1;
        }
        const option = innerOptions[index];
        if (option != null) {
          handleOnChange(option.value);
        }
        return index;
      });
    };
    const handleOnKeyDown = (event) => {
      switch (event.key) {
        case "Left":
        case "ArrowLeft":
        case "Up":
        case "ArrowUp":
          event.preventDefault();
          setPreviousRadioChecked();
          break;
        case "Right":
        case "ArrowRight":
        case "Down":
        case "ArrowDown":
          event.preventDefault();
          setNextRadioChecked();
          break;
        case " ":
          event.preventDefault();
          if (innerOptions[currentFocusIndex] != null) {
            handleOnChange(innerOptions[currentFocusIndex].value);
          }
          break;
        default:
          break;
      }
    };
    return /* @__PURE__ */ jsx68(ThemeProvider30, { theme: colorsTheme.radioGroup, children: /* @__PURE__ */ jsxs47(RadioGroupContainer, { ref, children: [
      label && /* @__PURE__ */ jsxs47(Label9, { id: radioGroupLabelId, helperText, disabled, children: [
        label,
        optional && /* @__PURE__ */ jsx68(OptionalLabel4, { children: ` ${translatedLabels.formFields.optionalLabel}` })
      ] }),
      helperText && /* @__PURE__ */ jsx68(HelperText6, { disabled, children: helperText }),
      /* @__PURE__ */ jsxs47(
        RadioGroup,
        {
          onBlur: handleOnBlur,
          onFocus: handleOnFocus,
          onKeyDown: handleOnKeyDown,
          stacking,
          role: "radiogroup",
          "aria-disabled": disabled,
          "aria-labelledby": label ? radioGroupLabelId : void 0,
          "aria-invalid": !!error,
          "aria-errormessage": error ? errorId : void 0,
          "aria-required": !disabled && !readOnly && !optional,
          "aria-readonly": readOnly,
          "aria-orientation": stacking === "column" ? "vertical" : "horizontal",
          "aria-label": label ? void 0 : ariaLabel,
          children: [
            /* @__PURE__ */ jsx68(ValueInput3, { name, disabled, value: value ?? innerValue ?? "", readOnly: true }),
            innerOptions.map((option, index) => /* @__PURE__ */ jsx68(
              Radio_default,
              {
                label: option.label ?? "",
                checked: (value ?? innerValue) === option.value,
                onClick: () => {
                  handleOnChange(option.value);
                  setCurrentFocusIndex(index);
                },
                error,
                disabled: option.disabled || disabled,
                focused: currentFocusIndex === index,
                readOnly,
                tabIndex
              },
              `radio-${index}`
            ))
          ]
        }
      ),
      !disabled && typeof error === "string" && /* @__PURE__ */ jsx68(ErrorMessageContainer2, { id: errorId, role: "alert", "aria-live": error ? "assertive" : "off", children: error })
    ] }) });
  }
);
var RadioGroupContainer = styled61.div`
  box-sizing: border-box;
  display: inline-flex;
  flex-direction: column;
`;
var Label9 = styled61.span`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
  ${(props) => !props.helperText && `margin-bottom: ${props.theme.groupLabelMargin}`}
`;
var OptionalLabel4 = styled61.span`
  font-weight: ${(props) => props.theme.optionalLabelFontWeight};
`;
var HelperText6 = styled61.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
  margin-bottom: ${(props) => props.theme.groupLabelMargin};
`;
var RadioGroup = styled61.div`
  display: flex;
  flex-wrap: wrap;
  flex-direction: ${(props) => props.stacking};
  row-gap: ${(props) => props.theme.groupVerticalGutter};
  column-gap: ${(props) => props.theme.groupHorizontalGutter};
`;
var ValueInput3 = styled61.input`
  display: none;
`;
var ErrorMessageContainer2 = styled61.span`
  min-height: 1.5em;
  color: ${(props) => props.theme.errorMessageColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.5em;
  margin-top: 0.5rem;
`;
var RadioGroup_default = DxcRadioGroup;

// src/resultset-table/ResultsetTable.tsx
import { useContext as useContext44, useEffect as useEffect22, useMemo as useMemo16, useRef as useRef18, useState as useState29 } from "react";
import styled62, { ThemeProvider as ThemeProvider31 } from "styled-components";

// src/resultset-table/Icons.tsx
import { jsx as jsx69, jsxs as jsxs48 } from "react/jsx-runtime";
var icons = {
  arrowUp: /* @__PURE__ */ jsxs48("svg", { xmlns: "http://www.w3.org/2000/svg", height: "24", viewBox: "0 0 24 24", width: "24", fill: "currentColor", children: [
    /* @__PURE__ */ jsx69("path", { d: "M0 0h24v24H0V0z", fill: "none" }),
    /* @__PURE__ */ jsx69("path", { d: "M4 12l1.41 1.41L11 7.83V20h2V7.83l5.58 5.59L20 12l-8-8-8 8z" })
  ] }),
  arrowDown: /* @__PURE__ */ jsxs48("svg", { xmlns: "http://www.w3.org/2000/svg", height: "24", viewBox: "0 0 24 24", width: "24", fill: "currentColor", children: [
    /* @__PURE__ */ jsx69("path", { d: "M0 0h24v24H0V0z", fill: "none" }),
    /* @__PURE__ */ jsx69("path", { d: "M20 12l-1.41-1.41L13 16.17V4h-2v12.17l-5.58-5.59L4 12l8 8 8-8z" })
  ] }),
  bothArrows: /* @__PURE__ */ jsxs48("svg", { xmlns: "http://www.w3.org/2000/svg", height: "24", viewBox: "0 0 24 24", width: "24", fill: "currentColor", children: [
    /* @__PURE__ */ jsx69("path", { d: "M0 0h24v24H0z", fill: "none" }),
    /* @__PURE__ */ jsx69("path", { d: "M12 5.83L15.17 9l1.41-1.41L12 3 7.41 7.59 8.83 9 12 5.83zm0 12.34L8.83 15l-1.41 1.41L12 21l4.59-4.59L15.17 15 12 18.17z" })
  ] })
};
var Icons_default2 = icons;

// src/resultset-table/ResultsetTable.tsx
import { jsx as jsx70, jsxs as jsxs49 } from "react/jsx-runtime";
var normalizeSortValue = (sortValue) => typeof sortValue === "string" ? sortValue.toUpperCase() : sortValue;
var isDateType = (value) => value instanceof Date;
var sortArray = (index, order, resultset) => resultset.slice().sort((element1, element2) => {
  const sortValueA = normalizeSortValue(element1.cells[index]?.sortValue || element1.cells[index]?.displayValue);
  const sortValueB = normalizeSortValue(element2.cells[index]?.sortValue || element2.cells[index]?.displayValue);
  let comparison = 0;
  if (sortValueA != null && sortValueB != null) {
    if (typeof sortValueA === "object" && !isDateType(sortValueA)) {
      comparison = -1;
    } else if (typeof sortValueB === "object" && !isDateType(sortValueB)) {
      comparison = 1;
    } else if (sortValueA > sortValueB) {
      comparison = 1;
    } else if (sortValueA < sortValueB) {
      comparison = -1;
    }
  }
  return order === "descending" ? comparison * -1 : comparison;
});
var getMinItemsPerPageIndex2 = (currentPageInternal, itemsPerPage, page) => currentPageInternal === 1 ? 0 : itemsPerPage * (page - 1);
var getMaxItemsPerPageIndex2 = (minItemsPerPageIndex, itemsPerPage, resultset, page) => minItemsPerPageIndex + itemsPerPage > resultset.length ? resultset.length : itemsPerPage * page - 1;
var assignIdsToRows = (resultset) => {
  if (resultset.length > 0) {
    return resultset.map((row, index) => ({
      cells: row,
      id: `row_${index}`
    }));
  }
  return [];
};
var DxcResultsetTable = ({
  columns,
  rows,
  hidePaginator = false,
  showGoToPage = true,
  itemsPerPage = 5,
  itemsPerPageOptions,
  itemsPerPageFunction,
  margin,
  tabIndex = 0,
  mode = "default"
}) => {
  const colorsTheme = useContext44(HalstackContext);
  const [page, changePage] = useState29(1);
  const [sortColumnIndex, changeSortColumnIndex] = useState29(-1);
  const [sortOrder, changeSortOrder] = useState29("ascending");
  const prevRowCountRef = useRef18(rows.length);
  const rowsWithIds = useMemo16(() => assignIdsToRows(rows), [rows]);
  const minItemsPerPageIndex = useMemo16(() => getMinItemsPerPageIndex2(page, itemsPerPage, page), [itemsPerPage, page]);
  const maxItemsPerPageIndex = useMemo16(
    () => getMaxItemsPerPageIndex2(minItemsPerPageIndex, itemsPerPage, rows, page),
    [itemsPerPage, minItemsPerPageIndex, page, rows]
  );
  const sortedResultset = useMemo16(
    () => sortColumnIndex !== -1 ? sortArray(sortColumnIndex, sortOrder, rowsWithIds) : rowsWithIds,
    [sortColumnIndex, sortOrder, rowsWithIds]
  );
  const filteredResultset = useMemo16(
    () => sortedResultset && sortedResultset.slice(minItemsPerPageIndex, maxItemsPerPageIndex + 1),
    [sortedResultset, minItemsPerPageIndex, maxItemsPerPageIndex]
  );
  const goToPage = (newPage) => {
    changePage(newPage);
  };
  const changeSorting = (columnIndex) => {
    changePage(1);
    changeSortColumnIndex(columnIndex);
    changeSortOrder(
      sortColumnIndex === -1 || sortColumnIndex !== columnIndex ? "ascending" : sortOrder === "ascending" ? "descending" : "ascending"
    );
  };
  useEffect22(() => {
    if (!hidePaginator) {
      if (rows.length === 0) {
        changePage(0);
      } else if (page === 0) {
        changePage(1);
      } else if (rows.length < prevRowCountRef.current) {
        const lastPage = Math.ceil(rows.length / itemsPerPage);
        const prevLastPage = Math.ceil(prevRowCountRef.current / itemsPerPage);
        if (lastPage < prevLastPage) {
          changePage(Math.min(lastPage, page));
        }
      }
      prevRowCountRef.current = rows.length;
    }
  }, [rows.length]);
  return /* @__PURE__ */ jsx70(ThemeProvider31, { theme: colorsTheme.table, children: /* @__PURE__ */ jsxs49(DxcResultsetTableContainer, { margin, children: [
    /* @__PURE__ */ jsxs49(Table_default, { mode, children: [
      /* @__PURE__ */ jsx70("thead", { children: /* @__PURE__ */ jsx70("tr", { children: columns.map((column, index) => /* @__PURE__ */ jsx70(
        "th",
        {
          "aria-sort": column.isSortable ? sortColumnIndex === index ? sortOrder : "none" : void 0,
          children: /* @__PURE__ */ jsxs49(
            HeaderContainer3,
            {
              role: column.isSortable ? "button" : void 0,
              onClick: () => {
                if (column.isSortable) {
                  changeSorting(index);
                }
              },
              tabIndex: column.isSortable ? tabIndex : -1,
              isSortable: column.isSortable,
              mode,
              "aria-label": column.isSortable ? "Sort column" : void 0,
              children: [
                /* @__PURE__ */ jsx70("span", { children: column.displayValue }),
                column.isSortable && /* @__PURE__ */ jsx70(SortIcon, { children: sortColumnIndex === index ? sortOrder === "ascending" ? Icons_default2.arrowUp : Icons_default2.arrowDown : Icons_default2.bothArrows })
              ]
            }
          )
        },
        `tableHeader_${index}`
      )) }) }),
      /* @__PURE__ */ jsx70("tbody", { children: filteredResultset.map((row) => /* @__PURE__ */ jsx70("tr", { children: row.cells.map((cellContent, cellIndex) => /* @__PURE__ */ jsx70("td", { children: cellContent.displayValue }, `resultSetTableCellContent_${cellIndex}`)) }, `resultSetTableCell_${row.id}`)) })
    ] }),
    !hidePaginator && /* @__PURE__ */ jsx70(
      Paginator_default,
      {
        totalItems: rows.length,
        itemsPerPage,
        itemsPerPageOptions,
        itemsPerPageFunction,
        currentPage: page,
        showGoToPage,
        onPageChange: goToPage,
        tabIndex
      }
    )
  ] }) });
};
var calculateWidth10 = (margin) => `calc(100% - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})`;
var DxcResultsetTableContainer = styled62.div`
  width: ${(props) => calculateWidth10(props.margin)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var HeaderContainer3 = styled62.span`
  display: flex;
  align-items: center;
  justify-content: ${(props) => props.theme.headerTextAlign === "center" ? "center" : props.theme.headerTextAlign === "right" ? "flex-end" : "flex-start"};
  gap: ${coreTokens_default.spacing_8};
  width: fit-content;
  border: 1px solid transparent;
  border-radius: 2px;
  cursor: ${(props) => props.isSortable ? "pointer" : "default"};

  ${(props) => props.isSortable && `&:focus {
      outline: #0095ff solid 2px;
    }`}
`;
var SortIcon = styled62.span`
  display: flex;
  height: 14px;
  width: 14px;
  color: ${(props) => props.theme.sortIconColor};

  svg {
    height: 100%;
    width: 100%;
  }
`;
DxcResultsetTable.ActionsCell = DxcActionsCell;
var ResultsetTable_default = DxcResultsetTable;

// src/slider/Slider.tsx
import { forwardRef as forwardRef14, useContext as useContext45, useId as useId17, useMemo as useMemo17, useState as useState30 } from "react";
import styled63, { ThemeProvider as ThemeProvider32 } from "styled-components";
import { jsx as jsx71, jsxs as jsxs50 } from "react/jsx-runtime";
var sizes6 = {
  medium: "360px",
  large: "480px",
  fillParent: "100%"
};
var calculateWidth11 = (margin, size) => size === "fillParent" ? `calc(${sizes6[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes6[size];
var getChromeStyles = () => `
  width: 100%;
  margin-right: 4px;`;
var getFirefoxStyles = () => `
  width: calc(100% - 16px);
  margin-right: 3px;`;
var Container3 = styled63.div`
  display: flex;
  flex-direction: column;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
  width: ${(props) => calculateWidth11(props.margin, props.size)};
`;
var Label10 = styled63.label`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
`;
var HelperText7 = styled63.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
`;
var SliderInput = styled63.input`
  width: 100%;
  min-width: 240px;
  height: ${(props) => props.theme.trackLineThickness};
  display: inline-block;
  vertical-align: middle;
  -webkit-appearance: none;
  background-color: ${(props) => props.disabled ? `${props.theme.disabledTotalLineColor}61` : props.theme.totalLineColor};
  background-image: ${(props) => props.disabled ? `linear-gradient(${props.theme.disabledTrackLineColor}, ${props.theme.disabledTrackLineColor})` : `linear-gradient(${props.theme.trackLineColor}, ${props.theme.trackLineColor})`};
  background-repeat: no-repeat;
  background-size: ${(props) => props.value != null && props.min != null && props.max != null && `${(props.value - props.min) * 100 / (props.max - props.min)}% 100%`};
  border-radius: 5px;
  cursor: ${(props) => props.disabled ? "not-allowed" : "pointer"};
  &::-webkit-slider-runnable-track {
    -webkit-appearance: none;
    box-shadow: none;
    border: none;
    background: transparent;
    margin: 0px -8px;
  }

  &::-webkit-slider-thumb {
    -webkit-appearance: none;
    border: none;
    height: ${(props) => props.theme.thumbHeight};
    width: ${(props) => props.theme.thumbWidth};
    border-radius: 25px;
    background: ${(props) => props.disabled ? props.theme.disabledThumbBackgroundColor : props.theme.thumbBackgroundColor};
    &:active {
      ${(props) => !props.disabled && `
          background: ${props.theme.activeThumbBackgroundColor};
            transform: scale(1.16667);`}
    }
    &:hover {
      ${(props) => !props.disabled && `height: ${props.theme.hoverThumbHeight};
          width: ${props.theme.hoverThumbWidth};
          transform: scale(1.16667);
          transform-origin: center center;
          background: ${props.theme.hoverThumbBackgroundColor};`}
    }
  }
  &::-moz-range-track {
    -webkit-appearance: none;
    box-shadow: none;
    border: none;
    background: transparent;
  }
  &::-moz-range-thumb {
    -webkit-appearance: none;
    border: none;
    height: ${(props) => props.theme.thumbHeight};
    width: ${(props) => props.theme.thumbWidth};
    border-radius: 25px;
    background: ${(props) => props.disabled ? props.theme.disabledThumbBackgroundColor : props.theme.thumbBackgroundColor};
    &:active {
      background: ${(props) => props.theme.activeThumbBackgroundColor};
      transform: scale(1.16667);
    }
    &:hover {
      ${(props) => !props.disabled && `height: ${props.theme.hoverThumbHeight};
          width: ${props.theme.hoverThumbWidth};
          transform: scale(1.16667);
          transform-origin: center center;
          background: ${props.theme.hoverThumbBackgroundColor};`}
    }
  }
  &:focus {
    outline: none;
    &::-webkit-slider-thumb {
      outline: ${(props) => props.disabled ? props.theme.disabledFocusColor : props.theme.focusColor} auto 1px;
      outline-offset: 2px;
    }
    &::-moz-range-thumb {
      outline: ${(props) => props.disabled ? props.theme.disabledFocusColor : props.theme.focusColor} auto 1px;
      outline-offset: 2px;
    }
  }
`;
var SliderContainer = styled63.div`
  display: flex;
  height: 48px;
  align-items: center;
`;
var LimitLabelContainer = styled63.span`
  color: ${(props) => props.disabled ? props.theme.disabledLimitValuesFontColor : props.theme.limitValuesFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.limitValuesFontSize};
  font-style: ${(props) => props.theme.limitValuesFontStyle};
  font-weight: ${(props) => props.theme.limitValuesFontWeight};
  letter-spacing: ${(props) => props.theme.limitValuesFontLetterSpacing};
  white-space: nowrap;
`;
var MinLabelContainer = styled63(LimitLabelContainer)`
  margin-right: ${(props) => props.theme.floorLabelMarginRight};
`;
var MaxLabelContainer = styled63(LimitLabelContainer)`
  margin-left: ${(props) => props.step === 1 ? props.theme.ceilLabelMarginLeft : "1.25rem"};
`;
var SliderInputContainer = styled63.div`
  position: relative;
  width: 100%;
  height: 24px;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-right: -2px;
  padding-top: 1px;
  z-index: 0;
`;
var MarksContainer = styled63.div`
  ${(props) => props.isFirefox ? getFirefoxStyles() : getChromeStyles()}
  position: absolute;
  pointer-events: none;
  height: 100%;
  display: flex;
  align-items: center;
`;
var TickMark = styled63.span`
  position: absolute;
  background: ${(props) => props.disabled ? props.theme.disabledTickBackgroundColor : props.theme.tickBackgroundColor};
  height: ${(props) => props.theme.tickHeight};
  width: ${(props) => props.theme.tickWidth};
  border-radius: 18px;
  left: ${(props) => `calc(${props.stepPosition} * 100%)`};
  z-index: ${(props) => props.stepValue != null && `${props.stepPosition <= props.stepValue ? "-1" : "0"}`};
`;
var TextInputContainer2 = styled63.div`
  margin-left: ${(props) => props.theme.inputMarginLeft};
  max-width: 70px;
`;
var DxcSlider = forwardRef14(
  ({
    label = "",
    name = "",
    defaultValue,
    value,
    helperText = "",
    minValue = 0,
    maxValue = 100,
    step = 1,
    showLimitsValues = false,
    showInput = false,
    disabled = false,
    marks = false,
    onChange,
    onDragEnd,
    labelFormatCallback,
    margin,
    size = "fillParent",
    ariaLabel = "Slider"
  }, ref) => {
    const labelId = `label-${useId17()}`;
    const [innerValue, setInnerValue] = useState30(defaultValue ?? 0);
    const [dragging, setDragging] = useState30(false);
    const colorsTheme = useContext45(HalstackContext);
    const isFirefox = navigator.userAgent.indexOf("Firefox") !== -1;
    const minLabel = useMemo17(
      () => labelFormatCallback ? labelFormatCallback(minValue) : minValue,
      [labelFormatCallback, minValue]
    );
    const maxLabel = useMemo17(
      () => labelFormatCallback ? labelFormatCallback(maxValue) : maxValue,
      [labelFormatCallback, maxValue]
    );
    const tickMarks = useMemo17(() => {
      const numberOfMarks = Math.floor(maxValue / step - minValue / step);
      const range = maxValue - minValue;
      const ticks = [];
      if (marks) {
        for (let index = 0; index <= numberOfMarks; index++) {
          ticks.push(
            /* @__PURE__ */ jsx71(
              TickMark,
              {
                disabled,
                stepPosition: step * index / range,
                stepValue: (value ?? innerValue) / maxValue
              },
              `tickmark-${index}`
            )
          );
        }
        return ticks;
      }
      return null;
    }, [minValue, maxValue, step, value, innerValue]);
    const handleSliderChange = (event) => {
      const intValue = parseInt(event.target.value, 10);
      if (intValue !== value || intValue !== innerValue) {
        setInnerValue(intValue);
      }
      onChange?.(intValue);
    };
    const handleSliderDragging = () => {
      setDragging(true);
    };
    const handleSliderOnChangeCommitted = (event) => {
      const intValue = parseInt(event.target.value, 10);
      if (dragging) {
        setDragging(false);
        onDragEnd?.(intValue);
      }
    };
    const handlerInputChange = (event) => {
      const intValue = parseInt(event.value, 10);
      if (!Number.isNaN(intValue)) {
        if (value == null) setInnerValue(intValue > maxValue ? maxValue : intValue);
        onChange?.(intValue > maxValue ? maxValue : intValue);
      }
    };
    return /* @__PURE__ */ jsx71(ThemeProvider32, { theme: colorsTheme.slider, children: /* @__PURE__ */ jsxs50(Container3, { margin, size, ref, children: [
      label && /* @__PURE__ */ jsx71(Label10, { id: labelId, disabled, children: label }),
      /* @__PURE__ */ jsx71(HelperText7, { disabled, children: helperText }),
      /* @__PURE__ */ jsxs50(SliderContainer, { children: [
        showLimitsValues && /* @__PURE__ */ jsx71(MinLabelContainer, { disabled, children: minLabel }),
        /* @__PURE__ */ jsxs50(SliderInputContainer, { children: [
          /* @__PURE__ */ jsx71(
            SliderInput,
            {
              role: "slider",
              type: "range",
              value: value != null && value >= 0 ? value : innerValue,
              min: minValue,
              max: maxValue,
              step,
              disabled,
              "aria-labelledby": label ? labelId : void 0,
              "aria-orientation": "horizontal",
              "aria-valuemax": maxValue,
              "aria-valuemin": minValue,
              "aria-valuenow": value != null && value >= 0 ? value : innerValue,
              "aria-label": label ? void 0 : ariaLabel,
              onChange: handleSliderChange,
              onMouseUp: handleSliderOnChangeCommitted,
              onMouseDown: handleSliderDragging
            }
          ),
          marks && /* @__PURE__ */ jsx71(MarksContainer, { isFirefox, children: tickMarks })
        ] }),
        showLimitsValues && /* @__PURE__ */ jsx71(MaxLabelContainer, { disabled, step, children: maxLabel }),
        showInput && /* @__PURE__ */ jsx71(TextInputContainer2, { children: /* @__PURE__ */ jsx71(
          TextInput_default,
          {
            name,
            value: value != null && value >= 0 ? value.toString() : innerValue.toString(),
            disabled,
            onChange: handlerInputChange,
            size: "fillParent"
          }
        ) })
      ] })
    ] }) });
  }
);
var Slider_default = DxcSlider;

// src/spinner/Spinner.tsx
import { useContext as useContext46, useId as useId18, useMemo as useMemo18 } from "react";
import styled64, { ThemeProvider as ThemeProvider33 } from "styled-components";
import { jsx as jsx72, jsxs as jsxs51 } from "react/jsx-runtime";
var DxcSpinner = ({
  label,
  value,
  showValue = false,
  mode = "large",
  margin,
  ariaLabel = "Spinner"
}) => {
  const labelId = useId18();
  const colorsTheme = useContext46(HalstackContext);
  const determinated = useMemo18(() => value != null && value >= 0 && value <= 100, [value]);
  return /* @__PURE__ */ jsx72(ThemeProvider33, { theme: colorsTheme.spinner, children: /* @__PURE__ */ jsx72(DXCSpinner, { margin, mode, children: /* @__PURE__ */ jsxs51(SpinnerContainer, { mode, children: [
    mode === "overlay" && /* @__PURE__ */ jsx72(BackOverlay, {}),
    /* @__PURE__ */ jsx72(BackgroundSpinner, { children: mode === "small" ? /* @__PURE__ */ jsx72(SVGBackground, { viewBox: "0 0 16 16", children: /* @__PURE__ */ jsx72(CircleBackground, { cx: "8", cy: "8", r: "6", mode }) }) : /* @__PURE__ */ jsx72(SVGBackground, { viewBox: "0 0 140 140", children: /* @__PURE__ */ jsx72(CircleBackground, { cx: "70", cy: "70", r: "65", mode }) }) }),
    /* @__PURE__ */ jsx72(
      Spinner,
      {
        role: "progressbar",
        "aria-valuenow": determinated && showValue ? value : void 0,
        "aria-valuemin": determinated ? 0 : void 0,
        "aria-valuemax": determinated ? 100 : void 0,
        "aria-labelledby": label && mode !== "small" ? labelId : void 0,
        "aria-label": !label ? ariaLabel : mode === "small" ? ariaLabel : void 0,
        children: mode === "small" ? /* @__PURE__ */ jsx72(SVGSpinner, { viewBox: "0 0 16 16", determinated, children: /* @__PURE__ */ jsx72(CircleSpinner, { cx: "8", cy: "8", r: "6", mode, determinated, value }) }) : /* @__PURE__ */ jsx72(SVGSpinner, { viewBox: "0 0 140 140", determinated, children: /* @__PURE__ */ jsx72(CircleSpinner, { cx: "70", cy: "70", r: "65", mode, determinated, value }) })
      }
    ),
    mode !== "small" && /* @__PURE__ */ jsxs51(LabelsContainer3, { children: [
      label && /* @__PURE__ */ jsx72(SpinnerLabel, { id: labelId, mode, children: label }),
      (value || value === 0) && showValue && /* @__PURE__ */ jsxs51(SpinnerProgress, { value, mode, showValue, children: [
        value,
        "%"
      ] })
    ] })
  ] }) }) });
};
var determinateValue = (value, strokeDashArray) => {
  let val = 0;
  if (value != null && value >= 0 && value <= 100) {
    val = strokeDashArray * (1 - value / 100);
  }
  return val;
};
var DXCSpinner = styled64.div`
  height: ${(props) => props.mode === "overlay" ? "100vh" : ""};
  width: ${(props) => props.mode === "overlay" ? "100vw" : ""};
  display: ${(props) => props.mode === "overlay" ? "flex" : ""};
  position: ${(props) => props.mode === "overlay" ? "fixed" : ""};
  top: ${(props) => props.mode === "overlay" ? 0 : ""};
  left: ${(props) => props.mode === "overlay" ? 0 : ""};
  justify-content: ${(props) => props.mode === "overlay" ? "center" : ""};
  align-items: ${(props) => props.mode === "overlay" ? "center" : ""};
  z-index: ${(props) => props.mode === "overlay" ? 1300 : ""};

  margin: ${(props) => props.mode !== "overlay" ? props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px" : ""};
  margin-top: ${(props) => props.mode !== "overlay" ? props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : "" : ""};
  margin-right: ${(props) => props.mode !== "overlay" ? props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : "" : ""};
  margin-bottom: ${(props) => props.mode !== "overlay" ? props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : "" : ""};
  margin-left: ${(props) => props.mode !== "overlay" ? props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : "" : ""};
`;
var SpinnerContainer = styled64.div`
  align-items: center;
  display: flex;
  height: ${(props) => props.mode === "small" ? "16px" : "140px"};
  width: ${(props) => props.mode === "small" ? "16px" : "140px"};
  justify-content: center;
  position: relative;
  background-color: transparent;

  @keyframes spinner-svg {
    0% {
      transform: rotateZ(0deg);
    }
    100% {
      transform: rotateZ(360deg);
    }
  }
  @keyframes svg-circle-large {
    0% {
      stroke-dashoffset: 400;
      transform: rotate(0);
    }

    50% {
      stroke-dashoffset: 75;
      transform: rotate(45deg);
    }

    100% {
      stroke-dashoffset: 400;
      transform: rotate(360deg);
    }
  }
  @keyframes svg-circle-small {
    0% {
      stroke-dashoffset: 35;
      transform: rotate(0);
    }

    50% {
      stroke-dashoffset: 8;
      transform: rotate(45deg);
    }

    100% {
      stroke-dashoffset: 35;
      transform: rotate(360deg);
    }
  }
`;
var BackOverlay = styled64.div`
  width: 100vw;
  height: 100vh;
  opacity: 1;
  transition: opacity 225ms cubic-bezier(0.4, 0, 0.2, 1) 0ms;
  position: fixed;
  top: 0;
  left: 0;
  background-color: ${(props) => `${props.theme.overlayBackgroundColor}`};
  opacity: ${(props) => `${props.theme.overlayOpacity}`};
`;
var BackgroundSpinner = styled64.div`
  height: inherit;
  width: inherit;
  position: absolute;
`;
var SVGBackground = styled64.svg`
  height: inherit;
  width: inherit;
`;
var CircleBackground = styled64.circle`
  animation: none;
  fill: transparent;
  stroke: ${(props) => `${props.theme.totalCircleColor}`};
  stroke-dasharray: ${(props) => props.mode !== "small" ? "409" : "38"};
  stroke-linecap: initial;
  stroke-width: ${(props) => props.mode !== "small" ? "8.5px" : "2px"};
  transform-origin: 50% 50%;
  vector-effect: non-scaling-stroke;
`;
var Spinner = styled64.div`
  height: inherit;
  width: inherit;
  position: relative;
`;
var SVGSpinner = styled64.svg`
  height: inherit;
  width: inherit;
  transform: rotate(-90deg);
  top: 0;
  left: 0;
  transform-origin: center;
  overflow: visible;
  animation: ${(props) => !props.determinated ? "1.4s linear infinite both spinner-svg" : ""};
`;
var CircleSpinner = styled64.circle`
  fill: transparent;
  stroke-linecap: initial;
  vector-effect: non-scaling-stroke;
  animation: ${(props) => props.determinated ? "none" : props.mode !== "small" ? "1.4s ease-in-out infinite both svg-circle-large" : "1.4s ease-in-out infinite both svg-circle-small"};
  stroke: ${(props) => props.mode === "overlay" ? props.theme.trackCircleColorOverlay : props.theme.trackCircleColor};
  transform-origin: ${(props) => !props.determinated ? "50% 50%" : ""};
  stroke-dasharray: ${(props) => props.mode !== "small" ? "409" : "38"};
  stroke-width: ${(props) => props.mode !== "small" ? "8.5px" : "2px"};
  stroke-dashoffset: ${(props) => props.determinated ? props.mode !== "small" ? determinateValue(props.value, 409) : determinateValue(props.value, 38) : ""};
`;
var LabelsContainer3 = styled64.div`
  position: absolute;
  margin: 0 auto;
  width: 110px;
  text-align: center;
`;
var SpinnerLabel = styled64.p`
  margin: 0;
  width: 100%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  font-family: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelFontFamily : props.theme.labelFontFamily};
  font-weight: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelFontWeight : props.theme.labelFontWeight};
  font-size: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelFontSize : props.theme.labelFontSize};
  font-style: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelFontStyle : props.theme.labelFontStyle};
  color: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelFontColor : props.theme.labelFontColor};
  text-align: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelTextAlign : props.theme.labelTextAlign};
  letter-spacing: ${(props) => props.mode === "overlay" ? props.theme.overlayLabelLetterSpacing : props.theme.labelLetterSpacing};
`;
var SpinnerProgress = styled64.p`
  margin: 0;
  width: 100%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  display: ${(props) => props.value && props.showValue === true && "block" || "none"};
  font-family: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueFontFamily : props.theme.progressValueFontFamily};
  font-weight: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueFontWeight : props.theme.progressValueFontWeight};
  font-size: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueFontSize : props.theme.progressValueFontSize};
  font-style: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueFontStyle : props.theme.progressValueFontStyle};
  color: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueFontColor : props.theme.progressValueFontColor};
  text-align: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueTextAlign : props.theme.progressValueTextAlign};
  letter-spacing: ${(props) => props.mode === "overlay" ? props.theme.overlayProgressValueLetterSpacing : props.theme.progressValueLetterSpacing};
`;
var Spinner_default = DxcSpinner;

// src/status-light/StatusLight.tsx
import styled65 from "styled-components";
import { jsx as jsx73, jsxs as jsxs52 } from "react/jsx-runtime";
var DxcStatusLight = ({ mode = "default", label, size = "medium" }) => {
  return /* @__PURE__ */ jsxs52(StatusLightContainer, { size, "aria-label": `${mode}: ${label}`, role: "status", children: [
    /* @__PURE__ */ jsx73(StatusDot, { mode, size, "aria-hidden": "true" }),
    /* @__PURE__ */ jsx73(StatusLabel, { mode, size, children: label })
  ] });
};
var StatusLightContainer = styled65.div`
  display: inline-flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_8};
`;
var StatusDot = styled65.div`
  width: ${({ size }) => size === "small" && coreTokens_default.type_scale_01 || size === "medium" && coreTokens_default.type_scale_02 || size === "large" && coreTokens_default.type_scale_03 || coreTokens_default.type_scale_02};
  height: ${({ size }) => size === "small" && coreTokens_default.type_scale_01 || size === "medium" && coreTokens_default.type_scale_02 || size === "large" && coreTokens_default.type_scale_03 || coreTokens_default.type_scale_02};
  border-radius: 50%;
  background-color: ${({ mode }) => mode === "default" && coreTokens_default.color_grey_700 || mode === "error" && coreTokens_default.color_red_700 || mode === "info" && coreTokens_default.color_blue_700 || mode === "success" && coreTokens_default.color_green_700 || mode === "warning" && coreTokens_default.color_orange_700 || coreTokens_default.color_grey_700};
`;
var StatusLabel = styled65.span`
  font-size: ${({ size }) => size === "small" && coreTokens_default.type_scale_01 || size === "medium" && coreTokens_default.type_scale_02 || size === "large" && coreTokens_default.type_scale_03 || coreTokens_default.type_scale_02};
  font-family: ${coreTokens_default.type_sans};
  font-style: ${coreTokens_default.type_normal};
  font-weight: ${coreTokens_default.type_semibold};
  color: ${({ mode }) => mode === "default" && coreTokens_default.color_grey_700 || mode === "error" && coreTokens_default.color_red_700 || mode === "info" && coreTokens_default.color_blue_700 || mode === "success" && coreTokens_default.color_green_700 || mode === "warning" && coreTokens_default.color_orange_700 || coreTokens_default.color_grey_700};
  text-align: center;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
`;
var StatusLight_default = DxcStatusLight;

// src/switch/Switch.tsx
import { forwardRef as forwardRef15, useContext as useContext47, useId as useId19, useRef as useRef19, useState as useState31 } from "react";
import styled66, { ThemeProvider as ThemeProvider34 } from "styled-components";
import { Fragment as Fragment13, jsx as jsx74, jsxs as jsxs53 } from "react/jsx-runtime";
var DxcSwitch = forwardRef15(
  ({
    defaultChecked = false,
    checked,
    value,
    label = "",
    labelPosition = "before",
    name = "",
    disabled = false,
    optional = false,
    onChange,
    margin,
    size = "fitContent",
    tabIndex = 0,
    ariaLabel = "Switch"
  }, ref) => {
    const switchId = `switch-${useId19()}`;
    const labelId = `label-${switchId}`;
    const [innerChecked, setInnerChecked] = useState31(defaultChecked);
    const colorsTheme = useContext47(HalstackContext);
    const translatedLabels = useContext47(HalstackLanguageContext);
    const refTrack = useRef19(null);
    const handleOnKeyDown = (event) => {
      switch (event.key) {
        case "Enter":
        case " ":
          event.preventDefault();
          refTrack.current?.focus();
          setInnerChecked(!(checked ?? innerChecked));
          onChange?.(!(checked ?? innerChecked));
          break;
        default:
          break;
      }
    };
    const handlerSwitchChange = () => {
      if (checked == null) {
        setInnerChecked((currentInnerChecked) => !currentInnerChecked);
      }
      onChange?.(checked ? !checked : !innerChecked);
    };
    return /* @__PURE__ */ jsx74(ThemeProvider34, { theme: colorsTheme.switch, children: /* @__PURE__ */ jsxs53(
      SwitchContainer,
      {
        margin,
        size,
        onKeyDown: handleOnKeyDown,
        disabled,
        onClick: !disabled ? handlerSwitchChange : void 0,
        ref,
        children: [
          labelPosition === "before" && label && /* @__PURE__ */ jsxs53(LabelContainer4, { id: labelId, labelPosition, disabled, label, children: [
            label,
            " ",
            optional && /* @__PURE__ */ jsx74(Fragment13, { children: translatedLabels.formFields.optionalLabel })
          ] }),
          /* @__PURE__ */ jsx74(
            ValueInput4,
            {
              type: "checkbox",
              name,
              "aria-hidden": true,
              value,
              disabled,
              checked: checked ?? innerChecked,
              readOnly: true
            }
          ),
          /* @__PURE__ */ jsx74(SwitchBase, { children: /* @__PURE__ */ jsx74(
            SwitchTrack,
            {
              role: "switch",
              "aria-checked": checked ?? innerChecked,
              "aria-disabled": disabled,
              disabled,
              "aria-labelledby": labelId,
              "aria-label": label ? void 0 : ariaLabel,
              tabIndex: !disabled ? tabIndex : -1,
              ref: refTrack
            }
          ) }),
          labelPosition === "after" && label && /* @__PURE__ */ jsxs53(LabelContainer4, { id: labelId, labelPosition, disabled, label, children: [
            optional && /* @__PURE__ */ jsx74(Fragment13, { children: translatedLabels.formFields.optionalLabel }),
            " ",
            label
          ] })
        ]
      }
    ) });
  }
);
var sizes7 = {
  small: "60px",
  medium: "240px",
  large: "480px",
  fillParent: "100%",
  fitContent: "fit-content"
};
var calculateWidth12 = (margin, size) => size === "fillParent" ? `calc(${sizes7[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes7[size];
var getDisabledColor2 = (theme, element, subElement) => {
  switch (element) {
    case "track":
      switch (subElement) {
        case "check":
          return theme.disabledCheckedTrackBackgroundColor;
        case "uncheck":
          return theme.disabledUncheckedTrackBackgroundColor;
        default:
          return void 0;
      }
    case "thumb":
      switch (subElement) {
        case "check":
          return theme.disabledCheckedThumbBackgroundColor;
        case "uncheck":
          return theme.disabledUncheckedThumbBackgroundColor;
        default:
          return void 0;
      }
    case "label":
      return theme.disabledLabelFontColor;
    default:
      return void 0;
  }
};
var getNotDisabledColor = (theme, element, subElement) => {
  switch (element) {
    case "track":
      switch (subElement) {
        case "check":
          return theme.checkedTrackBackgroundColor;
        case "uncheck":
          return theme.uncheckedTrackBackgroundColor;
        default:
          return void 0;
      }
      break;
    case "thumb":
      switch (subElement) {
        case "check":
          return theme.checkedThumbBackgroundColor;
        case "uncheck":
          return theme.uncheckedThumbBackgroundColor;
        default:
          return void 0;
      }
      break;
    case "label":
      return theme.labelFontColor;
    default:
      return void 0;
  }
};
var SwitchContainer = styled66.div`
  display: inline-flex;
  align-items: center;
  width: ${(props) => calculateWidth12(props.margin, props.size)};
  height: 40px;
  cursor: ${(props) => props.disabled === true ? "not-allowed" : "pointer"};

  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var LabelContainer4 = styled66.span`
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: ${(props) => props.disabled ? getDisabledColor2(props.theme, "label") : getNotDisabledColor(props.theme, "label")};
  opacity: 1;
  font-family: ${(props) => props.theme.labelFontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.disabled ? props.theme.disabledLabelFontStyle : props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};

  ${(props) => !props.label ? "margin: 0px;" : props.labelPosition === "after" ? `margin-left: ${props.theme.spaceBetweenLabelSwitch};` : `margin-right: ${props.theme.spaceBetweenLabelSwitch};`};

  ${(props) => props.labelPosition === "before" && "order: -1"}
`;
var SwitchBase = styled66.label`
  display: flex;
  align-items: center;
  justify-content: space-between;
  cursor: pointer;
  margin: 0px 12px;
`;
var ValueInput4 = styled66.input`
  display: none;
`;
var SwitchTrack = styled66.span`
  border-radius: 15px;
  width: ${(props) => props.theme.trackWidth};
  height: ${(props) => props.theme.trackHeight};
  position: relative;
  cursor: ${(props) => props.disabled ? "not-allowed" : "pointer"};

  &:focus-visible {
    outline: none;
    ::before {
      outline: ${(props) => `${props.theme.thumbFocusColor} solid 2px`};
      outline-offset: 6px;
    }
  }

  /* Thumb element */
  ::before {
    content: "";
    transform: initial;
    position: absolute;
    width: ${(props) => props.theme.thumbWidth};
    height: ${(props) => props.theme.thumbHeight};
    border-radius: 50%;
    box-shadow:
      0px 2px 1px -1px rgb(0 0 0 / 20%),
      0px 1px 1px 0px rgb(0 0 0 / 14%),
      0px 1px 3px 0px rgb(0 0 0 / 12%);
    bottom: -6px;
    left: -4px;
    transform: translateX(0px);
    background-color: ${(props) => props.disabled ? getDisabledColor2(props.theme, "thumb", "uncheck") : getNotDisabledColor(props.theme, "thumb", "uncheck")};
  }

  /* Unchecked */
  background-color: ${(props) => props.disabled ? getDisabledColor2(props.theme, "track", "uncheck") : getNotDisabledColor(props.theme, "track", "uncheck")};

  /* Checked */
  &[aria-checked="true"] {
    background-color: ${(props) => props.disabled ? getDisabledColor2(props.theme, "track", "check") : getNotDisabledColor(props.theme, "track", "check")};
    ::before {
      transform: translateX(${(props) => props.theme.thumbShift});
      background-color: ${(props) => props.disabled ? getDisabledColor2(props.theme, "thumb", "check") : getNotDisabledColor(props.theme, "thumb", "check")};
    }
  }
`;
var Switch_default = DxcSwitch;

// src/tabs/Tabs.tsx
import {
  Children as Children5,
  isValidElement as isValidElement2,
  useCallback as useCallback12,
  useContext as useContext50,
  useEffect as useEffect25,
  useMemo as useMemo20,
  useRef as useRef22,
  useState as useState33
} from "react";
import styled70, { ThemeProvider as ThemeProvider36 } from "styled-components";

// src/tabs/TabsContext.tsx
import { createContext as createContext9 } from "react";
var TabsContext_default = createContext9(null);

// src/tabs/Tab.tsx
import { forwardRef as forwardRef16, useContext as useContext48, useEffect as useEffect23, useRef as useRef20 } from "react";
import styled67 from "styled-components";
import { jsx as jsx75, jsxs as jsxs54 } from "react/jsx-runtime";
var DxcTab2 = forwardRef16(
  ({
    icon,
    label,
    title,
    tabId = label,
    disabled = false,
    active,
    notificationNumber = false,
    onClick = () => {
    },
    onHover = () => {
    }
  }, ref) => {
    const tabRef = useRef20(null);
    const {
      iconPosition = "top",
      tabIndex = 0,
      focusedTab,
      isControlled,
      activeTab,
      hasLabelAndIcon = false,
      setActiveTab,
      setActiveIndicatorWidth,
      setActiveIndicatorLeft
    } = useContext48(TabsContext_default) ?? {};
    useEffect23(() => {
      if (focusedTab === tabId) {
        tabRef?.current?.focus();
      }
    }, [focusedTab, tabId]);
    useEffect23(() => {
      if (activeTab === tabId) {
        setActiveIndicatorWidth?.(tabRef.current?.offsetWidth ?? 0);
        setActiveIndicatorLeft?.(tabRef.current?.offsetLeft ?? 0);
      }
    }, [activeTab, tabId, setActiveIndicatorWidth, setActiveIndicatorLeft]);
    useEffect23(() => {
      if (active) {
        setActiveTab?.(tabId ?? label ?? "");
      }
    }, [active, label, setActiveTab]);
    const handleOnKeyDown = (event) => {
      switch (event.key) {
        case " ":
        case "Enter":
          event.preventDefault();
          tabRef?.current?.click();
          break;
        default:
          break;
      }
    };
    return /* @__PURE__ */ jsx75(Tooltip, { label: title, children: /* @__PURE__ */ jsxs54(
      TabContainer2,
      {
        role: "tab",
        type: "button",
        tabIndex: activeTab === tabId && !disabled ? tabIndex : -1,
        disabled,
        "aria-label": label ?? tabId ?? "tab",
        "aria-selected": activeTab === tabId,
        hasLabelAndIcon,
        iconPosition,
        ref: (anchorRef) => {
          tabRef.current = anchorRef;
          if (ref) {
            if (typeof ref === "function") {
              ref(anchorRef);
            } else {
              const currentRef = ref;
              currentRef.current = anchorRef;
            }
          }
        },
        onClick: () => {
          if (!isControlled) {
            setActiveTab?.(tabId ?? "");
            console.log(tabId);
          }
          onClick();
        },
        onMouseEnter: () => onHover(),
        onKeyDown: handleOnKeyDown,
        children: [
          /* @__PURE__ */ jsxs54(
            MainLabelContainer,
            {
              notificationNumber,
              hasLabelAndIcon,
              iconPosition,
              disabled,
              children: [
                icon && /* @__PURE__ */ jsx75(TabIconContainer2, { hasLabelAndIcon, iconPosition, children: typeof icon === "string" ? /* @__PURE__ */ jsx75(Icon_default, { icon }) : icon }),
                label && /* @__PURE__ */ jsx75(Label11, { disabled, active: activeTab === tabId, label, children: label })
              ]
            }
          ),
          notificationNumber && !disabled && /* @__PURE__ */ jsx75(BadgeContainer2, { hasLabelAndIcon, iconPosition, children: /* @__PURE__ */ jsx75(
            Badge_default,
            {
              mode: "notification",
              size: "small",
              label: typeof notificationNumber === "number" ? notificationNumber : void 0
            }
          ) })
        ]
      }
    ) });
  }
);
var TabContainer2 = styled67.button`
  text-transform: ${(props) => props.theme.fontTextTransform};
  overflow: hidden;
  flex-shrink: 0;
  border: 0;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  user-select: none;
  vertical-align: middle;
  justify-content: center;
  min-width: 90px;
  max-width: 360px;
  padding: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "12px 16px" || "8px 16px"};
  height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "47px" || "71px"};
  min-height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "47px" || "71px"};
  background-color: ${(props) => props.theme.unselectedBackgroundColor};

  &:hover {
    background-color: ${(props) => `${props.theme.hoverBackgroundColor} !important`};
  }
  &:active {
    background-color: ${(props) => `${props.theme.pressedBackgroundColor} !important`};
  }
  &:focus {
    outline: ${(props) => props.theme.focusOutline} solid 1px;
    outline-offset: -1px;
  }

  svg,
  span:before {
    color: ${(props) => props.theme.unselectedIconColor};
  }

  &[aria-selected="true"] {
    background-color: ${(props) => props.theme.selectedBackgroundColor};
    svg,
    span:before {
      color: ${(props) => props.theme.selectedIconColor};
    }
    opacity: 1;
  }

  &:disabled {
    background-color: ${(props) => props.theme.unselectedBackgroundColor} !important;
    cursor: not-allowed !important;
    pointer-events: all;
    font-style: ${(props) => props.theme.disabledFontStyle};
    outline: none !important;

    svg,
    span:before {
      color: ${(props) => props.theme.disabledIconColor};
    }
    > div {
      opacity: 0.5;
    }
  }
`;
var BadgeContainer2 = styled67.div`
  margin-left: 12px;
  height: 100%;
  display: flex;
  align-items: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" ? "flex-start" : "center"};
  justify-content: flex-start;
  flex-direction: column;
`;
var MainLabelContainer = styled67.div`
  display: flex;
  flex-direction: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" && "column" || "row"};
  align-items: center;
  margin-left: ${(props) => props.notificationNumber && !props.disabled ? typeof props.notificationNumber === "number" ? "36px" : "18px" : "unset"};
`;
var Label11 = styled67.span`
  display: inline;
  color: ${(props) => props.disabled ? props.theme.disabledFontColor : props.active ? props.theme.selectedFontColor : props.theme.unselectedFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.disabled ? props.theme.disabledFontStyle : props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  text-align: center;
  letter-spacing: 0.025em;
  line-height: 1.715em;
  text-decoration: none;
  text-overflow: unset;
  white-space: normal;
  margin: 0;
`;
var TabIconContainer2 = styled67.div`
  display: flex;
  margin-bottom: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" && "8px" || ""};
  margin-right: ${(props) => props.hasLabelAndIcon && props.iconPosition === "left" && "12px" || ""};
  font-size: 22px;

  svg {
    height: 22px;
    width: 22px;
  }
`;
var Tab_default2 = DxcTab2;

// src/tabs/TabsLegacy.tsx
import { useCallback as useCallback11, useContext as useContext49, useEffect as useEffect24, useMemo as useMemo19, useRef as useRef21, useState as useState32 } from "react";
import styled69, { ThemeProvider as ThemeProvider35 } from "styled-components";

// src/tabs/TabLegacy.tsx
import { forwardRef as forwardRef17, memo as memo12 } from "react";
import styled68 from "styled-components";
import { jsx as jsx76, jsxs as jsxs55 } from "react/jsx-runtime";
var Tab2 = forwardRef17(
  ({ active, tab, tabIndex, hasLabelAndIcon, iconPosition, onClick, onMouseEnter, onMouseLeave }, ref) => /* @__PURE__ */ jsxs55(
    TabContainer3,
    {
      role: "tab",
      type: "button",
      tabIndex,
      disabled: tab.isDisabled,
      "aria-selected": active,
      hasLabelAndIcon,
      iconPosition,
      ref,
      onClick: () => {
        onClick();
      },
      onMouseEnter: () => {
        onMouseEnter();
      },
      onMouseLeave: () => {
        onMouseLeave();
      },
      children: [
        /* @__PURE__ */ jsxs55(
          MainLabelContainer2,
          {
            notificationNumber: tab.notificationNumber,
            hasLabelAndIcon,
            iconPosition,
            disabled: tab.isDisabled,
            children: [
              tab.icon && /* @__PURE__ */ jsx76(TabIconContainer3, { hasLabelAndIcon, iconPosition, children: typeof tab.icon === "string" ? /* @__PURE__ */ jsx76(Icon_default, { icon: tab.icon }) : tab.icon }),
              /* @__PURE__ */ jsx76(LabelContainer5, { disabled: tab.isDisabled, active, children: tab.label })
            ]
          }
        ),
        tab.notificationNumber && !tab.isDisabled && /* @__PURE__ */ jsx76(BadgeContainer3, { hasLabelAndIcon, iconPosition, children: /* @__PURE__ */ jsx76(
          Badge_default,
          {
            mode: "notification",
            size: "small",
            label: typeof tab.notificationNumber === "number" ? tab.notificationNumber : void 0
          }
        ) })
      ]
    }
  )
);
var TabContainer3 = styled68.button`
  text-transform: ${(props) => props.theme.fontTextTransform};
  overflow: hidden;
  flex-shrink: 0;
  border: 0;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  user-select: none;
  vertical-align: middle;
  justify-content: center;
  min-width: 90px;
  max-width: 360px;
  padding: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "12px 16px" || "8px 16px"};
  height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "47px" || "71px"};
  min-height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "47px" || "71px"};
  background-color: ${(props) => props.theme.unselectedBackgroundColor};

  &:hover {
    background-color: ${(props) => `${props.theme.hoverBackgroundColor} !important`};
  }
  &:active {
    background-color: ${(props) => `${props.theme.pressedBackgroundColor} !important`};
  }
  &:focus {
    outline: ${(props) => props.theme.focusOutline} solid 1px;
    outline-offset: -1px;
  }

  svg,
  span:before {
    color: ${(props) => props.theme.unselectedIconColor};
  }

  &[aria-selected="true"] {
    background-color: ${(props) => props.theme.selectedBackgroundColor};
    svg,
    span:before {
      color: ${(props) => props.theme.selectedIconColor};
    }
    opacity: 1;
  }

  &:disabled {
    background-color: ${(props) => props.theme.unselectedBackgroundColor} !important;
    cursor: not-allowed !important;
    pointer-events: all;
    font-style: ${(props) => props.theme.disabledFontStyle};
    outline: none !important;

    svg,
    span:before {
      color: ${(props) => props.theme.disabledIconColor};
    }
    > div {
      opacity: 0.5;
    }
  }
`;
var BadgeContainer3 = styled68.div`
  margin-left: 12px;
  height: 100%;
  display: flex;
  align-items: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" ? "flex-start" : "center"};
`;
var MainLabelContainer2 = styled68.div`
  display: flex;
  flex-direction: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" && "column" || "row"};
  align-items: center;
  margin-left: ${(props) => props.notificationNumber && !props.disabled ? typeof props.notificationNumber === "number" ? "36px" : "18px" : "unset"};
`;
var LabelContainer5 = styled68.span`
  display: inline;
  color: ${(props) => props.disabled ? props.theme.disabledFontColor : props.active ? props.theme.selectedFontColor : props.theme.unselectedFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.disabled ? props.theme.disabledFontStyle : props.theme.fontStyle};
  font-weight: ${(props) => props.active ? props.theme.pressedFontWeight : props.theme.fontWeight};
  text-align: center;
  letter-spacing: 0.025em;
  line-height: 1.715em;
  text-decoration: none;
  text-overflow: unset;
  white-space: normal;
  margin: 0;
`;
var TabIconContainer3 = styled68.div`
  display: flex;
  margin-bottom: ${(props) => props.hasLabelAndIcon && props.iconPosition === "top" && "8px" || ""};
  margin-right: ${(props) => props.hasLabelAndIcon && props.iconPosition === "left" && "12px" || ""};
  font-size: 22px;

  svg {
    height: 22px;
    width: 22px;
  }
`;
var TabLegacy_default = memo12(Tab2);

// src/tabs/TabsLegacy.tsx
import { jsx as jsx77, jsxs as jsxs56 } from "react/jsx-runtime";
var useResize = (refTabList) => {
  const [viewWidth, setViewWidth] = useState32(0);
  const handleWindowSizeChange = useCallback11(() => {
    setViewWidth(refTabList.current?.offsetWidth ?? 0);
  }, [refTabList]);
  useEffect24(() => {
    handleWindowSizeChange();
    window.addEventListener("resize", handleWindowSizeChange);
    return () => {
      window.removeEventListener("resize", handleWindowSizeChange);
    };
  }, [handleWindowSizeChange]);
  return viewWidth;
};
var DxcTabs = ({
  defaultActiveTabIndex,
  activeTabIndex,
  tabs,
  onTabClick,
  onTabHover,
  margin,
  iconPosition = "top",
  tabIndex = 0
}) => {
  const colorsTheme = useContext49(HalstackContext);
  const hasLabelAndIcon = tabs != null && tabs.filter((tab) => tab.label && tab.icon).length > 0;
  const firstFocus = tabs != null ? tabs.findIndex((tab) => !tab.isDisabled) : null;
  const [innerActiveTabIndex, setInnerActiveTabIndex] = useState32(
    tabs != null && defaultActiveTabIndex && !tabs[defaultActiveTabIndex]?.isDisabled ? defaultActiveTabIndex : firstFocus
  );
  const [activeIndicatorWidth, setActiveIndicatorWidth] = useState32(0);
  const [activeIndicatorLeft, setActiveIndicatorLeft] = useState32(0);
  const [translateScroll, setTranslateScroll] = useState32(0);
  const [scrollRightEnabled, setScrollRightEnabled] = useState32(true);
  const [scrollLeftEnabled, setScrollLeftEnabled] = useState32(false);
  const [countClick, setCountClick] = useState32(0);
  const [totalTabsWidth, setTotalTabsWidth] = useState32(0);
  const [currentFocusIndex, setCurrentFocusIndex] = useState32(activeTabIndex ?? innerActiveTabIndex);
  const [temporalFocusIndex, setTemporalFocusIndex] = useState32(activeTabIndex ?? innerActiveTabIndex);
  const [minHeightTabs, setMinHeightTabs] = useState32(0);
  const refTabs = useRef21([]);
  const refTabList = useRef21(null);
  const viewWidth = useResize(refTabList);
  const translatedLabels = useContext49(HalstackLanguageContext);
  const enabledIndicator = useMemo19(() => viewWidth < totalTabsWidth, [viewWidth]);
  useEffect24(() => {
    if (activeTabIndex != null || innerActiveTabIndex != null) {
      const sumWidth = refTabs.current?.reduce((count, obj) => count + obj.offsetWidth, 0);
      setTotalTabsWidth(sumWidth);
      setActiveIndicatorWidth(refTabs.current[activeTabIndex ?? innerActiveTabIndex]?.offsetWidth ?? 0);
      setActiveIndicatorLeft(refTabs.current[activeTabIndex ?? innerActiveTabIndex]?.offsetLeft ?? 0);
    }
  }, [activeTabIndex, innerActiveTabIndex]);
  useEffect24(() => {
    setMinHeightTabs((refTabList.current?.offsetHeight ?? 0) + 1);
  }, []);
  useEffect24(() => {
    if (activeTabIndex && activeTabIndex >= 0) {
      setActiveIndicatorWidth(refTabs.current[activeTabIndex]?.offsetWidth ?? 0);
      setActiveIndicatorLeft(refTabs.current[activeTabIndex]?.offsetLeft ?? 0);
    }
  }, [activeTabIndex]);
  const handleSelected = (newValue) => {
    if (activeTabIndex == null) {
      setInnerActiveTabIndex(newValue);
    }
    onTabClick?.(newValue);
    if (activeTabIndex === void 0) {
      setActiveIndicatorWidth(refTabs.current[newValue]?.offsetWidth ?? 0);
      setActiveIndicatorLeft(refTabs.current[newValue]?.offsetLeft ?? 0);
    }
  };
  const scrollLeft = () => {
    const scrollWidth = (refTabList?.current?.offsetHeight ?? 0) * 0.75;
    let moveX = 0;
    if (countClick <= scrollWidth) {
      moveX = 0;
      setScrollLeftEnabled(false);
      setScrollRightEnabled(true);
    } else {
      moveX = countClick - scrollWidth;
      setScrollRightEnabled(true);
      setScrollLeftEnabled(true);
    }
    setTranslateScroll(-moveX);
    setCountClick(moveX);
  };
  const scrollRight = () => {
    const offsetHeight = refTabList?.current?.offsetHeight ?? 0;
    const scrollWidth = offsetHeight * 0.75;
    let moveX = 0;
    if (countClick + scrollWidth + offsetHeight >= totalTabsWidth) {
      moveX = totalTabsWidth - offsetHeight;
      setScrollRightEnabled(false);
      setScrollLeftEnabled(true);
    } else {
      moveX = countClick + scrollWidth;
      setScrollLeftEnabled(true);
      setScrollRightEnabled(true);
    }
    setTranslateScroll(-moveX);
    setCountClick(moveX);
  };
  const setPreviousTabFocus = () => {
    if (tabs) {
      setTemporalFocusIndex((currentTemporalFocusIndex) => {
        if (currentTemporalFocusIndex != null) {
          let index = currentTemporalFocusIndex === 0 ? tabs.length - 1 : currentTemporalFocusIndex - 1;
          while (tabs[index]?.isDisabled) {
            index = index === 0 ? tabs.length - 1 : index - 1;
          }
          refTabs.current[index]?.focus({ preventScroll: true });
          setScrollFocus(index);
          return index;
        }
        return null;
      });
    }
  };
  const setNextTabFocus = () => {
    if (tabs) {
      setTemporalFocusIndex((currentTemporalFocusIndex) => {
        if (currentTemporalFocusIndex != null) {
          let index = currentTemporalFocusIndex === tabs.length - 1 ? 0 : currentTemporalFocusIndex + 1;
          while (tabs[index]?.isDisabled) {
            index = index === tabs.length - 1 ? 0 : index + 1;
          }
          refTabs.current[index]?.focus({ preventScroll: true });
          setScrollFocus(index);
          return index;
        }
        return null;
      });
    }
  };
  const setScrollFocus = (actualIndex) => {
    if (tabs) {
      let sumPrev = 0;
      refTabs.current?.forEach((item, index) => {
        if (index <= actualIndex) {
          sumPrev += item.offsetWidth;
        }
      });
      let moveX = 0;
      if (actualIndex === tabs.length - 1) {
        moveX = totalTabsWidth - (refTabList?.current?.offsetHeight || 0);
        setScrollLeftEnabled(true);
        setScrollRightEnabled(false);
      } else if (refTabList?.current?.offsetWidth && sumPrev > refTabList?.current?.offsetWidth) {
        moveX = sumPrev - (refTabList?.current?.offsetHeight || 0) + 1;
        setScrollLeftEnabled(true);
        setScrollRightEnabled(true);
      } else {
        setScrollLeftEnabled(false);
        setScrollRightEnabled(true);
      }
      setTranslateScroll(-moveX);
      setCountClick(moveX);
    }
  };
  const handleOnKeyDown = (event) => {
    switch (event.key) {
      case "Left":
      case "ArrowLeft":
        event.preventDefault();
        setPreviousTabFocus();
        break;
      case "Right":
      case "ArrowRight":
        event.preventDefault();
        setNextTabFocus();
        break;
      case "Enter":
      case " ":
        if (temporalFocusIndex != null) {
          event.preventDefault();
          setCurrentFocusIndex(temporalFocusIndex);
          handleSelected(temporalFocusIndex);
        }
        break;
      case "Tab":
        if (currentFocusIndex != null) {
          if (temporalFocusIndex !== currentFocusIndex) {
            event.preventDefault();
            setTemporalFocusIndex(currentFocusIndex);
            refTabs.current[currentFocusIndex]?.focus();
          }
          handleSelected(currentFocusIndex);
        }
        break;
      default:
        break;
    }
  };
  const isTabActive = (index) => activeTabIndex != null && activeTabIndex >= 0 ? activeTabIndex === index : innerActiveTabIndex === index;
  const isActiveIndicatorDisabled = firstFocus === -1 || tabs != null && activeTabIndex !== void 0 && activeTabIndex >= 0 && !!tabs[activeTabIndex]?.isDisabled;
  return /* @__PURE__ */ jsx77(ThemeProvider35, { theme: colorsTheme.tabs, children: /* @__PURE__ */ jsxs56(TabsContainer, { margin, children: [
    /* @__PURE__ */ jsx77(Underline2, {}),
    /* @__PURE__ */ jsxs56(Tabs, { hasLabelAndIcon, iconPosition, children: [
      /* @__PURE__ */ jsx77(
        ScrollIndicator,
        {
          onClick: scrollLeft,
          enabled: enabledIndicator,
          disabled: !scrollLeftEnabled,
          "aria-label": translatedLabels.tabs.scrollLeft,
          tabIndex: scrollLeftEnabled ? tabIndex : -1,
          minHeightTabs,
          children: /* @__PURE__ */ jsx77(Icon_default, { icon: "keyboard_arrow_left" })
        }
      ),
      /* @__PURE__ */ jsx77(TabsContent, { children: /* @__PURE__ */ jsxs56(TabsContentScroll, { translateScroll, ref: refTabList, enabled: enabledIndicator, children: [
        /* @__PURE__ */ jsx77(TabList, { role: "tablist", onKeyDown: handleOnKeyDown, minHeightTabs, children: tabs?.map((tab, i) => /* @__PURE__ */ jsx77(
          TabLegacy_default,
          {
            tab,
            active: isTabActive(i),
            tabIndex: isTabActive(i) && !tab.isDisabled ? tabIndex : -1,
            hasLabelAndIcon,
            iconPosition,
            ref: (el) => {
              refTabs.current[i] = el;
            },
            onClick: () => {
              setCurrentFocusIndex(i);
              setTemporalFocusIndex(i);
              handleSelected(i);
            },
            onMouseEnter: () => {
              onTabHover?.(i);
            },
            onMouseLeave: () => {
              onTabHover?.(null);
            }
          },
          `tab-${i}`
        )) }),
        /* @__PURE__ */ jsx77(
          ActiveIndicator,
          {
            tabWidth: activeIndicatorWidth,
            tabLeft: activeIndicatorLeft,
            "aria-disabled": isActiveIndicatorDisabled
          }
        )
      ] }) }),
      /* @__PURE__ */ jsx77(
        ScrollIndicator,
        {
          onClick: scrollRight,
          enabled: enabledIndicator,
          disabled: !scrollRightEnabled,
          "aria-label": translatedLabels.tabs.scrollRight,
          tabIndex: scrollRightEnabled ? tabIndex : -1,
          minHeightTabs,
          children: /* @__PURE__ */ jsx77(Icon_default, { icon: "keyboard_arrow_right" })
        }
      )
    ] })
  ] }) });
};
var Underline2 = styled69.div`
  position: absolute;
  left: 0;
  bottom: 0;
  width: 100%;
  height: ${(props) => props.theme.dividerThickness};
  background-color: ${(props) => props.theme.dividerColor};
`;
var TabsContainer = styled69.div`
  position: relative;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var Tabs = styled69.div`
  min-height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "48px" || "72px"};
  height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "48px" || "72px"};
  display: flex;
  overflow: hidden;
  background-color: ${(props) => props.theme.unselectedBackgroundColor};
`;
var ScrollIndicator = styled69.button`
  box-sizing: border-box;
  display: ${(props) => props.enabled ? "flex" : "none"};
  justify-content: center;
  min-width: ${(props) => props.theme.scrollButtonsWidth};
  height: ${(props) => props.minHeightTabs - 1}px;
  padding: 0;
  border: none;
  background-color: #ffffff;
  font-size: 1.25rem;
  cursor: pointer;

  &:hover {
    background-color: ${(props) => `${props.theme.hoverBackgroundColor} !important`};
  }
  &:focus {
    outline: ${(props) => props.theme.focusOutline} solid 1px;
    outline-offset: -1px;
  }
  &:active {
    background-color: ${(props) => `${props.theme.pressedBackgroundColor} !important`};
  }
  &:disabled {
    cursor: default;
    display: none;
    svg {
      visibility: hidden;
    }
    &:focus {
      outline: none;
    }
    &:hover,
    &:active {
      background-color: transparent !important;
    }
  }

  span {
    align-self: center;
    height: 20px;
    width: 20px;
  }

  span::before {
    color: ${(props) => props.theme.unselectedFontColor};
  }
`;
var ActiveIndicator = styled69.span`
  position: absolute;
  bottom: 0;
  left: ${(props) => `${props.tabLeft}px`};
  width: ${(props) => `${props.tabWidth}px`};
  height: ${(props) => props.theme.selectedUnderlineThickness};
  background-color: ${(props) => props.theme.selectedUnderlineColor};
  &[aria-disabled="true"] {
    background-color: ${(props) => props.theme.disabledFontColor};
    display: none;
  }
`;
var TabsContent = styled69.div`
  flex: 1 1 auto;
  display: inline-block;
  position: relative;
  white-space: nowrap;
  overflow-x: scroll;
  ::-webkit-scrollbar {
    display: none;
  }
`;
var TabList = styled69.div`
  display: flex;
  min-height: ${(props) => props.minHeightTabs}px;
`;
var TabsContentScroll = styled69.div`
  display: flex;
  ${(props) => props.enabled ? `transform: translateX(${props.translateScroll}px)` : `transform: translateX(0px)`};
  transition: all 300ms cubic-bezier(0.4, 0, 0.2, 1) 0ms;
`;
var TabsLegacy_default = DxcTabs;

// src/tabs/Tabs.tsx
import { Fragment as Fragment14, jsx as jsx78, jsxs as jsxs57 } from "react/jsx-runtime";
var useResize2 = (refTabList) => {
  const [viewWidth, setViewWidth] = useState33(0);
  const handleWindowSizeChange = useCallback12(() => {
    setViewWidth(refTabList?.current?.offsetWidth ?? 0);
  }, [refTabList]);
  useEffect25(() => {
    handleWindowSizeChange();
    window.addEventListener("resize", handleWindowSizeChange);
    return () => {
      window.removeEventListener("resize", handleWindowSizeChange);
    };
  }, [handleWindowSizeChange]);
  return viewWidth;
};
var getPreviousTabIndex2 = (array, initialIndex) => {
  let index = initialIndex === 0 ? array.length - 1 : initialIndex - 1;
  while (array[index]?.props.disabled) {
    index = index === 0 ? array.length - 1 : index - 1;
  }
  return index;
};
var getNextTabIndex2 = (array, initialIndex) => {
  let index = initialIndex === array.length - 1 ? 0 : initialIndex + 1;
  while (array[index]?.props.disabled) {
    index = index === array.length - 1 ? 0 : index + 1;
  }
  return index;
};
var DxcTabs2 = ({
  defaultActiveTabIndex,
  activeTabIndex,
  tabs,
  onTabClick,
  onTabHover,
  margin,
  iconPosition = "top",
  tabIndex = 0,
  children
}) => {
  const childrenArray = useMemo20(
    () => Children5.toArray(children),
    [children]
  );
  const hasLabelAndIcon = useMemo20(
    () => childrenArray.some((child) => isValidElement2(child) && child.props.icon && child.props.label),
    [childrenArray]
  );
  const [activeTab, setActiveTab] = useState33(() => {
    const hasActiveChild = childrenArray.some(
      (child) => isValidElement2(child) && (child.props.active || child.props.defaultActive) && !child.props.disabled
    );
    const initialActiveTab = hasActiveChild ? childrenArray.find(
      (child) => isValidElement2(child) && (child.props.active || child.props.defaultActive) && !child.props.disabled
    ) : childrenArray.find((child) => isValidElement2(child) && !child.props.disabled);
    return isValidElement2(initialActiveTab) ? initialActiveTab.props.label ?? initialActiveTab.props.tabId : "";
  });
  const [innerFocusIndex, setInnerFocusIndex] = useState33(null);
  const [activeIndicatorWidth, setActiveIndicatorWidth] = useState33(0);
  const [activeIndicatorLeft, setActiveIndicatorLeft] = useState33(0);
  const [countClick, setCountClick] = useState33(0);
  const [totalTabsWidth, setTotalTabsWidth] = useState33(0);
  const [translateScroll, setTranslateScroll] = useState33(0);
  const [scrollRightEnabled, setScrollRightEnabled] = useState33(true);
  const [scrollLeftEnabled, setScrollLeftEnabled] = useState33(false);
  const [minHeightTabs, setMinHeightTabs] = useState33(0);
  const refTabList = useRef22(null);
  const colorsTheme = useContext50(HalstackContext);
  const viewWidth = useResize2(refTabList);
  const translatedLabels = useContext50(HalstackLanguageContext);
  const enabledIndicator = useMemo20(() => viewWidth < totalTabsWidth, [viewWidth]);
  useEffect25(() => {
    if (refTabList.current) {
      setTotalTabsWidth(refTabList.current.firstElementChild?.offsetWidth);
      setMinHeightTabs(refTabList.current.offsetHeight + 1);
    }
  }, []);
  const contextValue = useMemo20(() => {
    const focusedChild = innerFocusIndex != null ? childrenArray[innerFocusIndex] : null;
    return {
      iconPosition,
      tabIndex,
      focusedTab: isValidElement2(focusedChild) ? focusedChild.props.label ?? focusedChild.props.tabId : "",
      isControlled: childrenArray.some((child) => isValidElement2(child) && typeof child.props.active !== "undefined"),
      activeTab,
      hasLabelAndIcon,
      setActiveTab,
      setActiveIndicatorWidth,
      setActiveIndicatorLeft
    };
  }, [iconPosition, tabIndex, innerFocusIndex, activeTab, childrenArray, hasLabelAndIcon]);
  const scrollLeft = () => {
    const scrollWidth = (refTabList?.current?.offsetHeight ?? 0) * 0.75;
    let moveX = 0;
    if (countClick <= scrollWidth) {
      moveX = 0;
      setScrollLeftEnabled(false);
      setScrollRightEnabled(true);
    } else {
      moveX = countClick - scrollWidth;
      setScrollRightEnabled(true);
      setScrollLeftEnabled(true);
    }
    setTranslateScroll(-moveX);
    setCountClick(moveX);
  };
  const scrollRight = () => {
    const offsetHeight = refTabList?.current?.offsetHeight ?? 0;
    const scrollWidth = offsetHeight * 0.75;
    let moveX = 0;
    if (countClick + scrollWidth + offsetHeight >= totalTabsWidth) {
      moveX = totalTabsWidth - offsetHeight;
      setScrollRightEnabled(false);
      setScrollLeftEnabled(true);
    } else {
      moveX = countClick + scrollWidth;
      setScrollLeftEnabled(true);
      setScrollRightEnabled(true);
    }
    setTranslateScroll(-moveX);
    setCountClick(moveX);
  };
  const handleOnKeyDown = (event) => {
    const active = childrenArray.findIndex(
      (child) => child.props.label ?? child.props.tabId === activeTab
    );
    switch (event.key) {
      case "Left":
      case "ArrowLeft":
        event.preventDefault();
        setInnerFocusIndex(getPreviousTabIndex2(childrenArray, innerFocusIndex === null ? active : innerFocusIndex));
        break;
      case "Right":
      case "ArrowRight":
        event.preventDefault();
        setInnerFocusIndex(getNextTabIndex2(childrenArray, innerFocusIndex === null ? active : innerFocusIndex));
        break;
      case "Tab":
        if (active !== innerFocusIndex) {
          setInnerFocusIndex(active);
        }
        break;
      default:
        break;
    }
  };
  return children ? /* @__PURE__ */ jsxs57(Fragment14, { children: [
    /* @__PURE__ */ jsx78(ThemeProvider36, { theme: colorsTheme.tabs, children: /* @__PURE__ */ jsxs57(TabsContainer2, { margin, children: [
      /* @__PURE__ */ jsx78(Underline3, {}),
      /* @__PURE__ */ jsxs57(Tabs2, { hasLabelAndIcon, iconPosition, children: [
        /* @__PURE__ */ jsx78(
          ScrollIndicator2,
          {
            onClick: scrollLeft,
            enabled: enabledIndicator,
            disabled: !scrollLeftEnabled,
            "aria-label": translatedLabels.tabs.scrollLeft,
            tabIndex: scrollLeftEnabled ? tabIndex : -1,
            minHeightTabs,
            children: /* @__PURE__ */ jsx78(Icon_default, { icon: "keyboard_arrow_left" })
          }
        ),
        /* @__PURE__ */ jsx78(TabsContent2, { children: /* @__PURE__ */ jsxs57(TabsContentScroll2, { translateScroll, ref: refTabList, enabled: enabledIndicator, children: [
          /* @__PURE__ */ jsx78(TabList2, { role: "tablist", onKeyDown: handleOnKeyDown, minHeightTabs, children: /* @__PURE__ */ jsx78(TabsContext_default.Provider, { value: contextValue, children }) }),
          /* @__PURE__ */ jsx78(
            ActiveIndicator2,
            {
              tabWidth: activeIndicatorWidth,
              tabLeft: activeIndicatorLeft,
              "aria-disabled": childrenArray.some(
                (child) => isValidElement2(child) && activeTab === (child.props.label ?? child.props.tabId) && child.props.disabled
              )
            }
          )
        ] }) }),
        /* @__PURE__ */ jsx78(
          ScrollIndicator2,
          {
            onClick: scrollRight,
            enabled: enabledIndicator,
            disabled: !scrollRightEnabled,
            "aria-label": translatedLabels.tabs.scrollRight,
            tabIndex: scrollRightEnabled ? tabIndex : -1,
            minHeightTabs,
            children: /* @__PURE__ */ jsx78(Icon_default, { icon: "keyboard_arrow_right" })
          }
        )
      ] })
    ] }) }),
    Children5.map(children, (child) => {
      if (isValidElement2(child) && (child.props.label ?? child.props.tabId) === activeTab) {
        return child.props.children;
      }
      return null;
    })
  ] }) : tabs != null && /* @__PURE__ */ jsx78(
    TabsLegacy_default,
    {
      defaultActiveTabIndex,
      activeTabIndex,
      tabs,
      onTabClick,
      onTabHover,
      margin,
      iconPosition,
      tabIndex
    }
  );
};
var Underline3 = styled70.div`
  position: absolute;
  left: 0;
  bottom: 0;
  width: 100%;
  height: ${(props) => props.theme.dividerThickness};
  background-color: ${(props) => props.theme.dividerColor};
`;
var TabsContainer2 = styled70.div`
  position: relative;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var Tabs2 = styled70.div`
  min-height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "48px" || "72px"};
  height: ${(props) => (!props.hasLabelAndIcon || props.hasLabelAndIcon && props.iconPosition !== "top") && "48px" || "72px"};
  display: flex;
  overflow: hidden;
  background-color: ${(props) => props.theme.unselectedBackgroundColor};
`;
var ScrollIndicator2 = styled70.button`
  box-sizing: border-box;
  display: ${(props) => props.enabled ? "flex" : "none"};
  justify-content: center;
  min-width: ${(props) => props.theme.scrollButtonsWidth};
  height: ${(props) => props.minHeightTabs - 1}px;
  padding: 0;
  border: none;
  background-color: #ffffff;
  font-size: 1.25rem;
  cursor: pointer;

  &:hover {
    background-color: ${(props) => `${props.theme.hoverBackgroundColor} !important`};
  }
  &:focus {
    outline: ${(props) => props.theme.focusOutline} solid 1px;
    outline-offset: -1px;
  }
  &:active {
    background-color: ${(props) => `${props.theme.pressedBackgroundColor} !important`};
  }
  &:disabled {
    cursor: default;
    display: none;
    svg {
      visibility: hidden;
    }
    &:focus {
      outline: none;
    }
    &:hover,
    &:active {
      background-color: transparent !important;
    }
  }

  span {
    align-self: center;
    height: 20px;
    width: 20px;
  }

  span::before {
    color: ${(props) => props.theme.unselectedFontColor};
  }
`;
var ActiveIndicator2 = styled70.span`
  position: absolute;
  bottom: 0;
  left: ${(props) => `${props.tabLeft}px`};
  width: ${(props) => `${props.tabWidth}px`};
  height: ${(props) => props.theme.selectedUnderlineThickness};
  background-color: ${(props) => props.theme.selectedUnderlineColor};
  &[aria-disabled="true"] {
    background-color: ${(props) => props.theme.disabledFontColor};
    display: none;
  }
`;
var TabsContent2 = styled70.div`
  flex: 1 1 auto;
  display: inline-block;
  position: relative;
  white-space: nowrap;
  overflow-x: scroll;
  ::-webkit-scrollbar {
    display: none;
  }
`;
var TabList2 = styled70.div`
  display: flex;
  min-height: ${(props) => props.minHeightTabs}px;
`;
var TabsContentScroll2 = styled70.div`
  display: flex;
  ${(props) => props.enabled ? `transform: translateX(${props.translateScroll}px)` : `transform: translateX(0px)`};
  transition: all 300ms cubic-bezier(0.4, 0, 0.2, 1) 0ms;
`;
DxcTabs2.Tab = Tab_default2;
var Tabs_default = DxcTabs2;

// src/tag/Tag.tsx
import { useContext as useContext51, useState as useState34 } from "react";
import styled71, { ThemeProvider as ThemeProvider37 } from "styled-components";
import { Fragment as Fragment15, jsx as jsx79, jsxs as jsxs58 } from "react/jsx-runtime";
var TagWrapper = ({ condition, wrapper, children }) => /* @__PURE__ */ jsx79(Fragment15, { children: condition ? wrapper(children) : children });
var DxcTag = ({
  icon,
  label = "",
  linkHref,
  onClick,
  iconBgColor = "#5f249f",
  labelPosition = "after",
  newWindow = false,
  margin,
  size = "fitContent",
  tabIndex = 0
}) => {
  const colorsTheme = useContext51(HalstackContext);
  const [isHovered, changeIsHovered] = useState34(false);
  return /* @__PURE__ */ jsx79(ThemeProvider37, { theme: colorsTheme.tag, children: /* @__PURE__ */ jsx79(
    StyledDxcTag,
    {
      margin,
      size,
      onMouseEnter: () => changeIsHovered(true),
      onMouseLeave: () => changeIsHovered(false),
      onClick: () => {
        onClick?.();
      },
      hasAction: onClick || linkHref,
      shadowDepth: isHovered && (onClick || linkHref) ? 2 : 1,
      children: /* @__PURE__ */ jsx79(
        TagWrapper,
        {
          condition: !!onClick || !!linkHref,
          wrapper: (children) => onClick ? /* @__PURE__ */ jsx79(StyledButton, { tabIndex, children }) : linkHref ? /* @__PURE__ */ jsx79(StyledLink2, { tabIndex, href: linkHref, target: newWindow ? "_blank" : "_self", children }) : /* @__PURE__ */ jsx79(Fragment15, {}),
          children: /* @__PURE__ */ jsxs58(TagContent, { children: [
            labelPosition === "before" && size !== "small" && label && /* @__PURE__ */ jsx79(TagLabel, { children: label }),
            icon && /* @__PURE__ */ jsx79(IconContainer6, { iconBgColor, children: typeof icon === "string" ? /* @__PURE__ */ jsx79(Icon_default, { icon }) : icon }),
            labelPosition === "after" && size !== "small" && label && /* @__PURE__ */ jsx79(TagLabel, { children: label })
          ] })
        }
      )
    }
  ) });
};
var sizes8 = {
  small: "42px",
  medium: "240px",
  large: "480px",
  fillParent: "100%",
  fitContent: "fit-content"
};
var calculateWidth13 = (margin, size) => size === "fillParent" ? `calc(${sizes8[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes8[size];
var StyledDxcTag = styled71.div`
  display: inline-flex;
  cursor: ${({ hasAction }) => hasAction && "pointer" || "unset"};
  margin: ${({ margin }) => margin && typeof margin !== "object" ? spaces[margin] : "0px"};
  margin-top: ${({ margin }) => margin && typeof margin === "object" && margin.top ? spaces[margin.top] : ""};
  margin-right: ${({ margin }) => margin && typeof margin === "object" && margin.right ? spaces[margin.right] : ""};
  margin-bottom: ${({ margin }) => margin && typeof margin === "object" && margin.bottom ? spaces[margin.bottom] : ""};
  margin-left: ${({ margin }) => margin && typeof margin === "object" && margin.left ? spaces[margin.left] : ""};
  width: ${(props) => calculateWidth13(props.margin, props.size)};
  height: ${(props) => props.theme.height};
  box-shadow: ${({ shadowDepth }) => shadowDepth === 1 ? `0px 3px 6px ${coreTokens_default.color_grey_300_a}` : shadowDepth === 2 ? `0px 3px 10px ${coreTokens_default.color_grey_300_a}` : "none"};
`;
var TagContent = styled71.div`
  display: inline-flex;
  align-items: center;
  width: 100%;
  height: ${(props) => props.theme.height};
`;
var StyledLink2 = styled71.a`
  text-decoration: none;
  border-radius: 4px;
  width: 100%;
  :focus {
    outline: 2px solid ${(props) => props.theme.focusColor};
    outline-offset: 0px;
  }
`;
var StyledButton = styled71.button`
  background: none;
  border-radius: 4px;
  border: none;
  padding: 0;
  cursor: pointer;
  font-family: inherit;
  width: 100%;
  :focus {
    outline: 2px solid ${(props) => props.theme.focusColor};
  }
`;
var IconContainer6 = styled71.div`
  display: inline-flex;
  background: ${({ iconBgColor }) => iconBgColor};
  width: ${(props) => props.theme.iconSectionWidth};
  height: 100%;
  justify-content: center;
  align-items: center;
  color: ${(props) => props.theme.iconColor};
  min-width: ${(props) => props.theme.iconSectionWidth};
  overflow: hidden;
  font-size: 24px;

  svg {
    width: ${(props) => props.theme.iconWidth};
    height: ${(props) => props.theme.iconHeight};
  }
`;
var TagLabel = styled71.div`
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.fontSize};
  font-style: ${(props) => props.theme.fontStyle};
  font-weight: ${(props) => props.theme.fontWeight};
  color: ${(props) => props.theme.fontColor};
  padding-top: ${(props) => props.theme.labelPaddingTop};
  padding-bottom: ${(props) => props.theme.labelPaddingBottom};
  padding-left: ${(props) => props.theme.labelPaddingLeft};
  padding-right: ${(props) => props.theme.labelPaddingRight};
  flex-grow: 1;
  text-align: center;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
`;
var Tag_default = DxcTag;

// src/textarea/Textarea.tsx
import { forwardRef as forwardRef18, useContext as useContext52, useEffect as useEffect26, useId as useId20, useRef as useRef23, useState as useState35 } from "react";
import styled72, { ThemeProvider as ThemeProvider38 } from "styled-components";
import { jsx as jsx80, jsxs as jsxs59 } from "react/jsx-runtime";
var patternMatch = (pattern, value) => new RegExp(pattern).test(value);
var DxcTextarea = forwardRef18(
  ({
    label,
    name = "",
    defaultValue = "",
    value,
    helperText,
    placeholder = "",
    disabled = false,
    readOnly = false,
    optional = false,
    verticalGrow = "auto",
    rows = 4,
    onChange,
    onBlur,
    error,
    pattern,
    minLength,
    maxLength,
    autocomplete = "off",
    margin,
    size = "medium",
    tabIndex = 0,
    ariaLabel = "Text area"
  }, ref) => {
    const [innerValue, setInnerValue] = useState35(defaultValue);
    const textareaId = `textarea-${useId20()}`;
    const colorsTheme = useContext52(HalstackContext);
    const translatedLabels = useContext52(HalstackLanguageContext);
    const textareaRef = useRef23(null);
    const prevValueRef = useRef23(null);
    const errorId = `error-${textareaId}`;
    const isNotOptional = (value2) => value2 === "" && !optional;
    const isLengthIncorrect2 = (value2) => value2 !== "" && minLength && maxLength && (value2.length < minLength || value2.length > maxLength);
    const changeValue = (newValue) => {
      if (value == null) {
        setInnerValue(newValue);
      }
      if (isNotOptional(newValue)) {
        onChange?.({
          value: newValue,
          error: translatedLabels.formFields.requiredValueErrorMessage
        });
      } else if (isLengthIncorrect2(newValue)) {
        onChange?.({
          value: newValue,
          error: translatedLabels.formFields.lengthErrorMessage?.(minLength, maxLength)
        });
      } else if (newValue && pattern && !patternMatch(pattern, newValue)) {
        onChange?.({
          value: newValue,
          error: translatedLabels.formFields.formatRequestedErrorMessage
        });
      } else {
        onChange?.({ value: newValue });
      }
    };
    const handleOnBlur = (event) => {
      if (isNotOptional(event.target.value)) {
        onBlur?.({
          value: event.target.value,
          error: translatedLabels.formFields.requiredValueErrorMessage
        });
      } else if (isLengthIncorrect2(event.target.value)) {
        onBlur?.({
          value: event.target.value,
          error: translatedLabels.formFields.lengthErrorMessage?.(minLength, maxLength)
        });
      } else if (event.target.value && pattern && !patternMatch(pattern, event.target.value)) {
        onBlur?.({
          value: event.target.value,
          error: translatedLabels.formFields.formatRequestedErrorMessage
        });
      } else {
        onBlur?.({ value: event.target.value });
      }
    };
    const handleOnChange = (event) => {
      changeValue(event.target.value);
    };
    useEffect26(() => {
      if (verticalGrow === "auto" && prevValueRef.current !== (value ?? innerValue) && textareaRef.current) {
        const computedStyle = window.getComputedStyle(textareaRef.current);
        const textareaLineHeight = parseInt(computedStyle.lineHeight || "0", 10);
        const textareaPaddingTopBottom = parseInt(computedStyle.paddingTop || "0", 10) * 2;
        textareaRef.current.style.height = `${textareaLineHeight * rows}px`;
        const newHeight = (textareaRef.current.scrollHeight ?? 0) - textareaPaddingTopBottom;
        textareaRef.current.style.height = `${newHeight}px`;
        prevValueRef.current = value ?? innerValue;
      }
    }, [verticalGrow, value, innerValue, rows]);
    return /* @__PURE__ */ jsx80(ThemeProvider38, { theme: colorsTheme.textarea, children: /* @__PURE__ */ jsxs59(TextareaContainer, { margin, size, ref, children: [
      label && /* @__PURE__ */ jsxs59(Label12, { htmlFor: textareaId, disabled, helperText, children: [
        label,
        " ",
        optional && /* @__PURE__ */ jsx80(OptionalLabel5, { children: translatedLabels.formFields.optionalLabel })
      ] }),
      helperText && /* @__PURE__ */ jsx80(HelperText8, { disabled, children: helperText }),
      /* @__PURE__ */ jsx80(
        Textarea,
        {
          id: textareaId,
          name,
          value: value ?? innerValue,
          placeholder,
          verticalGrow,
          rows,
          onChange: handleOnChange,
          onBlur: handleOnBlur,
          disabled,
          readOnly,
          error,
          minLength,
          maxLength,
          autoComplete: autocomplete,
          ref: textareaRef,
          tabIndex,
          "aria-invalid": !!error,
          "aria-errormessage": error ? errorId : void 0,
          "aria-required": !disabled && !optional,
          "aria-label": label ? void 0 : ariaLabel
        }
      ),
      !disabled && typeof error === "string" && /* @__PURE__ */ jsx80(ErrorMessageContainer3, { id: errorId, role: "alert", "aria-live": error ? "assertive" : "off", children: error })
    ] }) });
  }
);
var sizes9 = {
  small: "240px",
  medium: "360px",
  large: "480px",
  fillParent: "100%"
};
var calculateWidth14 = (margin, size) => size === "fillParent" ? `calc(${sizes9[size]} - ${getMargin(margin, "left")} - ${getMargin(margin, "right")})` : size && sizes9[size];
var TextareaContainer = styled72.div`
  display: flex;
  flex-direction: column;
  width: ${(props) => calculateWidth14(props.margin, props.size)};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var Label12 = styled72.label`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};

  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
  ${(props) => !props.helperText && `margin-bottom: 0.25rem`}
`;
var OptionalLabel5 = styled72.span`
  font-weight: ${(props) => props.theme.optionalLabelFontWeight};
`;
var HelperText8 = styled72.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};

  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
  margin-bottom: 0.25rem;
`;
var Textarea = styled72.textarea`
  ${({ verticalGrow }) => {
  if (verticalGrow === "none") return "resize: none;";
  else if (verticalGrow === "auto") return `resize: none; overflow: hidden;`;
  else if (verticalGrow === "manual") return "resize: vertical;";
  else return `resize: none;`;
}};

  ${(props) => props.disabled ? `background-color: ${props.theme.disabledContainerFillColor};` : `background-color: transparent;`}

  padding: 0.5rem 1rem;
  box-shadow: 0 0 0 2px transparent;
  border-radius: 0.25rem;
  border: 1px solid
    ${(props) => {
  if (props.disabled) return props.theme.disabledBorderColor;
  else if (props.error) return "transparent";
  else if (props.readOnly) return props.theme.readOnlyBorderColor;
  else return props.theme.enabledBorderColor;
}};

  ${(props) => props.error && !props.disabled && `box-shadow: 0 0 0 2px ${props.theme.errorBorderColor};
  `}

  ${(props) => !props.disabled ? `&:hover {
        border-color: ${props.error ? "transparent" : props.readOnly ? props.theme.hoverReadOnlyBorderColor : props.theme.hoverBorderColor};
        ${props.error && `box-shadow: 0 0 0 2px ${props.theme.hoverErrorBorderColor};`}
      }
      &:focus, &:focus-within {
        outline: none;
        border-color: transparent;
        box-shadow: 0 0 0 2px ${props.theme.focusBorderColor};
      }` : "cursor: not-allowed;"};

  color: ${(props) => props.disabled ? props.theme.disabledValueFontColor : props.theme.valueFontColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: ${(props) => props.theme.valueFontSize};
  font-style: ${(props) => props.theme.valueFontStyle};
  font-weight: ${(props) => props.theme.valueFontWeight};
  line-height: 1.5em;

  ::placeholder {
    color: ${(props) => props.disabled ? props.theme.disabledPlaceholderFontColor : props.theme.placeholderFontColor};
  }
`;
var ErrorMessageContainer3 = styled72.span`
  color: ${(props) => props.theme.errorMessageColor};
  font-family: ${(props) => props.theme.fontFamily};
  font-size: 0.75rem;
  font-weight: 400;
  min-height: 1.5em;
  line-height: 1.5em;
  margin-top: 0.25rem;
`;
var Textarea_default = DxcTextarea;

// src/toast/ToastsQueue.tsx
import { useCallback as useCallback14, useEffect as useEffect28, useMemo as useMemo21, useState as useState37 } from "react";
import { createPortal as createPortal3 } from "react-dom";
import styled74 from "styled-components";

// src/toast/Toast.tsx
import { memo as memo13, useContext as useContext53, useState as useState36 } from "react";
import styled73, { keyframes } from "styled-components";

// src/utils/useTimeout.tsx
import { useRef as useRef24, useCallback as useCallback13, useEffect as useEffect27 } from "react";
function useTimeout(callback, delay) {
  const savedCallback = useRef24();
  const timerRef = useRef24();
  const clearTimerCallback = useCallback13(() => clearTimeout(timerRef.current), []);
  useEffect27(() => {
    savedCallback.current = callback;
  }, [callback]);
  useEffect27(() => {
    function tick() {
      savedCallback.current?.();
    }
    if (delay != null) {
      timerRef.current = setTimeout(tick, delay);
      return clearTimerCallback;
    }
  }, [delay, clearTimerCallback]);
  return clearTimerCallback;
}

// src/toast/Toast.tsx
import { jsx as jsx81, jsxs as jsxs60 } from "react/jsx-runtime";
var fadeInUp = keyframes`
  0% {
    transform: translateY(100%);
    opacity: 0;
  }
  100% {
    transform: translateY(0);
    opacity: 1;
  }
`;
var fadeOutDown = keyframes`
  0% {
    transform: translateY(0);
    opacity: 1;
  }
  100% {
    transform: translateY(100%);
    opacity: 0;
  }
`;
var getSemantic = (semantic) => {
  switch (semantic) {
    case "info":
      return {
        primaryColor: coreTokens_default.color_blue_700,
        secondaryColor: coreTokens_default.color_blue_100,
        icon: "filled_info"
      };
    case "success":
      return {
        primaryColor: coreTokens_default.color_green_700,
        secondaryColor: coreTokens_default.color_green_100,
        icon: "filled_check_circle"
      };
    case "warning":
      return {
        primaryColor: coreTokens_default.color_orange_700,
        secondaryColor: coreTokens_default.color_orange_100,
        icon: "filled_warning"
      };
    default:
      return { primaryColor: coreTokens_default.color_purple_700, secondaryColor: coreTokens_default.color_purple_100, icon: "" };
  }
};
var Toast = styled73.output`
  box-sizing: border-box;
  min-width: 200px;
  max-width: 600px;
  width: fit-content;
  border-radius: ${coreTokens_default.border_radius_medium};
  border-left: ${coreTokens_default.border_width_2} solid ${({ semantic }) => getSemantic(semantic).primaryColor};
  box-shadow: 0px 2px 2px 0px rgba(181, 181, 181, 0.4);
  display: inline-flex;
  justify-content: space-between;
  gap: ${coreTokens_default.spacing_24};
  padding: ${coreTokens_default.spacing_8} ${coreTokens_default.spacing_12};
  background-color: ${({ semantic }) => getSemantic(semantic).secondaryColor};
  animation: ${({ isClosing }) => isClosing ? fadeOutDown : fadeInUp} 0.3s ease forwards;

  @media (max-width: ${responsiveSizes.medium}rem) {
    max-width: 100%;
  }
`;
var ContentContainer2 = styled73.div`
  display: flex;
  align-items: center;
  gap: ${coreTokens_default.spacing_8};
  overflow: hidden;
  color: ${({ semantic }) => getSemantic(semantic).primaryColor};

  ${({ loading }) => !loading && `font-size: ${coreTokens_default.type_scale_05}`};
  > svg {
    width: 24px;
    height: 24px;
  }
`;
var Message2 = styled73.span`
  color: ${coreTokens_default.color_grey_900};
  font-family: ${coreTokens_default.type_sans};
  font-size: ${coreTokens_default.type_scale_02};
  font-weight: ${coreTokens_default.type_semibold};
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
`;
var spinnerTheme = {
  spinner: {
    accentColor: getSemantic("info").primaryColor
  }
};
var ToastIcon = memo13(
  ({
    icon,
    hideSemanticIcon,
    loading,
    semantic
  }) => {
    if (semantic === "default") return typeof icon === "string" ? /* @__PURE__ */ jsx81(Icon_default, { icon }) : icon;
    else if (semantic === "info" && loading)
      return /* @__PURE__ */ jsx81(HalstackProvider, { theme: spinnerTheme, children: /* @__PURE__ */ jsx81(Spinner_default, { mode: "small" }) });
    else return !hideSemanticIcon && /* @__PURE__ */ jsx81(Icon_default, { icon: getSemantic(semantic).icon });
  }
);
var DxcToast = ({
  action,
  duration,
  hideSemanticIcon,
  icon,
  loading,
  message,
  onClear,
  semantic
}) => {
  const [isClosing, setIsClosing] = useState36(false);
  const translatedLabels = useContext53(HalstackLanguageContext);
  const clearClosingAnimationTimer = useTimeout(
    () => {
      setIsClosing(true);
    },
    loading ? void 0 : duration - 300
  );
  const clearTimer = useTimeout(
    () => {
      onClear();
    },
    loading ? void 0 : duration
  );
  return /* @__PURE__ */ jsxs60(Toast, { semantic, isClosing, role: "status", children: [
    /* @__PURE__ */ jsxs60(ContentContainer2, { loading, semantic, children: [
      /* @__PURE__ */ jsx81(ToastIcon, { hideSemanticIcon, icon, loading, semantic }),
      /* @__PURE__ */ jsx81(Message2, { children: message })
    ] }),
    /* @__PURE__ */ jsxs60(Flex_default, { alignItems: "center", gap: "0.25rem", children: [
      action && /* @__PURE__ */ jsx81(
        Button_default,
        {
          icon: action.icon,
          label: action.label,
          mode: "tertiary",
          onClick: action.onClick,
          semantic,
          size: { height: "small" }
        }
      ),
      /* @__PURE__ */ jsx81(
        ActionIcon_default,
        {
          icon: "clear",
          onClick: () => {
            if (!loading) {
              clearClosingAnimationTimer();
              clearTimer();
            }
            setIsClosing(true);
            setTimeout(() => {
              onClear();
            }, 300);
          },
          title: translatedLabels.toast.clearToastActionTitle
        }
      )
    ] })
  ] });
};
var Toast_default = memo13(DxcToast);

// src/toast/ToastContext.tsx
import { createContext as createContext10 } from "react";
var ToastContext_default = createContext10(null);

// src/toast/ToastsQueue.tsx
import { jsx as jsx82, jsxs as jsxs61 } from "react/jsx-runtime";
var ToastsQueue = styled74.section`
  box-sizing: border-box;
  position: fixed;
  bottom: 0;
  right: 0;
  z-index: 2147483647;
  display: flex;
  flex-direction: column;
  align-items: flex-end;
  gap: ${coreTokens_default.spacing_8};
  padding: ${coreTokens_default.spacing_24};

  @media (max-width: ${responsiveSizes.medium}rem) {
    align-items: center;
    width: 100%;
  }
`;
var generateUniqueToastId = (toasts) => {
  let id = "";
  let exists = true;
  while (exists) {
    id = `${performance.now()}-${Math.random().toString(36).slice(2, 9)}`;
    exists = toasts.some((toast) => toast.id === id);
  }
  return id;
};
var DxcToastsQueue = ({ children, duration = 3e3 }) => {
  const [toasts, setToasts] = useState37([]);
  const [isMounted, setIsMounted] = useState37(false);
  const adjustedDuration = useMemo21(() => duration > 5e3 ? 5e3 : duration < 3e3 ? 3e3 : duration, [duration]);
  const remove = useCallback14((id) => {
    setToasts((prevToasts) => prevToasts.filter((toast) => toast.id !== id));
  }, []);
  const add = useCallback14(
    (toast, semantic) => {
      const id = generateUniqueToastId(toasts);
      setToasts((prevToasts) => [...prevToasts, { id, semantic, ...toast }].slice(-5));
      return () => remove(id);
    },
    [duration]
  );
  useEffect28(() => {
    setIsMounted(true);
  }, []);
  return /* @__PURE__ */ jsxs61(ToastContext_default.Provider, { value: add, children: [
    isMounted && createPortal3(
      /* @__PURE__ */ jsx82(ToastsQueue, { children: toasts.map((t) => /* @__PURE__ */ jsx82(
        Toast_default,
        {
          duration: adjustedDuration,
          onClear: () => {
            remove(t.id);
          },
          ...t
        },
        t.id
      )) }),
      document.body
    ),
    children
  ] });
};
var ToastsQueue_default = DxcToastsQueue;

// src/toggle-group/ToggleGroup.tsx
import { useContext as useContext54, useId as useId21, useState as useState38 } from "react";
import styled75, { ThemeProvider as ThemeProvider39 } from "styled-components";
import { jsx as jsx83, jsxs as jsxs62 } from "react/jsx-runtime";
var DxcToggleGroup = ({
  label,
  helperText,
  defaultValue,
  value,
  onChange,
  disabled = false,
  options,
  margin,
  multiple = false,
  tabIndex = 0
}) => {
  const toggleGroupLabelId = `label-toggle-group-${useId21()}`;
  const [selectedValue, setSelectedValue] = useState38(defaultValue ?? (multiple ? [] : -1));
  const colorsTheme = useContext54(HalstackContext);
  const handleToggleChange = (selectedOption) => {
    let newSelectedOptions = [];
    if (value == null) {
      if (multiple && Array.isArray(selectedValue)) {
        newSelectedOptions = selectedValue.map((singleValue) => singleValue);
        if (newSelectedOptions.includes(selectedOption)) {
          const index = newSelectedOptions.indexOf(selectedOption);
          newSelectedOptions.splice(index, 1);
        } else {
          newSelectedOptions.push(selectedOption);
        }
        setSelectedValue(newSelectedOptions);
      } else {
        setSelectedValue(selectedOption === selectedValue ? -1 : selectedOption);
      }
    } else if (multiple) {
      newSelectedOptions = Array.isArray(value) ? value.map((v) => v) : [value];
      if (newSelectedOptions.includes(selectedOption)) {
        const index = newSelectedOptions.indexOf(selectedOption);
        newSelectedOptions.splice(index, 1);
      } else {
        newSelectedOptions.push(selectedOption);
      }
    }
    onChange?.(multiple ? newSelectedOptions : selectedOption);
  };
  const handleOnKeyDown = (event, optionValue) => {
    switch (event.key) {
      case "Enter":
      case " ":
        event.preventDefault();
        handleToggleChange(optionValue);
        break;
      default:
        break;
    }
  };
  return /* @__PURE__ */ jsx83(ThemeProvider39, { theme: colorsTheme.toggleGroup, children: /* @__PURE__ */ jsxs62(ToggleGroup, { margin, children: [
    /* @__PURE__ */ jsx83(Label13, { id: toggleGroupLabelId, disabled, children: label }),
    /* @__PURE__ */ jsx83(HelperText9, { disabled, children: helperText }),
    /* @__PURE__ */ jsx83(OptionsContainer, { "aria-labelledby": toggleGroupLabelId, children: options.map((option, i) => /* @__PURE__ */ jsx83(Tooltip, { label: option.title, children: /* @__PURE__ */ jsx83(
      ToggleButton,
      {
        "aria-label": option.title,
        "aria-pressed": multiple ? value ? Array.isArray(value) && value.includes(option.value) : Array.isArray(selectedValue) && selectedValue.includes(option.value) : value ? option.value === value : option.value === selectedValue,
        disabled,
        onClick: () => {
          handleToggleChange(option.value);
        },
        onKeyDown: (event) => {
          handleOnKeyDown(event, option.value);
        },
        tabIndex: !disabled ? tabIndex : -1,
        hasIcon: option.icon,
        optionLabel: option.label ?? "",
        selected: multiple ? value ? Array.isArray(value) && value.includes(option.value) : Array.isArray(selectedValue) && selectedValue.includes(option.value) : value ? option.value === value : option.value === selectedValue,
        children: /* @__PURE__ */ jsxs62(Flex_default, { alignItems: "center", children: [
          option.icon && /* @__PURE__ */ jsx83(IconContainer7, { optionLabel: option.label ?? "", children: typeof option.icon === "string" ? /* @__PURE__ */ jsx83(Icon_default, { icon: option.icon }) : option.icon }),
          option.label && /* @__PURE__ */ jsx83(LabelContainer6, { children: option.label })
        ] })
      }
    ) }, `toggle-${i}-${option.label}`)) })
  ] }) });
};
var ToggleGroup = styled75.div`
  display: inline-flex;
  flex-direction: column;
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var Label13 = styled75.label`
  color: ${(props) => props.disabled ? props.theme.disabledLabelFontColor : props.theme.labelFontColor};
  font-family: ${(props) => props.theme.labelFontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  line-height: ${(props) => props.theme.labelLineHeight};
`;
var HelperText9 = styled75.span`
  color: ${(props) => props.disabled ? props.theme.disabledHelperTextFontColor : props.theme.helperTextFontColor};
  font-family: ${(props) => props.theme.helperTextFontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  line-height: ${(props) => props.theme.helperTextLineHeight};
`;
var OptionsContainer = styled75.div`
  display: flex;
  gap: 0.25rem;
  width: max-content;
  height: calc(48px - 4px - 4px);
  padding: 0.25rem;
  border-width: ${(props) => props.theme.containerBorderThickness};
  border-style: ${(props) => props.theme.containerBorderStyle};
  border-radius: ${(props) => props.theme.containerBorderRadius};
  border-color: ${(props) => props.theme.containerBorderColor};
  margin-top: ${(props) => props.theme.containerMarginTop};
  background-color: ${(props) => props.theme.containerBackgroundColor};
`;
var ToggleButton = styled75.button`
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding-left: ${(props) => props.optionLabel && props.hasIcon || props.optionLabel && !props.hasIcon ? props.theme.labelPaddingLeft : props.theme.iconPaddingLeft};
  padding-right: ${(props) => props.optionLabel && props.hasIcon || props.optionLabel && !props.hasIcon ? props.theme.labelPaddingRight : props.theme.iconPaddingRight};
  border-width: ${(props) => props.theme.optionBorderThickness};
  border-style: ${(props) => props.theme.optionBorderStyle};
  border-radius: ${(props) => props.theme.optionBorderRadius};
  background-color: ${(props) => props.selected ? props.theme.selectedBackgroundColor : props.theme.unselectedBackgroundColor};
  color: ${(props) => props.selected ? props.theme.selectedFontColor : props.theme.unselectedFontColor};
  cursor: pointer;

  &:hover {
    background-color: ${(props) => props.selected ? props.theme.selectedHoverBackgroundColor : props.theme.unselectedHoverBackgroundColor};
  }
  &:active {
    background-color: ${(props) => props.selected ? props.theme.selectedActiveBackgroundColor : props.theme.unselectedActiveBackgroundColor};
    color: #ffffff;
  }
  &:focus {
    outline: none;
    box-shadow: ${(props) => `0 0 0 ${props.theme.optionFocusBorderThickness} ${props.theme.focusColor}`};
  }
  &:disabled {
    background-color: ${(props) => props.selected ? props.theme.selectedDisabledBackgroundColor : props.theme.unselectedDisabledBackgroundColor};
    color: ${(props) => props.selected ? props.theme.selectedDisabledFontColor : props.theme.unselectedDisabledFontColor};
    cursor: not-allowed;
  }
`;
var LabelContainer6 = styled75.span`
  font-family: ${(props) => props.theme.optionLabelFontFamily};
  font-size: ${(props) => props.theme.optionLabelFontSize};
  font-style: ${(props) => props.theme.optionLabelFontStyle};
  font-weight: ${(props) => props.theme.optionLabelFontWeight};
`;
var IconContainer7 = styled75.div`
  display: flex;
  margin-right: ${(props) => props.optionLabel && props.theme.iconMarginRight};
  overflow: hidden;
  font-size: 24px;
  svg {
    height: 24px;
    width: 24px;
  }
`;
var ToggleGroup_default = DxcToggleGroup;

// src/wizard/Wizard.tsx
import { useContext as useContext55, useMemo as useMemo22, useState as useState39 } from "react";
import styled76, { ThemeProvider as ThemeProvider40 } from "styled-components";

// src/wizard/Icons.tsx
import { jsx as jsx84, jsxs as jsxs63 } from "react/jsx-runtime";
var icons2 = {
  valid: /* @__PURE__ */ jsxs63("svg", { xmlns: "http://www.w3.org/2000/svg", width: "18", height: "18", viewBox: "0 0 18 18", children: [
    /* @__PURE__ */ jsx84("path", { "data-name": "Path 2946", d: "M0,0H18V18H0Z", fill: "none" }),
    /* @__PURE__ */ jsx84(
      "path",
      {
        "data-name": "Path 2947",
        d: "M9.986,4a5.986,5.986,0,1,0,5.986,5.986A5.994,5.994,0,0,0,9.986,4Zm-1.5,9.727L5.5,10.734,6.551,9.679l1.938,1.93L13.42,6.679l1.055,1.063Z",
        transform: "translate(-0.986 -0.986)",
        fill: "#eafaef",
        opacity: "0.999"
      }
    ),
    /* @__PURE__ */ jsx84(
      "path",
      {
        "data-name": "Path 2948",
        d: "M9.493,2a7.493,7.493,0,1,0,7.493,7.493A7.5,7.5,0,0,0,9.493,2Zm0,13.487a5.994,5.994,0,1,1,5.994-5.994A6,6,0,0,1,9.493,15.487Zm3.439-9.306L7.994,11.119,6.054,9.186,5,10.242l3,3,5.994-5.994Z",
        transform: "translate(-0.493 -0.493)",
        fill: "#24a148"
      }
    )
  ] }),
  invalid: /* @__PURE__ */ jsxs63("svg", { xmlns: "http://www.w3.org/2000/svg", width: "18", height: "18", viewBox: "0 0 18 18", children: [
    /* @__PURE__ */ jsx84("path", { "data-name": "Path 2943", d: "M0,0H18V18H0Z", fill: "none" }),
    /* @__PURE__ */ jsx84(
      "path",
      {
        "data-name": "Path 2944",
        d: "M10,4a6,6,0,1,0,6,6A6.01,6.01,0,0,0,10,4Zm3,7.945L11.945,13,10,11.06,8.059,13,7,11.945,8.944,10,7,8.059,8.059,7,10,8.944,11.945,7,13,8.059,11.06,10Z",
        transform: "translate(-1.002 -1.002)",
        fill: "#ffe6e9"
      }
    ),
    /* @__PURE__ */ jsx84(
      "path",
      {
        "data-name": "Path 2945",
        d: "M11.444,6.5,9.5,8.443,7.558,6.5,6.5,7.558,8.443,9.5,6.5,11.444,7.558,12.5,9.5,10.558,11.444,12.5,12.5,11.444,10.558,9.5,12.5,7.558ZM9.5,2A7.5,7.5,0,1,0,17,9.5,7.494,7.494,0,0,0,9.5,2Zm0,13.5a6,6,0,1,1,6-6A6.009,6.009,0,0,1,9.5,15.5Z",
        transform: "translate(-0.501 -0.501)",
        fill: "#d0011b"
      }
    )
  ] })
};
var Icons_default3 = icons2;

// src/wizard/Wizard.tsx
import { jsx as jsx85, jsxs as jsxs64 } from "react/jsx-runtime";
var StepsContainer = styled76.div`
  display: flex;
  flex-direction: ${(props) => props.mode === "vertical" ? "column" : "row"};
  justify-content: center;
  ${(props) => props.mode === "vertical" && "height: 500px"};
  font-family: ${(props) => props.theme.fontFamily};
  margin: ${(props) => props.margin && typeof props.margin !== "object" ? spaces[props.margin] : "0px"};
  margin-top: ${(props) => props.margin && typeof props.margin === "object" && props.margin.top ? spaces[props.margin.top] : ""};
  margin-right: ${(props) => props.margin && typeof props.margin === "object" && props.margin.right ? spaces[props.margin.right] : ""};
  margin-bottom: ${(props) => props.margin && typeof props.margin === "object" && props.margin.bottom ? spaces[props.margin.bottom] : ""};
  margin-left: ${(props) => props.margin && typeof props.margin === "object" && props.margin.left ? spaces[props.margin.left] : ""};
`;
var StepContainer = styled76.div`
  display: inline-flex;
  ${(props) => props.mode !== "vertical" && "align-items: center;"}
  flex-grow: ${(props) => props.lastStep ? "0" : "1"};
  flex-direction: ${(props) => props.mode === "vertical" ? "column" : "row"};
  ${(props) => props.mode === "vertical" && "width: fit-content;"}
`;
var Step = styled76.button`
  display: flex;
  justify-content: flex-start;
  align-items: center;
  gap: 0.75rem;
  border: none;
  border-radius: 0.25rem;
  background: inherit;
  margin: ${(props) => props.first ? props.mode === "vertical" ? "0 0 24px 0" : "0 24px 0 0" : props.last ? props.mode === "vertical" ? "24px 0 0 0" : "0 0 0 24px" : props.mode === "vertical" ? "24px 0" : "0 24px"};

  padding: 0px;
  ${(props) => props.disabled ? "cursor: not-allowed" : ""};

  &:hover {
    ${(props) => props.disabled ? "" : "cursor: pointer"};
  }
  &:focus {
    outline: 2px solid ${(props) => props.theme.focusColor};
  }
`;
var StepHeader = styled76.div`
  position: relative;
  display: inline-flex;
  ${(props) => props.validityIcon && "padding-bottom: 4px;"}
`;
var IconContainer8 = styled76.div`
  width: ${(props) => props.disabled ? props.theme.disabledStepWidth : props.current ? props.theme.selectedStepWidth : props.theme.stepWidth};
  height: ${(props) => props.disabled ? props.theme.disabledStepHeight : props.current ? props.theme.selectedStepHeight : props.theme.stepHeight};

  ${(props) => `
    ${props.disabled ? `border: ${props.theme.disabledStepBorderThickness} ${props.theme.disabledStepBorderStyle} ${props.theme.disabledStepBorderColor};` : props.current ? `border: ${props.theme.selectedStepBorderThickness} ${props.theme.selectedStepBorderStyle} ${props.theme.selectedStepBorderColor};` : props.visited ? `border: ${props.theme.stepBorderThickness} ${props.theme.stepBorderStyle} ${props.theme.visitedStepBorderColor};` : `border: ${props.theme.stepBorderThickness} ${props.theme.stepBorderStyle} ${props.theme.unvisitedStepBorderColor};`}
    background: ${props.disabled ? `${props.theme.disabledStepBackgroundColor}` : props.current ? `${props.theme.selectedStepBackgroundColor}` : !props.visited ? `${props.theme.unvisitedStepBackgroundColor}` : `${props.theme.visitedStepBackgroundColor}`};
  `}
  ${(props) => props.disabled ? `color: ${props.theme.disabledStepFontColor};` : `color: ${props.current ? props.theme.selectedStepFontColor : !props.visited ? props.theme.unvisitedStepFontColor : props.theme.visitedStepFontColor};`};

  border-radius: ${(props) => !props.current && !props.disabled ? props.theme.stepBorderRadius : props.current ? props.theme.selectedStepBorderRadius : props.disabled ? props.theme.disabledStepBorderRadius : ""};

  display: flex;
  justify-content: center;
  align-items: center;
  overflow: hidden;
  font-size: ${(props) => props.theme.stepIconSize};
  svg {
    width: ${(props) => props.theme.stepIconSize};
    height: ${(props) => props.theme.stepIconSize};
  }
`;
var Number3 = styled76.p`
  font-size: ${(props) => props.theme.stepFontSize};
  font-family: ${(props) => props.theme.stepFontFamily};
  font-style: ${(props) => props.theme.stepFontStyle};
  font-weight: ${(props) => props.theme.stepFontWeight};
  letter-spacing: ${(props) => props.theme.stepFontTracking};
  opacity: 1;
  margin: 0px 0px 0px 1px;
`;
var ValidityIconContainer = styled76.div`
  width: 18px;
  height: 18px;
  position: absolute;
  top: 22.5px;
  left: 22.5px;
`;
var Label14 = styled76.p`
  text-align: ${(props) => props.theme.labelTextAlign};
  font-family: ${(props) => props.theme.labelFontFamily};
  font-size: ${(props) => props.theme.labelFontSize};
  font-style: ${(props) => props.theme.labelFontStyle};
  font-weight: ${(props) => props.theme.labelFontWeight};
  letter-spacing: ${(props) => props.theme.labelFontTracking};
  ${(props) => props.disabled ? `color: ${props.theme.disabledLabelFontColor};` : `color: ${!props.visited ? props.theme.unvisitedLabelFontColor : props.current ? props.theme.selectedLabelFontColor : props.theme.visitedLabelFontColor};`};
  text-transform: ${(props) => props.theme.labelFontTextTransform};
  margin: 0;
`;
var Description = styled76.p`
  text-align: ${(props) => props.theme.helperTextTextAlign};
  font-family: ${(props) => props.theme.helperTextFontFamily};
  font-size: ${(props) => props.theme.helperTextFontSize};
  font-style: ${(props) => props.theme.helperTextFontStyle};
  font-weight: ${(props) => props.theme.helperTextFontWeight};
  letter-spacing: ${(props) => props.theme.helperTextFontTracking};
  text-transform: ${(props) => props.theme.helperTextFontTextTransform};
  ${(props) => props.disabled ? `color: ${props.theme.disabledHelperTextFontColor};` : `color: ${!props.visited ? props.theme.unvisitedHelperTextFontColor : props.current ? props.theme.selectedHelperTextFontColor : props.theme.visitedHelperTextFontColor};`};
  margin: 0;
`;
var StepSeparator = styled76.div`
  ${(props) => props.mode === "horizontal" ? "height: 0;" : "width: 0;"};
  ${(props) => props.mode === "vertical" && "margin: 0 18px;"}
  border: ${(props) => `${props.theme.separatorBorderStyle} ${props.theme.separatorBorderThickness} ${props.theme.separatorColor}`};
  opacity: 1;
  flex-grow: 1;
`;
var DxcWizard = ({
  mode = "horizontal",
  defaultCurrentStep = 0,
  currentStep,
  onStepClick,
  steps,
  margin,
  tabIndex = 0
}) => {
  const colorsTheme = useContext55(HalstackContext);
  const [innerCurrent, setInnerCurrentStep] = useState39(defaultCurrentStep);
  const renderedCurrent = useMemo22(() => currentStep ?? innerCurrent, [currentStep, innerCurrent]);
  const handleStepClick = (newValue) => {
    setInnerCurrentStep(newValue);
    onStepClick?.(newValue);
  };
  return /* @__PURE__ */ jsx85(ThemeProvider40, { theme: colorsTheme.wizard, children: /* @__PURE__ */ jsx85(StepsContainer, { mode, margin, role: "group", children: steps.map((step, i) => /* @__PURE__ */ jsxs64(StepContainer, { mode, lastStep: i === steps.length - 1, children: [
    /* @__PURE__ */ jsxs64(
      Step,
      {
        onClick: () => {
          handleStepClick(i);
        },
        disabled: step.disabled,
        mode,
        first: i === 0,
        last: i === steps.length - 1,
        "aria-current": renderedCurrent === i ? "step" : "false",
        tabIndex,
        children: [
          /* @__PURE__ */ jsxs64(StepHeader, { validityIcon: step.valid != null, children: [
            /* @__PURE__ */ jsx85(IconContainer8, { current: i === renderedCurrent, visited: i < renderedCurrent, disabled: step.disabled, children: step.icon ? typeof step.icon === "string" ? /* @__PURE__ */ jsx85(Icon_default, { icon: step.icon }) : step.icon : /* @__PURE__ */ jsx85(Number3, { children: i + 1 }) }),
            step.valid != null && /* @__PURE__ */ jsx85(ValidityIconContainer, { children: step.valid ? Icons_default3.valid : Icons_default3.invalid })
          ] }),
          (step.label || step.description) && /* @__PURE__ */ jsxs64("div", { children: [
            step.label && /* @__PURE__ */ jsx85(Label14, { current: i === renderedCurrent, disabled: step.disabled, visited: i <= innerCurrent, children: step.label }),
            step.description && /* @__PURE__ */ jsx85(Description, { current: i === renderedCurrent, disabled: step.disabled, visited: i <= innerCurrent, children: step.description })
          ] })
        ]
      }
    ),
    i === steps.length - 1 ? "" : /* @__PURE__ */ jsx85(StepSeparator, { mode })
  ] }, `step${i}`)) }) });
};
var Wizard_default = DxcWizard;

// src/toast/useToast.tsx
import { useContext as useContext56, useMemo as useMemo23 } from "react";
var useToast = () => {
  const add = useContext56(ToastContext_default);
  const toast = useMemo23(
    () => ({
      default: (toast2) => add?.(toast2, "default"),
      success: (toast2) => add?.(toast2, "success"),
      warning: (toast2) => add?.(toast2, "warning"),
      info: (toast2) => add?.(toast2, "info"),
      loading: (toast2) => add?.({ ...toast2, loading: true }, "info")
    }),
    [add]
  );
  return toast;
};
var useToast_default = useToast;
export {
  Accordion_default as DxcAccordion,
  DxcAlert,
  ApplicationLayout_default as DxcApplicationLayout,
  Badge_default as DxcBadge,
  Bleed_default as DxcBleed,
  Breadcrumbs_default as DxcBreadcrumbs,
  BulletedList_default as DxcBulletedList,
  Button_default as DxcButton,
  Card_default as DxcCard,
  Checkbox_default as DxcCheckbox,
  Chip_default as DxcChip,
  DxcContainer,
  DxcContextualMenu,
  DataGrid_default as DxcDataGrid,
  DateInput_default as DxcDateInput,
  Dialog_default as DxcDialog,
  Divider_default as DxcDivider,
  Dropdown_default as DxcDropdown,
  FileInput_default as DxcFileInput,
  Flex_default as DxcFlex,
  Grid_default as DxcGrid,
  Heading_default as DxcHeading,
  DxcImage,
  Inset_default as DxcInset,
  Link_default as DxcLink,
  NavTabs_default as DxcNavTabs,
  NumberInput_default as DxcNumberInput,
  Paginator_default as DxcPaginator,
  DxcParagraph,
  PasswordInput_default as DxcPasswordInput,
  ProgressBar_default as DxcProgressBar,
  QuickNav_default as DxcQuickNav,
  RadioGroup_default as DxcRadioGroup,
  ResultsetTable_default as DxcResultsetTable,
  Select_default as DxcSelect,
  Slider_default as DxcSlider,
  Spinner_default as DxcSpinner,
  StatusLight_default as DxcStatusLight,
  Switch_default as DxcSwitch,
  Table_default as DxcTable,
  Tabs_default as DxcTabs,
  Tag_default as DxcTag,
  TextInput_default as DxcTextInput,
  Textarea_default as DxcTextarea,
  ToastsQueue_default as DxcToastsQueue,
  ToggleGroup_default as DxcToggleGroup,
  DxcTooltip,
  DxcTypography,
  Wizard_default as DxcWizard,
  HalstackContext,
  HalstackLanguageContext,
  HalstackProvider,
  useToast_default as useToast
};
